""" Cisco_IOS_XR_fib_common_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR fib\-common package operational data.

This module contains definitions
for the following management objects\:
  fib\-statistics\: cef interface drops operational data
  fib\: fib
  oc\-aft\-l3\: oc aft l3
  mpls\-forwarding\: mpls forwarding

Copyright (c) 2013\-2018 by Cisco Systems, Inc.
All rights reserved.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class FibAdjacencyShow(Enum):
    """
    FibAdjacencyShow (Enum Class)

    Adjacency types

    .. data:: fib_adjacency_normal = 0

    	Normal adjacency

    .. data:: fib_adjacency_null = 1

    	Null adjacency

    .. data:: fib_adjacency_punt = 2

    	Punt adjacency

    .. data:: fib_adjacency_drop = 3

    	Drop adjacency

    .. data:: fib_adjacency_glean = 4

    	Glean adjacency

    .. data:: fib_adjacency_discard = 5

    	Discard adjacency

    .. data:: fib_adjacency_broadcast = 6

    	Broadcast adjacency

    .. data:: fib_adjacency_external = 7

    	external adjacency

    .. data:: fib_adjacency_lisp = 8

    	LISP adjacency

    .. data:: fib_adjacency_unknown = 9

    	Unknown adjacency

    """

    fib_adjacency_normal = Enum.YLeaf(0, "fib-adjacency-normal")

    fib_adjacency_null = Enum.YLeaf(1, "fib-adjacency-null")

    fib_adjacency_punt = Enum.YLeaf(2, "fib-adjacency-punt")

    fib_adjacency_drop = Enum.YLeaf(3, "fib-adjacency-drop")

    fib_adjacency_glean = Enum.YLeaf(4, "fib-adjacency-glean")

    fib_adjacency_discard = Enum.YLeaf(5, "fib-adjacency-discard")

    fib_adjacency_broadcast = Enum.YLeaf(6, "fib-adjacency-broadcast")

    fib_adjacency_external = Enum.YLeaf(7, "fib-adjacency-external")

    fib_adjacency_lisp = Enum.YLeaf(8, "fib-adjacency-lisp")

    fib_adjacency_unknown = Enum.YLeaf(9, "fib-adjacency-unknown")


class FibFrrProtocolShow(Enum):
    """
    FibFrrProtocolShow (Enum Class)

    Fib frr protocol show

    .. data:: frr_protocol_ipv4 = 0

    	frr protocol ipv4

    .. data:: frr_protocol_ipv6 = 1

    	frr protocol ipv6

    .. data:: frr_protocol_mpls = 2

    	frr protocol mpls

    """

    frr_protocol_ipv4 = Enum.YLeaf(0, "frr-protocol-ipv4")

    frr_protocol_ipv6 = Enum.YLeaf(1, "frr-protocol-ipv6")

    frr_protocol_mpls = Enum.YLeaf(2, "frr-protocol-mpls")


class FibLink(Enum):
    """
    FibLink (Enum Class)

    Fib link

    .. data:: link_ipv4 = 0

    	IPv4 link protocol

    .. data:: link_ipv6 = 1

    	IPv6 link protocol

    .. data:: link_mpls = 2

    	MPLS link protocol

    """

    link_ipv4 = Enum.YLeaf(0, "link-ipv4")

    link_ipv6 = Enum.YLeaf(1, "link-ipv6")

    link_mpls = Enum.YLeaf(2, "link-mpls")


class FibLoadshareShow(Enum):
    """
    FibLoadshareShow (Enum Class)

    Loadsharing type

    .. data:: fib_load_share_none = 0

    	No loadsharing

    .. data:: fib_load_share_per_packet = 1

    	Per packet loadsharing

    .. data:: fib_load_share_dest_sharing = 2

    	Destination loadsharing

    """

    fib_load_share_none = Enum.YLeaf(0, "fib-load-share-none")

    fib_load_share_per_packet = Enum.YLeaf(1, "fib-load-share-per-packet")

    fib_load_share_dest_sharing = Enum.YLeaf(2, "fib-load-share-dest-sharing")


class FibMplsLlcEntryBag(Enum):
    """
    FibMplsLlcEntryBag (Enum Class)

    Fib mpls llc entry bag

    .. data:: fib_mpls_llc_bag_type_xc = 1

    	fib mpls llc bag type xc

    .. data:: fib_mpls_llc_bag_type_pfx = 2

    	fib mpls llc bag type pfx

    .. data:: fib_mpls_llc_bag_type_lsm = 3

    	fib mpls llc bag type lsm

    .. data:: fib_mpls_llc_bag_type_max = 4

    	fib mpls llc bag type max

    """

    fib_mpls_llc_bag_type_xc = Enum.YLeaf(1, "fib-mpls-llc-bag-type-xc")

    fib_mpls_llc_bag_type_pfx = Enum.YLeaf(2, "fib-mpls-llc-bag-type-pfx")

    fib_mpls_llc_bag_type_lsm = Enum.YLeaf(3, "fib-mpls-llc-bag-type-lsm")

    fib_mpls_llc_bag_type_max = Enum.YLeaf(4, "fib-mpls-llc-bag-type-max")


class FibNeh(Enum):
    """
    FibNeh (Enum Class)

    Fib neh

    .. data:: nh_local = 0

    	nh local

    .. data:: nh_remote = 1

    	nh remote

    .. data:: nh_special = 2

    	nh special

    """

    nh_local = Enum.YLeaf(0, "nh-local")

    nh_remote = Enum.YLeaf(1, "nh-remote")

    nh_special = Enum.YLeaf(2, "nh-special")


class FibNehSpecial(Enum):
    """
    FibNehSpecial (Enum Class)

    Fib neh special

    .. data:: nh_not_found = 0

    	nh not found

    .. data:: nh_null0 = 1

    	nh null0

    .. data:: nh_punt = 2

    	nh punt

    .. data:: nh_drop = 3

    	nh drop

    .. data:: nh_glean = 4

    	nh glean

    .. data:: nh_receive = 5

    	nh receive

    .. data:: nh_broadcast = 6

    	nh broadcast

    .. data:: nh_external = 7

    	nh external

    .. data:: nh_lisp = 8

    	nh lisp

    .. data:: nh_lookup = 9

    	nh lookup

    .. data:: nh_max_type = 10

    	nh max type

    """

    nh_not_found = Enum.YLeaf(0, "nh-not-found")

    nh_null0 = Enum.YLeaf(1, "nh-null0")

    nh_punt = Enum.YLeaf(2, "nh-punt")

    nh_drop = Enum.YLeaf(3, "nh-drop")

    nh_glean = Enum.YLeaf(4, "nh-glean")

    nh_receive = Enum.YLeaf(5, "nh-receive")

    nh_broadcast = Enum.YLeaf(6, "nh-broadcast")

    nh_external = Enum.YLeaf(7, "nh-external")

    nh_lisp = Enum.YLeaf(8, "nh-lisp")

    nh_lookup = Enum.YLeaf(9, "nh-lookup")

    nh_max_type = Enum.YLeaf(10, "nh-max-type")


class FibNhinfoExtBag(Enum):
    """
    FibNhinfoExtBag (Enum Class)

    FIB NHINFO extension type

    .. data:: replicated_nh_info = 0

    	Replicated NHINFO

    .. data:: shared_nh_info = 1

    	Shared NHINFO

    """

    replicated_nh_info = Enum.YLeaf(0, "replicated-nh-info")

    shared_nh_info = Enum.YLeaf(1, "shared-nh-info")


class FibProtocol(Enum):
    """
    FibProtocol (Enum Class)

    Fib protocol

    .. data:: ipv4 = 0

    	ipv4 protocol

    .. data:: ipv6 = 1

    	ipv6 protocol

    .. data:: mpls = 2

    	MPLS protocol

    """

    ipv4 = Enum.YLeaf(0, "ipv4")

    ipv6 = Enum.YLeaf(1, "ipv6")

    mpls = Enum.YLeaf(2, "mpls")


class FibRouteSource(Enum):
    """
    FibRouteSource (Enum Class)

    Fib route source

    .. data:: lsd = 5

    	LSD

    .. data:: rib = 7

    	RIB

    .. data:: mrib = 13

    	MRIB

    """

    lsd = Enum.YLeaf(5, "lsd")

    rib = Enum.YLeaf(7, "rib")

    mrib = Enum.YLeaf(13, "mrib")


class FibRpfMode(Enum):
    """
    FibRpfMode (Enum Class)

    RPF mode types

    .. data:: fib_rpf_mode_strict = 0

    	RPF mode strict

    .. data:: fib_rpf_mode_loose = 1

    	RPF mode loose

    .. data:: fib_rpf_mode_unknown = 2

    	RPF mode unknown

    """

    fib_rpf_mode_strict = Enum.YLeaf(0, "fib-rpf-mode-strict")

    fib_rpf_mode_loose = Enum.YLeaf(1, "fib-rpf-mode-loose")

    fib_rpf_mode_unknown = Enum.YLeaf(2, "fib-rpf-mode-unknown")


class FibShIpencapHdr(Enum):
    """
    FibShIpencapHdr (Enum Class)

    IP Encap Header Type

    .. data:: fib_sh_ip_encap_none = 0

    	No Header

    .. data:: fib_sh_ip_encap_ip4 = 1

    	IPv4 Header

    .. data:: fib_sh_ip_encap_ip6 = 2

    	IPv6 Header

    .. data:: fib_sh_ip_encap_udp = 3

    	UDP Header

    .. data:: fib_sh_ip_encap_lisp = 4

    	Lisp Header

    """

    fib_sh_ip_encap_none = Enum.YLeaf(0, "fib-sh-ip-encap-none")

    fib_sh_ip_encap_ip4 = Enum.YLeaf(1, "fib-sh-ip-encap-ip4")

    fib_sh_ip_encap_ip6 = Enum.YLeaf(2, "fib-sh-ip-encap-ip6")

    fib_sh_ip_encap_udp = Enum.YLeaf(3, "fib-sh-ip-encap-udp")

    fib_sh_ip_encap_lisp = Enum.YLeaf(4, "fib-sh-ip-encap-lisp")


class FibShTblFibExtBag(Enum):
    """
    FibShTblFibExtBag (Enum Class)

    Fib sh tbl fib ext bag

    .. data:: leaf_extension = 1

    	Leaf Extension

    """

    leaf_extension = Enum.YLeaf(1, "leaf-extension")


class FibUpdatePathLfaProtection(Enum):
    """
    FibUpdatePathLfaProtection (Enum Class)

    LFA protection type

    .. data:: not_lfa_protected = 0

    	Not LFA-protected

    .. data:: local_lfa_protected = 1

    	Local-LFA protected

    .. data:: remote_lfa_protected = 2

    	Remote-LFA protected

    .. data:: ti_lfa_protected = 3

    	TI-LFA protected

    """

    not_lfa_protected = Enum.YLeaf(0, "not-lfa-protected")

    local_lfa_protected = Enum.YLeaf(1, "local-lfa-protected")

    remote_lfa_protected = Enum.YLeaf(2, "remote-lfa-protected")

    ti_lfa_protected = Enum.YLeaf(3, "ti-lfa-protected")


class FibafiProto(Enum):
    """
    FibafiProto (Enum Class)

    Fibafi proto

    .. data:: ipv4 = 0

    	ipv4 protocol

    .. data:: ipv4_mpls = 1

    	ipv4 mpls protocol

    .. data:: ipv6 = 2

    	ipv6 protocol

    .. data:: ipv6_mpls = 3

    	ipv6 mpls protocol

    """

    ipv4 = Enum.YLeaf(0, "ipv4")

    ipv4_mpls = Enum.YLeaf(1, "ipv4-mpls")

    ipv6 = Enum.YLeaf(2, "ipv6")

    ipv6_mpls = Enum.YLeaf(3, "ipv6-mpls")


class FibidbOper(Enum):
    """
    FibidbOper (Enum Class)

    Fibidb oper

    .. data:: fibidb_none = 0

    	fibidb none

    .. data:: fibidb_create = 1

    	fibidb create

    .. data:: fibidb_delete = 2

    	fibidb delete

    .. data:: fibidb_modify = 3

    	fibidb modify

    .. data:: fibidb_max = 4

    	fibidb max

    """

    fibidb_none = Enum.YLeaf(0, "fibidb-none")

    fibidb_create = Enum.YLeaf(1, "fibidb-create")

    fibidb_delete = Enum.YLeaf(2, "fibidb-delete")

    fibidb_modify = Enum.YLeaf(3, "fibidb-modify")

    fibidb_max = Enum.YLeaf(4, "fibidb-max")


class FibllcEntry(Enum):
    """
    FibllcEntry (Enum Class)

    Fibllc entry

    .. data:: xc = 1

    	LabelXconnect

    .. data:: pfx = 2

    	IPPrefix

    """

    xc = Enum.YLeaf(1, "xc")

    pfx = Enum.YLeaf(2, "pfx")


class MgmtFibMplsFrrState(Enum):
    """
    MgmtFibMplsFrrState (Enum Class)

    MPLS FRR entry state

    .. data:: partial = 0

    	Partial

    .. data:: active = 1

    	Active

    .. data:: ready = 2

    	Ready

    .. data:: complete = 3

    	Complete

    .. data:: any = 4

    	Any

    """

    partial = Enum.YLeaf(0, "partial")

    active = Enum.YLeaf(1, "active")

    ready = Enum.YLeaf(2, "ready")

    complete = Enum.YLeaf(3, "complete")

    any = Enum.YLeaf(4, "any")


class MgmtFibMplsLspRole(Enum):
    """
    MgmtFibMplsLspRole (Enum Class)

    MPLS FRR entry role

    .. data:: head = 0

    	Head

    .. data:: midpoint = 1

    	Midpoint

    """

    head = Enum.YLeaf(0, "head")

    midpoint = Enum.YLeaf(1, "midpoint")


class Mplseos(Enum):
    """
    Mplseos (Enum Class)

    Mplseos

    .. data:: eos0 = 0

    	EOS Disable

    .. data:: eos1 = 1

    	EOS Enable

    """

    eos0 = Enum.YLeaf(0, "eos0")

    eos1 = Enum.YLeaf(1, "eos1")


class NextHop(Enum):
    """
    NextHop (Enum Class)

    MPLS Forwarding Next Hop Type

    .. data:: tx = 0

    	TX

    .. data:: rx = 1

    	RX

    .. data:: special = 2

    	Special

    """

    tx = Enum.YLeaf(0, "tx")

    rx = Enum.YLeaf(1, "rx")

    special = Enum.YLeaf(2, "special")


class Proto(Enum):
    """
    Proto (Enum Class)

    MPLS Forwarding Protocol Type

    .. data:: ipv4 = 0

    	IPv4

    .. data:: ipv6 = 1

    	IPv6

    .. data:: mpls = 2

    	MPLS

    """

    ipv4 = Enum.YLeaf(0, "ipv4")

    ipv6 = Enum.YLeaf(1, "ipv6")

    mpls = Enum.YLeaf(2, "mpls")


class SsLbaState(Enum):
    """
    SsLbaState (Enum Class)

    Load Balance config

    .. data:: l3 = 0

    	L3 Load Balance config

    .. data:: l4 = 1

    	L4 Load Balance config

    """

    l3 = Enum.YLeaf(0, "l3")

    l4 = Enum.YLeaf(1, "l4")



class FibStatistics(Entity):
    """
    cef interface drops operational data
    
    .. attribute:: nodes
    
    	List of nodes
    	**type**\:  :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibStatistics.Nodes>`
    
    

    """

    _prefix = 'fib-common-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(FibStatistics, self).__init__()
        self._top_entity = None

        self.yang_name = "fib-statistics"
        self.yang_parent_name = "Cisco-IOS-XR-fib-common-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("nodes", ("nodes", FibStatistics.Nodes))])
        self._leafs = OrderedDict()

        self.nodes = FibStatistics.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._segment_path = lambda: "Cisco-IOS-XR-fib-common-oper:fib-statistics"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(FibStatistics, [], name, value)


    class Nodes(Entity):
        """
        List of nodes
        
        .. attribute:: node
        
        	Specific node operational data
        	**type**\: list of  		 :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibStatistics.Nodes.Node>`
        
        

        """

        _prefix = 'fib-common-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(FibStatistics.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "fib-statistics"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("node", ("node", FibStatistics.Nodes.Node))])
            self._leafs = OrderedDict()

            self.node = YList(self)
            self._segment_path = lambda: "nodes"
            self._absolute_path = lambda: "Cisco-IOS-XR-fib-common-oper:fib-statistics/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(FibStatistics.Nodes, [], name, value)


        class Node(Entity):
            """
            Specific node operational data
            
            .. attribute:: node_name  (key)
            
            	Node name
            	**type**\: str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: drops
            
            	Specific node drops
            	**type**\:  :py:class:`Drops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibStatistics.Nodes.Node.Drops>`
            
            

            """

            _prefix = 'fib-common-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(FibStatistics.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['node_name']
                self._child_classes = OrderedDict([("drops", ("drops", FibStatistics.Nodes.Node.Drops))])
                self._leafs = OrderedDict([
                    ('node_name', (YLeaf(YType.str, 'node-name'), ['str'])),
                ])
                self.node_name = None

                self.drops = FibStatistics.Nodes.Node.Drops()
                self.drops.parent = self
                self._children_name_map["drops"] = "drops"
                self._segment_path = lambda: "node" + "[node-name='" + str(self.node_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-fib-common-oper:fib-statistics/nodes/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(FibStatistics.Nodes.Node, ['node_name'], name, value)


            class Drops(Entity):
                """
                Specific node drops
                
                .. attribute:: no_route_packets
                
                	no route pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: punt_unreachable_packets
                
                	Punt generate unreach pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: df_unreachable_packets
                
                	DF unreachable pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: encapsulation_failure_packets
                
                	encapsulation failure pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: incomplete_adjacency_packets
                
                	incomplete adjacency pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: unresolved_prefix_packets
                
                	unresolved prefix pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: unsupported_feature_packets
                
                	unsupported feature pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: discard_packets
                
                	discard pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: checksum_error_packets
                
                	checksum error pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: fragmenation_consumed_packets
                
                	frag consumed packet pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: fragmenation_failure_packets
                
                	fragmenation failure pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: null_packets
                
                	null0 pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rpf_check_failure_packets
                
                	RPF check failures pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: acl_in_rpf_packets
                
                	ACL in RPF pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: rp_destination_drop_packets
                
                	rp dest drop pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: total_number_of_drop_packets
                
                	the total number of drop pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: mpls_disabled_interface
                
                	mpls disabled in interface
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: gre_lookup_failed_drop
                
                	GRE tunnel lookup failed drop pkt
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: gre_error_drop
                
                	GRE processing errors
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: lisp_punt_drops
                
                	LISP Punt drops
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: lisp_encap_error_drops
                
                	Lisp encap error drops
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: lisp_decap_error_drops
                
                	Lisp decap error drops
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: multi_label_drops
                
                	Drops for the packets with multi[le labels
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: unreachable_sr_label_drops
                
                	No route or unresolved route of MPLS SR labels
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: ttl_expired_sr_label_drops
                
                	TTL expired drops of MPLS SR labels
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                

                """

                _prefix = 'fib-common-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(FibStatistics.Nodes.Node.Drops, self).__init__()

                    self.yang_name = "drops"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('no_route_packets', (YLeaf(YType.uint64, 'no-route-packets'), ['int'])),
                        ('punt_unreachable_packets', (YLeaf(YType.uint64, 'punt-unreachable-packets'), ['int'])),
                        ('df_unreachable_packets', (YLeaf(YType.uint64, 'df-unreachable-packets'), ['int'])),
                        ('encapsulation_failure_packets', (YLeaf(YType.uint64, 'encapsulation-failure-packets'), ['int'])),
                        ('incomplete_adjacency_packets', (YLeaf(YType.uint64, 'incomplete-adjacency-packets'), ['int'])),
                        ('unresolved_prefix_packets', (YLeaf(YType.uint64, 'unresolved-prefix-packets'), ['int'])),
                        ('unsupported_feature_packets', (YLeaf(YType.uint64, 'unsupported-feature-packets'), ['int'])),
                        ('discard_packets', (YLeaf(YType.uint64, 'discard-packets'), ['int'])),
                        ('checksum_error_packets', (YLeaf(YType.uint64, 'checksum-error-packets'), ['int'])),
                        ('fragmenation_consumed_packets', (YLeaf(YType.uint64, 'fragmenation-consumed-packets'), ['int'])),
                        ('fragmenation_failure_packets', (YLeaf(YType.uint64, 'fragmenation-failure-packets'), ['int'])),
                        ('null_packets', (YLeaf(YType.uint64, 'null-packets'), ['int'])),
                        ('rpf_check_failure_packets', (YLeaf(YType.uint64, 'rpf-check-failure-packets'), ['int'])),
                        ('acl_in_rpf_packets', (YLeaf(YType.uint64, 'acl-in-rpf-packets'), ['int'])),
                        ('rp_destination_drop_packets', (YLeaf(YType.uint64, 'rp-destination-drop-packets'), ['int'])),
                        ('total_number_of_drop_packets', (YLeaf(YType.uint64, 'total-number-of-drop-packets'), ['int'])),
                        ('mpls_disabled_interface', (YLeaf(YType.uint64, 'mpls-disabled-interface'), ['int'])),
                        ('gre_lookup_failed_drop', (YLeaf(YType.uint64, 'gre-lookup-failed-drop'), ['int'])),
                        ('gre_error_drop', (YLeaf(YType.uint64, 'gre-error-drop'), ['int'])),
                        ('lisp_punt_drops', (YLeaf(YType.uint64, 'lisp-punt-drops'), ['int'])),
                        ('lisp_encap_error_drops', (YLeaf(YType.uint64, 'lisp-encap-error-drops'), ['int'])),
                        ('lisp_decap_error_drops', (YLeaf(YType.uint64, 'lisp-decap-error-drops'), ['int'])),
                        ('multi_label_drops', (YLeaf(YType.uint64, 'multi-label-drops'), ['int'])),
                        ('unreachable_sr_label_drops', (YLeaf(YType.uint64, 'unreachable-sr-label-drops'), ['int'])),
                        ('ttl_expired_sr_label_drops', (YLeaf(YType.uint64, 'ttl-expired-sr-label-drops'), ['int'])),
                    ])
                    self.no_route_packets = None
                    self.punt_unreachable_packets = None
                    self.df_unreachable_packets = None
                    self.encapsulation_failure_packets = None
                    self.incomplete_adjacency_packets = None
                    self.unresolved_prefix_packets = None
                    self.unsupported_feature_packets = None
                    self.discard_packets = None
                    self.checksum_error_packets = None
                    self.fragmenation_consumed_packets = None
                    self.fragmenation_failure_packets = None
                    self.null_packets = None
                    self.rpf_check_failure_packets = None
                    self.acl_in_rpf_packets = None
                    self.rp_destination_drop_packets = None
                    self.total_number_of_drop_packets = None
                    self.mpls_disabled_interface = None
                    self.gre_lookup_failed_drop = None
                    self.gre_error_drop = None
                    self.lisp_punt_drops = None
                    self.lisp_encap_error_drops = None
                    self.lisp_decap_error_drops = None
                    self.multi_label_drops = None
                    self.unreachable_sr_label_drops = None
                    self.ttl_expired_sr_label_drops = None
                    self._segment_path = lambda: "drops"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(FibStatistics.Nodes.Node.Drops, [u'no_route_packets', u'punt_unreachable_packets', u'df_unreachable_packets', u'encapsulation_failure_packets', u'incomplete_adjacency_packets', u'unresolved_prefix_packets', u'unsupported_feature_packets', u'discard_packets', u'checksum_error_packets', u'fragmenation_consumed_packets', u'fragmenation_failure_packets', u'null_packets', u'rpf_check_failure_packets', u'acl_in_rpf_packets', u'rp_destination_drop_packets', u'total_number_of_drop_packets', u'mpls_disabled_interface', u'gre_lookup_failed_drop', u'gre_error_drop', u'lisp_punt_drops', u'lisp_encap_error_drops', u'lisp_decap_error_drops', u'multi_label_drops', u'unreachable_sr_label_drops', u'ttl_expired_sr_label_drops'], name, value)

    def clone_ptr(self):
        self._top_entity = FibStatistics()
        return self._top_entity

class Fib(Entity):
    """
    fib
    
    .. attribute:: nodes
    
    	Table of nodes
    	**type**\:  :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes>`
    
    

    """

    _prefix = 'fib-common-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(Fib, self).__init__()
        self._top_entity = None

        self.yang_name = "fib"
        self.yang_parent_name = "Cisco-IOS-XR-fib-common-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("nodes", ("nodes", Fib.Nodes))])
        self._leafs = OrderedDict()

        self.nodes = Fib.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._segment_path = lambda: "Cisco-IOS-XR-fib-common-oper:fib"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(Fib, [], name, value)


    class Nodes(Entity):
        """
        Table of nodes
        
        .. attribute:: node
        
        	Operational data for a specific Node
        	**type**\: list of  		 :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node>`
        
        

        """

        _prefix = 'fib-common-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Fib.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "fib"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("node", ("node", Fib.Nodes.Node))])
            self._leafs = OrderedDict()

            self.node = YList(self)
            self._segment_path = lambda: "nodes"
            self._absolute_path = lambda: "Cisco-IOS-XR-fib-common-oper:fib/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Fib.Nodes, [], name, value)


        class Node(Entity):
            """
            Operational data for a specific Node
            
            .. attribute:: node_name  (key)
            
            	Node name
            	**type**\: str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: global_
            
            	FIB Global info
            	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global>`
            
            .. attribute:: protocols
            
            	Protocol table
            	**type**\:  :py:class:`Protocols <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols>`
            
            

            """

            _prefix = 'fib-common-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Fib.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['node_name']
                self._child_classes = OrderedDict([("global", ("global_", Fib.Nodes.Node.Global)), ("protocols", ("protocols", Fib.Nodes.Node.Protocols))])
                self._leafs = OrderedDict([
                    ('node_name', (YLeaf(YType.str, 'node-name'), ['str'])),
                ])
                self.node_name = None

                self.global_ = Fib.Nodes.Node.Global()
                self.global_.parent = self
                self._children_name_map["global_"] = "global"

                self.protocols = Fib.Nodes.Node.Protocols()
                self.protocols.parent = self
                self._children_name_map["protocols"] = "protocols"
                self._segment_path = lambda: "node" + "[node-name='" + str(self.node_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-fib-common-oper:fib/nodes/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Fib.Nodes.Node, ['node_name'], name, value)


            class Global(Entity):
                """
                FIB Global info
                
                .. attribute:: fib_cofo
                
                	Collapsed Forwarding
                	**type**\:  :py:class:`FibCofo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.FibCofo>`
                
                .. attribute:: summary
                
                	Global Summary
                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary>`
                
                .. attribute:: object_history
                
                	Object History
                	**type**\:  :py:class:`ObjectHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.ObjectHistory>`
                
                

                """

                _prefix = 'fib-common-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Fib.Nodes.Node.Global, self).__init__()

                    self.yang_name = "global"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("fib-cofo", ("fib_cofo", Fib.Nodes.Node.Global.FibCofo)), ("summary", ("summary", Fib.Nodes.Node.Global.Summary)), ("object-history", ("object_history", Fib.Nodes.Node.Global.ObjectHistory))])
                    self._leafs = OrderedDict()

                    self.fib_cofo = Fib.Nodes.Node.Global.FibCofo()
                    self.fib_cofo.parent = self
                    self._children_name_map["fib_cofo"] = "fib-cofo"

                    self.summary = Fib.Nodes.Node.Global.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"

                    self.object_history = Fib.Nodes.Node.Global.ObjectHistory()
                    self.object_history.parent = self
                    self._children_name_map["object_history"] = "object-history"
                    self._segment_path = lambda: "global"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Fib.Nodes.Node.Global, [], name, value)


                class FibCofo(Entity):
                    """
                    Collapsed Forwarding
                    
                    .. attribute:: fib_cofo_idb
                    
                    	Collapsed Forwarding IDB Table
                    	**type**\:  :py:class:`FibCofoIdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.FibCofo.FibCofoIdb>`
                    
                    .. attribute:: fib_cofo_table_id
                    
                    	Collapsed Forwarding Table Id Table
                    	**type**\:  :py:class:`FibCofoTableId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.FibCofo.FibCofoTableId>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Fib.Nodes.Node.Global.FibCofo, self).__init__()

                        self.yang_name = "fib-cofo"
                        self.yang_parent_name = "global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("fib-cofo-idb", ("fib_cofo_idb", Fib.Nodes.Node.Global.FibCofo.FibCofoIdb)), ("fib-cofo-table-id", ("fib_cofo_table_id", Fib.Nodes.Node.Global.FibCofo.FibCofoTableId))])
                        self._leafs = OrderedDict()

                        self.fib_cofo_idb = Fib.Nodes.Node.Global.FibCofo.FibCofoIdb()
                        self.fib_cofo_idb.parent = self
                        self._children_name_map["fib_cofo_idb"] = "fib-cofo-idb"

                        self.fib_cofo_table_id = Fib.Nodes.Node.Global.FibCofo.FibCofoTableId()
                        self.fib_cofo_table_id.parent = self
                        self._children_name_map["fib_cofo_table_id"] = "fib-cofo-table-id"
                        self._segment_path = lambda: "fib-cofo"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Fib.Nodes.Node.Global.FibCofo, [], name, value)


                    class FibCofoIdb(Entity):
                        """
                        Collapsed Forwarding IDB Table
                        
                        .. attribute:: fib_cofo_idb_table_entries
                        
                        	Collapsed Forwarding Idb Table Entries
                        	**type**\:  :py:class:`FibCofoIdbTableEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Global.FibCofo.FibCofoIdb, self).__init__()

                            self.yang_name = "fib-cofo-idb"
                            self.yang_parent_name = "fib-cofo"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fib-cofo-idb-table-entries", ("fib_cofo_idb_table_entries", Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries))])
                            self._leafs = OrderedDict()

                            self.fib_cofo_idb_table_entries = Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries()
                            self.fib_cofo_idb_table_entries.parent = self
                            self._children_name_map["fib_cofo_idb_table_entries"] = "fib-cofo-idb-table-entries"
                            self._segment_path = lambda: "fib-cofo-idb"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Global.FibCofo.FibCofoIdb, [], name, value)


                        class FibCofoIdbTableEntries(Entity):
                            """
                            Collapsed Forwarding Idb Table Entries
                            
                            .. attribute:: fib_cofo_idb_table_entry
                            
                            	Collapsed Forwarding Idb Table Entries
                            	**type**\: list of  		 :py:class:`FibCofoIdbTableEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries.FibCofoIdbTableEntry>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries, self).__init__()

                                self.yang_name = "fib-cofo-idb-table-entries"
                                self.yang_parent_name = "fib-cofo-idb"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("fib-cofo-idb-table-entry", ("fib_cofo_idb_table_entry", Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries.FibCofoIdbTableEntry))])
                                self._leafs = OrderedDict()

                                self.fib_cofo_idb_table_entry = YList(self)
                                self._segment_path = lambda: "fib-cofo-idb-table-entries"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries, [], name, value)


                            class FibCofoIdbTableEntry(Entity):
                                """
                                Collapsed Forwarding Idb Table Entries
                                
                                .. attribute:: sdr_id
                                
                                	SDR ID value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: if_index
                                
                                	Interface Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: object_base
                                
                                	FIB Object Base information
                                	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries.FibCofoIdbTableEntry.ObjectBase>`
                                
                                .. attribute:: sdrid
                                
                                	SDR ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intf_type
                                
                                	Interface Type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intf_index
                                
                                	Interface Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intf_state
                                
                                	Interface State
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: parent_intf_index
                                
                                	Parent Interface Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: parent_intf_type
                                
                                	Parent Interface Type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bundle_member_total_weight
                                
                                	Bundle Member Total Weight
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: main_pointer
                                
                                	Main Interface Pointer
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: table_pointer
                                
                                	Table Pointer
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: hardware_handle
                                
                                	Hardware Handle
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: intf_name
                                
                                	Interface Name
                                	**type**\: str
                                
                                .. attribute:: pic
                                
                                	Port Information Context
                                	**type**\: list of int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bundle_member_info
                                
                                	Bundle Member Info
                                	**type**\: list of  		 :py:class:`BundleMemberInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries.FibCofoIdbTableEntry.BundleMemberInfo>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries.FibCofoIdbTableEntry, self).__init__()

                                    self.yang_name = "fib-cofo-idb-table-entry"
                                    self.yang_parent_name = "fib-cofo-idb-table-entries"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries.FibCofoIdbTableEntry.ObjectBase)), ("bundle-member-info", ("bundle_member_info", Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries.FibCofoIdbTableEntry.BundleMemberInfo))])
                                    self._leafs = OrderedDict([
                                        ('sdr_id', (YLeaf(YType.uint32, 'sdr-id'), ['int'])),
                                        ('if_index', (YLeaf(YType.uint32, 'if-index'), ['int'])),
                                        ('sdrid', (YLeaf(YType.uint32, 'sdrid'), ['int'])),
                                        ('intf_type', (YLeaf(YType.uint32, 'intf-type'), ['int'])),
                                        ('intf_index', (YLeaf(YType.uint32, 'intf-index'), ['int'])),
                                        ('intf_state', (YLeaf(YType.uint32, 'intf-state'), ['int'])),
                                        ('parent_intf_index', (YLeaf(YType.uint32, 'parent-intf-index'), ['int'])),
                                        ('parent_intf_type', (YLeaf(YType.uint32, 'parent-intf-type'), ['int'])),
                                        ('bundle_member_total_weight', (YLeaf(YType.uint16, 'bundle-member-total-weight'), ['int'])),
                                        ('main_pointer', (YLeaf(YType.uint64, 'main-pointer'), ['int'])),
                                        ('table_pointer', (YLeaf(YType.uint64, 'table-pointer'), ['int'])),
                                        ('hardware_handle', (YLeaf(YType.uint64, 'hardware-handle'), ['int'])),
                                        ('intf_name', (YLeaf(YType.str, 'intf-name'), ['str'])),
                                        ('pic', (YLeafList(YType.uint64, 'pic'), ['int'])),
                                    ])
                                    self.sdr_id = None
                                    self.if_index = None
                                    self.sdrid = None
                                    self.intf_type = None
                                    self.intf_index = None
                                    self.intf_state = None
                                    self.parent_intf_index = None
                                    self.parent_intf_type = None
                                    self.bundle_member_total_weight = None
                                    self.main_pointer = None
                                    self.table_pointer = None
                                    self.hardware_handle = None
                                    self.intf_name = None
                                    self.pic = []

                                    self.object_base = Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries.FibCofoIdbTableEntry.ObjectBase()
                                    self.object_base.parent = self
                                    self._children_name_map["object_base"] = "object-base"

                                    self.bundle_member_info = YList(self)
                                    self._segment_path = lambda: "fib-cofo-idb-table-entry"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries.FibCofoIdbTableEntry, ['sdr_id', 'if_index', 'sdrid', 'intf_type', 'intf_index', 'intf_state', 'parent_intf_index', 'parent_intf_type', 'bundle_member_total_weight', 'main_pointer', 'table_pointer', 'hardware_handle', 'intf_name', 'pic'], name, value)


                                class ObjectBase(Entity):
                                    """
                                    FIB Object Base information
                                    
                                    .. attribute:: object_reference_count
                                    
                                    	FIB Object Reference Count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: object_flags
                                    
                                    	FIB Object flags
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: object_type
                                    
                                    	FIB Object type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: object_time_stamp
                                    
                                    	FIB Object TimeStamp in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: object_pointer
                                    
                                    	FIB Object pointer
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries.FibCofoIdbTableEntry.ObjectBase, self).__init__()

                                        self.yang_name = "object-base"
                                        self.yang_parent_name = "fib-cofo-idb-table-entry"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                            ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                            ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                            ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                            ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                        ])
                                        self.object_reference_count = None
                                        self.object_flags = None
                                        self.object_type = None
                                        self.object_time_stamp = None
                                        self.object_pointer = None
                                        self._segment_path = lambda: "object-base"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries.FibCofoIdbTableEntry.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                class BundleMemberInfo(Entity):
                                    """
                                    Bundle Member Info
                                    
                                    .. attribute:: intf_index
                                    
                                    	Interface Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: unique_id
                                    
                                    	Unique Identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: order_num
                                    
                                    	Link Order Number
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: weight
                                    
                                    	Member Weight
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: pic
                                    
                                    	Port Information Context
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries.FibCofoIdbTableEntry.BundleMemberInfo, self).__init__()

                                        self.yang_name = "bundle-member-info"
                                        self.yang_parent_name = "fib-cofo-idb-table-entry"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('intf_index', (YLeaf(YType.uint32, 'intf-index'), ['int'])),
                                            ('unique_id', (YLeaf(YType.uint8, 'unique-id'), ['int'])),
                                            ('order_num', (YLeaf(YType.uint8, 'order-num'), ['int'])),
                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                            ('pic', (YLeaf(YType.uint64, 'pic'), ['int'])),
                                        ])
                                        self.intf_index = None
                                        self.unique_id = None
                                        self.order_num = None
                                        self.weight = None
                                        self.pic = None
                                        self._segment_path = lambda: "bundle-member-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Global.FibCofo.FibCofoIdb.FibCofoIdbTableEntries.FibCofoIdbTableEntry.BundleMemberInfo, ['intf_index', 'unique_id', 'order_num', 'weight', 'pic'], name, value)


                    class FibCofoTableId(Entity):
                        """
                        Collapsed Forwarding Table Id Table
                        
                        .. attribute:: fib_cofo_table_id_entries
                        
                        	Collapsed Forwarding Table Id Entries
                        	**type**\:  :py:class:`FibCofoTableIdEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries>`
                        
                        .. attribute:: fib_cofo_table_id_summary
                        
                        	Collapsed Forwarding Table Id Entries
                        	**type**\:  :py:class:`FibCofoTableIdSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdSummary>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Global.FibCofo.FibCofoTableId, self).__init__()

                            self.yang_name = "fib-cofo-table-id"
                            self.yang_parent_name = "fib-cofo"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fib-cofo-table-id-entries", ("fib_cofo_table_id_entries", Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries)), ("fib-cofo-table-id-summary", ("fib_cofo_table_id_summary", Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdSummary))])
                            self._leafs = OrderedDict()

                            self.fib_cofo_table_id_entries = Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries()
                            self.fib_cofo_table_id_entries.parent = self
                            self._children_name_map["fib_cofo_table_id_entries"] = "fib-cofo-table-id-entries"

                            self.fib_cofo_table_id_summary = Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdSummary()
                            self.fib_cofo_table_id_summary.parent = self
                            self._children_name_map["fib_cofo_table_id_summary"] = "fib-cofo-table-id-summary"
                            self._segment_path = lambda: "fib-cofo-table-id"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Global.FibCofo.FibCofoTableId, [], name, value)


                        class FibCofoTableIdEntries(Entity):
                            """
                            Collapsed Forwarding Table Id Entries
                            
                            .. attribute:: fib_cofo_table_id_entry
                            
                            	Collapsed Forwarding Idb Table Entries
                            	**type**\: list of  		 :py:class:`FibCofoTableIdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries.FibCofoTableIdEntry>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries, self).__init__()

                                self.yang_name = "fib-cofo-table-id-entries"
                                self.yang_parent_name = "fib-cofo-table-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("fib-cofo-table-id-entry", ("fib_cofo_table_id_entry", Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries.FibCofoTableIdEntry))])
                                self._leafs = OrderedDict()

                                self.fib_cofo_table_id_entry = YList(self)
                                self._segment_path = lambda: "fib-cofo-table-id-entries"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries, [], name, value)


                            class FibCofoTableIdEntry(Entity):
                                """
                                Collapsed Forwarding Idb Table Entries
                                
                                .. attribute:: sdr_id
                                
                                	SDR ID value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:  :py:class:`FibProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibProtocol>`
                                
                                .. attribute:: rd
                                
                                	Route Distinguisher
                                	**type**\: str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: table_id
                                
                                	Table Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: object_base
                                
                                	FIB Object Base information
                                	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries.FibCofoTableIdEntry.ObjectBase>`
                                
                                .. attribute:: sdrid
                                
                                	SDR ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: protocol_type
                                
                                	Protocol
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_distinguisher
                                
                                	Route Distinguisher
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: table_id_xr
                                
                                	Table ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vrf_name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: table_pointer
                                
                                	Table Pointer
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries.FibCofoTableIdEntry, self).__init__()

                                    self.yang_name = "fib-cofo-table-id-entry"
                                    self.yang_parent_name = "fib-cofo-table-id-entries"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries.FibCofoTableIdEntry.ObjectBase))])
                                    self._leafs = OrderedDict([
                                        ('sdr_id', (YLeaf(YType.uint32, 'sdr-id'), ['int'])),
                                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibProtocol', '')])),
                                        ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                        ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                        ('sdrid', (YLeaf(YType.uint32, 'sdrid'), ['int'])),
                                        ('protocol_type', (YLeaf(YType.uint32, 'protocol-type'), ['int'])),
                                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                        ('table_id_xr', (YLeaf(YType.uint32, 'table-id-xr'), ['int'])),
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('table_pointer', (YLeaf(YType.uint64, 'table-pointer'), ['int'])),
                                    ])
                                    self.sdr_id = None
                                    self.protocol = None
                                    self.rd = None
                                    self.table_id = None
                                    self.sdrid = None
                                    self.protocol_type = None
                                    self.route_distinguisher = None
                                    self.table_id_xr = None
                                    self.vrf_name = None
                                    self.table_pointer = None

                                    self.object_base = Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries.FibCofoTableIdEntry.ObjectBase()
                                    self.object_base.parent = self
                                    self._children_name_map["object_base"] = "object-base"
                                    self._segment_path = lambda: "fib-cofo-table-id-entry"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries.FibCofoTableIdEntry, ['sdr_id', 'protocol', 'rd', 'table_id', 'sdrid', 'protocol_type', 'route_distinguisher', 'table_id_xr', 'vrf_name', 'table_pointer'], name, value)


                                class ObjectBase(Entity):
                                    """
                                    FIB Object Base information
                                    
                                    .. attribute:: object_reference_count
                                    
                                    	FIB Object Reference Count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: object_flags
                                    
                                    	FIB Object flags
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: object_type
                                    
                                    	FIB Object type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: object_time_stamp
                                    
                                    	FIB Object TimeStamp in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: object_pointer
                                    
                                    	FIB Object pointer
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries.FibCofoTableIdEntry.ObjectBase, self).__init__()

                                        self.yang_name = "object-base"
                                        self.yang_parent_name = "fib-cofo-table-id-entry"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                            ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                            ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                            ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                            ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                        ])
                                        self.object_reference_count = None
                                        self.object_flags = None
                                        self.object_type = None
                                        self.object_time_stamp = None
                                        self.object_pointer = None
                                        self._segment_path = lambda: "object-base"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdEntries.FibCofoTableIdEntry.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                        class FibCofoTableIdSummary(Entity):
                            """
                            Collapsed Forwarding Table Id Entries
                            
                            .. attribute:: number_of_tbl_id_allocated
                            
                            	Number of Table Id Allocated
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tbl_id_minimum
                            
                            	Minimum Table Id in Range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tbl_id_maximum
                            
                            	Maximum Table Id in Range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tbl_id_last_allocated
                            
                            	Last Table Id Allocated
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tbl_id_default_v4
                            
                            	COFO default V4 Table Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tbl_id_default_v6
                            
                            	COFO default V6 Table Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_tbl_id_in_gc
                            
                            	Number of Table Id in Garbage Collection List
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: per_sdr_stat
                            
                            	Per SDR statistics
                            	**type**\: list of  		 :py:class:`PerSdrStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdSummary.PerSdrStat>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdSummary, self).__init__()

                                self.yang_name = "fib-cofo-table-id-summary"
                                self.yang_parent_name = "fib-cofo-table-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("per-sdr-stat", ("per_sdr_stat", Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdSummary.PerSdrStat))])
                                self._leafs = OrderedDict([
                                    ('number_of_tbl_id_allocated', (YLeaf(YType.uint32, 'number-of-tbl-id-allocated'), ['int'])),
                                    ('tbl_id_minimum', (YLeaf(YType.uint32, 'tbl-id-minimum'), ['int'])),
                                    ('tbl_id_maximum', (YLeaf(YType.uint32, 'tbl-id-maximum'), ['int'])),
                                    ('tbl_id_last_allocated', (YLeaf(YType.uint32, 'tbl-id-last-allocated'), ['int'])),
                                    ('tbl_id_default_v4', (YLeaf(YType.uint32, 'tbl-id-default-v4'), ['int'])),
                                    ('tbl_id_default_v6', (YLeaf(YType.uint32, 'tbl-id-default-v6'), ['int'])),
                                    ('number_of_tbl_id_in_gc', (YLeaf(YType.uint32, 'number-of-tbl-id-in-gc'), ['int'])),
                                ])
                                self.number_of_tbl_id_allocated = None
                                self.tbl_id_minimum = None
                                self.tbl_id_maximum = None
                                self.tbl_id_last_allocated = None
                                self.tbl_id_default_v4 = None
                                self.tbl_id_default_v6 = None
                                self.number_of_tbl_id_in_gc = None

                                self.per_sdr_stat = YList(self)
                                self._segment_path = lambda: "fib-cofo-table-id-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdSummary, ['number_of_tbl_id_allocated', 'tbl_id_minimum', 'tbl_id_maximum', 'tbl_id_last_allocated', 'tbl_id_default_v4', 'tbl_id_default_v6', 'number_of_tbl_id_in_gc'], name, value)


                            class PerSdrStat(Entity):
                                """
                                Per SDR statistics
                                
                                .. attribute:: sdrid
                                
                                	SDR ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_ofipv4_tables
                                
                                	Number of Tables for IPv4
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: num_ofipv6_tables
                                
                                	Number of Tables for IPv6
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: num_ofmpls_tables
                                
                                	Number of Tables for MPLS
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdSummary.PerSdrStat, self).__init__()

                                    self.yang_name = "per-sdr-stat"
                                    self.yang_parent_name = "fib-cofo-table-id-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sdrid', (YLeaf(YType.uint32, 'sdrid'), ['int'])),
                                        ('num_ofipv4_tables', (YLeaf(YType.uint16, 'num-ofipv4-tables'), ['int'])),
                                        ('num_ofipv6_tables', (YLeaf(YType.uint16, 'num-ofipv6-tables'), ['int'])),
                                        ('num_ofmpls_tables', (YLeaf(YType.uint16, 'num-ofmpls-tables'), ['int'])),
                                    ])
                                    self.sdrid = None
                                    self.num_ofipv4_tables = None
                                    self.num_ofipv6_tables = None
                                    self.num_ofmpls_tables = None
                                    self._segment_path = lambda: "per-sdr-stat"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Global.FibCofo.FibCofoTableId.FibCofoTableIdSummary.PerSdrStat, ['sdrid', 'num_ofipv4_tables', 'num_ofipv6_tables', 'num_ofmpls_tables'], name, value)


                class Summary(Entity):
                    """
                    Global Summary
                    
                    .. attribute:: total
                    
                    	Display total counters and common info
                    	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Total>`
                    
                    .. attribute:: protos
                    
                    	Proto Table
                    	**type**\:  :py:class:`Protos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Protos>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Fib.Nodes.Node.Global.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("total", ("total", Fib.Nodes.Node.Global.Summary.Total)), ("protos", ("protos", Fib.Nodes.Node.Global.Summary.Protos))])
                        self._leafs = OrderedDict()

                        self.total = Fib.Nodes.Node.Global.Summary.Total()
                        self.total.parent = self
                        self._children_name_map["total"] = "total"

                        self.protos = Fib.Nodes.Node.Global.Summary.Protos()
                        self.protos.parent = self
                        self._children_name_map["protos"] = "protos"
                        self._segment_path = lambda: "summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Fib.Nodes.Node.Global.Summary, [], name, value)


                    class Total(Entity):
                        """
                        Display total counters and common info
                        
                        .. attribute:: common_info
                        
                        	Common info
                        	**type**\:  :py:class:`CommonInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Total.CommonInfo>`
                        
                        .. attribute:: total_counters
                        
                        	Aggregate counters of all protocols
                        	**type**\:  :py:class:`TotalCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Total.TotalCounters>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Global.Summary.Total, self).__init__()

                            self.yang_name = "total"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("common-info", ("common_info", Fib.Nodes.Node.Global.Summary.Total.CommonInfo)), ("total-counters", ("total_counters", Fib.Nodes.Node.Global.Summary.Total.TotalCounters))])
                            self._leafs = OrderedDict()

                            self.common_info = Fib.Nodes.Node.Global.Summary.Total.CommonInfo()
                            self.common_info.parent = self
                            self._children_name_map["common_info"] = "common-info"

                            self.total_counters = Fib.Nodes.Node.Global.Summary.Total.TotalCounters()
                            self.total_counters.parent = self
                            self._children_name_map["total_counters"] = "total-counters"
                            self._segment_path = lambda: "total"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Global.Summary.Total, [], name, value)


                        class CommonInfo(Entity):
                            """
                            Common info
                            
                            .. attribute:: count
                            
                            	Placeholder for common info counts
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Global.Summary.Total.CommonInfo, self).__init__()

                                self.yang_name = "common-info"
                                self.yang_parent_name = "total"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                ])
                                self.count = None
                                self._segment_path = lambda: "common-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Global.Summary.Total.CommonInfo, ['count'], name, value)


                        class TotalCounters(Entity):
                            """
                            Aggregate counters of all protocols
                            
                            .. attribute:: num_retry_timeouts
                            
                            	number of retry timeouts
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: num_retry_ojbects
                            
                            	number of elements in retry db
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: array_number_of_retry
                            
                            	number of objects in retry db
                            	**type**\: list of  		 :py:class:`ArrayNumberOfRetry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Total.TotalCounters.ArrayNumberOfRetry>`
                            
                            .. attribute:: array_number_of_object
                            
                            	total number of objects
                            	**type**\: list of  		 :py:class:`ArrayNumberOfObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Total.TotalCounters.ArrayNumberOfObject>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Global.Summary.Total.TotalCounters, self).__init__()

                                self.yang_name = "total-counters"
                                self.yang_parent_name = "total"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("array-number-of-retry", ("array_number_of_retry", Fib.Nodes.Node.Global.Summary.Total.TotalCounters.ArrayNumberOfRetry)), ("array-number-of-object", ("array_number_of_object", Fib.Nodes.Node.Global.Summary.Total.TotalCounters.ArrayNumberOfObject))])
                                self._leafs = OrderedDict([
                                    ('num_retry_timeouts', (YLeaf(YType.uint64, 'num-retry-timeouts'), ['int'])),
                                    ('num_retry_ojbects', (YLeaf(YType.uint32, 'num-retry-ojbects'), ['int'])),
                                ])
                                self.num_retry_timeouts = None
                                self.num_retry_ojbects = None

                                self.array_number_of_retry = YList(self)
                                self.array_number_of_object = YList(self)
                                self._segment_path = lambda: "total-counters"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Global.Summary.Total.TotalCounters, ['num_retry_timeouts', 'num_retry_ojbects'], name, value)


                            class ArrayNumberOfRetry(Entity):
                                """
                                number of objects in retry db
                                
                                .. attribute:: retry_object_type
                                
                                	retry object
                                	**type**\: str
                                
                                	**length:** 0..30
                                
                                .. attribute:: num_retries
                                
                                	number of elements for this obj type in retry db
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Global.Summary.Total.TotalCounters.ArrayNumberOfRetry, self).__init__()

                                    self.yang_name = "array-number-of-retry"
                                    self.yang_parent_name = "total-counters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('retry_object_type', (YLeaf(YType.str, 'retry-object-type'), ['str'])),
                                        ('num_retries', (YLeaf(YType.uint64, 'num-retries'), ['int'])),
                                    ])
                                    self.retry_object_type = None
                                    self.num_retries = None
                                    self._segment_path = lambda: "array-number-of-retry"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Global.Summary.Total.TotalCounters.ArrayNumberOfRetry, ['retry_object_type', 'num_retries'], name, value)


                            class ArrayNumberOfObject(Entity):
                                """
                                total number of objects
                                
                                .. attribute:: object_type
                                
                                	object
                                	**type**\: str
                                
                                	**length:** 0..30
                                
                                .. attribute:: num_objects
                                
                                	number of elements for this obj type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Global.Summary.Total.TotalCounters.ArrayNumberOfObject, self).__init__()

                                    self.yang_name = "array-number-of-object"
                                    self.yang_parent_name = "total-counters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('object_type', (YLeaf(YType.str, 'object-type'), ['str'])),
                                        ('num_objects', (YLeaf(YType.uint32, 'num-objects'), ['int'])),
                                    ])
                                    self.object_type = None
                                    self.num_objects = None
                                    self._segment_path = lambda: "array-number-of-object"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Global.Summary.Total.TotalCounters.ArrayNumberOfObject, ['object_type', 'num_objects'], name, value)


                    class Protos(Entity):
                        """
                        Proto Table
                        
                        .. attribute:: proto
                        
                        	Proto Table entry
                        	**type**\: list of  		 :py:class:`Proto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Protos.Proto>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Global.Summary.Protos, self).__init__()

                            self.yang_name = "protos"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("proto", ("proto", Fib.Nodes.Node.Global.Summary.Protos.Proto))])
                            self._leafs = OrderedDict()

                            self.proto = YList(self)
                            self._segment_path = lambda: "protos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Global.Summary.Protos, [], name, value)


                        class Proto(Entity):
                            """
                            Proto Table entry
                            
                            .. attribute:: protocol_name  (key)
                            
                            	Protocol Name
                            	**type**\:  :py:class:`FibafiProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibafiProto>`
                            
                            .. attribute:: common_info
                            
                            	Common Info
                            	**type**\:  :py:class:`CommonInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Protos.Proto.CommonInfo>`
                            
                            .. attribute:: summary
                            
                            	Global summary
                            	**type**\:  :py:class:`Summary_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Global.Summary.Protos.Proto, self).__init__()

                                self.yang_name = "proto"
                                self.yang_parent_name = "protos"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['protocol_name']
                                self._child_classes = OrderedDict([("common-info", ("common_info", Fib.Nodes.Node.Global.Summary.Protos.Proto.CommonInfo)), ("summary", ("summary", Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_))])
                                self._leafs = OrderedDict([
                                    ('protocol_name', (YLeaf(YType.enumeration, 'protocol-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibafiProto', '')])),
                                ])
                                self.protocol_name = None

                                self.common_info = Fib.Nodes.Node.Global.Summary.Protos.Proto.CommonInfo()
                                self.common_info.parent = self
                                self._children_name_map["common_info"] = "common-info"

                                self.summary = Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_()
                                self.summary.parent = self
                                self._children_name_map["summary"] = "summary"
                                self._segment_path = lambda: "proto" + "[protocol-name='" + str(self.protocol_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Global.Summary.Protos.Proto, ['protocol_name'], name, value)


                            class CommonInfo(Entity):
                                """
                                Common Info
                                
                                .. attribute:: count
                                
                                	Placeholder for common info counts
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Global.Summary.Protos.Proto.CommonInfo, self).__init__()

                                    self.yang_name = "common-info"
                                    self.yang_parent_name = "proto"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                    ])
                                    self.count = None
                                    self._segment_path = lambda: "common-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Global.Summary.Protos.Proto.CommonInfo, ['count'], name, value)


                            class Summary_(Entity):
                                """
                                Global summary
                                
                                .. attribute:: base_object
                                
                                	Base object
                                	**type**\:  :py:class:`BaseObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.BaseObject>`
                                
                                .. attribute:: summary_counts
                                
                                	Global Summary counts
                                	**type**\:  :py:class:`SummaryCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.SummaryCounts>`
                                
                                .. attribute:: health
                                
                                	Global summary health
                                	**type**\:  :py:class:`Health <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.Health>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_, self).__init__()

                                    self.yang_name = "summary"
                                    self.yang_parent_name = "proto"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base-object", ("base_object", Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.BaseObject)), ("summary-counts", ("summary_counts", Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.SummaryCounts)), ("health", ("health", Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.Health))])
                                    self._leafs = OrderedDict()

                                    self.base_object = Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.BaseObject()
                                    self.base_object.parent = self
                                    self._children_name_map["base_object"] = "base-object"

                                    self.summary_counts = Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.SummaryCounts()
                                    self.summary_counts.parent = self
                                    self._children_name_map["summary_counts"] = "summary-counts"

                                    self.health = Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.Health()
                                    self.health.parent = self
                                    self._children_name_map["health"] = "health"
                                    self._segment_path = lambda: "summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_, [], name, value)


                                class BaseObject(Entity):
                                    """
                                    Base object
                                    
                                    .. attribute:: protocol
                                    
                                    	protocol
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.BaseObject, self).__init__()

                                        self.yang_name = "base-object"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('protocol', (YLeaf(YType.uint32, 'protocol'), ['int'])),
                                        ])
                                        self.protocol = None
                                        self._segment_path = lambda: "base-object"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.BaseObject, ['protocol'], name, value)


                                class SummaryCounts(Entity):
                                    """
                                    Global Summary counts
                                    
                                    .. attribute:: num_retry_timeouts
                                    
                                    	number of retry timeouts
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: num_retry_ojbects
                                    
                                    	number of elements in retry db
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: array_number_of_retry
                                    
                                    	number of objects in retry db
                                    	**type**\: list of  		 :py:class:`ArrayNumberOfRetry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.SummaryCounts.ArrayNumberOfRetry>`
                                    
                                    .. attribute:: array_number_of_object
                                    
                                    	total number of objects
                                    	**type**\: list of  		 :py:class:`ArrayNumberOfObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.SummaryCounts.ArrayNumberOfObject>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.SummaryCounts, self).__init__()

                                        self.yang_name = "summary-counts"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("array-number-of-retry", ("array_number_of_retry", Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.SummaryCounts.ArrayNumberOfRetry)), ("array-number-of-object", ("array_number_of_object", Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.SummaryCounts.ArrayNumberOfObject))])
                                        self._leafs = OrderedDict([
                                            ('num_retry_timeouts', (YLeaf(YType.uint64, 'num-retry-timeouts'), ['int'])),
                                            ('num_retry_ojbects', (YLeaf(YType.uint32, 'num-retry-ojbects'), ['int'])),
                                        ])
                                        self.num_retry_timeouts = None
                                        self.num_retry_ojbects = None

                                        self.array_number_of_retry = YList(self)
                                        self.array_number_of_object = YList(self)
                                        self._segment_path = lambda: "summary-counts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.SummaryCounts, ['num_retry_timeouts', 'num_retry_ojbects'], name, value)


                                    class ArrayNumberOfRetry(Entity):
                                        """
                                        number of objects in retry db
                                        
                                        .. attribute:: retry_object_type
                                        
                                        	retry object
                                        	**type**\: str
                                        
                                        	**length:** 0..30
                                        
                                        .. attribute:: num_retries
                                        
                                        	number of elements for this obj type in retry db
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.SummaryCounts.ArrayNumberOfRetry, self).__init__()

                                            self.yang_name = "array-number-of-retry"
                                            self.yang_parent_name = "summary-counts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('retry_object_type', (YLeaf(YType.str, 'retry-object-type'), ['str'])),
                                                ('num_retries', (YLeaf(YType.uint64, 'num-retries'), ['int'])),
                                            ])
                                            self.retry_object_type = None
                                            self.num_retries = None
                                            self._segment_path = lambda: "array-number-of-retry"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.SummaryCounts.ArrayNumberOfRetry, ['retry_object_type', 'num_retries'], name, value)


                                    class ArrayNumberOfObject(Entity):
                                        """
                                        total number of objects
                                        
                                        .. attribute:: object_type
                                        
                                        	object
                                        	**type**\: str
                                        
                                        	**length:** 0..30
                                        
                                        .. attribute:: num_objects
                                        
                                        	number of elements for this obj type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.SummaryCounts.ArrayNumberOfObject, self).__init__()

                                            self.yang_name = "array-number-of-object"
                                            self.yang_parent_name = "summary-counts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('object_type', (YLeaf(YType.str, 'object-type'), ['str'])),
                                                ('num_objects', (YLeaf(YType.uint32, 'num-objects'), ['int'])),
                                            ])
                                            self.object_type = None
                                            self.num_objects = None
                                            self._segment_path = lambda: "array-number-of-object"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.SummaryCounts.ArrayNumberOfObject, ['object_type', 'num_objects'], name, value)


                                class Health(Entity):
                                    """
                                    Global summary health
                                    
                                    .. attribute:: is_retry_db_empty
                                    
                                    	Is the retry db empty?
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.Health, self).__init__()

                                        self.yang_name = "health"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('is_retry_db_empty', (YLeaf(YType.boolean, 'is-retry-db-empty'), ['bool'])),
                                        ])
                                        self.is_retry_db_empty = None
                                        self._segment_path = lambda: "health"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Global.Summary.Protos.Proto.Summary_.Health, ['is_retry_db_empty'], name, value)


                class ObjectHistory(Entity):
                    """
                    Object History
                    
                    .. attribute:: obj_history_protos
                    
                    	Proto Table
                    	**type**\:  :py:class:`ObjHistoryProtos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Fib.Nodes.Node.Global.ObjectHistory, self).__init__()

                        self.yang_name = "object-history"
                        self.yang_parent_name = "global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("obj-history-protos", ("obj_history_protos", Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos))])
                        self._leafs = OrderedDict()

                        self.obj_history_protos = Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos()
                        self.obj_history_protos.parent = self
                        self._children_name_map["obj_history_protos"] = "obj-history-protos"
                        self._segment_path = lambda: "object-history"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Fib.Nodes.Node.Global.ObjectHistory, [], name, value)


                    class ObjHistoryProtos(Entity):
                        """
                        Proto Table
                        
                        .. attribute:: obj_history_proto
                        
                        	Protocol Table entry
                        	**type**\: list of  		 :py:class:`ObjHistoryProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos, self).__init__()

                            self.yang_name = "obj-history-protos"
                            self.yang_parent_name = "object-history"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("obj-history-proto", ("obj_history_proto", Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto))])
                            self._leafs = OrderedDict()

                            self.obj_history_proto = YList(self)
                            self._segment_path = lambda: "obj-history-protos"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos, [], name, value)


                        class ObjHistoryProto(Entity):
                            """
                            Protocol Table entry
                            
                            .. attribute:: protocol_name  (key)
                            
                            	Protocol Name
                            	**type**\:  :py:class:`FibafiProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibafiProto>`
                            
                            .. attribute:: base_object
                            
                            	Base object
                            	**type**\:  :py:class:`BaseObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto.BaseObject>`
                            
                            .. attribute:: object_history
                            
                            	Obj History
                            	**type**\:  :py:class:`ObjectHistory_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto.ObjectHistory_>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto, self).__init__()

                                self.yang_name = "obj-history-proto"
                                self.yang_parent_name = "obj-history-protos"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['protocol_name']
                                self._child_classes = OrderedDict([("base-object", ("base_object", Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto.BaseObject)), ("object-history", ("object_history", Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto.ObjectHistory_))])
                                self._leafs = OrderedDict([
                                    ('protocol_name', (YLeaf(YType.enumeration, 'protocol-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibafiProto', '')])),
                                ])
                                self.protocol_name = None

                                self.base_object = Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto.BaseObject()
                                self.base_object.parent = self
                                self._children_name_map["base_object"] = "base-object"

                                self.object_history = Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto.ObjectHistory_()
                                self.object_history.parent = self
                                self._children_name_map["object_history"] = "object-history"
                                self._segment_path = lambda: "obj-history-proto" + "[protocol-name='" + str(self.protocol_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto, ['protocol_name'], name, value)


                            class BaseObject(Entity):
                                """
                                Base object
                                
                                .. attribute:: protocol
                                
                                	protocol
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto.BaseObject, self).__init__()

                                    self.yang_name = "base-object"
                                    self.yang_parent_name = "obj-history-proto"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('protocol', (YLeaf(YType.uint32, 'protocol'), ['int'])),
                                    ])
                                    self.protocol = None
                                    self._segment_path = lambda: "base-object"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto.BaseObject, ['protocol'], name, value)


                            class ObjectHistory_(Entity):
                                """
                                Obj History
                                
                                .. attribute:: count
                                
                                	Placeholder for obj history counts
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto.ObjectHistory_, self).__init__()

                                    self.yang_name = "object-history"
                                    self.yang_parent_name = "obj-history-proto"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                    ])
                                    self.count = None
                                    self._segment_path = lambda: "object-history"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Global.ObjectHistory.ObjHistoryProtos.ObjHistoryProto.ObjectHistory_, ['count'], name, value)


            class Protocols(Entity):
                """
                Protocol table
                
                .. attribute:: protocol
                
                	Protocol table entry
                	**type**\: list of  		 :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol>`
                
                

                """

                _prefix = 'fib-common-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Fib.Nodes.Node.Protocols, self).__init__()

                    self.yang_name = "protocols"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("protocol", ("protocol", Fib.Nodes.Node.Protocols.Protocol))])
                    self._leafs = OrderedDict()

                    self.protocol = YList(self)
                    self._segment_path = lambda: "protocols"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Fib.Nodes.Node.Protocols, [], name, value)


                class Protocol(Entity):
                    """
                    Protocol table entry
                    
                    .. attribute:: protocol_name  (key)
                    
                    	Protocol Name 
                    	**type**\:  :py:class:`FibProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibProtocol>`
                    
                    .. attribute:: issu_state
                    
                    	CEF ISSU State
                    	**type**\:  :py:class:`IssuState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.IssuState>`
                    
                    .. attribute:: resource
                    
                    	Resource information
                    	**type**\:  :py:class:`Resource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Resource>`
                    
                    .. attribute:: fib_summaries
                    
                    	Summary for FIB tables
                    	**type**\:  :py:class:`FibSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FibSummaries>`
                    
                    .. attribute:: external_summary_all
                    
                    	Summary for all external clients
                    	**type**\:  :py:class:`ExternalSummaryAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll>`
                    
                    .. attribute:: frr_log
                    
                    	Table of Fast Reroute activation logs
                    	**type**\:  :py:class:`FrrLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FrrLog>`
                    
                    .. attribute:: vrfs
                    
                    	VRF table
                    	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs>`
                    
                    .. attribute:: exact_routes
                    
                    	Exact Route Table
                    	**type**\:  :py:class:`ExactRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes>`
                    
                    .. attribute:: protocol_global
                    
                    	FIB ipv6 global information
                    	**type**\:  :py:class:`ProtocolGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal>`
                    
                    .. attribute:: nh_ids
                    
                    	NHIdTable is accessed by two keys; {NHId} and/or {NHInterface,NHAddress
                    	**type**\:  :py:class:`NhIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.NhIds>`
                    
                    .. attribute:: external_client_summaries
                    
                    	External Client Summary Table
                    	**type**\:  :py:class:`ExternalClientSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries>`
                    
                    .. attribute:: misc
                    
                    	CEF misc hidden data
                    	**type**\:  :py:class:`Misc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc>`
                    
                    .. attribute:: local_label
                    
                    	Local label
                    	**type**\:  :py:class:`LocalLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.LocalLabel>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Fib.Nodes.Node.Protocols.Protocol, self).__init__()

                        self.yang_name = "protocol"
                        self.yang_parent_name = "protocols"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['protocol_name']
                        self._child_classes = OrderedDict([("issu-state", ("issu_state", Fib.Nodes.Node.Protocols.Protocol.IssuState)), ("resource", ("resource", Fib.Nodes.Node.Protocols.Protocol.Resource)), ("fib-summaries", ("fib_summaries", Fib.Nodes.Node.Protocols.Protocol.FibSummaries)), ("external-summary-all", ("external_summary_all", Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll)), ("frr-log", ("frr_log", Fib.Nodes.Node.Protocols.Protocol.FrrLog)), ("vrfs", ("vrfs", Fib.Nodes.Node.Protocols.Protocol.Vrfs)), ("exact-routes", ("exact_routes", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes)), ("protocol-global", ("protocol_global", Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal)), ("nh-ids", ("nh_ids", Fib.Nodes.Node.Protocols.Protocol.NhIds)), ("external-client-summaries", ("external_client_summaries", Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries)), ("misc", ("misc", Fib.Nodes.Node.Protocols.Protocol.Misc)), ("local-label", ("local_label", Fib.Nodes.Node.Protocols.Protocol.LocalLabel))])
                        self._leafs = OrderedDict([
                            ('protocol_name', (YLeaf(YType.enumeration, 'protocol-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibProtocol', '')])),
                        ])
                        self.protocol_name = None

                        self.issu_state = Fib.Nodes.Node.Protocols.Protocol.IssuState()
                        self.issu_state.parent = self
                        self._children_name_map["issu_state"] = "issu-state"

                        self.resource = Fib.Nodes.Node.Protocols.Protocol.Resource()
                        self.resource.parent = self
                        self._children_name_map["resource"] = "resource"

                        self.fib_summaries = Fib.Nodes.Node.Protocols.Protocol.FibSummaries()
                        self.fib_summaries.parent = self
                        self._children_name_map["fib_summaries"] = "fib-summaries"

                        self.external_summary_all = Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll()
                        self.external_summary_all.parent = self
                        self._children_name_map["external_summary_all"] = "external-summary-all"

                        self.frr_log = Fib.Nodes.Node.Protocols.Protocol.FrrLog()
                        self.frr_log.parent = self
                        self._children_name_map["frr_log"] = "frr-log"

                        self.vrfs = Fib.Nodes.Node.Protocols.Protocol.Vrfs()
                        self.vrfs.parent = self
                        self._children_name_map["vrfs"] = "vrfs"

                        self.exact_routes = Fib.Nodes.Node.Protocols.Protocol.ExactRoutes()
                        self.exact_routes.parent = self
                        self._children_name_map["exact_routes"] = "exact-routes"

                        self.protocol_global = Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal()
                        self.protocol_global.parent = self
                        self._children_name_map["protocol_global"] = "protocol-global"

                        self.nh_ids = Fib.Nodes.Node.Protocols.Protocol.NhIds()
                        self.nh_ids.parent = self
                        self._children_name_map["nh_ids"] = "nh-ids"

                        self.external_client_summaries = Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries()
                        self.external_client_summaries.parent = self
                        self._children_name_map["external_client_summaries"] = "external-client-summaries"

                        self.misc = Fib.Nodes.Node.Protocols.Protocol.Misc()
                        self.misc.parent = self
                        self._children_name_map["misc"] = "misc"

                        self.local_label = Fib.Nodes.Node.Protocols.Protocol.LocalLabel()
                        self.local_label.parent = self
                        self._children_name_map["local_label"] = "local-label"
                        self._segment_path = lambda: "protocol" + "[protocol-name='" + str(self.protocol_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol, ['protocol_name'], name, value)


                    class IssuState(Entity):
                        """
                        CEF ISSU State
                        
                        .. attribute:: imdr_support
                        
                        	IMDR supported
                        	**type**\: bool
                        
                        .. attribute:: slc_support
                        
                        	SLC supported
                        	**type**\: bool
                        
                        .. attribute:: fis_issu_restart
                        
                        	ISSU restart
                        	**type**\: bool
                        
                        .. attribute:: imdr_eoc_implicit
                        
                        	IMDR End\-of\-config implicit
                        	**type**\: bool
                        
                        .. attribute:: slc_eoc_implicit
                        
                        	SLC End\-of\-config implicit
                        	**type**\: bool
                        
                        .. attribute:: eoc_received_imdr_time_stamp
                        
                        	End\-of\-config received from IMDR timestamp
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: eoc_received_slc_time_stamp
                        
                        	End\-of\-config received from SLC timestamp
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: eod_received_im_time_stamp
                        
                        	End\-of\-download received from IM timestamp
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: eod_sent_imdr_time_stamp
                        
                        	End\-of\-download send to IMDR timestamp
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: eod_sent_slc_time_stamp
                        
                        	End\-of\-download send to SLC timestamp
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: fis_issu_error_ts
                        
                        	ISSU error sent to ISSUMGR timetstamp
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: fis_proto_state
                        
                        	IMDR state for the protocols
                        	**type**\: list of  		 :py:class:`FisProtoState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.IssuState.FisProtoState>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Protocols.Protocol.IssuState, self).__init__()

                            self.yang_name = "issu-state"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fis-proto-state", ("fis_proto_state", Fib.Nodes.Node.Protocols.Protocol.IssuState.FisProtoState))])
                            self._leafs = OrderedDict([
                                ('imdr_support', (YLeaf(YType.boolean, 'imdr-support'), ['bool'])),
                                ('slc_support', (YLeaf(YType.boolean, 'slc-support'), ['bool'])),
                                ('fis_issu_restart', (YLeaf(YType.boolean, 'fis-issu-restart'), ['bool'])),
                                ('imdr_eoc_implicit', (YLeaf(YType.boolean, 'imdr-eoc-implicit'), ['bool'])),
                                ('slc_eoc_implicit', (YLeaf(YType.boolean, 'slc-eoc-implicit'), ['bool'])),
                                ('eoc_received_imdr_time_stamp', (YLeaf(YType.str, 'eoc-received-imdr-time-stamp'), ['str'])),
                                ('eoc_received_slc_time_stamp', (YLeaf(YType.str, 'eoc-received-slc-time-stamp'), ['str'])),
                                ('eod_received_im_time_stamp', (YLeaf(YType.str, 'eod-received-im-time-stamp'), ['str'])),
                                ('eod_sent_imdr_time_stamp', (YLeaf(YType.str, 'eod-sent-imdr-time-stamp'), ['str'])),
                                ('eod_sent_slc_time_stamp', (YLeaf(YType.str, 'eod-sent-slc-time-stamp'), ['str'])),
                                ('fis_issu_error_ts', (YLeaf(YType.uint64, 'fis-issu-error-ts'), ['int'])),
                            ])
                            self.imdr_support = None
                            self.slc_support = None
                            self.fis_issu_restart = None
                            self.imdr_eoc_implicit = None
                            self.slc_eoc_implicit = None
                            self.eoc_received_imdr_time_stamp = None
                            self.eoc_received_slc_time_stamp = None
                            self.eod_received_im_time_stamp = None
                            self.eod_sent_imdr_time_stamp = None
                            self.eod_sent_slc_time_stamp = None
                            self.fis_issu_error_ts = None

                            self.fis_proto_state = YList(self)
                            self._segment_path = lambda: "issu-state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.IssuState, ['imdr_support', 'slc_support', 'fis_issu_restart', 'imdr_eoc_implicit', 'slc_eoc_implicit', 'eoc_received_imdr_time_stamp', 'eoc_received_slc_time_stamp', 'eod_received_im_time_stamp', 'eod_sent_imdr_time_stamp', 'eod_sent_slc_time_stamp', 'fis_issu_error_ts'], name, value)


                        class FisProtoState(Entity):
                            """
                            IMDR state for the protocols
                            
                            .. attribute:: protocol_name
                            
                            	Protocol name
                            	**type**\: str
                            
                            	**length:** 0..6
                            
                            .. attribute:: aib_eod_time_stamp
                            
                            	AIB EODTimeStamp
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rsi_eod_valid
                            
                            	RSI EOD expected/valid
                            	**type**\: bool
                            
                            .. attribute:: rsi_eod_time_stamp
                            
                            	RSI EOD received timestamp
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: lsd_eod_valid
                            
                            	LSD EOD expected/valid
                            	**type**\: bool
                            
                            .. attribute:: lsd_eod_time_stamp
                            
                            	LSD EOD received timestamp
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: lmrib_eod_valid
                            
                            	LMRIB EOD expected/valid
                            	**type**\: bool
                            
                            .. attribute:: lmrib_eod_time_stamp
                            
                            	LMRIB EOD received timestamp
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: rib_info_valid
                            
                            	RIB table info valid
                            	**type**\: bool
                            
                            .. attribute:: bcdl_tables
                            
                            	Number of BCDL tables
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: converged_tables
                            
                            	Number of tables converged
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_tables_converged_time_stamp
                            
                            	All RIB tables converged timestamp
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: protocol_eod_valid
                            
                            	Protocol EOD expected/valid
                            	**type**\: bool
                            
                            .. attribute:: protocol_eod_time_stamp
                            
                            	Protocol EOD sent timestamp
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.IssuState.FisProtoState, self).__init__()

                                self.yang_name = "fis-proto-state"
                                self.yang_parent_name = "issu-state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                    ('aib_eod_time_stamp', (YLeaf(YType.str, 'aib-eod-time-stamp'), ['str'])),
                                    ('rsi_eod_valid', (YLeaf(YType.boolean, 'rsi-eod-valid'), ['bool'])),
                                    ('rsi_eod_time_stamp', (YLeaf(YType.str, 'rsi-eod-time-stamp'), ['str'])),
                                    ('lsd_eod_valid', (YLeaf(YType.boolean, 'lsd-eod-valid'), ['bool'])),
                                    ('lsd_eod_time_stamp', (YLeaf(YType.str, 'lsd-eod-time-stamp'), ['str'])),
                                    ('lmrib_eod_valid', (YLeaf(YType.boolean, 'lmrib-eod-valid'), ['bool'])),
                                    ('lmrib_eod_time_stamp', (YLeaf(YType.str, 'lmrib-eod-time-stamp'), ['str'])),
                                    ('rib_info_valid', (YLeaf(YType.boolean, 'rib-info-valid'), ['bool'])),
                                    ('bcdl_tables', (YLeaf(YType.uint32, 'bcdl-tables'), ['int'])),
                                    ('converged_tables', (YLeaf(YType.uint32, 'converged-tables'), ['int'])),
                                    ('rib_tables_converged_time_stamp', (YLeaf(YType.str, 'rib-tables-converged-time-stamp'), ['str'])),
                                    ('protocol_eod_valid', (YLeaf(YType.boolean, 'protocol-eod-valid'), ['bool'])),
                                    ('protocol_eod_time_stamp', (YLeaf(YType.str, 'protocol-eod-time-stamp'), ['str'])),
                                ])
                                self.protocol_name = None
                                self.aib_eod_time_stamp = None
                                self.rsi_eod_valid = None
                                self.rsi_eod_time_stamp = None
                                self.lsd_eod_valid = None
                                self.lsd_eod_time_stamp = None
                                self.lmrib_eod_valid = None
                                self.lmrib_eod_time_stamp = None
                                self.rib_info_valid = None
                                self.bcdl_tables = None
                                self.converged_tables = None
                                self.rib_tables_converged_time_stamp = None
                                self.protocol_eod_valid = None
                                self.protocol_eod_time_stamp = None
                                self._segment_path = lambda: "fis-proto-state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.IssuState.FisProtoState, ['protocol_name', 'aib_eod_time_stamp', 'rsi_eod_valid', 'rsi_eod_time_stamp', 'lsd_eod_valid', 'lsd_eod_time_stamp', 'lmrib_eod_valid', 'lmrib_eod_time_stamp', 'rib_info_valid', 'bcdl_tables', 'converged_tables', 'rib_tables_converged_time_stamp', 'protocol_eod_valid', 'protocol_eod_time_stamp'], name, value)


                    class Resource(Entity):
                        """
                        Resource information
                        
                        .. attribute:: resource_detail_info
                        
                        	Detailed info
                        	**type**\:  :py:class:`ResourceDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceDetailInfo>`
                        
                        .. attribute:: resource_hardware_ingress_info
                        
                        	Detailed info with ingress hardware info
                        	**type**\:  :py:class:`ResourceHardwareIngressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareIngressInfo>`
                        
                        .. attribute:: resource_hardware_egress_info
                        
                        	Detailed info with egress hardware info
                        	**type**\:  :py:class:`ResourceHardwareEgressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareEgressInfo>`
                        
                        .. attribute:: resource_summary_info
                        
                        	Summary info
                        	**type**\:  :py:class:`ResourceSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceSummaryInfo>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Protocols.Protocol.Resource, self).__init__()

                            self.yang_name = "resource"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("resource-detail-info", ("resource_detail_info", Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceDetailInfo)), ("resource-hardware-ingress-info", ("resource_hardware_ingress_info", Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareIngressInfo)), ("resource-hardware-egress-info", ("resource_hardware_egress_info", Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareEgressInfo)), ("resource-summary-info", ("resource_summary_info", Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceSummaryInfo))])
                            self._leafs = OrderedDict()

                            self.resource_detail_info = Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceDetailInfo()
                            self.resource_detail_info.parent = self
                            self._children_name_map["resource_detail_info"] = "resource-detail-info"

                            self.resource_hardware_ingress_info = Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareIngressInfo()
                            self.resource_hardware_ingress_info.parent = self
                            self._children_name_map["resource_hardware_ingress_info"] = "resource-hardware-ingress-info"

                            self.resource_hardware_egress_info = Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareEgressInfo()
                            self.resource_hardware_egress_info.parent = self
                            self._children_name_map["resource_hardware_egress_info"] = "resource-hardware-egress-info"

                            self.resource_summary_info = Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceSummaryInfo()
                            self.resource_summary_info.parent = self
                            self._children_name_map["resource_summary_info"] = "resource-summary-info"
                            self._segment_path = lambda: "resource"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Resource, [], name, value)


                        class ResourceDetailInfo(Entity):
                            """
                            Detailed info
                            
                            .. attribute:: sr_curr_mode
                            
                            	Current overall oor mode
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sr_hwrsrc_info
                            
                            	Opaque hardware rsrc state info
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: sr_shmwin_oor_count
                            
                            	sr shmwin oor count
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: sr_hw_oor_count
                            
                            	sr hw oor count
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: sr_in_oor_ts
                            
                            	sr in oor ts
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sr_out_oor_ts
                            
                            	sr out oor ts
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sr_hwrsrc_mode
                            
                            	Hardware resource mode
                            	**type**\: list of  		 :py:class:`SrHwrsrcMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceDetailInfo.SrHwrsrcMode>`
                            
                            .. attribute:: sr_shm_state
                            
                            	Current status of shared memories
                            	**type**\: list of  		 :py:class:`SrShmState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceDetailInfo.SrShmState>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceDetailInfo, self).__init__()

                                self.yang_name = "resource-detail-info"
                                self.yang_parent_name = "resource"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sr-hwrsrc-mode", ("sr_hwrsrc_mode", Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceDetailInfo.SrHwrsrcMode)), ("sr-shm-state", ("sr_shm_state", Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceDetailInfo.SrShmState))])
                                self._leafs = OrderedDict([
                                    ('sr_curr_mode', (YLeaf(YType.uint32, 'sr-curr-mode'), ['int'])),
                                    ('sr_hwrsrc_info', (YLeaf(YType.str, 'sr-hwrsrc-info'), ['str'])),
                                    ('sr_shmwin_oor_count', (YLeaf(YType.uint8, 'sr-shmwin-oor-count'), ['int'])),
                                    ('sr_hw_oor_count', (YLeaf(YType.uint8, 'sr-hw-oor-count'), ['int'])),
                                    ('sr_in_oor_ts', (YLeaf(YType.uint64, 'sr-in-oor-ts'), ['int'])),
                                    ('sr_out_oor_ts', (YLeaf(YType.uint64, 'sr-out-oor-ts'), ['int'])),
                                ])
                                self.sr_curr_mode = None
                                self.sr_hwrsrc_info = None
                                self.sr_shmwin_oor_count = None
                                self.sr_hw_oor_count = None
                                self.sr_in_oor_ts = None
                                self.sr_out_oor_ts = None

                                self.sr_hwrsrc_mode = YList(self)
                                self.sr_shm_state = YList(self)
                                self._segment_path = lambda: "resource-detail-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceDetailInfo, ['sr_curr_mode', 'sr_hwrsrc_info', 'sr_shmwin_oor_count', 'sr_hw_oor_count', 'sr_in_oor_ts', 'sr_out_oor_ts'], name, value)


                            class SrHwrsrcMode(Entity):
                                """
                                Hardware resource mode
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceDetailInfo.SrHwrsrcMode, self).__init__()

                                    self.yang_name = "sr-hwrsrc-mode"
                                    self.yang_parent_name = "resource-detail-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "sr-hwrsrc-mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceDetailInfo.SrHwrsrcMode, ['entry'], name, value)


                            class SrShmState(Entity):
                                """
                                Current status of shared memories
                                
                                .. attribute:: srs_curr_mode
                                
                                	OOR mode for this shared memory window
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srs_avg_avail
                                
                                	Average number of bytes available
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: srs_max_avail
                                
                                	Maximum bytes available
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceDetailInfo.SrShmState, self).__init__()

                                    self.yang_name = "sr-shm-state"
                                    self.yang_parent_name = "resource-detail-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('srs_curr_mode', (YLeaf(YType.uint32, 'srs-curr-mode'), ['int'])),
                                        ('srs_avg_avail', (YLeaf(YType.uint64, 'srs-avg-avail'), ['int'])),
                                        ('srs_max_avail', (YLeaf(YType.uint64, 'srs-max-avail'), ['int'])),
                                    ])
                                    self.srs_curr_mode = None
                                    self.srs_avg_avail = None
                                    self.srs_max_avail = None
                                    self._segment_path = lambda: "sr-shm-state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceDetailInfo.SrShmState, ['srs_curr_mode', 'srs_avg_avail', 'srs_max_avail'], name, value)


                        class ResourceHardwareIngressInfo(Entity):
                            """
                            Detailed info with ingress hardware info
                            
                            .. attribute:: sr_curr_mode
                            
                            	Current overall oor mode
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sr_hwrsrc_info
                            
                            	Opaque hardware rsrc state info
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: sr_shmwin_oor_count
                            
                            	sr shmwin oor count
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: sr_hw_oor_count
                            
                            	sr hw oor count
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: sr_in_oor_ts
                            
                            	sr in oor ts
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sr_out_oor_ts
                            
                            	sr out oor ts
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sr_hwrsrc_mode
                            
                            	Hardware resource mode
                            	**type**\: list of  		 :py:class:`SrHwrsrcMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareIngressInfo.SrHwrsrcMode>`
                            
                            .. attribute:: sr_shm_state
                            
                            	Current status of shared memories
                            	**type**\: list of  		 :py:class:`SrShmState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareIngressInfo.SrShmState>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareIngressInfo, self).__init__()

                                self.yang_name = "resource-hardware-ingress-info"
                                self.yang_parent_name = "resource"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sr-hwrsrc-mode", ("sr_hwrsrc_mode", Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareIngressInfo.SrHwrsrcMode)), ("sr-shm-state", ("sr_shm_state", Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareIngressInfo.SrShmState))])
                                self._leafs = OrderedDict([
                                    ('sr_curr_mode', (YLeaf(YType.uint32, 'sr-curr-mode'), ['int'])),
                                    ('sr_hwrsrc_info', (YLeaf(YType.str, 'sr-hwrsrc-info'), ['str'])),
                                    ('sr_shmwin_oor_count', (YLeaf(YType.uint8, 'sr-shmwin-oor-count'), ['int'])),
                                    ('sr_hw_oor_count', (YLeaf(YType.uint8, 'sr-hw-oor-count'), ['int'])),
                                    ('sr_in_oor_ts', (YLeaf(YType.uint64, 'sr-in-oor-ts'), ['int'])),
                                    ('sr_out_oor_ts', (YLeaf(YType.uint64, 'sr-out-oor-ts'), ['int'])),
                                ])
                                self.sr_curr_mode = None
                                self.sr_hwrsrc_info = None
                                self.sr_shmwin_oor_count = None
                                self.sr_hw_oor_count = None
                                self.sr_in_oor_ts = None
                                self.sr_out_oor_ts = None

                                self.sr_hwrsrc_mode = YList(self)
                                self.sr_shm_state = YList(self)
                                self._segment_path = lambda: "resource-hardware-ingress-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareIngressInfo, ['sr_curr_mode', 'sr_hwrsrc_info', 'sr_shmwin_oor_count', 'sr_hw_oor_count', 'sr_in_oor_ts', 'sr_out_oor_ts'], name, value)


                            class SrHwrsrcMode(Entity):
                                """
                                Hardware resource mode
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareIngressInfo.SrHwrsrcMode, self).__init__()

                                    self.yang_name = "sr-hwrsrc-mode"
                                    self.yang_parent_name = "resource-hardware-ingress-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "sr-hwrsrc-mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareIngressInfo.SrHwrsrcMode, ['entry'], name, value)


                            class SrShmState(Entity):
                                """
                                Current status of shared memories
                                
                                .. attribute:: srs_curr_mode
                                
                                	OOR mode for this shared memory window
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srs_avg_avail
                                
                                	Average number of bytes available
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: srs_max_avail
                                
                                	Maximum bytes available
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareIngressInfo.SrShmState, self).__init__()

                                    self.yang_name = "sr-shm-state"
                                    self.yang_parent_name = "resource-hardware-ingress-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('srs_curr_mode', (YLeaf(YType.uint32, 'srs-curr-mode'), ['int'])),
                                        ('srs_avg_avail', (YLeaf(YType.uint64, 'srs-avg-avail'), ['int'])),
                                        ('srs_max_avail', (YLeaf(YType.uint64, 'srs-max-avail'), ['int'])),
                                    ])
                                    self.srs_curr_mode = None
                                    self.srs_avg_avail = None
                                    self.srs_max_avail = None
                                    self._segment_path = lambda: "sr-shm-state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareIngressInfo.SrShmState, ['srs_curr_mode', 'srs_avg_avail', 'srs_max_avail'], name, value)


                        class ResourceHardwareEgressInfo(Entity):
                            """
                            Detailed info with egress hardware info
                            
                            .. attribute:: sr_curr_mode
                            
                            	Current overall oor mode
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sr_hwrsrc_info
                            
                            	Opaque hardware rsrc state info
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: sr_shmwin_oor_count
                            
                            	sr shmwin oor count
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: sr_hw_oor_count
                            
                            	sr hw oor count
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: sr_in_oor_ts
                            
                            	sr in oor ts
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sr_out_oor_ts
                            
                            	sr out oor ts
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sr_hwrsrc_mode
                            
                            	Hardware resource mode
                            	**type**\: list of  		 :py:class:`SrHwrsrcMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareEgressInfo.SrHwrsrcMode>`
                            
                            .. attribute:: sr_shm_state
                            
                            	Current status of shared memories
                            	**type**\: list of  		 :py:class:`SrShmState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareEgressInfo.SrShmState>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareEgressInfo, self).__init__()

                                self.yang_name = "resource-hardware-egress-info"
                                self.yang_parent_name = "resource"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sr-hwrsrc-mode", ("sr_hwrsrc_mode", Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareEgressInfo.SrHwrsrcMode)), ("sr-shm-state", ("sr_shm_state", Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareEgressInfo.SrShmState))])
                                self._leafs = OrderedDict([
                                    ('sr_curr_mode', (YLeaf(YType.uint32, 'sr-curr-mode'), ['int'])),
                                    ('sr_hwrsrc_info', (YLeaf(YType.str, 'sr-hwrsrc-info'), ['str'])),
                                    ('sr_shmwin_oor_count', (YLeaf(YType.uint8, 'sr-shmwin-oor-count'), ['int'])),
                                    ('sr_hw_oor_count', (YLeaf(YType.uint8, 'sr-hw-oor-count'), ['int'])),
                                    ('sr_in_oor_ts', (YLeaf(YType.uint64, 'sr-in-oor-ts'), ['int'])),
                                    ('sr_out_oor_ts', (YLeaf(YType.uint64, 'sr-out-oor-ts'), ['int'])),
                                ])
                                self.sr_curr_mode = None
                                self.sr_hwrsrc_info = None
                                self.sr_shmwin_oor_count = None
                                self.sr_hw_oor_count = None
                                self.sr_in_oor_ts = None
                                self.sr_out_oor_ts = None

                                self.sr_hwrsrc_mode = YList(self)
                                self.sr_shm_state = YList(self)
                                self._segment_path = lambda: "resource-hardware-egress-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareEgressInfo, ['sr_curr_mode', 'sr_hwrsrc_info', 'sr_shmwin_oor_count', 'sr_hw_oor_count', 'sr_in_oor_ts', 'sr_out_oor_ts'], name, value)


                            class SrHwrsrcMode(Entity):
                                """
                                Hardware resource mode
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareEgressInfo.SrHwrsrcMode, self).__init__()

                                    self.yang_name = "sr-hwrsrc-mode"
                                    self.yang_parent_name = "resource-hardware-egress-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "sr-hwrsrc-mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareEgressInfo.SrHwrsrcMode, ['entry'], name, value)


                            class SrShmState(Entity):
                                """
                                Current status of shared memories
                                
                                .. attribute:: srs_curr_mode
                                
                                	OOR mode for this shared memory window
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srs_avg_avail
                                
                                	Average number of bytes available
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: srs_max_avail
                                
                                	Maximum bytes available
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareEgressInfo.SrShmState, self).__init__()

                                    self.yang_name = "sr-shm-state"
                                    self.yang_parent_name = "resource-hardware-egress-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('srs_curr_mode', (YLeaf(YType.uint32, 'srs-curr-mode'), ['int'])),
                                        ('srs_avg_avail', (YLeaf(YType.uint64, 'srs-avg-avail'), ['int'])),
                                        ('srs_max_avail', (YLeaf(YType.uint64, 'srs-max-avail'), ['int'])),
                                    ])
                                    self.srs_curr_mode = None
                                    self.srs_avg_avail = None
                                    self.srs_max_avail = None
                                    self._segment_path = lambda: "sr-shm-state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceHardwareEgressInfo.SrShmState, ['srs_curr_mode', 'srs_avg_avail', 'srs_max_avail'], name, value)


                        class ResourceSummaryInfo(Entity):
                            """
                            Summary info
                            
                            .. attribute:: sr_curr_mode
                            
                            	Current overall oor mode
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sr_hwrsrc_info
                            
                            	Opaque hardware rsrc state info
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: sr_shmwin_oor_count
                            
                            	sr shmwin oor count
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: sr_hw_oor_count
                            
                            	sr hw oor count
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: sr_in_oor_ts
                            
                            	sr in oor ts
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sr_out_oor_ts
                            
                            	sr out oor ts
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sr_hwrsrc_mode
                            
                            	Hardware resource mode
                            	**type**\: list of  		 :py:class:`SrHwrsrcMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceSummaryInfo.SrHwrsrcMode>`
                            
                            .. attribute:: sr_shm_state
                            
                            	Current status of shared memories
                            	**type**\: list of  		 :py:class:`SrShmState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceSummaryInfo.SrShmState>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceSummaryInfo, self).__init__()

                                self.yang_name = "resource-summary-info"
                                self.yang_parent_name = "resource"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sr-hwrsrc-mode", ("sr_hwrsrc_mode", Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceSummaryInfo.SrHwrsrcMode)), ("sr-shm-state", ("sr_shm_state", Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceSummaryInfo.SrShmState))])
                                self._leafs = OrderedDict([
                                    ('sr_curr_mode', (YLeaf(YType.uint32, 'sr-curr-mode'), ['int'])),
                                    ('sr_hwrsrc_info', (YLeaf(YType.str, 'sr-hwrsrc-info'), ['str'])),
                                    ('sr_shmwin_oor_count', (YLeaf(YType.uint8, 'sr-shmwin-oor-count'), ['int'])),
                                    ('sr_hw_oor_count', (YLeaf(YType.uint8, 'sr-hw-oor-count'), ['int'])),
                                    ('sr_in_oor_ts', (YLeaf(YType.uint64, 'sr-in-oor-ts'), ['int'])),
                                    ('sr_out_oor_ts', (YLeaf(YType.uint64, 'sr-out-oor-ts'), ['int'])),
                                ])
                                self.sr_curr_mode = None
                                self.sr_hwrsrc_info = None
                                self.sr_shmwin_oor_count = None
                                self.sr_hw_oor_count = None
                                self.sr_in_oor_ts = None
                                self.sr_out_oor_ts = None

                                self.sr_hwrsrc_mode = YList(self)
                                self.sr_shm_state = YList(self)
                                self._segment_path = lambda: "resource-summary-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceSummaryInfo, ['sr_curr_mode', 'sr_hwrsrc_info', 'sr_shmwin_oor_count', 'sr_hw_oor_count', 'sr_in_oor_ts', 'sr_out_oor_ts'], name, value)


                            class SrHwrsrcMode(Entity):
                                """
                                Hardware resource mode
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceSummaryInfo.SrHwrsrcMode, self).__init__()

                                    self.yang_name = "sr-hwrsrc-mode"
                                    self.yang_parent_name = "resource-summary-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "sr-hwrsrc-mode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceSummaryInfo.SrHwrsrcMode, ['entry'], name, value)


                            class SrShmState(Entity):
                                """
                                Current status of shared memories
                                
                                .. attribute:: srs_curr_mode
                                
                                	OOR mode for this shared memory window
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srs_avg_avail
                                
                                	Average number of bytes available
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: srs_max_avail
                                
                                	Maximum bytes available
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceSummaryInfo.SrShmState, self).__init__()

                                    self.yang_name = "sr-shm-state"
                                    self.yang_parent_name = "resource-summary-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('srs_curr_mode', (YLeaf(YType.uint32, 'srs-curr-mode'), ['int'])),
                                        ('srs_avg_avail', (YLeaf(YType.uint64, 'srs-avg-avail'), ['int'])),
                                        ('srs_max_avail', (YLeaf(YType.uint64, 'srs-max-avail'), ['int'])),
                                    ])
                                    self.srs_curr_mode = None
                                    self.srs_avg_avail = None
                                    self.srs_max_avail = None
                                    self._segment_path = lambda: "sr-shm-state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Resource.ResourceSummaryInfo.SrShmState, ['srs_curr_mode', 'srs_avg_avail', 'srs_max_avail'], name, value)


                    class FibSummaries(Entity):
                        """
                        Summary for FIB tables
                        
                        .. attribute:: fib_summary
                        
                        	Summary for the requested fib table
                        	**type**\: list of  		 :py:class:`FibSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Protocols.Protocol.FibSummaries, self).__init__()

                            self.yang_name = "fib-summaries"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fib-summary", ("fib_summary", Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary))])
                            self._leafs = OrderedDict()

                            self.fib_summary = YList(self)
                            self._segment_path = lambda: "fib-summaries"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FibSummaries, [], name, value)


                        class FibSummary(Entity):
                            """
                            Summary for the requested fib table
                            
                            .. attribute:: vrf_name
                            
                            	VRF Name
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: table_id
                            
                            	FIB table id
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{1,8}
                            
                            .. attribute:: exclusive_load_sharing_element
                            
                            	Exclusive load sharing element
                            	**type**\:  :py:class:`ExclusiveLoadSharingElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.ExclusiveLoadSharingElement>`
                            
                            .. attribute:: shared_load_sharing_element
                            
                            	Shared load sharing element
                            	**type**\:  :py:class:`SharedLoadSharingElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.SharedLoadSharingElement>`
                            
                            .. attribute:: cross_shared_load_sharing_element
                            
                            	Cross\-table shared load sharing element
                            	**type**\:  :py:class:`CrossSharedLoadSharingElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.CrossSharedLoadSharingElement>`
                            
                            .. attribute:: encap_shared_load_sharing_element
                            
                            	Encap\-shared load sharing element
                            	**type**\:  :py:class:`EncapSharedLoadSharingElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.EncapSharedLoadSharingElement>`
                            
                            .. attribute:: prefix_masklen_distribution
                            
                            	Distribution of prefix mask lengths
                            	**type**\:  :py:class:`PrefixMasklenDistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution>`
                            
                            .. attribute:: prefix
                            
                            	The router\-id
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: ss_tbl_id
                            
                            	Table Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ss_tbl_id_ptr
                            
                            	Table Id Ptr
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ss_vrf_id
                            
                            	Virtual routing forwarding instance Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ss_vr_id
                            
                            	Virtual router instance Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: load_balancing
                            
                            	LBA configuration state
                            	**type**\:  :py:class:`SsLbaState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.SsLbaState>`
                            
                            .. attribute:: forwarding_elements
                            
                            	Number of forwarding elements linked to the table
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: routes
                            
                            	Number of routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prefix_in_place_modifications
                            
                            	Number of inplace modifications
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: stale_prefix_deletes
                            
                            	Number of deleted stale leafs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: load_sharing_elements
                            
                            	Count of load sharing elements
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: load_sharing_references
                            
                            	Count of load sharing references
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: total_load_share_element_bytes
                            
                            	Total memory used by load sharing elements
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: leaves_used_bytes
                            
                            	Total memory used by leaves
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reresolve_entries
                            
                            	Number of reresolved entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: old_unresolve_entries
                            
                            	Number of old unresolved entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: new_unresolve_entries
                            
                            	Number of new unresolved entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: unresolve_entries
                            
                            	Number of total unresolved entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: cef_route_drops
                            
                            	Number of routes dropped by CEF
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: cef_version_mismatch_route_drops
                            
                            	the number of routes dropped due to version mismatch
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: delete_cache_num_entries
                            
                            	Number of entries in the route delete cache
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: existing_leaves_revisions
                            
                            	Number of entries present on addition
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fib_default_prefix
                            
                            	Default prefix
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fib_default_prefix_mask_length
                            
                            	Default prefix mask length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hops
                            
                            	Number of NHINFOS
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: incomplete_next_hops
                            
                            	Number of incomplete NHINFOS
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resolution_timer
                            
                            	IP CEF resolution timer in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: slow_process_timer
                            
                            	IP CEF slow processing time in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: max_resolution_timer
                            
                            	IP CEF max resolution time in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: imposition_prefixes
                            
                            	Number of prefixes with imposition LDI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_prefixes
                            
                            	Number of prefixes with extended path\-list
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: cefl_bl_recycled_routes
                            
                            	Number of routes updates with recycled label handled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldi_backwalks
                            
                            	pd backwalks on LDI modify with backup path
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ss_prot_route_count
                            
                            	Number of routes with FRR protection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lisp_eid_prefixes
                            
                            	Number of lisp eid prefixes associated with table
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lisp_eid_valid_prefixes
                            
                            	Number of lisp eid prefixes eligible for forwarding
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lisp_rloc_objects
                            
                            	Number of lisp rloc objects associated with table
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_sr_labels
                            
                            	Number of SR labels
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ss_vxlan_ltep_ifh
                            
                            	VXLAN local Interface handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: ss_drop_pl_count
                            
                            	Number of dropped pathlists
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary, self).__init__()

                                self.yang_name = "fib-summary"
                                self.yang_parent_name = "fib-summaries"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("exclusive-load-sharing-element", ("exclusive_load_sharing_element", Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.ExclusiveLoadSharingElement)), ("shared-load-sharing-element", ("shared_load_sharing_element", Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.SharedLoadSharingElement)), ("cross-shared-load-sharing-element", ("cross_shared_load_sharing_element", Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.CrossSharedLoadSharingElement)), ("encap-shared-load-sharing-element", ("encap_shared_load_sharing_element", Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.EncapSharedLoadSharingElement)), ("prefix-masklen-distribution", ("prefix_masklen_distribution", Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution))])
                                self._leafs = OrderedDict([
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('table_id', (YLeaf(YType.str, 'table-id'), ['str'])),
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('ss_tbl_id', (YLeaf(YType.uint32, 'ss-tbl-id'), ['int'])),
                                    ('ss_tbl_id_ptr', (YLeaf(YType.uint32, 'ss-tbl-id-ptr'), ['int'])),
                                    ('ss_vrf_id', (YLeaf(YType.uint32, 'ss-vrf-id'), ['int'])),
                                    ('ss_vr_id', (YLeaf(YType.uint32, 'ss-vr-id'), ['int'])),
                                    ('load_balancing', (YLeaf(YType.enumeration, 'load-balancing'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'SsLbaState', '')])),
                                    ('forwarding_elements', (YLeaf(YType.uint32, 'forwarding-elements'), ['int'])),
                                    ('routes', (YLeaf(YType.uint32, 'routes'), ['int'])),
                                    ('prefix_in_place_modifications', (YLeaf(YType.uint32, 'prefix-in-place-modifications'), ['int'])),
                                    ('stale_prefix_deletes', (YLeaf(YType.uint32, 'stale-prefix-deletes'), ['int'])),
                                    ('load_sharing_elements', (YLeaf(YType.uint32, 'load-sharing-elements'), ['int'])),
                                    ('load_sharing_references', (YLeaf(YType.uint64, 'load-sharing-references'), ['int'])),
                                    ('total_load_share_element_bytes', (YLeaf(YType.uint32, 'total-load-share-element-bytes'), ['int'])),
                                    ('leaves_used_bytes', (YLeaf(YType.uint32, 'leaves-used-bytes'), ['int'])),
                                    ('reresolve_entries', (YLeaf(YType.uint32, 'reresolve-entries'), ['int'])),
                                    ('old_unresolve_entries', (YLeaf(YType.uint32, 'old-unresolve-entries'), ['int'])),
                                    ('new_unresolve_entries', (YLeaf(YType.uint32, 'new-unresolve-entries'), ['int'])),
                                    ('unresolve_entries', (YLeaf(YType.uint32, 'unresolve-entries'), ['int'])),
                                    ('cef_route_drops', (YLeaf(YType.uint32, 'cef-route-drops'), ['int'])),
                                    ('cef_version_mismatch_route_drops', (YLeaf(YType.uint64, 'cef-version-mismatch-route-drops'), ['int'])),
                                    ('delete_cache_num_entries', (YLeaf(YType.uint32, 'delete-cache-num-entries'), ['int'])),
                                    ('existing_leaves_revisions', (YLeaf(YType.uint32, 'existing-leaves-revisions'), ['int'])),
                                    ('fib_default_prefix', (YLeaf(YType.uint32, 'fib-default-prefix'), ['int'])),
                                    ('fib_default_prefix_mask_length', (YLeaf(YType.uint32, 'fib-default-prefix-mask-length'), ['int'])),
                                    ('next_hops', (YLeaf(YType.uint32, 'next-hops'), ['int'])),
                                    ('incomplete_next_hops', (YLeaf(YType.uint32, 'incomplete-next-hops'), ['int'])),
                                    ('resolution_timer', (YLeaf(YType.uint32, 'resolution-timer'), ['int'])),
                                    ('slow_process_timer', (YLeaf(YType.uint32, 'slow-process-timer'), ['int'])),
                                    ('max_resolution_timer', (YLeaf(YType.uint32, 'max-resolution-timer'), ['int'])),
                                    ('imposition_prefixes', (YLeaf(YType.uint32, 'imposition-prefixes'), ['int'])),
                                    ('extended_prefixes', (YLeaf(YType.uint32, 'extended-prefixes'), ['int'])),
                                    ('cefl_bl_recycled_routes', (YLeaf(YType.uint32, 'cefl-bl-recycled-routes'), ['int'])),
                                    ('ldi_backwalks', (YLeaf(YType.uint32, 'ldi-backwalks'), ['int'])),
                                    ('ss_prot_route_count', (YLeaf(YType.uint32, 'ss-prot-route-count'), ['int'])),
                                    ('lisp_eid_prefixes', (YLeaf(YType.uint32, 'lisp-eid-prefixes'), ['int'])),
                                    ('lisp_eid_valid_prefixes', (YLeaf(YType.uint32, 'lisp-eid-valid-prefixes'), ['int'])),
                                    ('lisp_rloc_objects', (YLeaf(YType.uint32, 'lisp-rloc-objects'), ['int'])),
                                    ('number_of_sr_labels', (YLeaf(YType.uint32, 'number-of-sr-labels'), ['int'])),
                                    ('ss_vxlan_ltep_ifh', (YLeaf(YType.str, 'ss-vxlan-ltep-ifh'), ['str'])),
                                    ('ss_drop_pl_count', (YLeaf(YType.uint32, 'ss-drop-pl-count'), ['int'])),
                                ])
                                self.vrf_name = None
                                self.table_id = None
                                self.prefix = None
                                self.ss_tbl_id = None
                                self.ss_tbl_id_ptr = None
                                self.ss_vrf_id = None
                                self.ss_vr_id = None
                                self.load_balancing = None
                                self.forwarding_elements = None
                                self.routes = None
                                self.prefix_in_place_modifications = None
                                self.stale_prefix_deletes = None
                                self.load_sharing_elements = None
                                self.load_sharing_references = None
                                self.total_load_share_element_bytes = None
                                self.leaves_used_bytes = None
                                self.reresolve_entries = None
                                self.old_unresolve_entries = None
                                self.new_unresolve_entries = None
                                self.unresolve_entries = None
                                self.cef_route_drops = None
                                self.cef_version_mismatch_route_drops = None
                                self.delete_cache_num_entries = None
                                self.existing_leaves_revisions = None
                                self.fib_default_prefix = None
                                self.fib_default_prefix_mask_length = None
                                self.next_hops = None
                                self.incomplete_next_hops = None
                                self.resolution_timer = None
                                self.slow_process_timer = None
                                self.max_resolution_timer = None
                                self.imposition_prefixes = None
                                self.extended_prefixes = None
                                self.cefl_bl_recycled_routes = None
                                self.ldi_backwalks = None
                                self.ss_prot_route_count = None
                                self.lisp_eid_prefixes = None
                                self.lisp_eid_valid_prefixes = None
                                self.lisp_rloc_objects = None
                                self.number_of_sr_labels = None
                                self.ss_vxlan_ltep_ifh = None
                                self.ss_drop_pl_count = None

                                self.exclusive_load_sharing_element = Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.ExclusiveLoadSharingElement()
                                self.exclusive_load_sharing_element.parent = self
                                self._children_name_map["exclusive_load_sharing_element"] = "exclusive-load-sharing-element"

                                self.shared_load_sharing_element = Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.SharedLoadSharingElement()
                                self.shared_load_sharing_element.parent = self
                                self._children_name_map["shared_load_sharing_element"] = "shared-load-sharing-element"

                                self.cross_shared_load_sharing_element = Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.CrossSharedLoadSharingElement()
                                self.cross_shared_load_sharing_element.parent = self
                                self._children_name_map["cross_shared_load_sharing_element"] = "cross-shared-load-sharing-element"

                                self.encap_shared_load_sharing_element = Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.EncapSharedLoadSharingElement()
                                self.encap_shared_load_sharing_element.parent = self
                                self._children_name_map["encap_shared_load_sharing_element"] = "encap-shared-load-sharing-element"

                                self.prefix_masklen_distribution = Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution()
                                self.prefix_masklen_distribution.parent = self
                                self._children_name_map["prefix_masklen_distribution"] = "prefix-masklen-distribution"
                                self._segment_path = lambda: "fib-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary, ['vrf_name', 'table_id', 'prefix', 'ss_tbl_id', 'ss_tbl_id_ptr', 'ss_vrf_id', 'ss_vr_id', 'load_balancing', 'forwarding_elements', 'routes', 'prefix_in_place_modifications', 'stale_prefix_deletes', 'load_sharing_elements', 'load_sharing_references', 'total_load_share_element_bytes', 'leaves_used_bytes', 'reresolve_entries', 'old_unresolve_entries', 'new_unresolve_entries', 'unresolve_entries', 'cef_route_drops', 'cef_version_mismatch_route_drops', 'delete_cache_num_entries', 'existing_leaves_revisions', 'fib_default_prefix', 'fib_default_prefix_mask_length', 'next_hops', 'incomplete_next_hops', 'resolution_timer', 'slow_process_timer', 'max_resolution_timer', 'imposition_prefixes', 'extended_prefixes', 'cefl_bl_recycled_routes', 'ldi_backwalks', 'ss_prot_route_count', 'lisp_eid_prefixes', 'lisp_eid_valid_prefixes', 'lisp_rloc_objects', 'number_of_sr_labels', 'ss_vxlan_ltep_ifh', 'ss_drop_pl_count'], name, value)


                            class ExclusiveLoadSharingElement(Entity):
                                """
                                Exclusive load sharing element
                                
                                .. attribute:: total_load_sharing_element_bytes
                                
                                	Total memory used by load sharing elements in bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: total_load_sharing_element_references
                                
                                	Total count of references to load sharing elements
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: total_path_list_elements
                                
                                	Total count of Pathlist elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recursive_path_list_elements
                                
                                	Count of recursive Pathlist elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: platform_shared_path_list_elements
                                
                                	Count of platform shared Pathlist elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retry_path_list_elements
                                
                                	Count of Pathlist elements in retry
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_load_info_elements
                                
                                	Total count of Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recursive_load_info_elements
                                
                                	Count of recursive Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: platform_shared_load_info_elements
                                
                                	Count of platform shared Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: xpl_load_info_elements
                                
                                	Count of XPL Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.ExclusiveLoadSharingElement, self).__init__()

                                    self.yang_name = "exclusive-load-sharing-element"
                                    self.yang_parent_name = "fib-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total_load_sharing_element_bytes', (YLeaf(YType.uint32, 'total-load-sharing-element-bytes'), ['int'])),
                                        ('total_load_sharing_element_references', (YLeaf(YType.uint64, 'total-load-sharing-element-references'), ['int'])),
                                        ('total_path_list_elements', (YLeaf(YType.uint32, 'total-path-list-elements'), ['int'])),
                                        ('recursive_path_list_elements', (YLeaf(YType.uint32, 'recursive-path-list-elements'), ['int'])),
                                        ('platform_shared_path_list_elements', (YLeaf(YType.uint32, 'platform-shared-path-list-elements'), ['int'])),
                                        ('retry_path_list_elements', (YLeaf(YType.uint32, 'retry-path-list-elements'), ['int'])),
                                        ('total_load_info_elements', (YLeaf(YType.uint32, 'total-load-info-elements'), ['int'])),
                                        ('recursive_load_info_elements', (YLeaf(YType.uint32, 'recursive-load-info-elements'), ['int'])),
                                        ('platform_shared_load_info_elements', (YLeaf(YType.uint32, 'platform-shared-load-info-elements'), ['int'])),
                                        ('xpl_load_info_elements', (YLeaf(YType.uint32, 'xpl-load-info-elements'), ['int'])),
                                    ])
                                    self.total_load_sharing_element_bytes = None
                                    self.total_load_sharing_element_references = None
                                    self.total_path_list_elements = None
                                    self.recursive_path_list_elements = None
                                    self.platform_shared_path_list_elements = None
                                    self.retry_path_list_elements = None
                                    self.total_load_info_elements = None
                                    self.recursive_load_info_elements = None
                                    self.platform_shared_load_info_elements = None
                                    self.xpl_load_info_elements = None
                                    self._segment_path = lambda: "exclusive-load-sharing-element"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.ExclusiveLoadSharingElement, ['total_load_sharing_element_bytes', 'total_load_sharing_element_references', 'total_path_list_elements', 'recursive_path_list_elements', 'platform_shared_path_list_elements', 'retry_path_list_elements', 'total_load_info_elements', 'recursive_load_info_elements', 'platform_shared_load_info_elements', 'xpl_load_info_elements'], name, value)


                            class SharedLoadSharingElement(Entity):
                                """
                                Shared load sharing element
                                
                                .. attribute:: total_load_sharing_element_bytes
                                
                                	Total memory used by load sharing elements in bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: total_load_sharing_element_references
                                
                                	Total count of references to load sharing elements
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: total_path_list_elements
                                
                                	Total count of Pathlist elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recursive_path_list_elements
                                
                                	Count of recursive Pathlist elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: platform_shared_path_list_elements
                                
                                	Count of platform shared Pathlist elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retry_path_list_elements
                                
                                	Count of Pathlist elements in retry
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_load_info_elements
                                
                                	Total count of Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recursive_load_info_elements
                                
                                	Count of recursive Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: platform_shared_load_info_elements
                                
                                	Count of platform shared Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: xpl_load_info_elements
                                
                                	Count of XPL Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.SharedLoadSharingElement, self).__init__()

                                    self.yang_name = "shared-load-sharing-element"
                                    self.yang_parent_name = "fib-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total_load_sharing_element_bytes', (YLeaf(YType.uint32, 'total-load-sharing-element-bytes'), ['int'])),
                                        ('total_load_sharing_element_references', (YLeaf(YType.uint64, 'total-load-sharing-element-references'), ['int'])),
                                        ('total_path_list_elements', (YLeaf(YType.uint32, 'total-path-list-elements'), ['int'])),
                                        ('recursive_path_list_elements', (YLeaf(YType.uint32, 'recursive-path-list-elements'), ['int'])),
                                        ('platform_shared_path_list_elements', (YLeaf(YType.uint32, 'platform-shared-path-list-elements'), ['int'])),
                                        ('retry_path_list_elements', (YLeaf(YType.uint32, 'retry-path-list-elements'), ['int'])),
                                        ('total_load_info_elements', (YLeaf(YType.uint32, 'total-load-info-elements'), ['int'])),
                                        ('recursive_load_info_elements', (YLeaf(YType.uint32, 'recursive-load-info-elements'), ['int'])),
                                        ('platform_shared_load_info_elements', (YLeaf(YType.uint32, 'platform-shared-load-info-elements'), ['int'])),
                                        ('xpl_load_info_elements', (YLeaf(YType.uint32, 'xpl-load-info-elements'), ['int'])),
                                    ])
                                    self.total_load_sharing_element_bytes = None
                                    self.total_load_sharing_element_references = None
                                    self.total_path_list_elements = None
                                    self.recursive_path_list_elements = None
                                    self.platform_shared_path_list_elements = None
                                    self.retry_path_list_elements = None
                                    self.total_load_info_elements = None
                                    self.recursive_load_info_elements = None
                                    self.platform_shared_load_info_elements = None
                                    self.xpl_load_info_elements = None
                                    self._segment_path = lambda: "shared-load-sharing-element"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.SharedLoadSharingElement, ['total_load_sharing_element_bytes', 'total_load_sharing_element_references', 'total_path_list_elements', 'recursive_path_list_elements', 'platform_shared_path_list_elements', 'retry_path_list_elements', 'total_load_info_elements', 'recursive_load_info_elements', 'platform_shared_load_info_elements', 'xpl_load_info_elements'], name, value)


                            class CrossSharedLoadSharingElement(Entity):
                                """
                                Cross\-table shared load sharing element
                                
                                .. attribute:: total_load_sharing_element_bytes
                                
                                	Total memory used by load sharing elements in bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: total_load_sharing_element_references
                                
                                	Total count of references to load sharing elements
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: total_path_list_elements
                                
                                	Total count of Pathlist elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recursive_path_list_elements
                                
                                	Count of recursive Pathlist elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: platform_shared_path_list_elements
                                
                                	Count of platform shared Pathlist elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retry_path_list_elements
                                
                                	Count of Pathlist elements in retry
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_load_info_elements
                                
                                	Total count of Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recursive_load_info_elements
                                
                                	Count of recursive Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: platform_shared_load_info_elements
                                
                                	Count of platform shared Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: xpl_load_info_elements
                                
                                	Count of XPL Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.CrossSharedLoadSharingElement, self).__init__()

                                    self.yang_name = "cross-shared-load-sharing-element"
                                    self.yang_parent_name = "fib-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total_load_sharing_element_bytes', (YLeaf(YType.uint32, 'total-load-sharing-element-bytes'), ['int'])),
                                        ('total_load_sharing_element_references', (YLeaf(YType.uint64, 'total-load-sharing-element-references'), ['int'])),
                                        ('total_path_list_elements', (YLeaf(YType.uint32, 'total-path-list-elements'), ['int'])),
                                        ('recursive_path_list_elements', (YLeaf(YType.uint32, 'recursive-path-list-elements'), ['int'])),
                                        ('platform_shared_path_list_elements', (YLeaf(YType.uint32, 'platform-shared-path-list-elements'), ['int'])),
                                        ('retry_path_list_elements', (YLeaf(YType.uint32, 'retry-path-list-elements'), ['int'])),
                                        ('total_load_info_elements', (YLeaf(YType.uint32, 'total-load-info-elements'), ['int'])),
                                        ('recursive_load_info_elements', (YLeaf(YType.uint32, 'recursive-load-info-elements'), ['int'])),
                                        ('platform_shared_load_info_elements', (YLeaf(YType.uint32, 'platform-shared-load-info-elements'), ['int'])),
                                        ('xpl_load_info_elements', (YLeaf(YType.uint32, 'xpl-load-info-elements'), ['int'])),
                                    ])
                                    self.total_load_sharing_element_bytes = None
                                    self.total_load_sharing_element_references = None
                                    self.total_path_list_elements = None
                                    self.recursive_path_list_elements = None
                                    self.platform_shared_path_list_elements = None
                                    self.retry_path_list_elements = None
                                    self.total_load_info_elements = None
                                    self.recursive_load_info_elements = None
                                    self.platform_shared_load_info_elements = None
                                    self.xpl_load_info_elements = None
                                    self._segment_path = lambda: "cross-shared-load-sharing-element"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.CrossSharedLoadSharingElement, ['total_load_sharing_element_bytes', 'total_load_sharing_element_references', 'total_path_list_elements', 'recursive_path_list_elements', 'platform_shared_path_list_elements', 'retry_path_list_elements', 'total_load_info_elements', 'recursive_load_info_elements', 'platform_shared_load_info_elements', 'xpl_load_info_elements'], name, value)


                            class EncapSharedLoadSharingElement(Entity):
                                """
                                Encap\-shared load sharing element
                                
                                .. attribute:: total_load_sharing_element_bytes
                                
                                	Total memory used by load sharing elements in bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: total_load_sharing_element_references
                                
                                	Total count of references to load sharing elements
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: total_path_list_elements
                                
                                	Total count of Pathlist elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recursive_path_list_elements
                                
                                	Count of recursive Pathlist elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: platform_shared_path_list_elements
                                
                                	Count of platform shared Pathlist elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retry_path_list_elements
                                
                                	Count of Pathlist elements in retry
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_load_info_elements
                                
                                	Total count of Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: recursive_load_info_elements
                                
                                	Count of recursive Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: platform_shared_load_info_elements
                                
                                	Count of platform shared Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: xpl_load_info_elements
                                
                                	Count of XPL Loadinfo elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.EncapSharedLoadSharingElement, self).__init__()

                                    self.yang_name = "encap-shared-load-sharing-element"
                                    self.yang_parent_name = "fib-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('total_load_sharing_element_bytes', (YLeaf(YType.uint32, 'total-load-sharing-element-bytes'), ['int'])),
                                        ('total_load_sharing_element_references', (YLeaf(YType.uint64, 'total-load-sharing-element-references'), ['int'])),
                                        ('total_path_list_elements', (YLeaf(YType.uint32, 'total-path-list-elements'), ['int'])),
                                        ('recursive_path_list_elements', (YLeaf(YType.uint32, 'recursive-path-list-elements'), ['int'])),
                                        ('platform_shared_path_list_elements', (YLeaf(YType.uint32, 'platform-shared-path-list-elements'), ['int'])),
                                        ('retry_path_list_elements', (YLeaf(YType.uint32, 'retry-path-list-elements'), ['int'])),
                                        ('total_load_info_elements', (YLeaf(YType.uint32, 'total-load-info-elements'), ['int'])),
                                        ('recursive_load_info_elements', (YLeaf(YType.uint32, 'recursive-load-info-elements'), ['int'])),
                                        ('platform_shared_load_info_elements', (YLeaf(YType.uint32, 'platform-shared-load-info-elements'), ['int'])),
                                        ('xpl_load_info_elements', (YLeaf(YType.uint32, 'xpl-load-info-elements'), ['int'])),
                                    ])
                                    self.total_load_sharing_element_bytes = None
                                    self.total_load_sharing_element_references = None
                                    self.total_path_list_elements = None
                                    self.recursive_path_list_elements = None
                                    self.platform_shared_path_list_elements = None
                                    self.retry_path_list_elements = None
                                    self.total_load_info_elements = None
                                    self.recursive_load_info_elements = None
                                    self.platform_shared_load_info_elements = None
                                    self.xpl_load_info_elements = None
                                    self._segment_path = lambda: "encap-shared-load-sharing-element"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.EncapSharedLoadSharingElement, ['total_load_sharing_element_bytes', 'total_load_sharing_element_references', 'total_path_list_elements', 'recursive_path_list_elements', 'platform_shared_path_list_elements', 'retry_path_list_elements', 'total_load_info_elements', 'recursive_load_info_elements', 'platform_shared_load_info_elements', 'xpl_load_info_elements'], name, value)


                            class PrefixMasklenDistribution(Entity):
                                """
                                Distribution of prefix mask lengths
                                
                                .. attribute:: unicast_prefixe
                                
                                	Masklength counts for unicast prefixes
                                	**type**\: list of  		 :py:class:`UnicastPrefixe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution.UnicastPrefixe>`
                                
                                .. attribute:: broadcast_prefixe
                                
                                	Masklength counts for broadcast prefixes
                                	**type**\: list of  		 :py:class:`BroadcastPrefixe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution.BroadcastPrefixe>`
                                
                                .. attribute:: multicast_prefix
                                
                                	Masklength counts for multicast prefixes
                                	**type**\: list of  		 :py:class:`MulticastPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution.MulticastPrefix>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution, self).__init__()

                                    self.yang_name = "prefix-masklen-distribution"
                                    self.yang_parent_name = "fib-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("unicast-prefixe", ("unicast_prefixe", Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution.UnicastPrefixe)), ("broadcast-prefixe", ("broadcast_prefixe", Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution.BroadcastPrefixe)), ("multicast-prefix", ("multicast_prefix", Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution.MulticastPrefix))])
                                    self._leafs = OrderedDict()

                                    self.unicast_prefixe = YList(self)
                                    self.broadcast_prefixe = YList(self)
                                    self.multicast_prefix = YList(self)
                                    self._segment_path = lambda: "prefix-masklen-distribution"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution, [], name, value)


                                class UnicastPrefixe(Entity):
                                    """
                                    Masklength counts for unicast prefixes
                                    
                                    .. attribute:: mask_length
                                    
                                    	Mask length
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: number_of_prefixes
                                    
                                    	Number of prefixes with given mask length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution.UnicastPrefixe, self).__init__()

                                        self.yang_name = "unicast-prefixe"
                                        self.yang_parent_name = "prefix-masklen-distribution"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mask_length', (YLeaf(YType.uint8, 'mask-length'), ['int'])),
                                            ('number_of_prefixes', (YLeaf(YType.uint32, 'number-of-prefixes'), ['int'])),
                                        ])
                                        self.mask_length = None
                                        self.number_of_prefixes = None
                                        self._segment_path = lambda: "unicast-prefixe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution.UnicastPrefixe, ['mask_length', 'number_of_prefixes'], name, value)


                                class BroadcastPrefixe(Entity):
                                    """
                                    Masklength counts for broadcast prefixes
                                    
                                    .. attribute:: mask_length
                                    
                                    	Mask length
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: number_of_prefixes
                                    
                                    	Number of prefixes with given mask length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution.BroadcastPrefixe, self).__init__()

                                        self.yang_name = "broadcast-prefixe"
                                        self.yang_parent_name = "prefix-masklen-distribution"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mask_length', (YLeaf(YType.uint8, 'mask-length'), ['int'])),
                                            ('number_of_prefixes', (YLeaf(YType.uint32, 'number-of-prefixes'), ['int'])),
                                        ])
                                        self.mask_length = None
                                        self.number_of_prefixes = None
                                        self._segment_path = lambda: "broadcast-prefixe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution.BroadcastPrefixe, ['mask_length', 'number_of_prefixes'], name, value)


                                class MulticastPrefix(Entity):
                                    """
                                    Masklength counts for multicast prefixes
                                    
                                    .. attribute:: mask_length
                                    
                                    	Mask length
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: number_of_prefixes
                                    
                                    	Number of prefixes with given mask length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution.MulticastPrefix, self).__init__()

                                        self.yang_name = "multicast-prefix"
                                        self.yang_parent_name = "prefix-masklen-distribution"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mask_length', (YLeaf(YType.uint8, 'mask-length'), ['int'])),
                                            ('number_of_prefixes', (YLeaf(YType.uint32, 'number-of-prefixes'), ['int'])),
                                        ])
                                        self.mask_length = None
                                        self.number_of_prefixes = None
                                        self._segment_path = lambda: "multicast-prefix"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FibSummaries.FibSummary.PrefixMasklenDistribution.MulticastPrefix, ['mask_length', 'number_of_prefixes'], name, value)


                    class ExternalSummaryAll(Entity):
                        """
                        Summary for all external clients
                        
                        .. attribute:: sesa_pl_sum
                        
                        	External pathlist summary
                        	**type**\:  :py:class:`SesaPlSum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll.SesaPlSum>`
                        
                        .. attribute:: sesa_num_client
                        
                        	Client information
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll, self).__init__()

                            self.yang_name = "external-summary-all"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sesa-pl-sum", ("sesa_pl_sum", Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll.SesaPlSum))])
                            self._leafs = OrderedDict([
                                ('sesa_num_client', (YLeaf(YType.uint32, 'sesa-num-client'), ['int'])),
                            ])
                            self.sesa_num_client = None

                            self.sesa_pl_sum = Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll.SesaPlSum()
                            self.sesa_pl_sum.parent = self
                            self._children_name_map["sesa_pl_sum"] = "sesa-pl-sum"
                            self._segment_path = lambda: "external-summary-all"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll, ['sesa_num_client'], name, value)


                        class SesaPlSum(Entity):
                            """
                            External pathlist summary
                            
                            .. attribute:: sep_num_ecd_pathlist
                            
                            	Number of ECD pathlists
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sep_num_ecd_pl_unresolved
                            
                            	Number of ECD pathlists unresolved
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sep_num_ecd_pl_per_interest
                            
                            	Number of ECD pathlists per interest
                            	**type**\: list of  		 :py:class:`SepNumEcdPlPerInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll.SesaPlSum.SepNumEcdPlPerInterest>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll.SesaPlSum, self).__init__()

                                self.yang_name = "sesa-pl-sum"
                                self.yang_parent_name = "external-summary-all"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sep-num-ecd-pl-per-interest", ("sep_num_ecd_pl_per_interest", Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll.SesaPlSum.SepNumEcdPlPerInterest))])
                                self._leafs = OrderedDict([
                                    ('sep_num_ecd_pathlist', (YLeaf(YType.uint32, 'sep-num-ecd-pathlist'), ['int'])),
                                    ('sep_num_ecd_pl_unresolved', (YLeaf(YType.uint32, 'sep-num-ecd-pl-unresolved'), ['int'])),
                                ])
                                self.sep_num_ecd_pathlist = None
                                self.sep_num_ecd_pl_unresolved = None

                                self.sep_num_ecd_pl_per_interest = YList(self)
                                self._segment_path = lambda: "sesa-pl-sum"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll.SesaPlSum, ['sep_num_ecd_pathlist', 'sep_num_ecd_pl_unresolved'], name, value)


                            class SepNumEcdPlPerInterest(Entity):
                                """
                                Number of ECD pathlists per interest
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll.SesaPlSum.SepNumEcdPlPerInterest, self).__init__()

                                    self.yang_name = "sep-num-ecd-pl-per-interest"
                                    self.yang_parent_name = "sesa-pl-sum"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "sep-num-ecd-pl-per-interest"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExternalSummaryAll.SesaPlSum.SepNumEcdPlPerInterest, ['entry'], name, value)


                    class FrrLog(Entity):
                        """
                        Table of Fast Reroute activation logs
                        
                        .. attribute:: frr_interfaces
                        
                        	FRR Interface Table
                        	**type**\:  :py:class:`FrrInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Protocols.Protocol.FrrLog, self).__init__()

                            self.yang_name = "frr-log"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("frr-interfaces", ("frr_interfaces", Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces))])
                            self._leafs = OrderedDict()

                            self.frr_interfaces = Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces()
                            self.frr_interfaces.parent = self
                            self._children_name_map["frr_interfaces"] = "frr-interfaces"
                            self._segment_path = lambda: "frr-log"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FrrLog, [], name, value)


                        class FrrInterfaces(Entity):
                            """
                            FRR Interface Table
                            
                            .. attribute:: frr_interface
                            
                            	Specify FRR Interface Name
                            	**type**\: list of  		 :py:class:`FrrInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces, self).__init__()

                                self.yang_name = "frr-interfaces"
                                self.yang_parent_name = "frr-log"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("frr-interface", ("frr_interface", Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface))])
                                self._leafs = OrderedDict()

                                self.frr_interface = YList(self)
                                self._segment_path = lambda: "frr-interfaces"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces, [], name, value)


                            class FrrInterface(Entity):
                                """
                                Specify FRR Interface Name
                                
                                .. attribute:: frr_interface_name  (key)
                                
                                	Interface Name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: logs
                                
                                	FRR log table
                                	**type**\:  :py:class:`Logs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface, self).__init__()

                                    self.yang_name = "frr-interface"
                                    self.yang_parent_name = "frr-interfaces"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['frr_interface_name']
                                    self._child_classes = OrderedDict([("logs", ("logs", Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs))])
                                    self._leafs = OrderedDict([
                                        ('frr_interface_name', (YLeaf(YType.str, 'frr-interface-name'), ['str'])),
                                    ])
                                    self.frr_interface_name = None

                                    self.logs = Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs()
                                    self.logs.parent = self
                                    self._children_name_map["logs"] = "logs"
                                    self._segment_path = lambda: "frr-interface" + "[frr-interface-name='" + str(self.frr_interface_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface, ['frr_interface_name'], name, value)


                                class Logs(Entity):
                                    """
                                    FRR log table
                                    
                                    .. attribute:: log
                                    
                                    	Specify index into frr log table
                                    	**type**\: list of  		 :py:class:`Log <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs.Log>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs, self).__init__()

                                        self.yang_name = "logs"
                                        self.yang_parent_name = "frr-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("log", ("log", Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs.Log))])
                                        self._leafs = OrderedDict()

                                        self.log = YList(self)
                                        self._segment_path = lambda: "logs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs, [], name, value)


                                    class Log(Entity):
                                        """
                                        Specify index into frr log table
                                        
                                        .. attribute:: log_index  (key)
                                        
                                        	FRR Log Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: frr_timestamp
                                        
                                        	frr timestamp
                                        	**type**\:  :py:class:`FrrTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs.Log.FrrTimestamp>`
                                        
                                        .. attribute:: frr_protocol_type
                                        
                                        	FIB Protocol Type
                                        	**type**\:  :py:class:`FibFrrProtocolShow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibFrrProtocolShow>`
                                        
                                        .. attribute:: frr_interface_name
                                        
                                        	Interface assoc w frr nh
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: frr_prefix
                                        
                                        	nh prefix
                                        	**type**\: str
                                        
                                        	**length:** 0..52
                                        
                                        .. attribute:: frr_switching_time
                                        
                                        	frr switching time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bundle_member_interface_name
                                        
                                        	bundle member
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs.Log, self).__init__()

                                            self.yang_name = "log"
                                            self.yang_parent_name = "logs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['log_index']
                                            self._child_classes = OrderedDict([("frr-timestamp", ("frr_timestamp", Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs.Log.FrrTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('log_index', (YLeaf(YType.uint32, 'log-index'), ['int'])),
                                                ('frr_protocol_type', (YLeaf(YType.enumeration, 'frr-protocol-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibFrrProtocolShow', '')])),
                                                ('frr_interface_name', (YLeaf(YType.str, 'frr-interface-name'), ['str'])),
                                                ('frr_prefix', (YLeaf(YType.str, 'frr-prefix'), ['str'])),
                                                ('frr_switching_time', (YLeaf(YType.uint32, 'frr-switching-time'), ['int'])),
                                                ('bundle_member_interface_name', (YLeaf(YType.str, 'bundle-member-interface-name'), ['str'])),
                                            ])
                                            self.log_index = None
                                            self.frr_protocol_type = None
                                            self.frr_interface_name = None
                                            self.frr_prefix = None
                                            self.frr_switching_time = None
                                            self.bundle_member_interface_name = None

                                            self.frr_timestamp = Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs.Log.FrrTimestamp()
                                            self.frr_timestamp.parent = self
                                            self._children_name_map["frr_timestamp"] = "frr-timestamp"
                                            self._segment_path = lambda: "log" + "[log-index='" + str(self.log_index) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs.Log, ['log_index', 'frr_protocol_type', 'frr_interface_name', 'frr_prefix', 'frr_switching_time', 'bundle_member_interface_name'], name, value)


                                        class FrrTimestamp(Entity):
                                            """
                                            frr timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds
                                            	**type**\: int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: nano_seconds
                                            
                                            	NanoSeconds
                                            	**type**\: int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs.Log.FrrTimestamp, self).__init__()

                                                self.yang_name = "frr-timestamp"
                                                self.yang_parent_name = "log"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.int32, 'seconds'), ['int'])),
                                                    ('nano_seconds', (YLeaf(YType.int32, 'nano-seconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nano_seconds = None
                                                self._segment_path = lambda: "frr-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.FrrLog.FrrInterfaces.FrrInterface.Logs.Log.FrrTimestamp, ['seconds', 'nano_seconds'], name, value)


                    class Vrfs(Entity):
                        """
                        VRF table
                        
                        .. attribute:: vrf
                        
                        	VRF table entry
                        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs, self).__init__()

                            self.yang_name = "vrfs"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("vrf", ("vrf", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf))])
                            self._leafs = OrderedDict()

                            self.vrf = YList(self)
                            self._segment_path = lambda: "vrfs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs, [], name, value)


                        class Vrf(Entity):
                            """
                            VRF table entry
                            
                            .. attribute:: vrf_name  (key)
                            
                            	VRF Name
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: nh_info_detail_hardware_egress
                            
                            	NHInfoTable is accessed by two keys; {NHInterface,NHAddress}
                            	**type**\:  :py:class:`NhInfoDetailHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress>`
                            
                            .. attribute:: ip_prefix_details
                            
                            	IP FIB prefix detail table
                            	**type**\:  :py:class:`IpPrefixDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails>`
                            
                            .. attribute:: nh_info_detail
                            
                            	NHInfoTable is accessed by two keys; {NHInterface,NHAddress}
                            	**type**\:  :py:class:`NhInfoDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail>`
                            
                            .. attribute:: summary
                            
                            	Operational data for FIB Tablee
                            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary>`
                            
                            .. attribute:: interface_infos
                            
                            	Table of InterfaceInfo
                            	**type**\:  :py:class:`InterfaceInfos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos>`
                            
                            .. attribute:: ip_prefix_briefs
                            
                            	IP FIB prefix brief table
                            	**type**\:  :py:class:`IpPrefixBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs>`
                            
                            .. attribute:: nh_info_detail_hardware_ingress
                            
                            	NHInfoTable is accessed by two keys; {NHInterface,NHAddress}
                            	**type**\:  :py:class:`NhInfoDetailHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress>`
                            
                            .. attribute:: nh_info_brief
                            
                            	NHInfoTable is accessed by two keys; {NHInterface,NHAddress}
                            	**type**\:  :py:class:`NhInfoBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "vrfs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['vrf_name']
                                self._child_classes = OrderedDict([("nh-info-detail-hardware-egress", ("nh_info_detail_hardware_egress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress)), ("ip-prefix-details", ("ip_prefix_details", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails)), ("nh-info-detail", ("nh_info_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail)), ("summary", ("summary", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary)), ("interface-infos", ("interface_infos", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos)), ("ip-prefix-briefs", ("ip_prefix_briefs", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs)), ("nh-info-detail-hardware-ingress", ("nh_info_detail_hardware_ingress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress)), ("nh-info-brief", ("nh_info_brief", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief))])
                                self._leafs = OrderedDict([
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ])
                                self.vrf_name = None

                                self.nh_info_detail_hardware_egress = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress()
                                self.nh_info_detail_hardware_egress.parent = self
                                self._children_name_map["nh_info_detail_hardware_egress"] = "nh-info-detail-hardware-egress"

                                self.ip_prefix_details = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails()
                                self.ip_prefix_details.parent = self
                                self._children_name_map["ip_prefix_details"] = "ip-prefix-details"

                                self.nh_info_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail()
                                self.nh_info_detail.parent = self
                                self._children_name_map["nh_info_detail"] = "nh-info-detail"

                                self.summary = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary()
                                self.summary.parent = self
                                self._children_name_map["summary"] = "summary"

                                self.interface_infos = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos()
                                self.interface_infos.parent = self
                                self._children_name_map["interface_infos"] = "interface-infos"

                                self.ip_prefix_briefs = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs()
                                self.ip_prefix_briefs.parent = self
                                self._children_name_map["ip_prefix_briefs"] = "ip-prefix-briefs"

                                self.nh_info_detail_hardware_ingress = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress()
                                self.nh_info_detail_hardware_ingress.parent = self
                                self._children_name_map["nh_info_detail_hardware_ingress"] = "nh-info-detail-hardware-ingress"

                                self.nh_info_brief = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief()
                                self.nh_info_brief.parent = self
                                self._children_name_map["nh_info_brief"] = "nh-info-brief"
                                self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf, ['vrf_name'], name, value)


                            class NhInfoDetailHardwareEgress(Entity):
                                """
                                NHInfoTable is accessed by two keys;
                                {NHInterface,NHAddress}
                                
                                .. attribute:: nh_info_special_detail_hardware_egress
                                
                                	Detail hardware engress info for Special nhinfo
                                	**type**\:  :py:class:`NhInfoSpecialDetailHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress>`
                                
                                .. attribute:: nh_info_local_detail_hardware_egresses
                                
                                	Local (non\-remote) nhinfo
                                	**type**\:  :py:class:`NhInfoLocalDetailHardwareEgresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses>`
                                
                                .. attribute:: nh_info_remote_detail_hardware_egresses
                                
                                	Detail hardware egress info for remote NHInfo table
                                	**type**\:  :py:class:`NhInfoRemoteDetailHardwareEgresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress, self).__init__()

                                    self.yang_name = "nh-info-detail-hardware-egress"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("nh-info-special-detail-hardware-egress", ("nh_info_special_detail_hardware_egress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress)), ("nh-info-local-detail-hardware-egresses", ("nh_info_local_detail_hardware_egresses", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses)), ("nh-info-remote-detail-hardware-egresses", ("nh_info_remote_detail_hardware_egresses", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses))])
                                    self._leafs = OrderedDict()

                                    self.nh_info_special_detail_hardware_egress = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress()
                                    self.nh_info_special_detail_hardware_egress.parent = self
                                    self._children_name_map["nh_info_special_detail_hardware_egress"] = "nh-info-special-detail-hardware-egress"

                                    self.nh_info_local_detail_hardware_egresses = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses()
                                    self.nh_info_local_detail_hardware_egresses.parent = self
                                    self._children_name_map["nh_info_local_detail_hardware_egresses"] = "nh-info-local-detail-hardware-egresses"

                                    self.nh_info_remote_detail_hardware_egresses = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses()
                                    self.nh_info_remote_detail_hardware_egresses.parent = self
                                    self._children_name_map["nh_info_remote_detail_hardware_egresses"] = "nh-info-remote-detail-hardware-egresses"
                                    self._segment_path = lambda: "nh-info-detail-hardware-egress"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress, [], name, value)


                                class NhInfoSpecialDetailHardwareEgress(Entity):
                                    """
                                    Detail hardware engress info for Special
                                    nhinfo
                                    
                                    .. attribute:: nh_info_special_null_detail_hardware_egress
                                    
                                    	Detail hardware engress info for special\-null NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialNullDetailHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress>`
                                    
                                    .. attribute:: nh_info_special_punt_detail_hardware_egress
                                    
                                    	Detail hardware engress info for special\-punt NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialPuntDetailHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress>`
                                    
                                    .. attribute:: nh_info_special_discard_detail_hardware_egress
                                    
                                    	Detail hardware engress info for special\-discard NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialDiscardDetailHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress>`
                                    
                                    .. attribute:: nh_info_special_drop_detail_hardware_egress
                                    
                                    	Detail hardware engress info for special\-drop NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialDropDetailHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress, self).__init__()

                                        self.yang_name = "nh-info-special-detail-hardware-egress"
                                        self.yang_parent_name = "nh-info-detail-hardware-egress"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("nh-info-special-null-detail-hardware-egress", ("nh_info_special_null_detail_hardware_egress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress)), ("nh-info-special-punt-detail-hardware-egress", ("nh_info_special_punt_detail_hardware_egress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress)), ("nh-info-special-discard-detail-hardware-egress", ("nh_info_special_discard_detail_hardware_egress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress)), ("nh-info-special-drop-detail-hardware-egress", ("nh_info_special_drop_detail_hardware_egress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress))])
                                        self._leafs = OrderedDict()

                                        self.nh_info_special_null_detail_hardware_egress = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress()
                                        self.nh_info_special_null_detail_hardware_egress.parent = self
                                        self._children_name_map["nh_info_special_null_detail_hardware_egress"] = "nh-info-special-null-detail-hardware-egress"

                                        self.nh_info_special_punt_detail_hardware_egress = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress()
                                        self.nh_info_special_punt_detail_hardware_egress.parent = self
                                        self._children_name_map["nh_info_special_punt_detail_hardware_egress"] = "nh-info-special-punt-detail-hardware-egress"

                                        self.nh_info_special_discard_detail_hardware_egress = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress()
                                        self.nh_info_special_discard_detail_hardware_egress.parent = self
                                        self._children_name_map["nh_info_special_discard_detail_hardware_egress"] = "nh-info-special-discard-detail-hardware-egress"

                                        self.nh_info_special_drop_detail_hardware_egress = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress()
                                        self.nh_info_special_drop_detail_hardware_egress.parent = self
                                        self._children_name_map["nh_info_special_drop_detail_hardware_egress"] = "nh-info-special-drop-detail-hardware-egress"
                                        self._segment_path = lambda: "nh-info-special-detail-hardware-egress"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress, [], name, value)


                                    class NhInfoSpecialNullDetailHardwareEgress(Entity):
                                        """
                                        Detail hardware engress info for
                                        special\-null NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress, self).__init__()

                                            self.yang_name = "nh-info-special-null-detail-hardware-egress"
                                            self.yang_parent_name = "nh-info-special-detail-hardware-egress"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-null-detail-hardware-egress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-null-detail-hardware-egress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-null-detail-hardware-egress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialNullDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                    class NhInfoSpecialPuntDetailHardwareEgress(Entity):
                                        """
                                        Detail hardware engress info for
                                        special\-punt NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress, self).__init__()

                                            self.yang_name = "nh-info-special-punt-detail-hardware-egress"
                                            self.yang_parent_name = "nh-info-special-detail-hardware-egress"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-punt-detail-hardware-egress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-punt-detail-hardware-egress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-punt-detail-hardware-egress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialPuntDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                    class NhInfoSpecialDiscardDetailHardwareEgress(Entity):
                                        """
                                        Detail hardware engress info for
                                        special\-discard NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress, self).__init__()

                                            self.yang_name = "nh-info-special-discard-detail-hardware-egress"
                                            self.yang_parent_name = "nh-info-special-detail-hardware-egress"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-discard-detail-hardware-egress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-discard-detail-hardware-egress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-discard-detail-hardware-egress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDiscardDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                    class NhInfoSpecialDropDetailHardwareEgress(Entity):
                                        """
                                        Detail hardware engress info for
                                        special\-drop NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress, self).__init__()

                                            self.yang_name = "nh-info-special-drop-detail-hardware-egress"
                                            self.yang_parent_name = "nh-info-special-detail-hardware-egress"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-drop-detail-hardware-egress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-drop-detail-hardware-egress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-drop-detail-hardware-egress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoSpecialDetailHardwareEgress.NhInfoSpecialDropDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                class NhInfoLocalDetailHardwareEgresses(Entity):
                                    """
                                    Local (non\-remote) nhinfo
                                    
                                    .. attribute:: nh_info_local_detail_hardware_egress
                                    
                                    	Detail NHinfo entry
                                    	**type**\: list of  		 :py:class:`NhInfoLocalDetailHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses, self).__init__()

                                        self.yang_name = "nh-info-local-detail-hardware-egresses"
                                        self.yang_parent_name = "nh-info-detail-hardware-egress"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("nh-info-local-detail-hardware-egress", ("nh_info_local_detail_hardware_egress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress))])
                                        self._leafs = OrderedDict()

                                        self.nh_info_local_detail_hardware_egress = YList(self)
                                        self._segment_path = lambda: "nh-info-local-detail-hardware-egresses"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses, [], name, value)


                                    class NhInfoLocalDetailHardwareEgress(Entity):
                                        """
                                        Detail NHinfo entry
                                        
                                        .. attribute:: nh_interface_name
                                        
                                        	Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: nh_proto
                                        
                                        	Next\-hop proto
                                        	**type**\:  :py:class:`FibProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibProtocol>`
                                        
                                        .. attribute:: nh_pfx_length
                                        
                                        	Next\-hop prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_address
                                        
                                        	Next\-hop address in string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress, self).__init__()

                                            self.yang_name = "nh-info-local-detail-hardware-egress"
                                            self.yang_parent_name = "nh-info-local-detail-hardware-egresses"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('nh_interface_name', (YLeaf(YType.str, 'nh-interface-name'), ['str'])),
                                                ('nh_proto', (YLeaf(YType.enumeration, 'nh-proto'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibProtocol', '')])),
                                                ('nh_pfx_length', (YLeaf(YType.uint32, 'nh-pfx-length'), ['int'])),
                                                ('nh_address', (YLeaf(YType.str, 'nh-address'), ['str'])),
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.nh_interface_name = None
                                            self.nh_proto = None
                                            self.nh_pfx_length = None
                                            self.nh_address = None
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-local-detail-hardware-egress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress, ['nh_interface_name', 'nh_proto', 'nh_pfx_length', 'nh_address', 'si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-local-detail-hardware-egress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-local-detail-hardware-egress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoLocalDetailHardwareEgresses.NhInfoLocalDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                class NhInfoRemoteDetailHardwareEgresses(Entity):
                                    """
                                    Detail hardware egress info for remote
                                    NHInfo table
                                    
                                    .. attribute:: nh_info_remote_detail_hardware_egress
                                    
                                    	Detail NHinfo entry
                                    	**type**\: list of  		 :py:class:`NhInfoRemoteDetailHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses, self).__init__()

                                        self.yang_name = "nh-info-remote-detail-hardware-egresses"
                                        self.yang_parent_name = "nh-info-detail-hardware-egress"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("nh-info-remote-detail-hardware-egress", ("nh_info_remote_detail_hardware_egress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress))])
                                        self._leafs = OrderedDict()

                                        self.nh_info_remote_detail_hardware_egress = YList(self)
                                        self._segment_path = lambda: "nh-info-remote-detail-hardware-egresses"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses, [], name, value)


                                    class NhInfoRemoteDetailHardwareEgress(Entity):
                                        """
                                        Detail NHinfo entry
                                        
                                        .. attribute:: nh_interface_name
                                        
                                        	Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: nh_proto
                                        
                                        	Next\-hop proto
                                        	**type**\:  :py:class:`FibProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibProtocol>`
                                        
                                        .. attribute:: nh_pfx_length
                                        
                                        	Next\-hop prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_address
                                        
                                        	Next\-hop address in string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress, self).__init__()

                                            self.yang_name = "nh-info-remote-detail-hardware-egress"
                                            self.yang_parent_name = "nh-info-remote-detail-hardware-egresses"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('nh_interface_name', (YLeaf(YType.str, 'nh-interface-name'), ['str'])),
                                                ('nh_proto', (YLeaf(YType.enumeration, 'nh-proto'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibProtocol', '')])),
                                                ('nh_pfx_length', (YLeaf(YType.uint32, 'nh-pfx-length'), ['int'])),
                                                ('nh_address', (YLeaf(YType.str, 'nh-address'), ['str'])),
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.nh_interface_name = None
                                            self.nh_proto = None
                                            self.nh_pfx_length = None
                                            self.nh_address = None
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-remote-detail-hardware-egress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress, ['nh_interface_name', 'nh_proto', 'nh_pfx_length', 'nh_address', 'si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-remote-detail-hardware-egress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-remote-detail-hardware-egress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareEgress.NhInfoRemoteDetailHardwareEgresses.NhInfoRemoteDetailHardwareEgress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                            class IpPrefixDetails(Entity):
                                """
                                IP FIB prefix detail table
                                
                                .. attribute:: ip_prefix_detail
                                
                                	IP FIB prefix detail table entry
                                	**type**\: list of  		 :py:class:`IpPrefixDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails, self).__init__()

                                    self.yang_name = "ip-prefix-details"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ip-prefix-detail", ("ip_prefix_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail))])
                                    self._leafs = OrderedDict()

                                    self.ip_prefix_detail = YList(self)
                                    self._segment_path = lambda: "ip-prefix-details"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails, [], name, value)


                                class IpPrefixDetail(Entity):
                                    """
                                    IP FIB prefix detail table entry
                                    
                                    .. attribute:: prefix
                                    
                                    	Destination IP address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	IP prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: detail_fib_entry_information
                                    
                                    	Detailed FIB entry information
                                    	**type**\:  :py:class:`DetailFibEntryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation>`
                                    
                                    .. attribute:: fib_entry_path
                                    
                                    	FIB entry path details
                                    	**type**\:  :py:class:`FibEntryPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath>`
                                    
                                    .. attribute:: protocol_type_fib_entry
                                    
                                    	Proto type for this entry
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: platform_hardware
                                    
                                    	Platform Hardware info
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: number_of_referances_to_path_list
                                    
                                    	Number of references to the pathlist
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_list_flags
                                    
                                    	The pathlist flags
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_list_source
                                    
                                    	The pathlist source
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_referances_to_ldi
                                    
                                    	Number of references to the LDI
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ldi_flags
                                    
                                    	The LDI flags
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flags_external_ldi
                                    
                                    	The flags of ext assocaited with LDI 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pointer_external_ldi
                                    
                                    	The pointer to the ext assocaited with LDI
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: exact_path_interface_handle
                                    
                                    	exact\-path interface handle
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: exact_path_gre_interface_handle
                                    
                                    	exact\-path GRE physical interface handle
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: exact_route_gre_phys_ifh_avail
                                    
                                    	exact\-route GRE phy ifh available
                                    	**type**\: bool
                                    
                                    .. attribute:: exact_route_result
                                    
                                    	exact\-route result
                                    	**type**\: bool
                                    
                                    .. attribute:: prefix_is_static_or_connected
                                    
                                    	Prefix is static or connected
                                    	**type**\: bool
                                    
                                    .. attribute:: packet_should_recieve
                                    
                                    	Packet should always be received
                                    	**type**\: bool
                                    
                                    .. attribute:: prefix_connected
                                    
                                    	Prefix is connected
                                    	**type**\: bool
                                    
                                    .. attribute:: prefix_for_adjancency
                                    
                                    	Prefix is for an adjacency
                                    	**type**\: bool
                                    
                                    .. attribute:: prefix_for_pic_next_hop
                                    
                                    	Prefix is for a PIC nexthop
                                    	**type**\: bool
                                    
                                    .. attribute:: purgable_after_purge_interval
                                    
                                    	Purgable after the purge interval
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast_recive_flag
                                    
                                    	Broadcast receive flag
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast_forward_flag
                                    
                                    	Broadcast forward flag
                                    	**type**\: bool
                                    
                                    .. attribute:: zero_by_zero_route_as_default
                                    
                                    	0/0 route added as default route
                                    	**type**\: bool
                                    
                                    .. attribute:: external_switch_triggered
                                    
                                    	External switch function triggered
                                    	**type**\: bool
                                    
                                    .. attribute:: route_attribute_flag
                                    
                                    	Route attributes summary flag
                                    	**type**\: bool
                                    
                                    .. attribute:: dummy_real_zero_route
                                    
                                    	Dummy real zero route
                                    	**type**\: bool
                                    
                                    .. attribute:: ldi_lw_flag
                                    
                                    	The LDI LW flags
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ref_counter_of_ldi_lw_ldi
                                    
                                    	The refcounter of LDI LW LDI
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: type_of_ldi_lw_ldi
                                    
                                    	The type of LDI LW LDI
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lspa_flags
                                    
                                    	The LSPA flags
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_of_route
                                    
                                    	The version of the route
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: fib_route_download_priority
                                    
                                    	Priority at which the route was downloaded
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_of_last_update_in_msec
                                    
                                    	The time of last update in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: l2_subscriber_route
                                    
                                    	Is L2 Subscriber route
                                    	**type**\: bool
                                    
                                    .. attribute:: l2_subscriber_xconnect_id
                                    
                                    	XConnect\-id associated with L2 subscriber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: l2_subscriber_flags
                                    
                                    	Flags associated with L2 subscriber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: l2_subscriber_ip_protocol
                                    
                                    	IP protocol associated with L2 subscriber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: l2tpv3_cookie_length_bits
                                    
                                    	L2TPv3 cookie length for L2 subscriber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_for_external_reach_linecard_flag
                                    
                                    	Route destined for Line Card that support External Reach only
                                    	**type**\: bool
                                    
                                    .. attribute:: route_is_sr_flag
                                    
                                    	Route is a MPLS Segment\-Routing prefix
                                    	**type**\: bool
                                    
                                    .. attribute:: extension_object
                                    
                                    	Leaf Extension Object List
                                    	**type**\: list of  		 :py:class:`ExtensionObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.ExtensionObject>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail, self).__init__()

                                        self.yang_name = "ip-prefix-detail"
                                        self.yang_parent_name = "ip-prefix-details"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detail-fib-entry-information", ("detail_fib_entry_information", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation)), ("fib-entry-path", ("fib_entry_path", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath)), ("extension-object", ("extension_object", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.ExtensionObject))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ('protocol_type_fib_entry', (YLeaf(YType.uint32, 'protocol-type-fib-entry'), ['int'])),
                                            ('platform_hardware', (YLeaf(YType.str, 'platform-hardware'), ['str'])),
                                            ('number_of_referances_to_path_list', (YLeaf(YType.uint32, 'number-of-referances-to-path-list'), ['int'])),
                                            ('path_list_flags', (YLeaf(YType.uint32, 'path-list-flags'), ['int'])),
                                            ('path_list_source', (YLeaf(YType.uint32, 'path-list-source'), ['int'])),
                                            ('number_of_referances_to_ldi', (YLeaf(YType.uint32, 'number-of-referances-to-ldi'), ['int'])),
                                            ('ldi_flags', (YLeaf(YType.uint32, 'ldi-flags'), ['int'])),
                                            ('flags_external_ldi', (YLeaf(YType.uint32, 'flags-external-ldi'), ['int'])),
                                            ('pointer_external_ldi', (YLeaf(YType.uint32, 'pointer-external-ldi'), ['int'])),
                                            ('exact_path_interface_handle', (YLeaf(YType.uint32, 'exact-path-interface-handle'), ['int'])),
                                            ('exact_path_gre_interface_handle', (YLeaf(YType.uint32, 'exact-path-gre-interface-handle'), ['int'])),
                                            ('exact_route_gre_phys_ifh_avail', (YLeaf(YType.boolean, 'exact-route-gre-phys-ifh-avail'), ['bool'])),
                                            ('exact_route_result', (YLeaf(YType.boolean, 'exact-route-result'), ['bool'])),
                                            ('prefix_is_static_or_connected', (YLeaf(YType.boolean, 'prefix-is-static-or-connected'), ['bool'])),
                                            ('packet_should_recieve', (YLeaf(YType.boolean, 'packet-should-recieve'), ['bool'])),
                                            ('prefix_connected', (YLeaf(YType.boolean, 'prefix-connected'), ['bool'])),
                                            ('prefix_for_adjancency', (YLeaf(YType.boolean, 'prefix-for-adjancency'), ['bool'])),
                                            ('prefix_for_pic_next_hop', (YLeaf(YType.boolean, 'prefix-for-pic-next-hop'), ['bool'])),
                                            ('purgable_after_purge_interval', (YLeaf(YType.boolean, 'purgable-after-purge-interval'), ['bool'])),
                                            ('broadcast_recive_flag', (YLeaf(YType.boolean, 'broadcast-recive-flag'), ['bool'])),
                                            ('broadcast_forward_flag', (YLeaf(YType.boolean, 'broadcast-forward-flag'), ['bool'])),
                                            ('zero_by_zero_route_as_default', (YLeaf(YType.boolean, 'zero-by-zero-route-as-default'), ['bool'])),
                                            ('external_switch_triggered', (YLeaf(YType.boolean, 'external-switch-triggered'), ['bool'])),
                                            ('route_attribute_flag', (YLeaf(YType.boolean, 'route-attribute-flag'), ['bool'])),
                                            ('dummy_real_zero_route', (YLeaf(YType.boolean, 'dummy-real-zero-route'), ['bool'])),
                                            ('ldi_lw_flag', (YLeaf(YType.uint32, 'ldi-lw-flag'), ['int'])),
                                            ('ref_counter_of_ldi_lw_ldi', (YLeaf(YType.uint32, 'ref-counter-of-ldi-lw-ldi'), ['int'])),
                                            ('type_of_ldi_lw_ldi', (YLeaf(YType.uint32, 'type-of-ldi-lw-ldi'), ['int'])),
                                            ('lspa_flags', (YLeaf(YType.uint32, 'lspa-flags'), ['int'])),
                                            ('version_of_route', (YLeaf(YType.uint64, 'version-of-route'), ['int'])),
                                            ('fib_route_download_priority', (YLeaf(YType.uint32, 'fib-route-download-priority'), ['int'])),
                                            ('time_of_last_update_in_msec', (YLeaf(YType.uint64, 'time-of-last-update-in-msec'), ['int'])),
                                            ('l2_subscriber_route', (YLeaf(YType.boolean, 'l2-subscriber-route'), ['bool'])),
                                            ('l2_subscriber_xconnect_id', (YLeaf(YType.uint32, 'l2-subscriber-xconnect-id'), ['int'])),
                                            ('l2_subscriber_flags', (YLeaf(YType.uint32, 'l2-subscriber-flags'), ['int'])),
                                            ('l2_subscriber_ip_protocol', (YLeaf(YType.uint32, 'l2-subscriber-ip-protocol'), ['int'])),
                                            ('l2tpv3_cookie_length_bits', (YLeaf(YType.uint32, 'l2tpv3-cookie-length-bits'), ['int'])),
                                            ('route_for_external_reach_linecard_flag', (YLeaf(YType.boolean, 'route-for-external-reach-linecard-flag'), ['bool'])),
                                            ('route_is_sr_flag', (YLeaf(YType.boolean, 'route-is-sr-flag'), ['bool'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.protocol_type_fib_entry = None
                                        self.platform_hardware = None
                                        self.number_of_referances_to_path_list = None
                                        self.path_list_flags = None
                                        self.path_list_source = None
                                        self.number_of_referances_to_ldi = None
                                        self.ldi_flags = None
                                        self.flags_external_ldi = None
                                        self.pointer_external_ldi = None
                                        self.exact_path_interface_handle = None
                                        self.exact_path_gre_interface_handle = None
                                        self.exact_route_gre_phys_ifh_avail = None
                                        self.exact_route_result = None
                                        self.prefix_is_static_or_connected = None
                                        self.packet_should_recieve = None
                                        self.prefix_connected = None
                                        self.prefix_for_adjancency = None
                                        self.prefix_for_pic_next_hop = None
                                        self.purgable_after_purge_interval = None
                                        self.broadcast_recive_flag = None
                                        self.broadcast_forward_flag = None
                                        self.zero_by_zero_route_as_default = None
                                        self.external_switch_triggered = None
                                        self.route_attribute_flag = None
                                        self.dummy_real_zero_route = None
                                        self.ldi_lw_flag = None
                                        self.ref_counter_of_ldi_lw_ldi = None
                                        self.type_of_ldi_lw_ldi = None
                                        self.lspa_flags = None
                                        self.version_of_route = None
                                        self.fib_route_download_priority = None
                                        self.time_of_last_update_in_msec = None
                                        self.l2_subscriber_route = None
                                        self.l2_subscriber_xconnect_id = None
                                        self.l2_subscriber_flags = None
                                        self.l2_subscriber_ip_protocol = None
                                        self.l2tpv3_cookie_length_bits = None
                                        self.route_for_external_reach_linecard_flag = None
                                        self.route_is_sr_flag = None

                                        self.detail_fib_entry_information = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation()
                                        self.detail_fib_entry_information.parent = self
                                        self._children_name_map["detail_fib_entry_information"] = "detail-fib-entry-information"

                                        self.fib_entry_path = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath()
                                        self.fib_entry_path.parent = self
                                        self._children_name_map["fib_entry_path"] = "fib-entry-path"

                                        self.extension_object = YList(self)
                                        self._segment_path = lambda: "ip-prefix-detail"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail, ['prefix', 'prefix_length', 'protocol_type_fib_entry', 'platform_hardware', 'number_of_referances_to_path_list', 'path_list_flags', 'path_list_source', 'number_of_referances_to_ldi', 'ldi_flags', 'flags_external_ldi', 'pointer_external_ldi', 'exact_path_interface_handle', 'exact_path_gre_interface_handle', 'exact_route_gre_phys_ifh_avail', 'exact_route_result', 'prefix_is_static_or_connected', 'packet_should_recieve', 'prefix_connected', 'prefix_for_adjancency', 'prefix_for_pic_next_hop', 'purgable_after_purge_interval', 'broadcast_recive_flag', 'broadcast_forward_flag', 'zero_by_zero_route_as_default', 'external_switch_triggered', 'route_attribute_flag', 'dummy_real_zero_route', 'ldi_lw_flag', 'ref_counter_of_ldi_lw_ldi', 'type_of_ldi_lw_ldi', 'lspa_flags', 'version_of_route', 'fib_route_download_priority', 'time_of_last_update_in_msec', 'l2_subscriber_route', 'l2_subscriber_xconnect_id', 'l2_subscriber_flags', 'l2_subscriber_ip_protocol', 'l2tpv3_cookie_length_bits', 'route_for_external_reach_linecard_flag', 'route_is_sr_flag'], name, value)


                                    class DetailFibEntryInformation(Entity):
                                        """
                                        Detailed FIB entry information
                                        
                                        .. attribute:: loadshare_information
                                        
                                        	Detailed Loadshare info
                                        	**type**\:  :py:class:`LoadshareInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation>`
                                        
                                        .. attribute:: fib_entry_version
                                        
                                        	FIB entry version number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: per_prefix_accounting
                                        
                                        	Per Prefix Accounting
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: load_sharing_type
                                        
                                        	Load sharing type
                                        	**type**\:  :py:class:`FibLoadshareShow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibLoadshareShow>`
                                        
                                        .. attribute:: fib_entry_adjacency_type
                                        
                                        	FIB entry adjacency type
                                        	**type**\:  :py:class:`FibAdjacencyShow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibAdjacencyShow>`
                                        
                                        .. attribute:: fib_protocol_type
                                        
                                        	FIB Protocol type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: afi_fib_protocol_type
                                        
                                        	AFI FIB protocol type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: aib_l3_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: adjacency_address_length
                                        
                                        	ADJ ADDR LEN
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: adjacency_interface
                                        
                                        	ADJ IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fib_special_nh_information_type
                                        
                                        	FIB Special NHINFO Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fib_entry_adjacency_address
                                        
                                        	FIB entry adj address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: fib_entry_adjacency_interface
                                        
                                        	FIB entry adjacency interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: packets_through_fib_entry
                                        
                                        	Packets through this FIB entry
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bytes_through_fib_entry
                                        
                                        	Bytes through this FIB entry
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: detailed_prefix_length
                                        
                                        	Prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix_protocol
                                        
                                        	Prefix protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: precedence_forpackets
                                        
                                        	Precedence for packets to this entry
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: traffic_index_for_packets
                                        
                                        	Traffic index for packets to this entry
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: switch_compontent_id
                                        
                                        	Switch function compontent ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fast_adjacency_flag
                                        
                                        	Fast adjacency flag
                                        	**type**\: bool
                                        
                                        .. attribute:: illegal_fast_adjacency_flag
                                        
                                        	Illegal fast adjacency flag
                                        	**type**\: bool
                                        
                                        .. attribute:: remote_adjacency_flag
                                        
                                        	Remote adjacency flag
                                        	**type**\: bool
                                        
                                        .. attribute:: bgp_attribute_id
                                        
                                        	BGP attribute id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bgp_local_attribute_id
                                        
                                        	BGP local attribute id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bgp_attribute_origin_as
                                        
                                        	BGP attribute origin as
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bgp_attribute_next_hop_as
                                        
                                        	BGP attribute next hop as
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_string
                                        
                                        	As path string
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: extcom_string
                                        
                                        	extcom st
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: com_string
                                        
                                        	com st
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: extended_community
                                        
                                        	extended community
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: qos_group
                                        
                                        	qos group
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mpls_fec
                                        
                                        	mpls fec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: qppb_qos_group_and_ip_precedence
                                        
                                        	qppb QOS group and IP precedence
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: flow_tag
                                        
                                        	PBR flow\-tag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: forward_class
                                        
                                        	SPP forwarding class ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: pl_time_of_last_update_in_msec
                                        
                                        	The time of last update for PL in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: ldi_time_of_last_update_in_msec
                                        
                                        	The time of last update for LDI in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: lwldi_time_of_last_update_in_msec
                                        
                                        	The time of last update for LW\-LDI in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pl_time_stamp_type
                                        
                                        	The type of time\-stamp on PL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation, self).__init__()

                                            self.yang_name = "detail-fib-entry-information"
                                            self.yang_parent_name = "ip-prefix-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("loadshare-information", ("loadshare_information", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation))])
                                            self._leafs = OrderedDict([
                                                ('fib_entry_version', (YLeaf(YType.uint32, 'fib-entry-version'), ['int'])),
                                                ('per_prefix_accounting', (YLeaf(YType.uint8, 'per-prefix-accounting'), ['int'])),
                                                ('load_sharing_type', (YLeaf(YType.enumeration, 'load-sharing-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibLoadshareShow', '')])),
                                                ('fib_entry_adjacency_type', (YLeaf(YType.enumeration, 'fib-entry-adjacency-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibAdjacencyShow', '')])),
                                                ('fib_protocol_type', (YLeaf(YType.uint32, 'fib-protocol-type'), ['int'])),
                                                ('afi_fib_protocol_type', (YLeaf(YType.uint32, 'afi-fib-protocol-type'), ['int'])),
                                                ('aib_l3_address', (YLeaf(YType.str, 'aib-l3-address'), ['str'])),
                                                ('adjacency_address_length', (YLeaf(YType.uint32, 'adjacency-address-length'), ['int'])),
                                                ('adjacency_interface', (YLeaf(YType.uint32, 'adjacency-interface'), ['int'])),
                                                ('fib_special_nh_information_type', (YLeaf(YType.uint32, 'fib-special-nh-information-type'), ['int'])),
                                                ('fib_entry_adjacency_address', (YLeaf(YType.str, 'fib-entry-adjacency-address'), ['str'])),
                                                ('fib_entry_adjacency_interface', (YLeaf(YType.uint32, 'fib-entry-adjacency-interface'), ['int'])),
                                                ('packets_through_fib_entry', (YLeaf(YType.uint64, 'packets-through-fib-entry'), ['int'])),
                                                ('bytes_through_fib_entry', (YLeaf(YType.uint64, 'bytes-through-fib-entry'), ['int'])),
                                                ('detailed_prefix_length', (YLeaf(YType.uint32, 'detailed-prefix-length'), ['int'])),
                                                ('prefix_protocol', (YLeaf(YType.uint32, 'prefix-protocol'), ['int'])),
                                                ('precedence_forpackets', (YLeaf(YType.uint8, 'precedence-forpackets'), ['int'])),
                                                ('traffic_index_for_packets', (YLeaf(YType.uint8, 'traffic-index-for-packets'), ['int'])),
                                                ('switch_compontent_id', (YLeaf(YType.uint32, 'switch-compontent-id'), ['int'])),
                                                ('fast_adjacency_flag', (YLeaf(YType.boolean, 'fast-adjacency-flag'), ['bool'])),
                                                ('illegal_fast_adjacency_flag', (YLeaf(YType.boolean, 'illegal-fast-adjacency-flag'), ['bool'])),
                                                ('remote_adjacency_flag', (YLeaf(YType.boolean, 'remote-adjacency-flag'), ['bool'])),
                                                ('bgp_attribute_id', (YLeaf(YType.uint32, 'bgp-attribute-id'), ['int'])),
                                                ('bgp_local_attribute_id', (YLeaf(YType.uint32, 'bgp-local-attribute-id'), ['int'])),
                                                ('bgp_attribute_origin_as', (YLeaf(YType.uint32, 'bgp-attribute-origin-as'), ['int'])),
                                                ('bgp_attribute_next_hop_as', (YLeaf(YType.uint32, 'bgp-attribute-next-hop-as'), ['int'])),
                                                ('path_string', (YLeaf(YType.str, 'path-string'), ['str'])),
                                                ('extcom_string', (YLeaf(YType.str, 'extcom-string'), ['str'])),
                                                ('com_string', (YLeaf(YType.str, 'com-string'), ['str'])),
                                                ('extended_community', (YLeaf(YType.uint32, 'extended-community'), ['int'])),
                                                ('qos_group', (YLeaf(YType.uint32, 'qos-group'), ['int'])),
                                                ('mpls_fec', (YLeaf(YType.uint32, 'mpls-fec'), ['int'])),
                                                ('qppb_qos_group_and_ip_precedence', (YLeaf(YType.uint32, 'qppb-qos-group-and-ip-precedence'), ['int'])),
                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                ('forward_class', (YLeaf(YType.uint8, 'forward-class'), ['int'])),
                                                ('pl_time_of_last_update_in_msec', (YLeaf(YType.uint64, 'pl-time-of-last-update-in-msec'), ['int'])),
                                                ('ldi_time_of_last_update_in_msec', (YLeaf(YType.uint64, 'ldi-time-of-last-update-in-msec'), ['int'])),
                                                ('lwldi_time_of_last_update_in_msec', (YLeaf(YType.uint64, 'lwldi-time-of-last-update-in-msec'), ['int'])),
                                                ('pl_time_stamp_type', (YLeaf(YType.uint32, 'pl-time-stamp-type'), ['int'])),
                                            ])
                                            self.fib_entry_version = None
                                            self.per_prefix_accounting = None
                                            self.load_sharing_type = None
                                            self.fib_entry_adjacency_type = None
                                            self.fib_protocol_type = None
                                            self.afi_fib_protocol_type = None
                                            self.aib_l3_address = None
                                            self.adjacency_address_length = None
                                            self.adjacency_interface = None
                                            self.fib_special_nh_information_type = None
                                            self.fib_entry_adjacency_address = None
                                            self.fib_entry_adjacency_interface = None
                                            self.packets_through_fib_entry = None
                                            self.bytes_through_fib_entry = None
                                            self.detailed_prefix_length = None
                                            self.prefix_protocol = None
                                            self.precedence_forpackets = None
                                            self.traffic_index_for_packets = None
                                            self.switch_compontent_id = None
                                            self.fast_adjacency_flag = None
                                            self.illegal_fast_adjacency_flag = None
                                            self.remote_adjacency_flag = None
                                            self.bgp_attribute_id = None
                                            self.bgp_local_attribute_id = None
                                            self.bgp_attribute_origin_as = None
                                            self.bgp_attribute_next_hop_as = None
                                            self.path_string = None
                                            self.extcom_string = None
                                            self.com_string = None
                                            self.extended_community = None
                                            self.qos_group = None
                                            self.mpls_fec = None
                                            self.qppb_qos_group_and_ip_precedence = None
                                            self.flow_tag = None
                                            self.forward_class = None
                                            self.pl_time_of_last_update_in_msec = None
                                            self.ldi_time_of_last_update_in_msec = None
                                            self.lwldi_time_of_last_update_in_msec = None
                                            self.pl_time_stamp_type = None

                                            self.loadshare_information = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation()
                                            self.loadshare_information.parent = self
                                            self._children_name_map["loadshare_information"] = "loadshare-information"
                                            self._segment_path = lambda: "detail-fib-entry-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation, ['fib_entry_version', 'per_prefix_accounting', 'load_sharing_type', 'fib_entry_adjacency_type', 'fib_protocol_type', 'afi_fib_protocol_type', 'aib_l3_address', 'adjacency_address_length', 'adjacency_interface', 'fib_special_nh_information_type', 'fib_entry_adjacency_address', 'fib_entry_adjacency_interface', 'packets_through_fib_entry', 'bytes_through_fib_entry', 'detailed_prefix_length', 'prefix_protocol', 'precedence_forpackets', 'traffic_index_for_packets', 'switch_compontent_id', 'fast_adjacency_flag', 'illegal_fast_adjacency_flag', 'remote_adjacency_flag', 'bgp_attribute_id', 'bgp_local_attribute_id', 'bgp_attribute_origin_as', 'bgp_attribute_next_hop_as', 'path_string', 'extcom_string', 'com_string', 'extended_community', 'qos_group', 'mpls_fec', 'qppb_qos_group_and_ip_precedence', 'flow_tag', 'forward_class', 'pl_time_of_last_update_in_msec', 'ldi_time_of_last_update_in_msec', 'lwldi_time_of_last_update_in_msec', 'pl_time_stamp_type'], name, value)


                                        class LoadshareInformation(Entity):
                                            """
                                            Detailed Loadshare info
                                            
                                            .. attribute:: load_informtion_internal_data
                                            
                                            	Loadinfo internal data
                                            	**type**\:  :py:class:`LoadInformtionInternalData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData>`
                                            
                                            .. attribute:: packets_through_load_information
                                            
                                            	Packets through this loadinfo
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: bytes_through_load_information
                                            
                                            	Bytes through this loadinfo
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: total_packets_through_load_information
                                            
                                            	Total packets through this loadinfo
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: total_bytes_through_load_information
                                            
                                            	Total bytes through this loadinfo
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: prefix_of_owner
                                            
                                            	Prefix of the owner
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mask_length_of_owner
                                            
                                            	Mask length of the owner
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: load_information_reference_count
                                            
                                            	Loadinfo reference count
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: per_dest_load_sharing_flag
                                            
                                            	Per destination load sharing flag
                                            	**type**\: bool
                                            
                                            .. attribute:: load_information_owner_deleted_flag
                                            
                                            	Loadinfo owner deleted flag
                                            	**type**\: bool
                                            
                                            .. attribute:: loadinfo_sanity_flag
                                            
                                            	Loadinfo sanity flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_owner
                                            
                                            	Owner flag
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation, self).__init__()

                                                self.yang_name = "loadshare-information"
                                                self.yang_parent_name = "detail-fib-entry-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("load-informtion-internal-data", ("load_informtion_internal_data", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData))])
                                                self._leafs = OrderedDict([
                                                    ('packets_through_load_information', (YLeaf(YType.uint64, 'packets-through-load-information'), ['int'])),
                                                    ('bytes_through_load_information', (YLeaf(YType.uint64, 'bytes-through-load-information'), ['int'])),
                                                    ('total_packets_through_load_information', (YLeaf(YType.uint64, 'total-packets-through-load-information'), ['int'])),
                                                    ('total_bytes_through_load_information', (YLeaf(YType.uint64, 'total-bytes-through-load-information'), ['int'])),
                                                    ('prefix_of_owner', (YLeaf(YType.uint32, 'prefix-of-owner'), ['int'])),
                                                    ('mask_length_of_owner', (YLeaf(YType.uint32, 'mask-length-of-owner'), ['int'])),
                                                    ('load_information_reference_count', (YLeaf(YType.uint16, 'load-information-reference-count'), ['int'])),
                                                    ('per_dest_load_sharing_flag', (YLeaf(YType.boolean, 'per-dest-load-sharing-flag'), ['bool'])),
                                                    ('load_information_owner_deleted_flag', (YLeaf(YType.boolean, 'load-information-owner-deleted-flag'), ['bool'])),
                                                    ('loadinfo_sanity_flag', (YLeaf(YType.boolean, 'loadinfo-sanity-flag'), ['bool'])),
                                                    ('is_owner', (YLeaf(YType.boolean, 'is-owner'), ['bool'])),
                                                ])
                                                self.packets_through_load_information = None
                                                self.bytes_through_load_information = None
                                                self.total_packets_through_load_information = None
                                                self.total_bytes_through_load_information = None
                                                self.prefix_of_owner = None
                                                self.mask_length_of_owner = None
                                                self.load_information_reference_count = None
                                                self.per_dest_load_sharing_flag = None
                                                self.load_information_owner_deleted_flag = None
                                                self.loadinfo_sanity_flag = None
                                                self.is_owner = None

                                                self.load_informtion_internal_data = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData()
                                                self.load_informtion_internal_data.parent = self
                                                self._children_name_map["load_informtion_internal_data"] = "load-informtion-internal-data"
                                                self._segment_path = lambda: "loadshare-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation, ['packets_through_load_information', 'bytes_through_load_information', 'total_packets_through_load_information', 'total_bytes_through_load_information', 'prefix_of_owner', 'mask_length_of_owner', 'load_information_reference_count', 'per_dest_load_sharing_flag', 'load_information_owner_deleted_flag', 'loadinfo_sanity_flag', 'is_owner'], name, value)


                                            class LoadInformtionInternalData(Entity):
                                                """
                                                Loadinfo internal data
                                                
                                                .. attribute:: level_ofldis
                                                
                                                	level of ldis
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: number_of_ldis
                                                
                                                	no. of ldis
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: maximum_index_arrays
                                                
                                                	Maximum index of the arrays
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_indices
                                                
                                                	Path indices
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: path_ldi_numbers
                                                
                                                	Path indices
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: maximum_slots
                                                
                                                	Maximum slots
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: normalized_weights
                                                
                                                	Normalized weights
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_class_value
                                                
                                                	Tunnel class value
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: is_pbts_info_valid
                                                
                                                	PBTS info valid flag
                                                	**type**\: bool
                                                
                                                .. attribute:: pbts_class_offset
                                                
                                                	PBTS class offset
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: pbts_class_num_paths
                                                
                                                	PBTS class num paths
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: pbts_fallback_mapped_class
                                                
                                                	PBTS class falls back to class
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: round_robin_disable
                                                
                                                	Round Robin Disable
                                                	**type**\: bool
                                                
                                                .. attribute:: ldi_next_hop_buckets
                                                
                                                	Number of LDI next hop buckets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: platform_hardware_information
                                                
                                                	Platform Hardware info
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: sanity_flag
                                                
                                                	Sanity flag
                                                	**type**\: list of  		 :py:class:`SanityFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.SanityFlag>`
                                                
                                                .. attribute:: interface_handle
                                                
                                                	Interface handle
                                                	**type**\: list of  		 :py:class:`InterfaceHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.InterfaceHandle>`
                                                
                                                .. attribute:: weights_of_path
                                                
                                                	Weights of paths
                                                	**type**\: list of  		 :py:class:`WeightsOfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.WeightsOfPath>`
                                                
                                                .. attribute:: adjacency_address
                                                
                                                	Adjacency address
                                                	**type**\: list of  		 :py:class:`AdjacencyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.AdjacencyAddress>`
                                                
                                                .. attribute:: pbts_class_is_fallback_mapped
                                                
                                                	Does PBTS class fall back to drop or any class
                                                	**type**\: list of  		 :py:class:`PbtsClassIsFallbackMapped <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsClassIsFallbackMapped>`
                                                
                                                .. attribute:: pbts_fallback_to_drop
                                                
                                                	PBTS class falls back to drop
                                                	**type**\: list of  		 :py:class:`PbtsFallbackToDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsFallbackToDrop>`
                                                
                                                .. attribute:: tunnel_is_forward_class
                                                
                                                	Tunnel is forward class
                                                	**type**\: list of  		 :py:class:`TunnelIsForwardClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.TunnelIsForwardClass>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData, self).__init__()

                                                    self.yang_name = "load-informtion-internal-data"
                                                    self.yang_parent_name = "loadshare-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sanity-flag", ("sanity_flag", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.SanityFlag)), ("interface-handle", ("interface_handle", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.InterfaceHandle)), ("weights-of-path", ("weights_of_path", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.WeightsOfPath)), ("adjacency-address", ("adjacency_address", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.AdjacencyAddress)), ("pbts-class-is-fallback-mapped", ("pbts_class_is_fallback_mapped", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsClassIsFallbackMapped)), ("pbts-fallback-to-drop", ("pbts_fallback_to_drop", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsFallbackToDrop)), ("tunnel-is-forward-class", ("tunnel_is_forward_class", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.TunnelIsForwardClass))])
                                                    self._leafs = OrderedDict([
                                                        ('level_ofldis', (YLeaf(YType.uint8, 'level-ofldis'), ['int'])),
                                                        ('number_of_ldis', (YLeaf(YType.uint8, 'number-of-ldis'), ['int'])),
                                                        ('maximum_index_arrays', (YLeaf(YType.uint32, 'maximum-index-arrays'), ['int'])),
                                                        ('path_indices', (YLeaf(YType.str, 'path-indices'), ['str'])),
                                                        ('path_ldi_numbers', (YLeaf(YType.str, 'path-ldi-numbers'), ['str'])),
                                                        ('maximum_slots', (YLeaf(YType.uint32, 'maximum-slots'), ['int'])),
                                                        ('normalized_weights', (YLeaf(YType.str, 'normalized-weights'), ['str'])),
                                                        ('tunnel_class_value', (YLeaf(YType.str, 'tunnel-class-value'), ['str'])),
                                                        ('is_pbts_info_valid', (YLeaf(YType.boolean, 'is-pbts-info-valid'), ['bool'])),
                                                        ('pbts_class_offset', (YLeaf(YType.str, 'pbts-class-offset'), ['str'])),
                                                        ('pbts_class_num_paths', (YLeaf(YType.str, 'pbts-class-num-paths'), ['str'])),
                                                        ('pbts_fallback_mapped_class', (YLeaf(YType.str, 'pbts-fallback-mapped-class'), ['str'])),
                                                        ('round_robin_disable', (YLeaf(YType.boolean, 'round-robin-disable'), ['bool'])),
                                                        ('ldi_next_hop_buckets', (YLeaf(YType.uint8, 'ldi-next-hop-buckets'), ['int'])),
                                                        ('platform_hardware_information', (YLeaf(YType.str, 'platform-hardware-information'), ['str'])),
                                                    ])
                                                    self.level_ofldis = None
                                                    self.number_of_ldis = None
                                                    self.maximum_index_arrays = None
                                                    self.path_indices = None
                                                    self.path_ldi_numbers = None
                                                    self.maximum_slots = None
                                                    self.normalized_weights = None
                                                    self.tunnel_class_value = None
                                                    self.is_pbts_info_valid = None
                                                    self.pbts_class_offset = None
                                                    self.pbts_class_num_paths = None
                                                    self.pbts_fallback_mapped_class = None
                                                    self.round_robin_disable = None
                                                    self.ldi_next_hop_buckets = None
                                                    self.platform_hardware_information = None

                                                    self.sanity_flag = YList(self)
                                                    self.interface_handle = YList(self)
                                                    self.weights_of_path = YList(self)
                                                    self.adjacency_address = YList(self)
                                                    self.pbts_class_is_fallback_mapped = YList(self)
                                                    self.pbts_fallback_to_drop = YList(self)
                                                    self.tunnel_is_forward_class = YList(self)
                                                    self._segment_path = lambda: "load-informtion-internal-data"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData, ['level_ofldis', 'number_of_ldis', 'maximum_index_arrays', 'path_indices', 'path_ldi_numbers', 'maximum_slots', 'normalized_weights', 'tunnel_class_value', 'is_pbts_info_valid', 'pbts_class_offset', 'pbts_class_num_paths', 'pbts_fallback_mapped_class', 'round_robin_disable', 'ldi_next_hop_buckets', 'platform_hardware_information'], name, value)


                                                class SanityFlag(Entity):
                                                    """
                                                    Sanity flag
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.SanityFlag, self).__init__()

                                                        self.yang_name = "sanity-flag"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "sanity-flag"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.SanityFlag, ['entry'], name, value)


                                                class InterfaceHandle(Entity):
                                                    """
                                                    Interface handle
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.InterfaceHandle, self).__init__()

                                                        self.yang_name = "interface-handle"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "interface-handle"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.InterfaceHandle, ['entry'], name, value)


                                                class WeightsOfPath(Entity):
                                                    """
                                                    Weights of paths
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.WeightsOfPath, self).__init__()

                                                        self.yang_name = "weights-of-path"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "weights-of-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.WeightsOfPath, ['entry'], name, value)


                                                class AdjacencyAddress(Entity):
                                                    """
                                                    Adjacency address
                                                    
                                                    .. attribute:: address
                                                    
                                                    	address
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..60
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.AdjacencyAddress, self).__init__()

                                                        self.yang_name = "adjacency-address"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None
                                                        self._segment_path = lambda: "adjacency-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.AdjacencyAddress, ['address'], name, value)


                                                class PbtsClassIsFallbackMapped(Entity):
                                                    """
                                                    Does PBTS class fall back to drop or any class
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	Array entry
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsClassIsFallbackMapped, self).__init__()

                                                        self.yang_name = "pbts-class-is-fallback-mapped"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pbts-class-is-fallback-mapped"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsClassIsFallbackMapped, ['entry'], name, value)


                                                class PbtsFallbackToDrop(Entity):
                                                    """
                                                    PBTS class falls back to drop
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	Array entry
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsFallbackToDrop, self).__init__()

                                                        self.yang_name = "pbts-fallback-to-drop"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pbts-fallback-to-drop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsFallbackToDrop, ['entry'], name, value)


                                                class TunnelIsForwardClass(Entity):
                                                    """
                                                    Tunnel is forward class
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	Array entry
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.TunnelIsForwardClass, self).__init__()

                                                        self.yang_name = "tunnel-is-forward-class"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "tunnel-is-forward-class"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.TunnelIsForwardClass, ['entry'], name, value)


                                    class FibEntryPath(Entity):
                                        """
                                        FIB entry path details
                                        
                                        .. attribute:: fib_sh_tbl_path
                                        
                                        	fib sh tbl path
                                        	**type**\: list of  		 :py:class:`FibShTblPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath>`
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath, self).__init__()

                                            self.yang_name = "fib-entry-path"
                                            self.yang_parent_name = "ip-prefix-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("fib-sh-tbl-path", ("fib_sh_tbl_path", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath))])
                                            self._leafs = OrderedDict()

                                            self.fib_sh_tbl_path = YList(self)
                                            self._segment_path = lambda: "fib-entry-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath, [], name, value)


                                        class FibShTblPath(Entity):
                                            """
                                            fib sh tbl path
                                            
                                            .. attribute:: more_detail_about_path
                                            
                                            	More detail about this path entry
                                            	**type**\:  :py:class:`MoreDetailAboutPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath>`
                                            
                                            .. attribute:: mpls_information_for_path
                                            
                                            	mpls info for this path entry
                                            	**type**\:  :py:class:`MplsInformationForPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath>`
                                            
                                            .. attribute:: hardware_information
                                            
                                            	Hardware info
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: brief_interface_handle
                                            
                                            	Interface handle
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: brief_next_hop_prefix
                                            
                                            	Next hop prefix
                                            	**type**\: str
                                            
                                            	**length:** 0..52
                                            
                                            .. attribute:: via_label_to_recurse
                                            
                                            	Local label to recurse over
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: brief_pnode_address
                                            
                                            	P\-node address
                                            	**type**\: str
                                            
                                            	**length:** 0..52
                                            
                                            .. attribute:: brief_qnode_address
                                            
                                            	Q\-node address
                                            	**type**\: str
                                            
                                            	**length:** 0..52
                                            
                                            .. attribute:: brief_lfa_protection_type
                                            
                                            	LFA protection type
                                            	**type**\:  :py:class:`FibUpdatePathLfaProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibUpdatePathLfaProtection>`
                                            
                                            .. attribute:: resolved_path
                                            
                                            	Resolved path
                                            	**type**\: bool
                                            
                                            .. attribute:: recursive_path
                                            
                                            	Recursive path
                                            	**type**\: bool
                                            
                                            .. attribute:: packets_received_path
                                            
                                            	Packets received on this path
                                            	**type**\: bool
                                            
                                            .. attribute:: attached_path
                                            
                                            	Attached path
                                            	**type**\: bool
                                            
                                            .. attribute:: backup_path
                                            
                                            	Backup path
                                            	**type**\: bool
                                            
                                            .. attribute:: best_external_path
                                            
                                            	Best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: protect_ignore
                                            
                                            	Is protection ignored
                                            	**type**\: bool
                                            
                                            .. attribute:: path_dlb
                                            
                                            	Is this the path used for DLB
                                            	**type**\: bool
                                            
                                            .. attribute:: path_flags
                                            
                                            	Path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_info_flags
                                            
                                            	Path Info flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: path_index
                                            
                                            	Path index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_index
                                            
                                            	Backup path index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: next_hop_index
                                            
                                            	Next Hop Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: parent_interface_handle
                                            
                                            	Parent Interface Handle
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: recursionvia_len
                                            
                                            	recursion via /N constraint
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath, self).__init__()

                                                self.yang_name = "fib-sh-tbl-path"
                                                self.yang_parent_name = "fib-entry-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("more-detail-about-path", ("more_detail_about_path", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath)), ("mpls-information-for-path", ("mpls_information_for_path", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath))])
                                                self._leafs = OrderedDict([
                                                    ('hardware_information', (YLeaf(YType.str, 'hardware-information'), ['str'])),
                                                    ('brief_interface_handle', (YLeaf(YType.str, 'brief-interface-handle'), ['str'])),
                                                    ('brief_next_hop_prefix', (YLeaf(YType.str, 'brief-next-hop-prefix'), ['str'])),
                                                    ('via_label_to_recurse', (YLeaf(YType.uint32, 'via-label-to-recurse'), ['int'])),
                                                    ('brief_pnode_address', (YLeaf(YType.str, 'brief-pnode-address'), ['str'])),
                                                    ('brief_qnode_address', (YLeaf(YType.str, 'brief-qnode-address'), ['str'])),
                                                    ('brief_lfa_protection_type', (YLeaf(YType.enumeration, 'brief-lfa-protection-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibUpdatePathLfaProtection', '')])),
                                                    ('resolved_path', (YLeaf(YType.boolean, 'resolved-path'), ['bool'])),
                                                    ('recursive_path', (YLeaf(YType.boolean, 'recursive-path'), ['bool'])),
                                                    ('packets_received_path', (YLeaf(YType.boolean, 'packets-received-path'), ['bool'])),
                                                    ('attached_path', (YLeaf(YType.boolean, 'attached-path'), ['bool'])),
                                                    ('backup_path', (YLeaf(YType.boolean, 'backup-path'), ['bool'])),
                                                    ('best_external_path', (YLeaf(YType.boolean, 'best-external-path'), ['bool'])),
                                                    ('protect_ignore', (YLeaf(YType.boolean, 'protect-ignore'), ['bool'])),
                                                    ('path_dlb', (YLeaf(YType.boolean, 'path-dlb'), ['bool'])),
                                                    ('path_flags', (YLeaf(YType.uint32, 'path-flags'), ['int'])),
                                                    ('path_info_flags', (YLeaf(YType.uint16, 'path-info-flags'), ['int'])),
                                                    ('path_index', (YLeaf(YType.uint8, 'path-index'), ['int'])),
                                                    ('backup_index', (YLeaf(YType.uint8, 'backup-index'), ['int'])),
                                                    ('next_hop_index', (YLeaf(YType.uint32, 'next-hop-index'), ['int'])),
                                                    ('parent_interface_handle', (YLeaf(YType.str, 'parent-interface-handle'), ['str'])),
                                                    ('recursionvia_len', (YLeaf(YType.uint8, 'recursionvia-len'), ['int'])),
                                                ])
                                                self.hardware_information = None
                                                self.brief_interface_handle = None
                                                self.brief_next_hop_prefix = None
                                                self.via_label_to_recurse = None
                                                self.brief_pnode_address = None
                                                self.brief_qnode_address = None
                                                self.brief_lfa_protection_type = None
                                                self.resolved_path = None
                                                self.recursive_path = None
                                                self.packets_received_path = None
                                                self.attached_path = None
                                                self.backup_path = None
                                                self.best_external_path = None
                                                self.protect_ignore = None
                                                self.path_dlb = None
                                                self.path_flags = None
                                                self.path_info_flags = None
                                                self.path_index = None
                                                self.backup_index = None
                                                self.next_hop_index = None
                                                self.parent_interface_handle = None
                                                self.recursionvia_len = None

                                                self.more_detail_about_path = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath()
                                                self.more_detail_about_path.parent = self
                                                self._children_name_map["more_detail_about_path"] = "more-detail-about-path"

                                                self.mpls_information_for_path = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath()
                                                self.mpls_information_for_path.parent = self
                                                self._children_name_map["mpls_information_for_path"] = "mpls-information-for-path"
                                                self._segment_path = lambda: "fib-sh-tbl-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath, ['hardware_information', 'brief_interface_handle', 'brief_next_hop_prefix', 'via_label_to_recurse', 'brief_pnode_address', 'brief_qnode_address', 'brief_lfa_protection_type', 'resolved_path', 'recursive_path', 'packets_received_path', 'attached_path', 'backup_path', 'best_external_path', 'protect_ignore', 'path_dlb', 'path_flags', 'path_info_flags', 'path_index', 'backup_index', 'next_hop_index', 'parent_interface_handle', 'recursionvia_len'], name, value)


                                            class MoreDetailAboutPath(Entity):
                                                """
                                                More detail about this path entry
                                                
                                                .. attribute:: ip_address_to_recurse
                                                
                                                	IP address to recurse to
                                                	**type**\: str
                                                
                                                	**length:** 0..52
                                                
                                                .. attribute:: label_to_recurse
                                                
                                                	Local label to recurse over
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: detail_next_hop_prefix
                                                
                                                	Next hop prefix
                                                	**type**\: str
                                                
                                                	**length:** 0..52
                                                
                                                .. attribute:: next_hop_mask_length
                                                
                                                	Next hop mask length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: interface_associated_path
                                                
                                                	Interface associated with this path
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_interface
                                                
                                                	Next hop interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_vrf
                                                
                                                	Next hop VRF
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: tunnle_endpoint_id
                                                
                                                	Tunnel endpoint id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lisprlocid
                                                
                                                	LISP RLOC ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: number_of_dependencies_this_path
                                                
                                                	No. of dependents for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: robin_reset_value
                                                
                                                	Round robin reset value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: recurse_prefix_object
                                                
                                                	Is recursion object a leaf?
                                                	**type**\: bool
                                                
                                                .. attribute:: next_prefix_recursion
                                                
                                                	Next prefix recursion in the path
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: next_prefix_length
                                                
                                                	Next prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: recurse_prefix_object2
                                                
                                                	Recursion has two leaves (e.g. implicit\-null path)
                                                	**type**\: bool
                                                
                                                .. attribute:: next_prefix_recursion2
                                                
                                                	Next prefix2 recursion in the path
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: next_prefix_length2
                                                
                                                	Next prefix2 length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: detail_fib_adjacency_type
                                                
                                                	FIB entry adjacency type
                                                	**type**\:  :py:class:`FibAdjacencyShow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibAdjacencyShow>`
                                                
                                                .. attribute:: current_path_flag
                                                
                                                	Current path flag
                                                	**type**\: bool
                                                
                                                .. attribute:: recursive_path_information
                                                
                                                	Recursive path information is available
                                                	**type**\: bool
                                                
                                                .. attribute:: external_adjacency
                                                
                                                	Path is an external adjacency
                                                	**type**\: bool
                                                
                                                .. attribute:: fib_path_nh_information_type
                                                
                                                	FIB Nhinfo type
                                                	**type**\:  :py:class:`FibNeh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNeh>`
                                                
                                                .. attribute:: fib_path_nh_information_type_special
                                                
                                                	FIB Nhinfo type special
                                                	**type**\:  :py:class:`FibNehSpecial <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNehSpecial>`
                                                
                                                .. attribute:: weight_of_path
                                                
                                                	Weight of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_class
                                                
                                                	Tunnel class of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tunnel_is_forward_class
                                                
                                                	Tunnel is forward class
                                                	**type**\: bool
                                                
                                                .. attribute:: spd_ipencap
                                                
                                                	IP Encap
                                                	**type**\: list of  		 :py:class:`SpdIpencap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap>`
                                                
                                                .. attribute:: next_next_hop
                                                
                                                	Next Next hop sets
                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath.NextNextHop>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath, self).__init__()

                                                    self.yang_name = "more-detail-about-path"
                                                    self.yang_parent_name = "fib-sh-tbl-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("spd-ipencap", ("spd_ipencap", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap)), ("next-next-hop", ("next_next_hop", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath.NextNextHop))])
                                                    self._leafs = OrderedDict([
                                                        ('ip_address_to_recurse', (YLeaf(YType.str, 'ip-address-to-recurse'), ['str'])),
                                                        ('label_to_recurse', (YLeaf(YType.uint32, 'label-to-recurse'), ['int'])),
                                                        ('detail_next_hop_prefix', (YLeaf(YType.str, 'detail-next-hop-prefix'), ['str'])),
                                                        ('next_hop_mask_length', (YLeaf(YType.uint8, 'next-hop-mask-length'), ['int'])),
                                                        ('interface_associated_path', (YLeaf(YType.str, 'interface-associated-path'), ['str'])),
                                                        ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                                        ('next_hop_vrf', (YLeaf(YType.str, 'next-hop-vrf'), ['str'])),
                                                        ('tunnle_endpoint_id', (YLeaf(YType.uint32, 'tunnle-endpoint-id'), ['int'])),
                                                        ('lisprlocid', (YLeaf(YType.uint32, 'lisprlocid'), ['int'])),
                                                        ('number_of_dependencies_this_path', (YLeaf(YType.uint32, 'number-of-dependencies-this-path'), ['int'])),
                                                        ('robin_reset_value', (YLeaf(YType.uint8, 'robin-reset-value'), ['int'])),
                                                        ('recurse_prefix_object', (YLeaf(YType.boolean, 'recurse-prefix-object'), ['bool'])),
                                                        ('next_prefix_recursion', (YLeaf(YType.str, 'next-prefix-recursion'), ['str'])),
                                                        ('next_prefix_length', (YLeaf(YType.uint8, 'next-prefix-length'), ['int'])),
                                                        ('recurse_prefix_object2', (YLeaf(YType.boolean, 'recurse-prefix-object2'), ['bool'])),
                                                        ('next_prefix_recursion2', (YLeaf(YType.str, 'next-prefix-recursion2'), ['str'])),
                                                        ('next_prefix_length2', (YLeaf(YType.uint8, 'next-prefix-length2'), ['int'])),
                                                        ('detail_fib_adjacency_type', (YLeaf(YType.enumeration, 'detail-fib-adjacency-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibAdjacencyShow', '')])),
                                                        ('current_path_flag', (YLeaf(YType.boolean, 'current-path-flag'), ['bool'])),
                                                        ('recursive_path_information', (YLeaf(YType.boolean, 'recursive-path-information'), ['bool'])),
                                                        ('external_adjacency', (YLeaf(YType.boolean, 'external-adjacency'), ['bool'])),
                                                        ('fib_path_nh_information_type', (YLeaf(YType.enumeration, 'fib-path-nh-information-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNeh', '')])),
                                                        ('fib_path_nh_information_type_special', (YLeaf(YType.enumeration, 'fib-path-nh-information-type-special'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNehSpecial', '')])),
                                                        ('weight_of_path', (YLeaf(YType.uint32, 'weight-of-path'), ['int'])),
                                                        ('tunnel_class', (YLeaf(YType.uint8, 'tunnel-class'), ['int'])),
                                                        ('tunnel_is_forward_class', (YLeaf(YType.boolean, 'tunnel-is-forward-class'), ['bool'])),
                                                    ])
                                                    self.ip_address_to_recurse = None
                                                    self.label_to_recurse = None
                                                    self.detail_next_hop_prefix = None
                                                    self.next_hop_mask_length = None
                                                    self.interface_associated_path = None
                                                    self.next_hop_interface = None
                                                    self.next_hop_vrf = None
                                                    self.tunnle_endpoint_id = None
                                                    self.lisprlocid = None
                                                    self.number_of_dependencies_this_path = None
                                                    self.robin_reset_value = None
                                                    self.recurse_prefix_object = None
                                                    self.next_prefix_recursion = None
                                                    self.next_prefix_length = None
                                                    self.recurse_prefix_object2 = None
                                                    self.next_prefix_recursion2 = None
                                                    self.next_prefix_length2 = None
                                                    self.detail_fib_adjacency_type = None
                                                    self.current_path_flag = None
                                                    self.recursive_path_information = None
                                                    self.external_adjacency = None
                                                    self.fib_path_nh_information_type = None
                                                    self.fib_path_nh_information_type_special = None
                                                    self.weight_of_path = None
                                                    self.tunnel_class = None
                                                    self.tunnel_is_forward_class = None

                                                    self.spd_ipencap = YList(self)
                                                    self.next_next_hop = YList(self)
                                                    self._segment_path = lambda: "more-detail-about-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath, ['ip_address_to_recurse', 'label_to_recurse', 'detail_next_hop_prefix', 'next_hop_mask_length', 'interface_associated_path', 'next_hop_interface', 'next_hop_vrf', 'tunnle_endpoint_id', 'lisprlocid', 'number_of_dependencies_this_path', 'robin_reset_value', 'recurse_prefix_object', 'next_prefix_recursion', 'next_prefix_length', 'recurse_prefix_object2', 'next_prefix_recursion2', 'next_prefix_length2', 'detail_fib_adjacency_type', 'current_path_flag', 'recursive_path_information', 'external_adjacency', 'fib_path_nh_information_type', 'fib_path_nh_information_type_special', 'weight_of_path', 'tunnel_class', 'tunnel_is_forward_class'], name, value)


                                                class SpdIpencap(Entity):
                                                    """
                                                    IP Encap
                                                    
                                                    .. attribute:: ip_encap_hdr_count
                                                    
                                                    	Header Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ip_encap_locks
                                                    
                                                    	IPEncap Object Locks
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ip_encap_transport_tbl
                                                    
                                                    	Transport Table
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipe_transport_vrf_name
                                                    
                                                    	Transport VRF name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: ip_encap_transport_af
                                                    
                                                    	Transport AF
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ip_encap_payload_af
                                                    
                                                    	Payload AF
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ip_encap_payload_mtu
                                                    
                                                    	Payload MTU
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ip_encap_parent
                                                    
                                                    	Pointer to parent
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ip_encap_parent_type
                                                    
                                                    	Parent type enumeration
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ip_encap_hdr
                                                    
                                                    	Headers
                                                    	**type**\: list of  		 :py:class:`IpEncapHdr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap.IpEncapHdr>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap, self).__init__()

                                                        self.yang_name = "spd-ipencap"
                                                        self.yang_parent_name = "more-detail-about-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ip-encap-hdr", ("ip_encap_hdr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap.IpEncapHdr))])
                                                        self._leafs = OrderedDict([
                                                            ('ip_encap_hdr_count', (YLeaf(YType.uint8, 'ip-encap-hdr-count'), ['int'])),
                                                            ('ip_encap_locks', (YLeaf(YType.uint32, 'ip-encap-locks'), ['int'])),
                                                            ('ip_encap_transport_tbl', (YLeaf(YType.uint32, 'ip-encap-transport-tbl'), ['int'])),
                                                            ('ipe_transport_vrf_name', (YLeaf(YType.str, 'ipe-transport-vrf-name'), ['str'])),
                                                            ('ip_encap_transport_af', (YLeaf(YType.uint32, 'ip-encap-transport-af'), ['int'])),
                                                            ('ip_encap_payload_af', (YLeaf(YType.uint32, 'ip-encap-payload-af'), ['int'])),
                                                            ('ip_encap_payload_mtu', (YLeaf(YType.uint16, 'ip-encap-payload-mtu'), ['int'])),
                                                            ('ip_encap_parent', (YLeaf(YType.uint32, 'ip-encap-parent'), ['int'])),
                                                            ('ip_encap_parent_type', (YLeaf(YType.uint32, 'ip-encap-parent-type'), ['int'])),
                                                        ])
                                                        self.ip_encap_hdr_count = None
                                                        self.ip_encap_locks = None
                                                        self.ip_encap_transport_tbl = None
                                                        self.ipe_transport_vrf_name = None
                                                        self.ip_encap_transport_af = None
                                                        self.ip_encap_payload_af = None
                                                        self.ip_encap_payload_mtu = None
                                                        self.ip_encap_parent = None
                                                        self.ip_encap_parent_type = None

                                                        self.ip_encap_hdr = YList(self)
                                                        self._segment_path = lambda: "spd-ipencap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap, ['ip_encap_hdr_count', 'ip_encap_locks', 'ip_encap_transport_tbl', 'ipe_transport_vrf_name', 'ip_encap_transport_af', 'ip_encap_payload_af', 'ip_encap_payload_mtu', 'ip_encap_parent', 'ip_encap_parent_type'], name, value)


                                                    class IpEncapHdr(Entity):
                                                        """
                                                        Headers
                                                        
                                                        .. attribute:: ip_encap_hdr_type
                                                        
                                                        	Header Type
                                                        	**type**\:  :py:class:`FibShIpencapHdr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibShIpencapHdr>`
                                                        
                                                        .. attribute:: ip_encap_hdrp
                                                        
                                                        	Static Header
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: ip_encap_hdr_dyn
                                                        
                                                        	Dynamic Header Fields
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap.IpEncapHdr, self).__init__()

                                                            self.yang_name = "ip-encap-hdr"
                                                            self.yang_parent_name = "spd-ipencap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ip_encap_hdr_type', (YLeaf(YType.enumeration, 'ip-encap-hdr-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibShIpencapHdr', '')])),
                                                                ('ip_encap_hdrp', (YLeaf(YType.str, 'ip-encap-hdrp'), ['str'])),
                                                                ('ip_encap_hdr_dyn', (YLeaf(YType.uint32, 'ip-encap-hdr-dyn'), ['int'])),
                                                            ])
                                                            self.ip_encap_hdr_type = None
                                                            self.ip_encap_hdrp = None
                                                            self.ip_encap_hdr_dyn = None
                                                            self._segment_path = lambda: "ip-encap-hdr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap.IpEncapHdr, ['ip_encap_hdr_type', 'ip_encap_hdrp', 'ip_encap_hdr_dyn'], name, value)


                                                class NextNextHop(Entity):
                                                    """
                                                    Next Next hop sets
                                                    
                                                    .. attribute:: next_next_hop_index
                                                    
                                                    	Next next hop index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: next_next_hop_prefix
                                                    
                                                    	Next next hop prefix
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..52
                                                    
                                                    .. attribute:: next_next_hop_interface
                                                    
                                                    	Next next hop interface index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath.NextNextHop, self).__init__()

                                                        self.yang_name = "next-next-hop"
                                                        self.yang_parent_name = "more-detail-about-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_next_hop_index', (YLeaf(YType.uint8, 'next-next-hop-index'), ['int'])),
                                                            ('next_next_hop_prefix', (YLeaf(YType.str, 'next-next-hop-prefix'), ['str'])),
                                                            ('next_next_hop_interface', (YLeaf(YType.uint32, 'next-next-hop-interface'), ['int'])),
                                                        ])
                                                        self.next_next_hop_index = None
                                                        self.next_next_hop_prefix = None
                                                        self.next_next_hop_interface = None
                                                        self._segment_path = lambda: "next-next-hop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MoreDetailAboutPath.NextNextHop, ['next_next_hop_index', 'next_next_hop_prefix', 'next_next_hop_interface'], name, value)


                                            class MplsInformationForPath(Entity):
                                                """
                                                mpls info for this path entry
                                                
                                                .. attribute:: local_lable
                                                
                                                	LocalLable
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: recursive_fwd_chain
                                                
                                                	RecursiveFwdChain
                                                	**type**\: bool
                                                
                                                .. attribute:: number_of_igp_paths
                                                
                                                	NumberOfIGPPaths
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: remote_backup
                                                
                                                	RemoteBackupPath
                                                	**type**\: bool
                                                
                                                .. attribute:: recursive_lbl_stack
                                                
                                                	Recursive Label(s)
                                                	**type**\: list of  		 :py:class:`RecursiveLblStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath.RecursiveLblStack>`
                                                
                                                .. attribute:: igp_label_stack_array
                                                
                                                	igp label stack array
                                                	**type**\: list of  		 :py:class:`IgpLabelStackArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath, self).__init__()

                                                    self.yang_name = "mpls-information-for-path"
                                                    self.yang_parent_name = "fib-sh-tbl-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("recursive-lbl-stack", ("recursive_lbl_stack", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath.RecursiveLblStack)), ("igp-label-stack-array", ("igp_label_stack_array", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray))])
                                                    self._leafs = OrderedDict([
                                                        ('local_lable', (YLeaf(YType.uint32, 'local-lable'), ['int'])),
                                                        ('recursive_fwd_chain', (YLeaf(YType.boolean, 'recursive-fwd-chain'), ['bool'])),
                                                        ('number_of_igp_paths', (YLeaf(YType.uint32, 'number-of-igp-paths'), ['int'])),
                                                        ('remote_backup', (YLeaf(YType.boolean, 'remote-backup'), ['bool'])),
                                                    ])
                                                    self.local_lable = None
                                                    self.recursive_fwd_chain = None
                                                    self.number_of_igp_paths = None
                                                    self.remote_backup = None

                                                    self.recursive_lbl_stack = YList(self)
                                                    self.igp_label_stack_array = YList(self)
                                                    self._segment_path = lambda: "mpls-information-for-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath, ['local_lable', 'recursive_fwd_chain', 'number_of_igp_paths', 'remote_backup'], name, value)


                                                class RecursiveLblStack(Entity):
                                                    """
                                                    Recursive Label(s)
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath.RecursiveLblStack, self).__init__()

                                                        self.yang_name = "recursive-lbl-stack"
                                                        self.yang_parent_name = "mpls-information-for-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "recursive-lbl-stack"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath.RecursiveLblStack, ['entry'], name, value)


                                                class IgpLabelStackArray(Entity):
                                                    """
                                                    igp label stack array
                                                    
                                                    .. attribute:: number_of_labels
                                                    
                                                    	NumberOfLabels
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: out_interface
                                                    
                                                    	OutInterface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: nh_address
                                                    
                                                    	NHAddress
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..52
                                                    
                                                    .. attribute:: lstack
                                                    
                                                    	lstack
                                                    	**type**\: list of  		 :py:class:`Lstack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray.Lstack>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray, self).__init__()

                                                        self.yang_name = "igp-label-stack-array"
                                                        self.yang_parent_name = "mpls-information-for-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lstack", ("lstack", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray.Lstack))])
                                                        self._leafs = OrderedDict([
                                                            ('number_of_labels', (YLeaf(YType.uint32, 'number-of-labels'), ['int'])),
                                                            ('out_interface', (YLeaf(YType.str, 'out-interface'), ['str'])),
                                                            ('nh_address', (YLeaf(YType.str, 'nh-address'), ['str'])),
                                                        ])
                                                        self.number_of_labels = None
                                                        self.out_interface = None
                                                        self.nh_address = None

                                                        self.lstack = YList(self)
                                                        self._segment_path = lambda: "igp-label-stack-array"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray, ['number_of_labels', 'out_interface', 'nh_address'], name, value)


                                                    class Lstack(Entity):
                                                        """
                                                        lstack
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray.Lstack, self).__init__()

                                                            self.yang_name = "lstack"
                                                            self.yang_parent_name = "igp-label-stack-array"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "lstack"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray.Lstack, ['entry'], name, value)


                                    class ExtensionObject(Entity):
                                        """
                                        Leaf Extension Object List
                                        
                                        .. attribute:: sfecd_le
                                        
                                        	sfecd le
                                        	**type**\:  :py:class:`SfecdLe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.ExtensionObject.SfecdLe>`
                                        
                                        .. attribute:: type
                                        
                                        	type
                                        	**type**\:  :py:class:`FibShTblFibExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibShTblFibExtBag>`
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.ExtensionObject, self).__init__()

                                            self.yang_name = "extension-object"
                                            self.yang_parent_name = "ip-prefix-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sfecd-le", ("sfecd_le", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.ExtensionObject.SfecdLe))])
                                            self._leafs = OrderedDict([
                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibShTblFibExtBag', '')])),
                                            ])
                                            self.type = None

                                            self.sfecd_le = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.ExtensionObject.SfecdLe()
                                            self.sfecd_le.parent = self
                                            self._children_name_map["sfecd_le"] = "sfecd-le"
                                            self._segment_path = lambda: "extension-object"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.ExtensionObject, ['type'], name, value)


                                        class SfecdLe(Entity):
                                            """
                                            sfecd le
                                            
                                            .. attribute:: context_label_flag
                                            
                                            	Context Label Exist
                                            	**type**\: bool
                                            
                                            .. attribute:: context_label
                                            
                                            	Context Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.ExtensionObject.SfecdLe, self).__init__()

                                                self.yang_name = "sfecd-le"
                                                self.yang_parent_name = "extension-object"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('context_label_flag', (YLeaf(YType.boolean, 'context-label-flag'), ['bool'])),
                                                    ('context_label', (YLeaf(YType.uint32, 'context-label'), ['int'])),
                                                ])
                                                self.context_label_flag = None
                                                self.context_label = None
                                                self._segment_path = lambda: "sfecd-le"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixDetails.IpPrefixDetail.ExtensionObject.SfecdLe, ['context_label_flag', 'context_label'], name, value)


                            class NhInfoDetail(Entity):
                                """
                                NHInfoTable is accessed by two keys;
                                {NHInterface,NHAddress}
                                
                                .. attribute:: nh_info_local_details
                                
                                	Local (non\-remote) nhinfo
                                	**type**\:  :py:class:`NhInfoLocalDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails>`
                                
                                .. attribute:: nh_info_special_detail
                                
                                	Special nhinfo
                                	**type**\:  :py:class:`NhInfoSpecialDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail>`
                                
                                .. attribute:: nh_info_remote_details
                                
                                	Detailed Remote NHInfo table
                                	**type**\:  :py:class:`NhInfoRemoteDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail, self).__init__()

                                    self.yang_name = "nh-info-detail"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("nh-info-local-details", ("nh_info_local_details", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails)), ("nh-info-special-detail", ("nh_info_special_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail)), ("nh-info-remote-details", ("nh_info_remote_details", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails))])
                                    self._leafs = OrderedDict()

                                    self.nh_info_local_details = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails()
                                    self.nh_info_local_details.parent = self
                                    self._children_name_map["nh_info_local_details"] = "nh-info-local-details"

                                    self.nh_info_special_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail()
                                    self.nh_info_special_detail.parent = self
                                    self._children_name_map["nh_info_special_detail"] = "nh-info-special-detail"

                                    self.nh_info_remote_details = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails()
                                    self.nh_info_remote_details.parent = self
                                    self._children_name_map["nh_info_remote_details"] = "nh-info-remote-details"
                                    self._segment_path = lambda: "nh-info-detail"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail, [], name, value)


                                class NhInfoLocalDetails(Entity):
                                    """
                                    Local (non\-remote) nhinfo
                                    
                                    .. attribute:: nh_info_local_detail
                                    
                                    	Detail NHinfo entry
                                    	**type**\: list of  		 :py:class:`NhInfoLocalDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails, self).__init__()

                                        self.yang_name = "nh-info-local-details"
                                        self.yang_parent_name = "nh-info-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("nh-info-local-detail", ("nh_info_local_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail))])
                                        self._leafs = OrderedDict()

                                        self.nh_info_local_detail = YList(self)
                                        self._segment_path = lambda: "nh-info-local-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails, [], name, value)


                                    class NhInfoLocalDetail(Entity):
                                        """
                                        Detail NHinfo entry
                                        
                                        .. attribute:: nh_interface_name
                                        
                                        	Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: nh_proto
                                        
                                        	Next\-hop proto
                                        	**type**\:  :py:class:`FibProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibProtocol>`
                                        
                                        .. attribute:: nh_pfx_length
                                        
                                        	Next\-hop prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_address
                                        
                                        	Next\-hop address in string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail, self).__init__()

                                            self.yang_name = "nh-info-local-detail"
                                            self.yang_parent_name = "nh-info-local-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('nh_interface_name', (YLeaf(YType.str, 'nh-interface-name'), ['str'])),
                                                ('nh_proto', (YLeaf(YType.enumeration, 'nh-proto'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibProtocol', '')])),
                                                ('nh_pfx_length', (YLeaf(YType.uint32, 'nh-pfx-length'), ['int'])),
                                                ('nh_address', (YLeaf(YType.str, 'nh-address'), ['str'])),
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.nh_interface_name = None
                                            self.nh_proto = None
                                            self.nh_pfx_length = None
                                            self.nh_address = None
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-local-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail, ['nh_interface_name', 'nh_proto', 'nh_pfx_length', 'nh_address', 'si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-local-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-local-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoLocalDetails.NhInfoLocalDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                class NhInfoSpecialDetail(Entity):
                                    """
                                    Special nhinfo
                                    
                                    .. attribute:: nh_info_special_punt_detail
                                    
                                    	Detail special\-punt NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialPuntDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail>`
                                    
                                    .. attribute:: nh_info_special_drop_detail
                                    
                                    	Detail special\-drop NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialDropDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail>`
                                    
                                    .. attribute:: nh_info_special_null_detail
                                    
                                    	Detail special\-null NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialNullDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail>`
                                    
                                    .. attribute:: nh_info_special_discard_detail
                                    
                                    	Detail special\-discard NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialDiscardDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail, self).__init__()

                                        self.yang_name = "nh-info-special-detail"
                                        self.yang_parent_name = "nh-info-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("nh-info-special-punt-detail", ("nh_info_special_punt_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail)), ("nh-info-special-drop-detail", ("nh_info_special_drop_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail)), ("nh-info-special-null-detail", ("nh_info_special_null_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail)), ("nh-info-special-discard-detail", ("nh_info_special_discard_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail))])
                                        self._leafs = OrderedDict()

                                        self.nh_info_special_punt_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail()
                                        self.nh_info_special_punt_detail.parent = self
                                        self._children_name_map["nh_info_special_punt_detail"] = "nh-info-special-punt-detail"

                                        self.nh_info_special_drop_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail()
                                        self.nh_info_special_drop_detail.parent = self
                                        self._children_name_map["nh_info_special_drop_detail"] = "nh-info-special-drop-detail"

                                        self.nh_info_special_null_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail()
                                        self.nh_info_special_null_detail.parent = self
                                        self._children_name_map["nh_info_special_null_detail"] = "nh-info-special-null-detail"

                                        self.nh_info_special_discard_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail()
                                        self.nh_info_special_discard_detail.parent = self
                                        self._children_name_map["nh_info_special_discard_detail"] = "nh-info-special-discard-detail"
                                        self._segment_path = lambda: "nh-info-special-detail"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail, [], name, value)


                                    class NhInfoSpecialPuntDetail(Entity):
                                        """
                                        Detail special\-punt NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail, self).__init__()

                                            self.yang_name = "nh-info-special-punt-detail"
                                            self.yang_parent_name = "nh-info-special-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-punt-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-punt-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-punt-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialPuntDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                    class NhInfoSpecialDropDetail(Entity):
                                        """
                                        Detail special\-drop NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail, self).__init__()

                                            self.yang_name = "nh-info-special-drop-detail"
                                            self.yang_parent_name = "nh-info-special-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-drop-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-drop-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-drop-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDropDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                    class NhInfoSpecialNullDetail(Entity):
                                        """
                                        Detail special\-null NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail, self).__init__()

                                            self.yang_name = "nh-info-special-null-detail"
                                            self.yang_parent_name = "nh-info-special-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-null-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-null-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-null-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialNullDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                    class NhInfoSpecialDiscardDetail(Entity):
                                        """
                                        Detail special\-discard NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail, self).__init__()

                                            self.yang_name = "nh-info-special-discard-detail"
                                            self.yang_parent_name = "nh-info-special-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-discard-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-discard-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-discard-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoSpecialDetail.NhInfoSpecialDiscardDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                class NhInfoRemoteDetails(Entity):
                                    """
                                    Detailed Remote NHInfo table
                                    
                                    .. attribute:: nh_info_remote_detail
                                    
                                    	Detail NHinfo entry
                                    	**type**\: list of  		 :py:class:`NhInfoRemoteDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails, self).__init__()

                                        self.yang_name = "nh-info-remote-details"
                                        self.yang_parent_name = "nh-info-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("nh-info-remote-detail", ("nh_info_remote_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail))])
                                        self._leafs = OrderedDict()

                                        self.nh_info_remote_detail = YList(self)
                                        self._segment_path = lambda: "nh-info-remote-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails, [], name, value)


                                    class NhInfoRemoteDetail(Entity):
                                        """
                                        Detail NHinfo entry
                                        
                                        .. attribute:: nh_interface_name
                                        
                                        	Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: nh_proto
                                        
                                        	Next\-hop proto
                                        	**type**\:  :py:class:`FibProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibProtocol>`
                                        
                                        .. attribute:: nh_pfx_length
                                        
                                        	Next\-hop prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_address
                                        
                                        	Next\-hop address in string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail, self).__init__()

                                            self.yang_name = "nh-info-remote-detail"
                                            self.yang_parent_name = "nh-info-remote-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('nh_interface_name', (YLeaf(YType.str, 'nh-interface-name'), ['str'])),
                                                ('nh_proto', (YLeaf(YType.enumeration, 'nh-proto'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibProtocol', '')])),
                                                ('nh_pfx_length', (YLeaf(YType.uint32, 'nh-pfx-length'), ['int'])),
                                                ('nh_address', (YLeaf(YType.str, 'nh-address'), ['str'])),
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.nh_interface_name = None
                                            self.nh_proto = None
                                            self.nh_pfx_length = None
                                            self.nh_address = None
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-remote-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail, ['nh_interface_name', 'nh_proto', 'nh_pfx_length', 'nh_address', 'si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-remote-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-remote-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetail.NhInfoRemoteDetails.NhInfoRemoteDetail.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                            class Summary(Entity):
                                """
                                Operational data for FIB Tablee
                                
                                .. attribute:: exclusive_load_sharing_element
                                
                                	Exclusive load sharing element
                                	**type**\:  :py:class:`ExclusiveLoadSharingElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.ExclusiveLoadSharingElement>`
                                
                                .. attribute:: shared_load_sharing_element
                                
                                	Shared load sharing element
                                	**type**\:  :py:class:`SharedLoadSharingElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.SharedLoadSharingElement>`
                                
                                .. attribute:: cross_shared_load_sharing_element
                                
                                	Cross\-table shared load sharing element
                                	**type**\:  :py:class:`CrossSharedLoadSharingElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.CrossSharedLoadSharingElement>`
                                
                                .. attribute:: encap_shared_load_sharing_element
                                
                                	Encap\-shared load sharing element
                                	**type**\:  :py:class:`EncapSharedLoadSharingElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.EncapSharedLoadSharingElement>`
                                
                                .. attribute:: prefix_masklen_distribution
                                
                                	Distribution of prefix mask lengths
                                	**type**\:  :py:class:`PrefixMasklenDistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution>`
                                
                                .. attribute:: prefix
                                
                                	The router\-id
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: ss_tbl_id
                                
                                	Table Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ss_tbl_id_ptr
                                
                                	Table Id Ptr
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ss_vrf_id
                                
                                	Virtual routing forwarding instance Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ss_vr_id
                                
                                	Virtual router instance Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: load_balancing
                                
                                	LBA configuration state
                                	**type**\:  :py:class:`SsLbaState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.SsLbaState>`
                                
                                .. attribute:: forwarding_elements
                                
                                	Number of forwarding elements linked to the table
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: routes
                                
                                	Number of routes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_in_place_modifications
                                
                                	Number of inplace modifications
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: stale_prefix_deletes
                                
                                	Number of deleted stale leafs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: load_sharing_elements
                                
                                	Count of load sharing elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: load_sharing_references
                                
                                	Count of load sharing references
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: total_load_share_element_bytes
                                
                                	Total memory used by load sharing elements
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: leaves_used_bytes
                                
                                	Total memory used by leaves
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reresolve_entries
                                
                                	Number of reresolved entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: old_unresolve_entries
                                
                                	Number of old unresolved entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: new_unresolve_entries
                                
                                	Number of new unresolved entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: unresolve_entries
                                
                                	Number of total unresolved entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: cef_route_drops
                                
                                	Number of routes dropped by CEF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: cef_version_mismatch_route_drops
                                
                                	the number of routes dropped due to version mismatch
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: delete_cache_num_entries
                                
                                	Number of entries in the route delete cache
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: existing_leaves_revisions
                                
                                	Number of entries present on addition
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fib_default_prefix
                                
                                	Default prefix
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fib_default_prefix_mask_length
                                
                                	Default prefix mask length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hops
                                
                                	Number of NHINFOS
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: incomplete_next_hops
                                
                                	Number of incomplete NHINFOS
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: resolution_timer
                                
                                	IP CEF resolution timer in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: slow_process_timer
                                
                                	IP CEF slow processing time in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: max_resolution_timer
                                
                                	IP CEF max resolution time in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: imposition_prefixes
                                
                                	Number of prefixes with imposition LDI
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_prefixes
                                
                                	Number of prefixes with extended path\-list
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: cefl_bl_recycled_routes
                                
                                	Number of routes updates with recycled label handled
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ldi_backwalks
                                
                                	pd backwalks on LDI modify with backup path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ss_prot_route_count
                                
                                	Number of routes with FRR protection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lisp_eid_prefixes
                                
                                	Number of lisp eid prefixes associated with table
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lisp_eid_valid_prefixes
                                
                                	Number of lisp eid prefixes eligible for forwarding
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lisp_rloc_objects
                                
                                	Number of lisp rloc objects associated with table
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_sr_labels
                                
                                	Number of SR labels
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ss_vxlan_ltep_ifh
                                
                                	VXLAN local Interface handle
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: ss_drop_pl_count
                                
                                	Number of dropped pathlists
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary, self).__init__()

                                    self.yang_name = "summary"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("exclusive-load-sharing-element", ("exclusive_load_sharing_element", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.ExclusiveLoadSharingElement)), ("shared-load-sharing-element", ("shared_load_sharing_element", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.SharedLoadSharingElement)), ("cross-shared-load-sharing-element", ("cross_shared_load_sharing_element", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.CrossSharedLoadSharingElement)), ("encap-shared-load-sharing-element", ("encap_shared_load_sharing_element", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.EncapSharedLoadSharingElement)), ("prefix-masklen-distribution", ("prefix_masklen_distribution", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                        ('ss_tbl_id', (YLeaf(YType.uint32, 'ss-tbl-id'), ['int'])),
                                        ('ss_tbl_id_ptr', (YLeaf(YType.uint32, 'ss-tbl-id-ptr'), ['int'])),
                                        ('ss_vrf_id', (YLeaf(YType.uint32, 'ss-vrf-id'), ['int'])),
                                        ('ss_vr_id', (YLeaf(YType.uint32, 'ss-vr-id'), ['int'])),
                                        ('load_balancing', (YLeaf(YType.enumeration, 'load-balancing'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'SsLbaState', '')])),
                                        ('forwarding_elements', (YLeaf(YType.uint32, 'forwarding-elements'), ['int'])),
                                        ('routes', (YLeaf(YType.uint32, 'routes'), ['int'])),
                                        ('prefix_in_place_modifications', (YLeaf(YType.uint32, 'prefix-in-place-modifications'), ['int'])),
                                        ('stale_prefix_deletes', (YLeaf(YType.uint32, 'stale-prefix-deletes'), ['int'])),
                                        ('load_sharing_elements', (YLeaf(YType.uint32, 'load-sharing-elements'), ['int'])),
                                        ('load_sharing_references', (YLeaf(YType.uint64, 'load-sharing-references'), ['int'])),
                                        ('total_load_share_element_bytes', (YLeaf(YType.uint32, 'total-load-share-element-bytes'), ['int'])),
                                        ('leaves_used_bytes', (YLeaf(YType.uint32, 'leaves-used-bytes'), ['int'])),
                                        ('reresolve_entries', (YLeaf(YType.uint32, 'reresolve-entries'), ['int'])),
                                        ('old_unresolve_entries', (YLeaf(YType.uint32, 'old-unresolve-entries'), ['int'])),
                                        ('new_unresolve_entries', (YLeaf(YType.uint32, 'new-unresolve-entries'), ['int'])),
                                        ('unresolve_entries', (YLeaf(YType.uint32, 'unresolve-entries'), ['int'])),
                                        ('cef_route_drops', (YLeaf(YType.uint32, 'cef-route-drops'), ['int'])),
                                        ('cef_version_mismatch_route_drops', (YLeaf(YType.uint64, 'cef-version-mismatch-route-drops'), ['int'])),
                                        ('delete_cache_num_entries', (YLeaf(YType.uint32, 'delete-cache-num-entries'), ['int'])),
                                        ('existing_leaves_revisions', (YLeaf(YType.uint32, 'existing-leaves-revisions'), ['int'])),
                                        ('fib_default_prefix', (YLeaf(YType.uint32, 'fib-default-prefix'), ['int'])),
                                        ('fib_default_prefix_mask_length', (YLeaf(YType.uint32, 'fib-default-prefix-mask-length'), ['int'])),
                                        ('next_hops', (YLeaf(YType.uint32, 'next-hops'), ['int'])),
                                        ('incomplete_next_hops', (YLeaf(YType.uint32, 'incomplete-next-hops'), ['int'])),
                                        ('resolution_timer', (YLeaf(YType.uint32, 'resolution-timer'), ['int'])),
                                        ('slow_process_timer', (YLeaf(YType.uint32, 'slow-process-timer'), ['int'])),
                                        ('max_resolution_timer', (YLeaf(YType.uint32, 'max-resolution-timer'), ['int'])),
                                        ('imposition_prefixes', (YLeaf(YType.uint32, 'imposition-prefixes'), ['int'])),
                                        ('extended_prefixes', (YLeaf(YType.uint32, 'extended-prefixes'), ['int'])),
                                        ('cefl_bl_recycled_routes', (YLeaf(YType.uint32, 'cefl-bl-recycled-routes'), ['int'])),
                                        ('ldi_backwalks', (YLeaf(YType.uint32, 'ldi-backwalks'), ['int'])),
                                        ('ss_prot_route_count', (YLeaf(YType.uint32, 'ss-prot-route-count'), ['int'])),
                                        ('lisp_eid_prefixes', (YLeaf(YType.uint32, 'lisp-eid-prefixes'), ['int'])),
                                        ('lisp_eid_valid_prefixes', (YLeaf(YType.uint32, 'lisp-eid-valid-prefixes'), ['int'])),
                                        ('lisp_rloc_objects', (YLeaf(YType.uint32, 'lisp-rloc-objects'), ['int'])),
                                        ('number_of_sr_labels', (YLeaf(YType.uint32, 'number-of-sr-labels'), ['int'])),
                                        ('ss_vxlan_ltep_ifh', (YLeaf(YType.str, 'ss-vxlan-ltep-ifh'), ['str'])),
                                        ('ss_drop_pl_count', (YLeaf(YType.uint32, 'ss-drop-pl-count'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.ss_tbl_id = None
                                    self.ss_tbl_id_ptr = None
                                    self.ss_vrf_id = None
                                    self.ss_vr_id = None
                                    self.load_balancing = None
                                    self.forwarding_elements = None
                                    self.routes = None
                                    self.prefix_in_place_modifications = None
                                    self.stale_prefix_deletes = None
                                    self.load_sharing_elements = None
                                    self.load_sharing_references = None
                                    self.total_load_share_element_bytes = None
                                    self.leaves_used_bytes = None
                                    self.reresolve_entries = None
                                    self.old_unresolve_entries = None
                                    self.new_unresolve_entries = None
                                    self.unresolve_entries = None
                                    self.cef_route_drops = None
                                    self.cef_version_mismatch_route_drops = None
                                    self.delete_cache_num_entries = None
                                    self.existing_leaves_revisions = None
                                    self.fib_default_prefix = None
                                    self.fib_default_prefix_mask_length = None
                                    self.next_hops = None
                                    self.incomplete_next_hops = None
                                    self.resolution_timer = None
                                    self.slow_process_timer = None
                                    self.max_resolution_timer = None
                                    self.imposition_prefixes = None
                                    self.extended_prefixes = None
                                    self.cefl_bl_recycled_routes = None
                                    self.ldi_backwalks = None
                                    self.ss_prot_route_count = None
                                    self.lisp_eid_prefixes = None
                                    self.lisp_eid_valid_prefixes = None
                                    self.lisp_rloc_objects = None
                                    self.number_of_sr_labels = None
                                    self.ss_vxlan_ltep_ifh = None
                                    self.ss_drop_pl_count = None

                                    self.exclusive_load_sharing_element = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.ExclusiveLoadSharingElement()
                                    self.exclusive_load_sharing_element.parent = self
                                    self._children_name_map["exclusive_load_sharing_element"] = "exclusive-load-sharing-element"

                                    self.shared_load_sharing_element = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.SharedLoadSharingElement()
                                    self.shared_load_sharing_element.parent = self
                                    self._children_name_map["shared_load_sharing_element"] = "shared-load-sharing-element"

                                    self.cross_shared_load_sharing_element = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.CrossSharedLoadSharingElement()
                                    self.cross_shared_load_sharing_element.parent = self
                                    self._children_name_map["cross_shared_load_sharing_element"] = "cross-shared-load-sharing-element"

                                    self.encap_shared_load_sharing_element = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.EncapSharedLoadSharingElement()
                                    self.encap_shared_load_sharing_element.parent = self
                                    self._children_name_map["encap_shared_load_sharing_element"] = "encap-shared-load-sharing-element"

                                    self.prefix_masklen_distribution = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution()
                                    self.prefix_masklen_distribution.parent = self
                                    self._children_name_map["prefix_masklen_distribution"] = "prefix-masklen-distribution"
                                    self._segment_path = lambda: "summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary, ['prefix', 'ss_tbl_id', 'ss_tbl_id_ptr', 'ss_vrf_id', 'ss_vr_id', 'load_balancing', 'forwarding_elements', 'routes', 'prefix_in_place_modifications', 'stale_prefix_deletes', 'load_sharing_elements', 'load_sharing_references', 'total_load_share_element_bytes', 'leaves_used_bytes', 'reresolve_entries', 'old_unresolve_entries', 'new_unresolve_entries', 'unresolve_entries', 'cef_route_drops', 'cef_version_mismatch_route_drops', 'delete_cache_num_entries', 'existing_leaves_revisions', 'fib_default_prefix', 'fib_default_prefix_mask_length', 'next_hops', 'incomplete_next_hops', 'resolution_timer', 'slow_process_timer', 'max_resolution_timer', 'imposition_prefixes', 'extended_prefixes', 'cefl_bl_recycled_routes', 'ldi_backwalks', 'ss_prot_route_count', 'lisp_eid_prefixes', 'lisp_eid_valid_prefixes', 'lisp_rloc_objects', 'number_of_sr_labels', 'ss_vxlan_ltep_ifh', 'ss_drop_pl_count'], name, value)


                                class ExclusiveLoadSharingElement(Entity):
                                    """
                                    Exclusive load sharing element
                                    
                                    .. attribute:: total_load_sharing_element_bytes
                                    
                                    	Total memory used by load sharing elements in bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: total_load_sharing_element_references
                                    
                                    	Total count of references to load sharing elements
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: total_path_list_elements
                                    
                                    	Total count of Pathlist elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recursive_path_list_elements
                                    
                                    	Count of recursive Pathlist elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: platform_shared_path_list_elements
                                    
                                    	Count of platform shared Pathlist elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retry_path_list_elements
                                    
                                    	Count of Pathlist elements in retry
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_load_info_elements
                                    
                                    	Total count of Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recursive_load_info_elements
                                    
                                    	Count of recursive Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: platform_shared_load_info_elements
                                    
                                    	Count of platform shared Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: xpl_load_info_elements
                                    
                                    	Count of XPL Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.ExclusiveLoadSharingElement, self).__init__()

                                        self.yang_name = "exclusive-load-sharing-element"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('total_load_sharing_element_bytes', (YLeaf(YType.uint32, 'total-load-sharing-element-bytes'), ['int'])),
                                            ('total_load_sharing_element_references', (YLeaf(YType.uint64, 'total-load-sharing-element-references'), ['int'])),
                                            ('total_path_list_elements', (YLeaf(YType.uint32, 'total-path-list-elements'), ['int'])),
                                            ('recursive_path_list_elements', (YLeaf(YType.uint32, 'recursive-path-list-elements'), ['int'])),
                                            ('platform_shared_path_list_elements', (YLeaf(YType.uint32, 'platform-shared-path-list-elements'), ['int'])),
                                            ('retry_path_list_elements', (YLeaf(YType.uint32, 'retry-path-list-elements'), ['int'])),
                                            ('total_load_info_elements', (YLeaf(YType.uint32, 'total-load-info-elements'), ['int'])),
                                            ('recursive_load_info_elements', (YLeaf(YType.uint32, 'recursive-load-info-elements'), ['int'])),
                                            ('platform_shared_load_info_elements', (YLeaf(YType.uint32, 'platform-shared-load-info-elements'), ['int'])),
                                            ('xpl_load_info_elements', (YLeaf(YType.uint32, 'xpl-load-info-elements'), ['int'])),
                                        ])
                                        self.total_load_sharing_element_bytes = None
                                        self.total_load_sharing_element_references = None
                                        self.total_path_list_elements = None
                                        self.recursive_path_list_elements = None
                                        self.platform_shared_path_list_elements = None
                                        self.retry_path_list_elements = None
                                        self.total_load_info_elements = None
                                        self.recursive_load_info_elements = None
                                        self.platform_shared_load_info_elements = None
                                        self.xpl_load_info_elements = None
                                        self._segment_path = lambda: "exclusive-load-sharing-element"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.ExclusiveLoadSharingElement, ['total_load_sharing_element_bytes', 'total_load_sharing_element_references', 'total_path_list_elements', 'recursive_path_list_elements', 'platform_shared_path_list_elements', 'retry_path_list_elements', 'total_load_info_elements', 'recursive_load_info_elements', 'platform_shared_load_info_elements', 'xpl_load_info_elements'], name, value)


                                class SharedLoadSharingElement(Entity):
                                    """
                                    Shared load sharing element
                                    
                                    .. attribute:: total_load_sharing_element_bytes
                                    
                                    	Total memory used by load sharing elements in bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: total_load_sharing_element_references
                                    
                                    	Total count of references to load sharing elements
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: total_path_list_elements
                                    
                                    	Total count of Pathlist elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recursive_path_list_elements
                                    
                                    	Count of recursive Pathlist elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: platform_shared_path_list_elements
                                    
                                    	Count of platform shared Pathlist elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retry_path_list_elements
                                    
                                    	Count of Pathlist elements in retry
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_load_info_elements
                                    
                                    	Total count of Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recursive_load_info_elements
                                    
                                    	Count of recursive Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: platform_shared_load_info_elements
                                    
                                    	Count of platform shared Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: xpl_load_info_elements
                                    
                                    	Count of XPL Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.SharedLoadSharingElement, self).__init__()

                                        self.yang_name = "shared-load-sharing-element"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('total_load_sharing_element_bytes', (YLeaf(YType.uint32, 'total-load-sharing-element-bytes'), ['int'])),
                                            ('total_load_sharing_element_references', (YLeaf(YType.uint64, 'total-load-sharing-element-references'), ['int'])),
                                            ('total_path_list_elements', (YLeaf(YType.uint32, 'total-path-list-elements'), ['int'])),
                                            ('recursive_path_list_elements', (YLeaf(YType.uint32, 'recursive-path-list-elements'), ['int'])),
                                            ('platform_shared_path_list_elements', (YLeaf(YType.uint32, 'platform-shared-path-list-elements'), ['int'])),
                                            ('retry_path_list_elements', (YLeaf(YType.uint32, 'retry-path-list-elements'), ['int'])),
                                            ('total_load_info_elements', (YLeaf(YType.uint32, 'total-load-info-elements'), ['int'])),
                                            ('recursive_load_info_elements', (YLeaf(YType.uint32, 'recursive-load-info-elements'), ['int'])),
                                            ('platform_shared_load_info_elements', (YLeaf(YType.uint32, 'platform-shared-load-info-elements'), ['int'])),
                                            ('xpl_load_info_elements', (YLeaf(YType.uint32, 'xpl-load-info-elements'), ['int'])),
                                        ])
                                        self.total_load_sharing_element_bytes = None
                                        self.total_load_sharing_element_references = None
                                        self.total_path_list_elements = None
                                        self.recursive_path_list_elements = None
                                        self.platform_shared_path_list_elements = None
                                        self.retry_path_list_elements = None
                                        self.total_load_info_elements = None
                                        self.recursive_load_info_elements = None
                                        self.platform_shared_load_info_elements = None
                                        self.xpl_load_info_elements = None
                                        self._segment_path = lambda: "shared-load-sharing-element"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.SharedLoadSharingElement, ['total_load_sharing_element_bytes', 'total_load_sharing_element_references', 'total_path_list_elements', 'recursive_path_list_elements', 'platform_shared_path_list_elements', 'retry_path_list_elements', 'total_load_info_elements', 'recursive_load_info_elements', 'platform_shared_load_info_elements', 'xpl_load_info_elements'], name, value)


                                class CrossSharedLoadSharingElement(Entity):
                                    """
                                    Cross\-table shared load sharing element
                                    
                                    .. attribute:: total_load_sharing_element_bytes
                                    
                                    	Total memory used by load sharing elements in bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: total_load_sharing_element_references
                                    
                                    	Total count of references to load sharing elements
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: total_path_list_elements
                                    
                                    	Total count of Pathlist elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recursive_path_list_elements
                                    
                                    	Count of recursive Pathlist elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: platform_shared_path_list_elements
                                    
                                    	Count of platform shared Pathlist elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retry_path_list_elements
                                    
                                    	Count of Pathlist elements in retry
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_load_info_elements
                                    
                                    	Total count of Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recursive_load_info_elements
                                    
                                    	Count of recursive Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: platform_shared_load_info_elements
                                    
                                    	Count of platform shared Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: xpl_load_info_elements
                                    
                                    	Count of XPL Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.CrossSharedLoadSharingElement, self).__init__()

                                        self.yang_name = "cross-shared-load-sharing-element"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('total_load_sharing_element_bytes', (YLeaf(YType.uint32, 'total-load-sharing-element-bytes'), ['int'])),
                                            ('total_load_sharing_element_references', (YLeaf(YType.uint64, 'total-load-sharing-element-references'), ['int'])),
                                            ('total_path_list_elements', (YLeaf(YType.uint32, 'total-path-list-elements'), ['int'])),
                                            ('recursive_path_list_elements', (YLeaf(YType.uint32, 'recursive-path-list-elements'), ['int'])),
                                            ('platform_shared_path_list_elements', (YLeaf(YType.uint32, 'platform-shared-path-list-elements'), ['int'])),
                                            ('retry_path_list_elements', (YLeaf(YType.uint32, 'retry-path-list-elements'), ['int'])),
                                            ('total_load_info_elements', (YLeaf(YType.uint32, 'total-load-info-elements'), ['int'])),
                                            ('recursive_load_info_elements', (YLeaf(YType.uint32, 'recursive-load-info-elements'), ['int'])),
                                            ('platform_shared_load_info_elements', (YLeaf(YType.uint32, 'platform-shared-load-info-elements'), ['int'])),
                                            ('xpl_load_info_elements', (YLeaf(YType.uint32, 'xpl-load-info-elements'), ['int'])),
                                        ])
                                        self.total_load_sharing_element_bytes = None
                                        self.total_load_sharing_element_references = None
                                        self.total_path_list_elements = None
                                        self.recursive_path_list_elements = None
                                        self.platform_shared_path_list_elements = None
                                        self.retry_path_list_elements = None
                                        self.total_load_info_elements = None
                                        self.recursive_load_info_elements = None
                                        self.platform_shared_load_info_elements = None
                                        self.xpl_load_info_elements = None
                                        self._segment_path = lambda: "cross-shared-load-sharing-element"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.CrossSharedLoadSharingElement, ['total_load_sharing_element_bytes', 'total_load_sharing_element_references', 'total_path_list_elements', 'recursive_path_list_elements', 'platform_shared_path_list_elements', 'retry_path_list_elements', 'total_load_info_elements', 'recursive_load_info_elements', 'platform_shared_load_info_elements', 'xpl_load_info_elements'], name, value)


                                class EncapSharedLoadSharingElement(Entity):
                                    """
                                    Encap\-shared load sharing element
                                    
                                    .. attribute:: total_load_sharing_element_bytes
                                    
                                    	Total memory used by load sharing elements in bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: total_load_sharing_element_references
                                    
                                    	Total count of references to load sharing elements
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: total_path_list_elements
                                    
                                    	Total count of Pathlist elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recursive_path_list_elements
                                    
                                    	Count of recursive Pathlist elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: platform_shared_path_list_elements
                                    
                                    	Count of platform shared Pathlist elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retry_path_list_elements
                                    
                                    	Count of Pathlist elements in retry
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_load_info_elements
                                    
                                    	Total count of Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: recursive_load_info_elements
                                    
                                    	Count of recursive Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: platform_shared_load_info_elements
                                    
                                    	Count of platform shared Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: xpl_load_info_elements
                                    
                                    	Count of XPL Loadinfo elements
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.EncapSharedLoadSharingElement, self).__init__()

                                        self.yang_name = "encap-shared-load-sharing-element"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('total_load_sharing_element_bytes', (YLeaf(YType.uint32, 'total-load-sharing-element-bytes'), ['int'])),
                                            ('total_load_sharing_element_references', (YLeaf(YType.uint64, 'total-load-sharing-element-references'), ['int'])),
                                            ('total_path_list_elements', (YLeaf(YType.uint32, 'total-path-list-elements'), ['int'])),
                                            ('recursive_path_list_elements', (YLeaf(YType.uint32, 'recursive-path-list-elements'), ['int'])),
                                            ('platform_shared_path_list_elements', (YLeaf(YType.uint32, 'platform-shared-path-list-elements'), ['int'])),
                                            ('retry_path_list_elements', (YLeaf(YType.uint32, 'retry-path-list-elements'), ['int'])),
                                            ('total_load_info_elements', (YLeaf(YType.uint32, 'total-load-info-elements'), ['int'])),
                                            ('recursive_load_info_elements', (YLeaf(YType.uint32, 'recursive-load-info-elements'), ['int'])),
                                            ('platform_shared_load_info_elements', (YLeaf(YType.uint32, 'platform-shared-load-info-elements'), ['int'])),
                                            ('xpl_load_info_elements', (YLeaf(YType.uint32, 'xpl-load-info-elements'), ['int'])),
                                        ])
                                        self.total_load_sharing_element_bytes = None
                                        self.total_load_sharing_element_references = None
                                        self.total_path_list_elements = None
                                        self.recursive_path_list_elements = None
                                        self.platform_shared_path_list_elements = None
                                        self.retry_path_list_elements = None
                                        self.total_load_info_elements = None
                                        self.recursive_load_info_elements = None
                                        self.platform_shared_load_info_elements = None
                                        self.xpl_load_info_elements = None
                                        self._segment_path = lambda: "encap-shared-load-sharing-element"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.EncapSharedLoadSharingElement, ['total_load_sharing_element_bytes', 'total_load_sharing_element_references', 'total_path_list_elements', 'recursive_path_list_elements', 'platform_shared_path_list_elements', 'retry_path_list_elements', 'total_load_info_elements', 'recursive_load_info_elements', 'platform_shared_load_info_elements', 'xpl_load_info_elements'], name, value)


                                class PrefixMasklenDistribution(Entity):
                                    """
                                    Distribution of prefix mask lengths
                                    
                                    .. attribute:: unicast_prefixe
                                    
                                    	Masklength counts for unicast prefixes
                                    	**type**\: list of  		 :py:class:`UnicastPrefixe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution.UnicastPrefixe>`
                                    
                                    .. attribute:: broadcast_prefixe
                                    
                                    	Masklength counts for broadcast prefixes
                                    	**type**\: list of  		 :py:class:`BroadcastPrefixe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution.BroadcastPrefixe>`
                                    
                                    .. attribute:: multicast_prefix
                                    
                                    	Masklength counts for multicast prefixes
                                    	**type**\: list of  		 :py:class:`MulticastPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution.MulticastPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution, self).__init__()

                                        self.yang_name = "prefix-masklen-distribution"
                                        self.yang_parent_name = "summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("unicast-prefixe", ("unicast_prefixe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution.UnicastPrefixe)), ("broadcast-prefixe", ("broadcast_prefixe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution.BroadcastPrefixe)), ("multicast-prefix", ("multicast_prefix", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution.MulticastPrefix))])
                                        self._leafs = OrderedDict()

                                        self.unicast_prefixe = YList(self)
                                        self.broadcast_prefixe = YList(self)
                                        self.multicast_prefix = YList(self)
                                        self._segment_path = lambda: "prefix-masklen-distribution"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution, [], name, value)


                                    class UnicastPrefixe(Entity):
                                        """
                                        Masklength counts for unicast prefixes
                                        
                                        .. attribute:: mask_length
                                        
                                        	Mask length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: number_of_prefixes
                                        
                                        	Number of prefixes with given mask length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution.UnicastPrefixe, self).__init__()

                                            self.yang_name = "unicast-prefixe"
                                            self.yang_parent_name = "prefix-masklen-distribution"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mask_length', (YLeaf(YType.uint8, 'mask-length'), ['int'])),
                                                ('number_of_prefixes', (YLeaf(YType.uint32, 'number-of-prefixes'), ['int'])),
                                            ])
                                            self.mask_length = None
                                            self.number_of_prefixes = None
                                            self._segment_path = lambda: "unicast-prefixe"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution.UnicastPrefixe, ['mask_length', 'number_of_prefixes'], name, value)


                                    class BroadcastPrefixe(Entity):
                                        """
                                        Masklength counts for broadcast prefixes
                                        
                                        .. attribute:: mask_length
                                        
                                        	Mask length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: number_of_prefixes
                                        
                                        	Number of prefixes with given mask length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution.BroadcastPrefixe, self).__init__()

                                            self.yang_name = "broadcast-prefixe"
                                            self.yang_parent_name = "prefix-masklen-distribution"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mask_length', (YLeaf(YType.uint8, 'mask-length'), ['int'])),
                                                ('number_of_prefixes', (YLeaf(YType.uint32, 'number-of-prefixes'), ['int'])),
                                            ])
                                            self.mask_length = None
                                            self.number_of_prefixes = None
                                            self._segment_path = lambda: "broadcast-prefixe"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution.BroadcastPrefixe, ['mask_length', 'number_of_prefixes'], name, value)


                                    class MulticastPrefix(Entity):
                                        """
                                        Masklength counts for multicast prefixes
                                        
                                        .. attribute:: mask_length
                                        
                                        	Mask length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: number_of_prefixes
                                        
                                        	Number of prefixes with given mask length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution.MulticastPrefix, self).__init__()

                                            self.yang_name = "multicast-prefix"
                                            self.yang_parent_name = "prefix-masklen-distribution"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mask_length', (YLeaf(YType.uint8, 'mask-length'), ['int'])),
                                                ('number_of_prefixes', (YLeaf(YType.uint32, 'number-of-prefixes'), ['int'])),
                                            ])
                                            self.mask_length = None
                                            self.number_of_prefixes = None
                                            self._segment_path = lambda: "multicast-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.Summary.PrefixMasklenDistribution.MulticastPrefix, ['mask_length', 'number_of_prefixes'], name, value)


                            class InterfaceInfos(Entity):
                                """
                                Table of InterfaceInfo
                                
                                .. attribute:: interface_info
                                
                                	Specify link type
                                	**type**\: list of  		 :py:class:`InterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos, self).__init__()

                                    self.yang_name = "interface-infos"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("interface-info", ("interface_info", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo))])
                                    self._leafs = OrderedDict()

                                    self.interface_info = YList(self)
                                    self._segment_path = lambda: "interface-infos"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos, [], name, value)


                                class InterfaceInfo(Entity):
                                    """
                                    Specify link type
                                    
                                    .. attribute:: link_type  (key)
                                    
                                    	Link type
                                    	**type**\:  :py:class:`FibLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibLink>`
                                    
                                    .. attribute:: interfaces
                                    
                                    	Table of interfaces
                                    	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo, self).__init__()

                                        self.yang_name = "interface-info"
                                        self.yang_parent_name = "interface-infos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['link_type']
                                        self._child_classes = OrderedDict([("interfaces", ("interfaces", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces))])
                                        self._leafs = OrderedDict([
                                            ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibLink', '')])),
                                        ])
                                        self.link_type = None

                                        self.interfaces = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces()
                                        self.interfaces.parent = self
                                        self._children_name_map["interfaces"] = "interfaces"
                                        self._segment_path = lambda: "interface-info" + "[link-type='" + str(self.link_type) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo, ['link_type'], name, value)


                                    class Interfaces(Entity):
                                        """
                                        Table of interfaces
                                        
                                        .. attribute:: interface
                                        
                                        	Specify Interface name
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces, self).__init__()

                                            self.yang_name = "interfaces"
                                            self.yang_parent_name = "interface-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface))])
                                            self._leafs = OrderedDict()

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interfaces"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces, [], name, value)


                                        class Interface(Entity):
                                            """
                                            Specify Interface name
                                            
                                            .. attribute:: interface_name  (key)
                                            
                                            	Interface Name
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: detail_fib_int_information
                                            
                                            	Detailed FIB interface information
                                            	**type**\:  :py:class:`DetailFibIntInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.DetailFibIntInformation>`
                                            
                                            .. attribute:: si_internal
                                            
                                            	Internal Information
                                            	**type**\:  :py:class:`SiInternal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal>`
                                            
                                            .. attribute:: per_interface
                                            
                                            	Interface handle
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: fib_interface_type
                                            
                                            	FIB Interface type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fib_id_pointer
                                            
                                            	Pointer to fibidb
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fib_id_flags
                                            
                                            	Flags on fibidb
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fib_id_extension_pointer
                                            
                                            	Pointer to fibidb extension
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fib_id_extension_flags
                                            
                                            	Flags on fibidb extension
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_dependent_next_hop_information
                                            
                                            	Number of dependent nhinfo's
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vrf_local_cef_information_pointer
                                            
                                            	Vrf local cef info ptr
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reference_count
                                            
                                            	Reference count
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: last_modified_time
                                            
                                            	Time last modified
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_operation
                                            
                                            	Last Oper
                                            	**type**\:  :py:class:`FibidbOper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibidbOper>`
                                            
                                            .. attribute:: protocol_enabled
                                            
                                            	Is the protocol configured?
                                            	**type**\: bool
                                            
                                            .. attribute:: referance_count_for_protocol
                                            
                                            	Reference count for the protocol
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_input_packets
                                            
                                            	Number of input packets
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: number_of_input_bytes
                                            
                                            	Number of input bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: number_of_output_packets
                                            
                                            	Number of output packets
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: number_of_output_bytes
                                            
                                            	Number of output bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: interface_up_flag
                                            
                                            	Interface up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: per_packet_load_balancing_flag
                                            
                                            	Per packet loadbalancing flag
                                            	**type**\: bool
                                            
                                            .. attribute:: p2p_interface_flag
                                            
                                            	P2P interface flag
                                            	**type**\: bool
                                            
                                            .. attribute:: loopback_interface_flag
                                            
                                            	Loopback interface flag
                                            	**type**\: bool
                                            
                                            .. attribute:: null_interface_flag
                                            
                                            	Null interface flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_interface_flag
                                            
                                            	Tunnel interface flag
                                            	**type**\: bool
                                            
                                            .. attribute:: gre_tunnel_interface_flag
                                            
                                            	GRE Tunnel interface flag
                                            	**type**\: bool
                                            
                                            .. attribute:: punt_packets_from_fib_switching_flag
                                            
                                            	Punt packets from FIB switching flag
                                            	**type**\: bool
                                            
                                            .. attribute:: drop_packets_while_fib_switching_flag
                                            
                                            	Drop packets while FIB switching flag
                                            	**type**\: bool
                                            
                                            .. attribute:: punt_packets_from_linecard_flag
                                            
                                            	Punt packets from linecard flag
                                            	**type**\: bool
                                            
                                            .. attribute:: primary_ipv4_address
                                            
                                            	Pimary local v4 address for the interface
                                            	**type**\: str
                                            
                                            	**length:** 0..52
                                            
                                            .. attribute:: primary_ipv6_address
                                            
                                            	Pimary local v6 address for the interface
                                            	**type**\: str
                                            
                                            	**length:** 0..52
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interfaces"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['interface_name']
                                                self._child_classes = OrderedDict([("detail-fib-int-information", ("detail_fib_int_information", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.DetailFibIntInformation)), ("si-internal", ("si_internal", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('per_interface', (YLeaf(YType.str, 'per-interface'), ['str'])),
                                                    ('fib_interface_type', (YLeaf(YType.uint32, 'fib-interface-type'), ['int'])),
                                                    ('fib_id_pointer', (YLeaf(YType.uint32, 'fib-id-pointer'), ['int'])),
                                                    ('fib_id_flags', (YLeaf(YType.uint32, 'fib-id-flags'), ['int'])),
                                                    ('fib_id_extension_pointer', (YLeaf(YType.uint32, 'fib-id-extension-pointer'), ['int'])),
                                                    ('fib_id_extension_flags', (YLeaf(YType.uint32, 'fib-id-extension-flags'), ['int'])),
                                                    ('number_of_dependent_next_hop_information', (YLeaf(YType.uint32, 'number-of-dependent-next-hop-information'), ['int'])),
                                                    ('vrf_local_cef_information_pointer', (YLeaf(YType.uint32, 'vrf-local-cef-information-pointer'), ['int'])),
                                                    ('reference_count', (YLeaf(YType.uint16, 'reference-count'), ['int'])),
                                                    ('last_modified_time', (YLeaf(YType.uint32, 'last-modified-time'), ['int'])),
                                                    ('last_operation', (YLeaf(YType.enumeration, 'last-operation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibidbOper', '')])),
                                                    ('protocol_enabled', (YLeaf(YType.boolean, 'protocol-enabled'), ['bool'])),
                                                    ('referance_count_for_protocol', (YLeaf(YType.uint32, 'referance-count-for-protocol'), ['int'])),
                                                    ('number_of_input_packets', (YLeaf(YType.uint64, 'number-of-input-packets'), ['int'])),
                                                    ('number_of_input_bytes', (YLeaf(YType.uint64, 'number-of-input-bytes'), ['int'])),
                                                    ('number_of_output_packets', (YLeaf(YType.uint64, 'number-of-output-packets'), ['int'])),
                                                    ('number_of_output_bytes', (YLeaf(YType.uint64, 'number-of-output-bytes'), ['int'])),
                                                    ('interface_up_flag', (YLeaf(YType.boolean, 'interface-up-flag'), ['bool'])),
                                                    ('per_packet_load_balancing_flag', (YLeaf(YType.boolean, 'per-packet-load-balancing-flag'), ['bool'])),
                                                    ('p2p_interface_flag', (YLeaf(YType.boolean, 'p2p-interface-flag'), ['bool'])),
                                                    ('loopback_interface_flag', (YLeaf(YType.boolean, 'loopback-interface-flag'), ['bool'])),
                                                    ('null_interface_flag', (YLeaf(YType.boolean, 'null-interface-flag'), ['bool'])),
                                                    ('tunnel_interface_flag', (YLeaf(YType.boolean, 'tunnel-interface-flag'), ['bool'])),
                                                    ('gre_tunnel_interface_flag', (YLeaf(YType.boolean, 'gre-tunnel-interface-flag'), ['bool'])),
                                                    ('punt_packets_from_fib_switching_flag', (YLeaf(YType.boolean, 'punt-packets-from-fib-switching-flag'), ['bool'])),
                                                    ('drop_packets_while_fib_switching_flag', (YLeaf(YType.boolean, 'drop-packets-while-fib-switching-flag'), ['bool'])),
                                                    ('punt_packets_from_linecard_flag', (YLeaf(YType.boolean, 'punt-packets-from-linecard-flag'), ['bool'])),
                                                    ('primary_ipv4_address', (YLeaf(YType.str, 'primary-ipv4-address'), ['str'])),
                                                    ('primary_ipv6_address', (YLeaf(YType.str, 'primary-ipv6-address'), ['str'])),
                                                ])
                                                self.interface_name = None
                                                self.per_interface = None
                                                self.fib_interface_type = None
                                                self.fib_id_pointer = None
                                                self.fib_id_flags = None
                                                self.fib_id_extension_pointer = None
                                                self.fib_id_extension_flags = None
                                                self.number_of_dependent_next_hop_information = None
                                                self.vrf_local_cef_information_pointer = None
                                                self.reference_count = None
                                                self.last_modified_time = None
                                                self.last_operation = None
                                                self.protocol_enabled = None
                                                self.referance_count_for_protocol = None
                                                self.number_of_input_packets = None
                                                self.number_of_input_bytes = None
                                                self.number_of_output_packets = None
                                                self.number_of_output_bytes = None
                                                self.interface_up_flag = None
                                                self.per_packet_load_balancing_flag = None
                                                self.p2p_interface_flag = None
                                                self.loopback_interface_flag = None
                                                self.null_interface_flag = None
                                                self.tunnel_interface_flag = None
                                                self.gre_tunnel_interface_flag = None
                                                self.punt_packets_from_fib_switching_flag = None
                                                self.drop_packets_while_fib_switching_flag = None
                                                self.punt_packets_from_linecard_flag = None
                                                self.primary_ipv4_address = None
                                                self.primary_ipv6_address = None

                                                self.detail_fib_int_information = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.DetailFibIntInformation()
                                                self.detail_fib_int_information.parent = self
                                                self._children_name_map["detail_fib_int_information"] = "detail-fib-int-information"

                                                self.si_internal = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal()
                                                self.si_internal.parent = self
                                                self._children_name_map["si_internal"] = "si-internal"
                                                self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface, ['interface_name', 'per_interface', 'fib_interface_type', 'fib_id_pointer', 'fib_id_flags', 'fib_id_extension_pointer', 'fib_id_extension_flags', 'number_of_dependent_next_hop_information', 'vrf_local_cef_information_pointer', 'reference_count', 'last_modified_time', 'last_operation', 'protocol_enabled', 'referance_count_for_protocol', 'number_of_input_packets', 'number_of_input_bytes', 'number_of_output_packets', 'number_of_output_bytes', 'interface_up_flag', 'per_packet_load_balancing_flag', 'p2p_interface_flag', 'loopback_interface_flag', 'null_interface_flag', 'tunnel_interface_flag', 'gre_tunnel_interface_flag', 'punt_packets_from_fib_switching_flag', 'drop_packets_while_fib_switching_flag', 'punt_packets_from_linecard_flag', 'primary_ipv4_address', 'primary_ipv6_address'], name, value)


                                            class DetailFibIntInformation(Entity):
                                                """
                                                Detailed FIB interface information
                                                
                                                .. attribute:: interface_mtu
                                                
                                                	Interface Protocol MTU
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: forwarding_flag
                                                
                                                	Forwarding enabled/disabled flag
                                                	**type**\: bool
                                                
                                                .. attribute:: rpf_configured_flag
                                                
                                                	RPF configured flag
                                                	**type**\: bool
                                                
                                                .. attribute:: rpf_mode
                                                
                                                	RPF mode
                                                	**type**\:  :py:class:`FibRpfMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibRpfMode>`
                                                
                                                .. attribute:: default_route_with_rpf
                                                
                                                	Allow default route with RPF
                                                	**type**\: bool
                                                
                                                .. attribute:: self_ping_with_rpf
                                                
                                                	Allow selfping with RPF
                                                	**type**\: bool
                                                
                                                .. attribute:: bgp_pa_input_configured_flag
                                                
                                                	BGP PA configured flag
                                                	**type**\: bool
                                                
                                                .. attribute:: source_bgp_pa_input_configured_flag
                                                
                                                	src BGP PA configured flag
                                                	**type**\: bool
                                                
                                                .. attribute:: destination_bgp_pa_input_configured_flag
                                                
                                                	dst BGP PA configured flag
                                                	**type**\: bool
                                                
                                                .. attribute:: bgp_pa_output_configured_flag
                                                
                                                	BGP PA configured flag
                                                	**type**\: bool
                                                
                                                .. attribute:: source_bgp_pa_output_configured_flag
                                                
                                                	src BGP PA configured flag
                                                	**type**\: bool
                                                
                                                .. attribute:: destination_bgp_pa_output_configured_flag
                                                
                                                	dst BGP PA configured flag
                                                	**type**\: bool
                                                
                                                .. attribute:: icmp_flag
                                                
                                                	ICMP  configured flag
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: multi_label_drop_flag
                                                
                                                	Drop packets with multiple\-label\-stack if set
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.DetailFibIntInformation, self).__init__()

                                                    self.yang_name = "detail-fib-int-information"
                                                    self.yang_parent_name = "interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_mtu', (YLeaf(YType.uint16, 'interface-mtu'), ['int'])),
                                                        ('forwarding_flag', (YLeaf(YType.boolean, 'forwarding-flag'), ['bool'])),
                                                        ('rpf_configured_flag', (YLeaf(YType.boolean, 'rpf-configured-flag'), ['bool'])),
                                                        ('rpf_mode', (YLeaf(YType.enumeration, 'rpf-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibRpfMode', '')])),
                                                        ('default_route_with_rpf', (YLeaf(YType.boolean, 'default-route-with-rpf'), ['bool'])),
                                                        ('self_ping_with_rpf', (YLeaf(YType.boolean, 'self-ping-with-rpf'), ['bool'])),
                                                        ('bgp_pa_input_configured_flag', (YLeaf(YType.boolean, 'bgp-pa-input-configured-flag'), ['bool'])),
                                                        ('source_bgp_pa_input_configured_flag', (YLeaf(YType.boolean, 'source-bgp-pa-input-configured-flag'), ['bool'])),
                                                        ('destination_bgp_pa_input_configured_flag', (YLeaf(YType.boolean, 'destination-bgp-pa-input-configured-flag'), ['bool'])),
                                                        ('bgp_pa_output_configured_flag', (YLeaf(YType.boolean, 'bgp-pa-output-configured-flag'), ['bool'])),
                                                        ('source_bgp_pa_output_configured_flag', (YLeaf(YType.boolean, 'source-bgp-pa-output-configured-flag'), ['bool'])),
                                                        ('destination_bgp_pa_output_configured_flag', (YLeaf(YType.boolean, 'destination-bgp-pa-output-configured-flag'), ['bool'])),
                                                        ('icmp_flag', (YLeaf(YType.uint32, 'icmp-flag'), ['int'])),
                                                        ('multi_label_drop_flag', (YLeaf(YType.boolean, 'multi-label-drop-flag'), ['bool'])),
                                                    ])
                                                    self.interface_mtu = None
                                                    self.forwarding_flag = None
                                                    self.rpf_configured_flag = None
                                                    self.rpf_mode = None
                                                    self.default_route_with_rpf = None
                                                    self.self_ping_with_rpf = None
                                                    self.bgp_pa_input_configured_flag = None
                                                    self.source_bgp_pa_input_configured_flag = None
                                                    self.destination_bgp_pa_input_configured_flag = None
                                                    self.bgp_pa_output_configured_flag = None
                                                    self.source_bgp_pa_output_configured_flag = None
                                                    self.destination_bgp_pa_output_configured_flag = None
                                                    self.icmp_flag = None
                                                    self.multi_label_drop_flag = None
                                                    self._segment_path = lambda: "detail-fib-int-information"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.DetailFibIntInformation, ['interface_mtu', 'forwarding_flag', 'rpf_configured_flag', 'rpf_mode', 'default_route_with_rpf', 'self_ping_with_rpf', 'bgp_pa_input_configured_flag', 'source_bgp_pa_input_configured_flag', 'destination_bgp_pa_input_configured_flag', 'bgp_pa_output_configured_flag', 'source_bgp_pa_output_configured_flag', 'destination_bgp_pa_output_configured_flag', 'icmp_flag', 'multi_label_drop_flag'], name, value)


                                            class SiInternal(Entity):
                                                """
                                                Internal Information
                                                
                                                .. attribute:: fib_idb_hist
                                                
                                                	Event History for IDB
                                                	**type**\:  :py:class:`FibIdbHist <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibIdbHist>`
                                                
                                                .. attribute:: fib_srte_head_hist
                                                
                                                	Event History for Srtehead
                                                	**type**\:  :py:class:`FibSrteHeadHist <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibSrteHeadHist>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal, self).__init__()

                                                    self.yang_name = "si-internal"
                                                    self.yang_parent_name = "interface"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("fib-idb-hist", ("fib_idb_hist", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibIdbHist)), ("fib-srte-head-hist", ("fib_srte_head_hist", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibSrteHeadHist))])
                                                    self._leafs = OrderedDict()

                                                    self.fib_idb_hist = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibIdbHist()
                                                    self.fib_idb_hist.parent = self
                                                    self._children_name_map["fib_idb_hist"] = "fib-idb-hist"

                                                    self.fib_srte_head_hist = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibSrteHeadHist()
                                                    self.fib_srte_head_hist.parent = self
                                                    self._children_name_map["fib_srte_head_hist"] = "fib-srte-head-hist"
                                                    self._segment_path = lambda: "si-internal"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal, [], name, value)


                                                class FibIdbHist(Entity):
                                                    """
                                                    Event History for IDB
                                                    
                                                    .. attribute:: evt_class_name
                                                    
                                                    	Class name string
                                                    	**type**\: str
                                                    
                                                    .. attribute:: evt_entry
                                                    
                                                    	Array of event entries
                                                    	**type**\: list of  		 :py:class:`EvtEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibIdbHist.EvtEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibIdbHist, self).__init__()

                                                        self.yang_name = "fib-idb-hist"
                                                        self.yang_parent_name = "si-internal"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("evt-entry", ("evt_entry", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibIdbHist.EvtEntry))])
                                                        self._leafs = OrderedDict([
                                                            ('evt_class_name', (YLeaf(YType.str, 'evt-class-name'), ['str'])),
                                                        ])
                                                        self.evt_class_name = None

                                                        self.evt_entry = YList(self)
                                                        self._segment_path = lambda: "fib-idb-hist"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibIdbHist, ['evt_class_name'], name, value)


                                                    class EvtEntry(Entity):
                                                        """
                                                        Array of event entries
                                                        
                                                        .. attribute:: evt_timestamp
                                                        
                                                        	The timestamp of the event
                                                        	**type**\: str
                                                        
                                                        .. attribute:: evt_name
                                                        
                                                        	Event name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: evt_type
                                                        
                                                        	Event type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: evt_many
                                                        
                                                        	Multiple instance flag
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: evt_sticky
                                                        
                                                        	Sticky flag
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: evt_data
                                                        
                                                        	Optional data
                                                        	**type**\: list of  		 :py:class:`EvtData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibIdbHist.EvtEntry.EvtData>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibIdbHist.EvtEntry, self).__init__()

                                                            self.yang_name = "evt-entry"
                                                            self.yang_parent_name = "fib-idb-hist"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("evt-data", ("evt_data", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibIdbHist.EvtEntry.EvtData))])
                                                            self._leafs = OrderedDict([
                                                                ('evt_timestamp', (YLeaf(YType.str, 'evt-timestamp'), ['str'])),
                                                                ('evt_name', (YLeaf(YType.str, 'evt-name'), ['str'])),
                                                                ('evt_type', (YLeaf(YType.uint8, 'evt-type'), ['int'])),
                                                                ('evt_many', (YLeaf(YType.boolean, 'evt-many'), ['bool'])),
                                                                ('evt_sticky', (YLeaf(YType.boolean, 'evt-sticky'), ['bool'])),
                                                            ])
                                                            self.evt_timestamp = None
                                                            self.evt_name = None
                                                            self.evt_type = None
                                                            self.evt_many = None
                                                            self.evt_sticky = None

                                                            self.evt_data = YList(self)
                                                            self._segment_path = lambda: "evt-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibIdbHist.EvtEntry, ['evt_timestamp', 'evt_name', 'evt_type', 'evt_many', 'evt_sticky'], name, value)


                                                        class EvtData(Entity):
                                                            """
                                                            Optional data
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'fib-common-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibIdbHist.EvtEntry.EvtData, self).__init__()

                                                                self.yang_name = "evt-data"
                                                                self.yang_parent_name = "evt-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "evt-data"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibIdbHist.EvtEntry.EvtData, ['entry'], name, value)


                                                class FibSrteHeadHist(Entity):
                                                    """
                                                    Event History for Srtehead
                                                    
                                                    .. attribute:: evt_class_name
                                                    
                                                    	Class name string
                                                    	**type**\: str
                                                    
                                                    .. attribute:: evt_entry
                                                    
                                                    	Array of event entries
                                                    	**type**\: list of  		 :py:class:`EvtEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibSrteHeadHist.EvtEntry>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibSrteHeadHist, self).__init__()

                                                        self.yang_name = "fib-srte-head-hist"
                                                        self.yang_parent_name = "si-internal"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("evt-entry", ("evt_entry", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibSrteHeadHist.EvtEntry))])
                                                        self._leafs = OrderedDict([
                                                            ('evt_class_name', (YLeaf(YType.str, 'evt-class-name'), ['str'])),
                                                        ])
                                                        self.evt_class_name = None

                                                        self.evt_entry = YList(self)
                                                        self._segment_path = lambda: "fib-srte-head-hist"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibSrteHeadHist, ['evt_class_name'], name, value)


                                                    class EvtEntry(Entity):
                                                        """
                                                        Array of event entries
                                                        
                                                        .. attribute:: evt_timestamp
                                                        
                                                        	The timestamp of the event
                                                        	**type**\: str
                                                        
                                                        .. attribute:: evt_name
                                                        
                                                        	Event name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: evt_type
                                                        
                                                        	Event type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: evt_many
                                                        
                                                        	Multiple instance flag
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: evt_sticky
                                                        
                                                        	Sticky flag
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: evt_data
                                                        
                                                        	Optional data
                                                        	**type**\: list of  		 :py:class:`EvtData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibSrteHeadHist.EvtEntry.EvtData>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibSrteHeadHist.EvtEntry, self).__init__()

                                                            self.yang_name = "evt-entry"
                                                            self.yang_parent_name = "fib-srte-head-hist"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("evt-data", ("evt_data", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibSrteHeadHist.EvtEntry.EvtData))])
                                                            self._leafs = OrderedDict([
                                                                ('evt_timestamp', (YLeaf(YType.str, 'evt-timestamp'), ['str'])),
                                                                ('evt_name', (YLeaf(YType.str, 'evt-name'), ['str'])),
                                                                ('evt_type', (YLeaf(YType.uint8, 'evt-type'), ['int'])),
                                                                ('evt_many', (YLeaf(YType.boolean, 'evt-many'), ['bool'])),
                                                                ('evt_sticky', (YLeaf(YType.boolean, 'evt-sticky'), ['bool'])),
                                                            ])
                                                            self.evt_timestamp = None
                                                            self.evt_name = None
                                                            self.evt_type = None
                                                            self.evt_many = None
                                                            self.evt_sticky = None

                                                            self.evt_data = YList(self)
                                                            self._segment_path = lambda: "evt-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibSrteHeadHist.EvtEntry, ['evt_timestamp', 'evt_name', 'evt_type', 'evt_many', 'evt_sticky'], name, value)


                                                        class EvtData(Entity):
                                                            """
                                                            Optional data
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'fib-common-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibSrteHeadHist.EvtEntry.EvtData, self).__init__()

                                                                self.yang_name = "evt-data"
                                                                self.yang_parent_name = "evt-entry"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "evt-data"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.InterfaceInfos.InterfaceInfo.Interfaces.Interface.SiInternal.FibSrteHeadHist.EvtEntry.EvtData, ['entry'], name, value)


                            class IpPrefixBriefs(Entity):
                                """
                                IP FIB prefix brief table
                                
                                .. attribute:: ip_prefix_brief
                                
                                	IP FIB prefix brief table entry
                                	**type**\: list of  		 :py:class:`IpPrefixBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs, self).__init__()

                                    self.yang_name = "ip-prefix-briefs"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ip-prefix-brief", ("ip_prefix_brief", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief))])
                                    self._leafs = OrderedDict()

                                    self.ip_prefix_brief = YList(self)
                                    self._segment_path = lambda: "ip-prefix-briefs"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs, [], name, value)


                                class IpPrefixBrief(Entity):
                                    """
                                    IP FIB prefix brief table entry
                                    
                                    .. attribute:: prefix
                                    
                                    	Destination IP address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	IP prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: detail_fib_entry_information
                                    
                                    	Detailed FIB entry information
                                    	**type**\:  :py:class:`DetailFibEntryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation>`
                                    
                                    .. attribute:: fib_entry_path
                                    
                                    	FIB entry path details
                                    	**type**\:  :py:class:`FibEntryPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath>`
                                    
                                    .. attribute:: protocol_type_fib_entry
                                    
                                    	Proto type for this entry
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: platform_hardware
                                    
                                    	Platform Hardware info
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: number_of_referances_to_path_list
                                    
                                    	Number of references to the pathlist
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_list_flags
                                    
                                    	The pathlist flags
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_list_source
                                    
                                    	The pathlist source
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_referances_to_ldi
                                    
                                    	Number of references to the LDI
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ldi_flags
                                    
                                    	The LDI flags
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flags_external_ldi
                                    
                                    	The flags of ext assocaited with LDI 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pointer_external_ldi
                                    
                                    	The pointer to the ext assocaited with LDI
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: exact_path_interface_handle
                                    
                                    	exact\-path interface handle
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: exact_path_gre_interface_handle
                                    
                                    	exact\-path GRE physical interface handle
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: exact_route_gre_phys_ifh_avail
                                    
                                    	exact\-route GRE phy ifh available
                                    	**type**\: bool
                                    
                                    .. attribute:: exact_route_result
                                    
                                    	exact\-route result
                                    	**type**\: bool
                                    
                                    .. attribute:: prefix_is_static_or_connected
                                    
                                    	Prefix is static or connected
                                    	**type**\: bool
                                    
                                    .. attribute:: packet_should_recieve
                                    
                                    	Packet should always be received
                                    	**type**\: bool
                                    
                                    .. attribute:: prefix_connected
                                    
                                    	Prefix is connected
                                    	**type**\: bool
                                    
                                    .. attribute:: prefix_for_adjancency
                                    
                                    	Prefix is for an adjacency
                                    	**type**\: bool
                                    
                                    .. attribute:: prefix_for_pic_next_hop
                                    
                                    	Prefix is for a PIC nexthop
                                    	**type**\: bool
                                    
                                    .. attribute:: purgable_after_purge_interval
                                    
                                    	Purgable after the purge interval
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast_recive_flag
                                    
                                    	Broadcast receive flag
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast_forward_flag
                                    
                                    	Broadcast forward flag
                                    	**type**\: bool
                                    
                                    .. attribute:: zero_by_zero_route_as_default
                                    
                                    	0/0 route added as default route
                                    	**type**\: bool
                                    
                                    .. attribute:: external_switch_triggered
                                    
                                    	External switch function triggered
                                    	**type**\: bool
                                    
                                    .. attribute:: route_attribute_flag
                                    
                                    	Route attributes summary flag
                                    	**type**\: bool
                                    
                                    .. attribute:: dummy_real_zero_route
                                    
                                    	Dummy real zero route
                                    	**type**\: bool
                                    
                                    .. attribute:: ldi_lw_flag
                                    
                                    	The LDI LW flags
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ref_counter_of_ldi_lw_ldi
                                    
                                    	The refcounter of LDI LW LDI
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: type_of_ldi_lw_ldi
                                    
                                    	The type of LDI LW LDI
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lspa_flags
                                    
                                    	The LSPA flags
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_of_route
                                    
                                    	The version of the route
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: fib_route_download_priority
                                    
                                    	Priority at which the route was downloaded
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_of_last_update_in_msec
                                    
                                    	The time of last update in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: l2_subscriber_route
                                    
                                    	Is L2 Subscriber route
                                    	**type**\: bool
                                    
                                    .. attribute:: l2_subscriber_xconnect_id
                                    
                                    	XConnect\-id associated with L2 subscriber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: l2_subscriber_flags
                                    
                                    	Flags associated with L2 subscriber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: l2_subscriber_ip_protocol
                                    
                                    	IP protocol associated with L2 subscriber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: l2tpv3_cookie_length_bits
                                    
                                    	L2TPv3 cookie length for L2 subscriber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_for_external_reach_linecard_flag
                                    
                                    	Route destined for Line Card that support External Reach only
                                    	**type**\: bool
                                    
                                    .. attribute:: route_is_sr_flag
                                    
                                    	Route is a MPLS Segment\-Routing prefix
                                    	**type**\: bool
                                    
                                    .. attribute:: extension_object
                                    
                                    	Leaf Extension Object List
                                    	**type**\: list of  		 :py:class:`ExtensionObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.ExtensionObject>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief, self).__init__()

                                        self.yang_name = "ip-prefix-brief"
                                        self.yang_parent_name = "ip-prefix-briefs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("detail-fib-entry-information", ("detail_fib_entry_information", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation)), ("fib-entry-path", ("fib_entry_path", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath)), ("extension-object", ("extension_object", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.ExtensionObject))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ('protocol_type_fib_entry', (YLeaf(YType.uint32, 'protocol-type-fib-entry'), ['int'])),
                                            ('platform_hardware', (YLeaf(YType.str, 'platform-hardware'), ['str'])),
                                            ('number_of_referances_to_path_list', (YLeaf(YType.uint32, 'number-of-referances-to-path-list'), ['int'])),
                                            ('path_list_flags', (YLeaf(YType.uint32, 'path-list-flags'), ['int'])),
                                            ('path_list_source', (YLeaf(YType.uint32, 'path-list-source'), ['int'])),
                                            ('number_of_referances_to_ldi', (YLeaf(YType.uint32, 'number-of-referances-to-ldi'), ['int'])),
                                            ('ldi_flags', (YLeaf(YType.uint32, 'ldi-flags'), ['int'])),
                                            ('flags_external_ldi', (YLeaf(YType.uint32, 'flags-external-ldi'), ['int'])),
                                            ('pointer_external_ldi', (YLeaf(YType.uint32, 'pointer-external-ldi'), ['int'])),
                                            ('exact_path_interface_handle', (YLeaf(YType.uint32, 'exact-path-interface-handle'), ['int'])),
                                            ('exact_path_gre_interface_handle', (YLeaf(YType.uint32, 'exact-path-gre-interface-handle'), ['int'])),
                                            ('exact_route_gre_phys_ifh_avail', (YLeaf(YType.boolean, 'exact-route-gre-phys-ifh-avail'), ['bool'])),
                                            ('exact_route_result', (YLeaf(YType.boolean, 'exact-route-result'), ['bool'])),
                                            ('prefix_is_static_or_connected', (YLeaf(YType.boolean, 'prefix-is-static-or-connected'), ['bool'])),
                                            ('packet_should_recieve', (YLeaf(YType.boolean, 'packet-should-recieve'), ['bool'])),
                                            ('prefix_connected', (YLeaf(YType.boolean, 'prefix-connected'), ['bool'])),
                                            ('prefix_for_adjancency', (YLeaf(YType.boolean, 'prefix-for-adjancency'), ['bool'])),
                                            ('prefix_for_pic_next_hop', (YLeaf(YType.boolean, 'prefix-for-pic-next-hop'), ['bool'])),
                                            ('purgable_after_purge_interval', (YLeaf(YType.boolean, 'purgable-after-purge-interval'), ['bool'])),
                                            ('broadcast_recive_flag', (YLeaf(YType.boolean, 'broadcast-recive-flag'), ['bool'])),
                                            ('broadcast_forward_flag', (YLeaf(YType.boolean, 'broadcast-forward-flag'), ['bool'])),
                                            ('zero_by_zero_route_as_default', (YLeaf(YType.boolean, 'zero-by-zero-route-as-default'), ['bool'])),
                                            ('external_switch_triggered', (YLeaf(YType.boolean, 'external-switch-triggered'), ['bool'])),
                                            ('route_attribute_flag', (YLeaf(YType.boolean, 'route-attribute-flag'), ['bool'])),
                                            ('dummy_real_zero_route', (YLeaf(YType.boolean, 'dummy-real-zero-route'), ['bool'])),
                                            ('ldi_lw_flag', (YLeaf(YType.uint32, 'ldi-lw-flag'), ['int'])),
                                            ('ref_counter_of_ldi_lw_ldi', (YLeaf(YType.uint32, 'ref-counter-of-ldi-lw-ldi'), ['int'])),
                                            ('type_of_ldi_lw_ldi', (YLeaf(YType.uint32, 'type-of-ldi-lw-ldi'), ['int'])),
                                            ('lspa_flags', (YLeaf(YType.uint32, 'lspa-flags'), ['int'])),
                                            ('version_of_route', (YLeaf(YType.uint64, 'version-of-route'), ['int'])),
                                            ('fib_route_download_priority', (YLeaf(YType.uint32, 'fib-route-download-priority'), ['int'])),
                                            ('time_of_last_update_in_msec', (YLeaf(YType.uint64, 'time-of-last-update-in-msec'), ['int'])),
                                            ('l2_subscriber_route', (YLeaf(YType.boolean, 'l2-subscriber-route'), ['bool'])),
                                            ('l2_subscriber_xconnect_id', (YLeaf(YType.uint32, 'l2-subscriber-xconnect-id'), ['int'])),
                                            ('l2_subscriber_flags', (YLeaf(YType.uint32, 'l2-subscriber-flags'), ['int'])),
                                            ('l2_subscriber_ip_protocol', (YLeaf(YType.uint32, 'l2-subscriber-ip-protocol'), ['int'])),
                                            ('l2tpv3_cookie_length_bits', (YLeaf(YType.uint32, 'l2tpv3-cookie-length-bits'), ['int'])),
                                            ('route_for_external_reach_linecard_flag', (YLeaf(YType.boolean, 'route-for-external-reach-linecard-flag'), ['bool'])),
                                            ('route_is_sr_flag', (YLeaf(YType.boolean, 'route-is-sr-flag'), ['bool'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.protocol_type_fib_entry = None
                                        self.platform_hardware = None
                                        self.number_of_referances_to_path_list = None
                                        self.path_list_flags = None
                                        self.path_list_source = None
                                        self.number_of_referances_to_ldi = None
                                        self.ldi_flags = None
                                        self.flags_external_ldi = None
                                        self.pointer_external_ldi = None
                                        self.exact_path_interface_handle = None
                                        self.exact_path_gre_interface_handle = None
                                        self.exact_route_gre_phys_ifh_avail = None
                                        self.exact_route_result = None
                                        self.prefix_is_static_or_connected = None
                                        self.packet_should_recieve = None
                                        self.prefix_connected = None
                                        self.prefix_for_adjancency = None
                                        self.prefix_for_pic_next_hop = None
                                        self.purgable_after_purge_interval = None
                                        self.broadcast_recive_flag = None
                                        self.broadcast_forward_flag = None
                                        self.zero_by_zero_route_as_default = None
                                        self.external_switch_triggered = None
                                        self.route_attribute_flag = None
                                        self.dummy_real_zero_route = None
                                        self.ldi_lw_flag = None
                                        self.ref_counter_of_ldi_lw_ldi = None
                                        self.type_of_ldi_lw_ldi = None
                                        self.lspa_flags = None
                                        self.version_of_route = None
                                        self.fib_route_download_priority = None
                                        self.time_of_last_update_in_msec = None
                                        self.l2_subscriber_route = None
                                        self.l2_subscriber_xconnect_id = None
                                        self.l2_subscriber_flags = None
                                        self.l2_subscriber_ip_protocol = None
                                        self.l2tpv3_cookie_length_bits = None
                                        self.route_for_external_reach_linecard_flag = None
                                        self.route_is_sr_flag = None

                                        self.detail_fib_entry_information = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation()
                                        self.detail_fib_entry_information.parent = self
                                        self._children_name_map["detail_fib_entry_information"] = "detail-fib-entry-information"

                                        self.fib_entry_path = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath()
                                        self.fib_entry_path.parent = self
                                        self._children_name_map["fib_entry_path"] = "fib-entry-path"

                                        self.extension_object = YList(self)
                                        self._segment_path = lambda: "ip-prefix-brief"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief, ['prefix', 'prefix_length', 'protocol_type_fib_entry', 'platform_hardware', 'number_of_referances_to_path_list', 'path_list_flags', 'path_list_source', 'number_of_referances_to_ldi', 'ldi_flags', 'flags_external_ldi', 'pointer_external_ldi', 'exact_path_interface_handle', 'exact_path_gre_interface_handle', 'exact_route_gre_phys_ifh_avail', 'exact_route_result', 'prefix_is_static_or_connected', 'packet_should_recieve', 'prefix_connected', 'prefix_for_adjancency', 'prefix_for_pic_next_hop', 'purgable_after_purge_interval', 'broadcast_recive_flag', 'broadcast_forward_flag', 'zero_by_zero_route_as_default', 'external_switch_triggered', 'route_attribute_flag', 'dummy_real_zero_route', 'ldi_lw_flag', 'ref_counter_of_ldi_lw_ldi', 'type_of_ldi_lw_ldi', 'lspa_flags', 'version_of_route', 'fib_route_download_priority', 'time_of_last_update_in_msec', 'l2_subscriber_route', 'l2_subscriber_xconnect_id', 'l2_subscriber_flags', 'l2_subscriber_ip_protocol', 'l2tpv3_cookie_length_bits', 'route_for_external_reach_linecard_flag', 'route_is_sr_flag'], name, value)


                                    class DetailFibEntryInformation(Entity):
                                        """
                                        Detailed FIB entry information
                                        
                                        .. attribute:: loadshare_information
                                        
                                        	Detailed Loadshare info
                                        	**type**\:  :py:class:`LoadshareInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation>`
                                        
                                        .. attribute:: fib_entry_version
                                        
                                        	FIB entry version number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: per_prefix_accounting
                                        
                                        	Per Prefix Accounting
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: load_sharing_type
                                        
                                        	Load sharing type
                                        	**type**\:  :py:class:`FibLoadshareShow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibLoadshareShow>`
                                        
                                        .. attribute:: fib_entry_adjacency_type
                                        
                                        	FIB entry adjacency type
                                        	**type**\:  :py:class:`FibAdjacencyShow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibAdjacencyShow>`
                                        
                                        .. attribute:: fib_protocol_type
                                        
                                        	FIB Protocol type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: afi_fib_protocol_type
                                        
                                        	AFI FIB protocol type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: aib_l3_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: adjacency_address_length
                                        
                                        	ADJ ADDR LEN
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: adjacency_interface
                                        
                                        	ADJ IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fib_special_nh_information_type
                                        
                                        	FIB Special NHINFO Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fib_entry_adjacency_address
                                        
                                        	FIB entry adj address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: fib_entry_adjacency_interface
                                        
                                        	FIB entry adjacency interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: packets_through_fib_entry
                                        
                                        	Packets through this FIB entry
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bytes_through_fib_entry
                                        
                                        	Bytes through this FIB entry
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: detailed_prefix_length
                                        
                                        	Prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix_protocol
                                        
                                        	Prefix protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: precedence_forpackets
                                        
                                        	Precedence for packets to this entry
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: traffic_index_for_packets
                                        
                                        	Traffic index for packets to this entry
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: switch_compontent_id
                                        
                                        	Switch function compontent ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fast_adjacency_flag
                                        
                                        	Fast adjacency flag
                                        	**type**\: bool
                                        
                                        .. attribute:: illegal_fast_adjacency_flag
                                        
                                        	Illegal fast adjacency flag
                                        	**type**\: bool
                                        
                                        .. attribute:: remote_adjacency_flag
                                        
                                        	Remote adjacency flag
                                        	**type**\: bool
                                        
                                        .. attribute:: bgp_attribute_id
                                        
                                        	BGP attribute id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bgp_local_attribute_id
                                        
                                        	BGP local attribute id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bgp_attribute_origin_as
                                        
                                        	BGP attribute origin as
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bgp_attribute_next_hop_as
                                        
                                        	BGP attribute next hop as
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_string
                                        
                                        	As path string
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: extcom_string
                                        
                                        	extcom st
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: com_string
                                        
                                        	com st
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: extended_community
                                        
                                        	extended community
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: qos_group
                                        
                                        	qos group
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mpls_fec
                                        
                                        	mpls fec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: qppb_qos_group_and_ip_precedence
                                        
                                        	qppb QOS group and IP precedence
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: flow_tag
                                        
                                        	PBR flow\-tag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: forward_class
                                        
                                        	SPP forwarding class ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: pl_time_of_last_update_in_msec
                                        
                                        	The time of last update for PL in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: ldi_time_of_last_update_in_msec
                                        
                                        	The time of last update for LDI in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: lwldi_time_of_last_update_in_msec
                                        
                                        	The time of last update for LW\-LDI in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pl_time_stamp_type
                                        
                                        	The type of time\-stamp on PL
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation, self).__init__()

                                            self.yang_name = "detail-fib-entry-information"
                                            self.yang_parent_name = "ip-prefix-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("loadshare-information", ("loadshare_information", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation))])
                                            self._leafs = OrderedDict([
                                                ('fib_entry_version', (YLeaf(YType.uint32, 'fib-entry-version'), ['int'])),
                                                ('per_prefix_accounting', (YLeaf(YType.uint8, 'per-prefix-accounting'), ['int'])),
                                                ('load_sharing_type', (YLeaf(YType.enumeration, 'load-sharing-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibLoadshareShow', '')])),
                                                ('fib_entry_adjacency_type', (YLeaf(YType.enumeration, 'fib-entry-adjacency-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibAdjacencyShow', '')])),
                                                ('fib_protocol_type', (YLeaf(YType.uint32, 'fib-protocol-type'), ['int'])),
                                                ('afi_fib_protocol_type', (YLeaf(YType.uint32, 'afi-fib-protocol-type'), ['int'])),
                                                ('aib_l3_address', (YLeaf(YType.str, 'aib-l3-address'), ['str'])),
                                                ('adjacency_address_length', (YLeaf(YType.uint32, 'adjacency-address-length'), ['int'])),
                                                ('adjacency_interface', (YLeaf(YType.uint32, 'adjacency-interface'), ['int'])),
                                                ('fib_special_nh_information_type', (YLeaf(YType.uint32, 'fib-special-nh-information-type'), ['int'])),
                                                ('fib_entry_adjacency_address', (YLeaf(YType.str, 'fib-entry-adjacency-address'), ['str'])),
                                                ('fib_entry_adjacency_interface', (YLeaf(YType.uint32, 'fib-entry-adjacency-interface'), ['int'])),
                                                ('packets_through_fib_entry', (YLeaf(YType.uint64, 'packets-through-fib-entry'), ['int'])),
                                                ('bytes_through_fib_entry', (YLeaf(YType.uint64, 'bytes-through-fib-entry'), ['int'])),
                                                ('detailed_prefix_length', (YLeaf(YType.uint32, 'detailed-prefix-length'), ['int'])),
                                                ('prefix_protocol', (YLeaf(YType.uint32, 'prefix-protocol'), ['int'])),
                                                ('precedence_forpackets', (YLeaf(YType.uint8, 'precedence-forpackets'), ['int'])),
                                                ('traffic_index_for_packets', (YLeaf(YType.uint8, 'traffic-index-for-packets'), ['int'])),
                                                ('switch_compontent_id', (YLeaf(YType.uint32, 'switch-compontent-id'), ['int'])),
                                                ('fast_adjacency_flag', (YLeaf(YType.boolean, 'fast-adjacency-flag'), ['bool'])),
                                                ('illegal_fast_adjacency_flag', (YLeaf(YType.boolean, 'illegal-fast-adjacency-flag'), ['bool'])),
                                                ('remote_adjacency_flag', (YLeaf(YType.boolean, 'remote-adjacency-flag'), ['bool'])),
                                                ('bgp_attribute_id', (YLeaf(YType.uint32, 'bgp-attribute-id'), ['int'])),
                                                ('bgp_local_attribute_id', (YLeaf(YType.uint32, 'bgp-local-attribute-id'), ['int'])),
                                                ('bgp_attribute_origin_as', (YLeaf(YType.uint32, 'bgp-attribute-origin-as'), ['int'])),
                                                ('bgp_attribute_next_hop_as', (YLeaf(YType.uint32, 'bgp-attribute-next-hop-as'), ['int'])),
                                                ('path_string', (YLeaf(YType.str, 'path-string'), ['str'])),
                                                ('extcom_string', (YLeaf(YType.str, 'extcom-string'), ['str'])),
                                                ('com_string', (YLeaf(YType.str, 'com-string'), ['str'])),
                                                ('extended_community', (YLeaf(YType.uint32, 'extended-community'), ['int'])),
                                                ('qos_group', (YLeaf(YType.uint32, 'qos-group'), ['int'])),
                                                ('mpls_fec', (YLeaf(YType.uint32, 'mpls-fec'), ['int'])),
                                                ('qppb_qos_group_and_ip_precedence', (YLeaf(YType.uint32, 'qppb-qos-group-and-ip-precedence'), ['int'])),
                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                ('forward_class', (YLeaf(YType.uint8, 'forward-class'), ['int'])),
                                                ('pl_time_of_last_update_in_msec', (YLeaf(YType.uint64, 'pl-time-of-last-update-in-msec'), ['int'])),
                                                ('ldi_time_of_last_update_in_msec', (YLeaf(YType.uint64, 'ldi-time-of-last-update-in-msec'), ['int'])),
                                                ('lwldi_time_of_last_update_in_msec', (YLeaf(YType.uint64, 'lwldi-time-of-last-update-in-msec'), ['int'])),
                                                ('pl_time_stamp_type', (YLeaf(YType.uint32, 'pl-time-stamp-type'), ['int'])),
                                            ])
                                            self.fib_entry_version = None
                                            self.per_prefix_accounting = None
                                            self.load_sharing_type = None
                                            self.fib_entry_adjacency_type = None
                                            self.fib_protocol_type = None
                                            self.afi_fib_protocol_type = None
                                            self.aib_l3_address = None
                                            self.adjacency_address_length = None
                                            self.adjacency_interface = None
                                            self.fib_special_nh_information_type = None
                                            self.fib_entry_adjacency_address = None
                                            self.fib_entry_adjacency_interface = None
                                            self.packets_through_fib_entry = None
                                            self.bytes_through_fib_entry = None
                                            self.detailed_prefix_length = None
                                            self.prefix_protocol = None
                                            self.precedence_forpackets = None
                                            self.traffic_index_for_packets = None
                                            self.switch_compontent_id = None
                                            self.fast_adjacency_flag = None
                                            self.illegal_fast_adjacency_flag = None
                                            self.remote_adjacency_flag = None
                                            self.bgp_attribute_id = None
                                            self.bgp_local_attribute_id = None
                                            self.bgp_attribute_origin_as = None
                                            self.bgp_attribute_next_hop_as = None
                                            self.path_string = None
                                            self.extcom_string = None
                                            self.com_string = None
                                            self.extended_community = None
                                            self.qos_group = None
                                            self.mpls_fec = None
                                            self.qppb_qos_group_and_ip_precedence = None
                                            self.flow_tag = None
                                            self.forward_class = None
                                            self.pl_time_of_last_update_in_msec = None
                                            self.ldi_time_of_last_update_in_msec = None
                                            self.lwldi_time_of_last_update_in_msec = None
                                            self.pl_time_stamp_type = None

                                            self.loadshare_information = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation()
                                            self.loadshare_information.parent = self
                                            self._children_name_map["loadshare_information"] = "loadshare-information"
                                            self._segment_path = lambda: "detail-fib-entry-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation, ['fib_entry_version', 'per_prefix_accounting', 'load_sharing_type', 'fib_entry_adjacency_type', 'fib_protocol_type', 'afi_fib_protocol_type', 'aib_l3_address', 'adjacency_address_length', 'adjacency_interface', 'fib_special_nh_information_type', 'fib_entry_adjacency_address', 'fib_entry_adjacency_interface', 'packets_through_fib_entry', 'bytes_through_fib_entry', 'detailed_prefix_length', 'prefix_protocol', 'precedence_forpackets', 'traffic_index_for_packets', 'switch_compontent_id', 'fast_adjacency_flag', 'illegal_fast_adjacency_flag', 'remote_adjacency_flag', 'bgp_attribute_id', 'bgp_local_attribute_id', 'bgp_attribute_origin_as', 'bgp_attribute_next_hop_as', 'path_string', 'extcom_string', 'com_string', 'extended_community', 'qos_group', 'mpls_fec', 'qppb_qos_group_and_ip_precedence', 'flow_tag', 'forward_class', 'pl_time_of_last_update_in_msec', 'ldi_time_of_last_update_in_msec', 'lwldi_time_of_last_update_in_msec', 'pl_time_stamp_type'], name, value)


                                        class LoadshareInformation(Entity):
                                            """
                                            Detailed Loadshare info
                                            
                                            .. attribute:: load_informtion_internal_data
                                            
                                            	Loadinfo internal data
                                            	**type**\:  :py:class:`LoadInformtionInternalData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData>`
                                            
                                            .. attribute:: packets_through_load_information
                                            
                                            	Packets through this loadinfo
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: bytes_through_load_information
                                            
                                            	Bytes through this loadinfo
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: total_packets_through_load_information
                                            
                                            	Total packets through this loadinfo
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: total_bytes_through_load_information
                                            
                                            	Total bytes through this loadinfo
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: prefix_of_owner
                                            
                                            	Prefix of the owner
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mask_length_of_owner
                                            
                                            	Mask length of the owner
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: load_information_reference_count
                                            
                                            	Loadinfo reference count
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: per_dest_load_sharing_flag
                                            
                                            	Per destination load sharing flag
                                            	**type**\: bool
                                            
                                            .. attribute:: load_information_owner_deleted_flag
                                            
                                            	Loadinfo owner deleted flag
                                            	**type**\: bool
                                            
                                            .. attribute:: loadinfo_sanity_flag
                                            
                                            	Loadinfo sanity flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_owner
                                            
                                            	Owner flag
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation, self).__init__()

                                                self.yang_name = "loadshare-information"
                                                self.yang_parent_name = "detail-fib-entry-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("load-informtion-internal-data", ("load_informtion_internal_data", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData))])
                                                self._leafs = OrderedDict([
                                                    ('packets_through_load_information', (YLeaf(YType.uint64, 'packets-through-load-information'), ['int'])),
                                                    ('bytes_through_load_information', (YLeaf(YType.uint64, 'bytes-through-load-information'), ['int'])),
                                                    ('total_packets_through_load_information', (YLeaf(YType.uint64, 'total-packets-through-load-information'), ['int'])),
                                                    ('total_bytes_through_load_information', (YLeaf(YType.uint64, 'total-bytes-through-load-information'), ['int'])),
                                                    ('prefix_of_owner', (YLeaf(YType.uint32, 'prefix-of-owner'), ['int'])),
                                                    ('mask_length_of_owner', (YLeaf(YType.uint32, 'mask-length-of-owner'), ['int'])),
                                                    ('load_information_reference_count', (YLeaf(YType.uint16, 'load-information-reference-count'), ['int'])),
                                                    ('per_dest_load_sharing_flag', (YLeaf(YType.boolean, 'per-dest-load-sharing-flag'), ['bool'])),
                                                    ('load_information_owner_deleted_flag', (YLeaf(YType.boolean, 'load-information-owner-deleted-flag'), ['bool'])),
                                                    ('loadinfo_sanity_flag', (YLeaf(YType.boolean, 'loadinfo-sanity-flag'), ['bool'])),
                                                    ('is_owner', (YLeaf(YType.boolean, 'is-owner'), ['bool'])),
                                                ])
                                                self.packets_through_load_information = None
                                                self.bytes_through_load_information = None
                                                self.total_packets_through_load_information = None
                                                self.total_bytes_through_load_information = None
                                                self.prefix_of_owner = None
                                                self.mask_length_of_owner = None
                                                self.load_information_reference_count = None
                                                self.per_dest_load_sharing_flag = None
                                                self.load_information_owner_deleted_flag = None
                                                self.loadinfo_sanity_flag = None
                                                self.is_owner = None

                                                self.load_informtion_internal_data = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData()
                                                self.load_informtion_internal_data.parent = self
                                                self._children_name_map["load_informtion_internal_data"] = "load-informtion-internal-data"
                                                self._segment_path = lambda: "loadshare-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation, ['packets_through_load_information', 'bytes_through_load_information', 'total_packets_through_load_information', 'total_bytes_through_load_information', 'prefix_of_owner', 'mask_length_of_owner', 'load_information_reference_count', 'per_dest_load_sharing_flag', 'load_information_owner_deleted_flag', 'loadinfo_sanity_flag', 'is_owner'], name, value)


                                            class LoadInformtionInternalData(Entity):
                                                """
                                                Loadinfo internal data
                                                
                                                .. attribute:: level_ofldis
                                                
                                                	level of ldis
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: number_of_ldis
                                                
                                                	no. of ldis
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: maximum_index_arrays
                                                
                                                	Maximum index of the arrays
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_indices
                                                
                                                	Path indices
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: path_ldi_numbers
                                                
                                                	Path indices
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: maximum_slots
                                                
                                                	Maximum slots
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: normalized_weights
                                                
                                                	Normalized weights
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tunnel_class_value
                                                
                                                	Tunnel class value
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: is_pbts_info_valid
                                                
                                                	PBTS info valid flag
                                                	**type**\: bool
                                                
                                                .. attribute:: pbts_class_offset
                                                
                                                	PBTS class offset
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: pbts_class_num_paths
                                                
                                                	PBTS class num paths
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: pbts_fallback_mapped_class
                                                
                                                	PBTS class falls back to class
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: round_robin_disable
                                                
                                                	Round Robin Disable
                                                	**type**\: bool
                                                
                                                .. attribute:: ldi_next_hop_buckets
                                                
                                                	Number of LDI next hop buckets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: platform_hardware_information
                                                
                                                	Platform Hardware info
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: sanity_flag
                                                
                                                	Sanity flag
                                                	**type**\: list of  		 :py:class:`SanityFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.SanityFlag>`
                                                
                                                .. attribute:: interface_handle
                                                
                                                	Interface handle
                                                	**type**\: list of  		 :py:class:`InterfaceHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.InterfaceHandle>`
                                                
                                                .. attribute:: weights_of_path
                                                
                                                	Weights of paths
                                                	**type**\: list of  		 :py:class:`WeightsOfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.WeightsOfPath>`
                                                
                                                .. attribute:: adjacency_address
                                                
                                                	Adjacency address
                                                	**type**\: list of  		 :py:class:`AdjacencyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.AdjacencyAddress>`
                                                
                                                .. attribute:: pbts_class_is_fallback_mapped
                                                
                                                	Does PBTS class fall back to drop or any class
                                                	**type**\: list of  		 :py:class:`PbtsClassIsFallbackMapped <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsClassIsFallbackMapped>`
                                                
                                                .. attribute:: pbts_fallback_to_drop
                                                
                                                	PBTS class falls back to drop
                                                	**type**\: list of  		 :py:class:`PbtsFallbackToDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsFallbackToDrop>`
                                                
                                                .. attribute:: tunnel_is_forward_class
                                                
                                                	Tunnel is forward class
                                                	**type**\: list of  		 :py:class:`TunnelIsForwardClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.TunnelIsForwardClass>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData, self).__init__()

                                                    self.yang_name = "load-informtion-internal-data"
                                                    self.yang_parent_name = "loadshare-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sanity-flag", ("sanity_flag", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.SanityFlag)), ("interface-handle", ("interface_handle", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.InterfaceHandle)), ("weights-of-path", ("weights_of_path", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.WeightsOfPath)), ("adjacency-address", ("adjacency_address", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.AdjacencyAddress)), ("pbts-class-is-fallback-mapped", ("pbts_class_is_fallback_mapped", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsClassIsFallbackMapped)), ("pbts-fallback-to-drop", ("pbts_fallback_to_drop", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsFallbackToDrop)), ("tunnel-is-forward-class", ("tunnel_is_forward_class", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.TunnelIsForwardClass))])
                                                    self._leafs = OrderedDict([
                                                        ('level_ofldis', (YLeaf(YType.uint8, 'level-ofldis'), ['int'])),
                                                        ('number_of_ldis', (YLeaf(YType.uint8, 'number-of-ldis'), ['int'])),
                                                        ('maximum_index_arrays', (YLeaf(YType.uint32, 'maximum-index-arrays'), ['int'])),
                                                        ('path_indices', (YLeaf(YType.str, 'path-indices'), ['str'])),
                                                        ('path_ldi_numbers', (YLeaf(YType.str, 'path-ldi-numbers'), ['str'])),
                                                        ('maximum_slots', (YLeaf(YType.uint32, 'maximum-slots'), ['int'])),
                                                        ('normalized_weights', (YLeaf(YType.str, 'normalized-weights'), ['str'])),
                                                        ('tunnel_class_value', (YLeaf(YType.str, 'tunnel-class-value'), ['str'])),
                                                        ('is_pbts_info_valid', (YLeaf(YType.boolean, 'is-pbts-info-valid'), ['bool'])),
                                                        ('pbts_class_offset', (YLeaf(YType.str, 'pbts-class-offset'), ['str'])),
                                                        ('pbts_class_num_paths', (YLeaf(YType.str, 'pbts-class-num-paths'), ['str'])),
                                                        ('pbts_fallback_mapped_class', (YLeaf(YType.str, 'pbts-fallback-mapped-class'), ['str'])),
                                                        ('round_robin_disable', (YLeaf(YType.boolean, 'round-robin-disable'), ['bool'])),
                                                        ('ldi_next_hop_buckets', (YLeaf(YType.uint8, 'ldi-next-hop-buckets'), ['int'])),
                                                        ('platform_hardware_information', (YLeaf(YType.str, 'platform-hardware-information'), ['str'])),
                                                    ])
                                                    self.level_ofldis = None
                                                    self.number_of_ldis = None
                                                    self.maximum_index_arrays = None
                                                    self.path_indices = None
                                                    self.path_ldi_numbers = None
                                                    self.maximum_slots = None
                                                    self.normalized_weights = None
                                                    self.tunnel_class_value = None
                                                    self.is_pbts_info_valid = None
                                                    self.pbts_class_offset = None
                                                    self.pbts_class_num_paths = None
                                                    self.pbts_fallback_mapped_class = None
                                                    self.round_robin_disable = None
                                                    self.ldi_next_hop_buckets = None
                                                    self.platform_hardware_information = None

                                                    self.sanity_flag = YList(self)
                                                    self.interface_handle = YList(self)
                                                    self.weights_of_path = YList(self)
                                                    self.adjacency_address = YList(self)
                                                    self.pbts_class_is_fallback_mapped = YList(self)
                                                    self.pbts_fallback_to_drop = YList(self)
                                                    self.tunnel_is_forward_class = YList(self)
                                                    self._segment_path = lambda: "load-informtion-internal-data"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData, ['level_ofldis', 'number_of_ldis', 'maximum_index_arrays', 'path_indices', 'path_ldi_numbers', 'maximum_slots', 'normalized_weights', 'tunnel_class_value', 'is_pbts_info_valid', 'pbts_class_offset', 'pbts_class_num_paths', 'pbts_fallback_mapped_class', 'round_robin_disable', 'ldi_next_hop_buckets', 'platform_hardware_information'], name, value)


                                                class SanityFlag(Entity):
                                                    """
                                                    Sanity flag
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.SanityFlag, self).__init__()

                                                        self.yang_name = "sanity-flag"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "sanity-flag"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.SanityFlag, ['entry'], name, value)


                                                class InterfaceHandle(Entity):
                                                    """
                                                    Interface handle
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.InterfaceHandle, self).__init__()

                                                        self.yang_name = "interface-handle"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "interface-handle"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.InterfaceHandle, ['entry'], name, value)


                                                class WeightsOfPath(Entity):
                                                    """
                                                    Weights of paths
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.WeightsOfPath, self).__init__()

                                                        self.yang_name = "weights-of-path"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "weights-of-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.WeightsOfPath, ['entry'], name, value)


                                                class AdjacencyAddress(Entity):
                                                    """
                                                    Adjacency address
                                                    
                                                    .. attribute:: address
                                                    
                                                    	address
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..60
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.AdjacencyAddress, self).__init__()

                                                        self.yang_name = "adjacency-address"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = None
                                                        self._segment_path = lambda: "adjacency-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.AdjacencyAddress, ['address'], name, value)


                                                class PbtsClassIsFallbackMapped(Entity):
                                                    """
                                                    Does PBTS class fall back to drop or any class
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	Array entry
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsClassIsFallbackMapped, self).__init__()

                                                        self.yang_name = "pbts-class-is-fallback-mapped"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pbts-class-is-fallback-mapped"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsClassIsFallbackMapped, ['entry'], name, value)


                                                class PbtsFallbackToDrop(Entity):
                                                    """
                                                    PBTS class falls back to drop
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	Array entry
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsFallbackToDrop, self).__init__()

                                                        self.yang_name = "pbts-fallback-to-drop"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pbts-fallback-to-drop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsFallbackToDrop, ['entry'], name, value)


                                                class TunnelIsForwardClass(Entity):
                                                    """
                                                    Tunnel is forward class
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	Array entry
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.TunnelIsForwardClass, self).__init__()

                                                        self.yang_name = "tunnel-is-forward-class"
                                                        self.yang_parent_name = "load-informtion-internal-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "tunnel-is-forward-class"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.TunnelIsForwardClass, ['entry'], name, value)


                                    class FibEntryPath(Entity):
                                        """
                                        FIB entry path details
                                        
                                        .. attribute:: fib_sh_tbl_path
                                        
                                        	fib sh tbl path
                                        	**type**\: list of  		 :py:class:`FibShTblPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath>`
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath, self).__init__()

                                            self.yang_name = "fib-entry-path"
                                            self.yang_parent_name = "ip-prefix-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("fib-sh-tbl-path", ("fib_sh_tbl_path", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath))])
                                            self._leafs = OrderedDict()

                                            self.fib_sh_tbl_path = YList(self)
                                            self._segment_path = lambda: "fib-entry-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath, [], name, value)


                                        class FibShTblPath(Entity):
                                            """
                                            fib sh tbl path
                                            
                                            .. attribute:: more_detail_about_path
                                            
                                            	More detail about this path entry
                                            	**type**\:  :py:class:`MoreDetailAboutPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath>`
                                            
                                            .. attribute:: mpls_information_for_path
                                            
                                            	mpls info for this path entry
                                            	**type**\:  :py:class:`MplsInformationForPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath>`
                                            
                                            .. attribute:: hardware_information
                                            
                                            	Hardware info
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: brief_interface_handle
                                            
                                            	Interface handle
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: brief_next_hop_prefix
                                            
                                            	Next hop prefix
                                            	**type**\: str
                                            
                                            	**length:** 0..52
                                            
                                            .. attribute:: via_label_to_recurse
                                            
                                            	Local label to recurse over
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: brief_pnode_address
                                            
                                            	P\-node address
                                            	**type**\: str
                                            
                                            	**length:** 0..52
                                            
                                            .. attribute:: brief_qnode_address
                                            
                                            	Q\-node address
                                            	**type**\: str
                                            
                                            	**length:** 0..52
                                            
                                            .. attribute:: brief_lfa_protection_type
                                            
                                            	LFA protection type
                                            	**type**\:  :py:class:`FibUpdatePathLfaProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibUpdatePathLfaProtection>`
                                            
                                            .. attribute:: resolved_path
                                            
                                            	Resolved path
                                            	**type**\: bool
                                            
                                            .. attribute:: recursive_path
                                            
                                            	Recursive path
                                            	**type**\: bool
                                            
                                            .. attribute:: packets_received_path
                                            
                                            	Packets received on this path
                                            	**type**\: bool
                                            
                                            .. attribute:: attached_path
                                            
                                            	Attached path
                                            	**type**\: bool
                                            
                                            .. attribute:: backup_path
                                            
                                            	Backup path
                                            	**type**\: bool
                                            
                                            .. attribute:: best_external_path
                                            
                                            	Best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: protect_ignore
                                            
                                            	Is protection ignored
                                            	**type**\: bool
                                            
                                            .. attribute:: path_dlb
                                            
                                            	Is this the path used for DLB
                                            	**type**\: bool
                                            
                                            .. attribute:: path_flags
                                            
                                            	Path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_info_flags
                                            
                                            	Path Info flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: path_index
                                            
                                            	Path index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_index
                                            
                                            	Backup path index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: next_hop_index
                                            
                                            	Next Hop Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: parent_interface_handle
                                            
                                            	Parent Interface Handle
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: recursionvia_len
                                            
                                            	recursion via /N constraint
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath, self).__init__()

                                                self.yang_name = "fib-sh-tbl-path"
                                                self.yang_parent_name = "fib-entry-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("more-detail-about-path", ("more_detail_about_path", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath)), ("mpls-information-for-path", ("mpls_information_for_path", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath))])
                                                self._leafs = OrderedDict([
                                                    ('hardware_information', (YLeaf(YType.str, 'hardware-information'), ['str'])),
                                                    ('brief_interface_handle', (YLeaf(YType.str, 'brief-interface-handle'), ['str'])),
                                                    ('brief_next_hop_prefix', (YLeaf(YType.str, 'brief-next-hop-prefix'), ['str'])),
                                                    ('via_label_to_recurse', (YLeaf(YType.uint32, 'via-label-to-recurse'), ['int'])),
                                                    ('brief_pnode_address', (YLeaf(YType.str, 'brief-pnode-address'), ['str'])),
                                                    ('brief_qnode_address', (YLeaf(YType.str, 'brief-qnode-address'), ['str'])),
                                                    ('brief_lfa_protection_type', (YLeaf(YType.enumeration, 'brief-lfa-protection-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibUpdatePathLfaProtection', '')])),
                                                    ('resolved_path', (YLeaf(YType.boolean, 'resolved-path'), ['bool'])),
                                                    ('recursive_path', (YLeaf(YType.boolean, 'recursive-path'), ['bool'])),
                                                    ('packets_received_path', (YLeaf(YType.boolean, 'packets-received-path'), ['bool'])),
                                                    ('attached_path', (YLeaf(YType.boolean, 'attached-path'), ['bool'])),
                                                    ('backup_path', (YLeaf(YType.boolean, 'backup-path'), ['bool'])),
                                                    ('best_external_path', (YLeaf(YType.boolean, 'best-external-path'), ['bool'])),
                                                    ('protect_ignore', (YLeaf(YType.boolean, 'protect-ignore'), ['bool'])),
                                                    ('path_dlb', (YLeaf(YType.boolean, 'path-dlb'), ['bool'])),
                                                    ('path_flags', (YLeaf(YType.uint32, 'path-flags'), ['int'])),
                                                    ('path_info_flags', (YLeaf(YType.uint16, 'path-info-flags'), ['int'])),
                                                    ('path_index', (YLeaf(YType.uint8, 'path-index'), ['int'])),
                                                    ('backup_index', (YLeaf(YType.uint8, 'backup-index'), ['int'])),
                                                    ('next_hop_index', (YLeaf(YType.uint32, 'next-hop-index'), ['int'])),
                                                    ('parent_interface_handle', (YLeaf(YType.str, 'parent-interface-handle'), ['str'])),
                                                    ('recursionvia_len', (YLeaf(YType.uint8, 'recursionvia-len'), ['int'])),
                                                ])
                                                self.hardware_information = None
                                                self.brief_interface_handle = None
                                                self.brief_next_hop_prefix = None
                                                self.via_label_to_recurse = None
                                                self.brief_pnode_address = None
                                                self.brief_qnode_address = None
                                                self.brief_lfa_protection_type = None
                                                self.resolved_path = None
                                                self.recursive_path = None
                                                self.packets_received_path = None
                                                self.attached_path = None
                                                self.backup_path = None
                                                self.best_external_path = None
                                                self.protect_ignore = None
                                                self.path_dlb = None
                                                self.path_flags = None
                                                self.path_info_flags = None
                                                self.path_index = None
                                                self.backup_index = None
                                                self.next_hop_index = None
                                                self.parent_interface_handle = None
                                                self.recursionvia_len = None

                                                self.more_detail_about_path = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath()
                                                self.more_detail_about_path.parent = self
                                                self._children_name_map["more_detail_about_path"] = "more-detail-about-path"

                                                self.mpls_information_for_path = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath()
                                                self.mpls_information_for_path.parent = self
                                                self._children_name_map["mpls_information_for_path"] = "mpls-information-for-path"
                                                self._segment_path = lambda: "fib-sh-tbl-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath, ['hardware_information', 'brief_interface_handle', 'brief_next_hop_prefix', 'via_label_to_recurse', 'brief_pnode_address', 'brief_qnode_address', 'brief_lfa_protection_type', 'resolved_path', 'recursive_path', 'packets_received_path', 'attached_path', 'backup_path', 'best_external_path', 'protect_ignore', 'path_dlb', 'path_flags', 'path_info_flags', 'path_index', 'backup_index', 'next_hop_index', 'parent_interface_handle', 'recursionvia_len'], name, value)


                                            class MoreDetailAboutPath(Entity):
                                                """
                                                More detail about this path entry
                                                
                                                .. attribute:: ip_address_to_recurse
                                                
                                                	IP address to recurse to
                                                	**type**\: str
                                                
                                                	**length:** 0..52
                                                
                                                .. attribute:: label_to_recurse
                                                
                                                	Local label to recurse over
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: detail_next_hop_prefix
                                                
                                                	Next hop prefix
                                                	**type**\: str
                                                
                                                	**length:** 0..52
                                                
                                                .. attribute:: next_hop_mask_length
                                                
                                                	Next hop mask length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: interface_associated_path
                                                
                                                	Interface associated with this path
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_interface
                                                
                                                	Next hop interface
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: next_hop_vrf
                                                
                                                	Next hop VRF
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: tunnle_endpoint_id
                                                
                                                	Tunnel endpoint id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lisprlocid
                                                
                                                	LISP RLOC ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: number_of_dependencies_this_path
                                                
                                                	No. of dependents for this path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: robin_reset_value
                                                
                                                	Round robin reset value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: recurse_prefix_object
                                                
                                                	Is recursion object a leaf?
                                                	**type**\: bool
                                                
                                                .. attribute:: next_prefix_recursion
                                                
                                                	Next prefix recursion in the path
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: next_prefix_length
                                                
                                                	Next prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: recurse_prefix_object2
                                                
                                                	Recursion has two leaves (e.g. implicit\-null path)
                                                	**type**\: bool
                                                
                                                .. attribute:: next_prefix_recursion2
                                                
                                                	Next prefix2 recursion in the path
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: next_prefix_length2
                                                
                                                	Next prefix2 length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: detail_fib_adjacency_type
                                                
                                                	FIB entry adjacency type
                                                	**type**\:  :py:class:`FibAdjacencyShow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibAdjacencyShow>`
                                                
                                                .. attribute:: current_path_flag
                                                
                                                	Current path flag
                                                	**type**\: bool
                                                
                                                .. attribute:: recursive_path_information
                                                
                                                	Recursive path information is available
                                                	**type**\: bool
                                                
                                                .. attribute:: external_adjacency
                                                
                                                	Path is an external adjacency
                                                	**type**\: bool
                                                
                                                .. attribute:: fib_path_nh_information_type
                                                
                                                	FIB Nhinfo type
                                                	**type**\:  :py:class:`FibNeh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNeh>`
                                                
                                                .. attribute:: fib_path_nh_information_type_special
                                                
                                                	FIB Nhinfo type special
                                                	**type**\:  :py:class:`FibNehSpecial <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNehSpecial>`
                                                
                                                .. attribute:: weight_of_path
                                                
                                                	Weight of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_class
                                                
                                                	Tunnel class of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tunnel_is_forward_class
                                                
                                                	Tunnel is forward class
                                                	**type**\: bool
                                                
                                                .. attribute:: spd_ipencap
                                                
                                                	IP Encap
                                                	**type**\: list of  		 :py:class:`SpdIpencap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap>`
                                                
                                                .. attribute:: next_next_hop
                                                
                                                	Next Next hop sets
                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath.NextNextHop>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath, self).__init__()

                                                    self.yang_name = "more-detail-about-path"
                                                    self.yang_parent_name = "fib-sh-tbl-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("spd-ipencap", ("spd_ipencap", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap)), ("next-next-hop", ("next_next_hop", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath.NextNextHop))])
                                                    self._leafs = OrderedDict([
                                                        ('ip_address_to_recurse', (YLeaf(YType.str, 'ip-address-to-recurse'), ['str'])),
                                                        ('label_to_recurse', (YLeaf(YType.uint32, 'label-to-recurse'), ['int'])),
                                                        ('detail_next_hop_prefix', (YLeaf(YType.str, 'detail-next-hop-prefix'), ['str'])),
                                                        ('next_hop_mask_length', (YLeaf(YType.uint8, 'next-hop-mask-length'), ['int'])),
                                                        ('interface_associated_path', (YLeaf(YType.str, 'interface-associated-path'), ['str'])),
                                                        ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                                        ('next_hop_vrf', (YLeaf(YType.str, 'next-hop-vrf'), ['str'])),
                                                        ('tunnle_endpoint_id', (YLeaf(YType.uint32, 'tunnle-endpoint-id'), ['int'])),
                                                        ('lisprlocid', (YLeaf(YType.uint32, 'lisprlocid'), ['int'])),
                                                        ('number_of_dependencies_this_path', (YLeaf(YType.uint32, 'number-of-dependencies-this-path'), ['int'])),
                                                        ('robin_reset_value', (YLeaf(YType.uint8, 'robin-reset-value'), ['int'])),
                                                        ('recurse_prefix_object', (YLeaf(YType.boolean, 'recurse-prefix-object'), ['bool'])),
                                                        ('next_prefix_recursion', (YLeaf(YType.str, 'next-prefix-recursion'), ['str'])),
                                                        ('next_prefix_length', (YLeaf(YType.uint8, 'next-prefix-length'), ['int'])),
                                                        ('recurse_prefix_object2', (YLeaf(YType.boolean, 'recurse-prefix-object2'), ['bool'])),
                                                        ('next_prefix_recursion2', (YLeaf(YType.str, 'next-prefix-recursion2'), ['str'])),
                                                        ('next_prefix_length2', (YLeaf(YType.uint8, 'next-prefix-length2'), ['int'])),
                                                        ('detail_fib_adjacency_type', (YLeaf(YType.enumeration, 'detail-fib-adjacency-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibAdjacencyShow', '')])),
                                                        ('current_path_flag', (YLeaf(YType.boolean, 'current-path-flag'), ['bool'])),
                                                        ('recursive_path_information', (YLeaf(YType.boolean, 'recursive-path-information'), ['bool'])),
                                                        ('external_adjacency', (YLeaf(YType.boolean, 'external-adjacency'), ['bool'])),
                                                        ('fib_path_nh_information_type', (YLeaf(YType.enumeration, 'fib-path-nh-information-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNeh', '')])),
                                                        ('fib_path_nh_information_type_special', (YLeaf(YType.enumeration, 'fib-path-nh-information-type-special'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNehSpecial', '')])),
                                                        ('weight_of_path', (YLeaf(YType.uint32, 'weight-of-path'), ['int'])),
                                                        ('tunnel_class', (YLeaf(YType.uint8, 'tunnel-class'), ['int'])),
                                                        ('tunnel_is_forward_class', (YLeaf(YType.boolean, 'tunnel-is-forward-class'), ['bool'])),
                                                    ])
                                                    self.ip_address_to_recurse = None
                                                    self.label_to_recurse = None
                                                    self.detail_next_hop_prefix = None
                                                    self.next_hop_mask_length = None
                                                    self.interface_associated_path = None
                                                    self.next_hop_interface = None
                                                    self.next_hop_vrf = None
                                                    self.tunnle_endpoint_id = None
                                                    self.lisprlocid = None
                                                    self.number_of_dependencies_this_path = None
                                                    self.robin_reset_value = None
                                                    self.recurse_prefix_object = None
                                                    self.next_prefix_recursion = None
                                                    self.next_prefix_length = None
                                                    self.recurse_prefix_object2 = None
                                                    self.next_prefix_recursion2 = None
                                                    self.next_prefix_length2 = None
                                                    self.detail_fib_adjacency_type = None
                                                    self.current_path_flag = None
                                                    self.recursive_path_information = None
                                                    self.external_adjacency = None
                                                    self.fib_path_nh_information_type = None
                                                    self.fib_path_nh_information_type_special = None
                                                    self.weight_of_path = None
                                                    self.tunnel_class = None
                                                    self.tunnel_is_forward_class = None

                                                    self.spd_ipencap = YList(self)
                                                    self.next_next_hop = YList(self)
                                                    self._segment_path = lambda: "more-detail-about-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath, ['ip_address_to_recurse', 'label_to_recurse', 'detail_next_hop_prefix', 'next_hop_mask_length', 'interface_associated_path', 'next_hop_interface', 'next_hop_vrf', 'tunnle_endpoint_id', 'lisprlocid', 'number_of_dependencies_this_path', 'robin_reset_value', 'recurse_prefix_object', 'next_prefix_recursion', 'next_prefix_length', 'recurse_prefix_object2', 'next_prefix_recursion2', 'next_prefix_length2', 'detail_fib_adjacency_type', 'current_path_flag', 'recursive_path_information', 'external_adjacency', 'fib_path_nh_information_type', 'fib_path_nh_information_type_special', 'weight_of_path', 'tunnel_class', 'tunnel_is_forward_class'], name, value)


                                                class SpdIpencap(Entity):
                                                    """
                                                    IP Encap
                                                    
                                                    .. attribute:: ip_encap_hdr_count
                                                    
                                                    	Header Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ip_encap_locks
                                                    
                                                    	IPEncap Object Locks
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ip_encap_transport_tbl
                                                    
                                                    	Transport Table
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipe_transport_vrf_name
                                                    
                                                    	Transport VRF name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: ip_encap_transport_af
                                                    
                                                    	Transport AF
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ip_encap_payload_af
                                                    
                                                    	Payload AF
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ip_encap_payload_mtu
                                                    
                                                    	Payload MTU
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ip_encap_parent
                                                    
                                                    	Pointer to parent
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ip_encap_parent_type
                                                    
                                                    	Parent type enumeration
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ip_encap_hdr
                                                    
                                                    	Headers
                                                    	**type**\: list of  		 :py:class:`IpEncapHdr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap.IpEncapHdr>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap, self).__init__()

                                                        self.yang_name = "spd-ipencap"
                                                        self.yang_parent_name = "more-detail-about-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ip-encap-hdr", ("ip_encap_hdr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap.IpEncapHdr))])
                                                        self._leafs = OrderedDict([
                                                            ('ip_encap_hdr_count', (YLeaf(YType.uint8, 'ip-encap-hdr-count'), ['int'])),
                                                            ('ip_encap_locks', (YLeaf(YType.uint32, 'ip-encap-locks'), ['int'])),
                                                            ('ip_encap_transport_tbl', (YLeaf(YType.uint32, 'ip-encap-transport-tbl'), ['int'])),
                                                            ('ipe_transport_vrf_name', (YLeaf(YType.str, 'ipe-transport-vrf-name'), ['str'])),
                                                            ('ip_encap_transport_af', (YLeaf(YType.uint32, 'ip-encap-transport-af'), ['int'])),
                                                            ('ip_encap_payload_af', (YLeaf(YType.uint32, 'ip-encap-payload-af'), ['int'])),
                                                            ('ip_encap_payload_mtu', (YLeaf(YType.uint16, 'ip-encap-payload-mtu'), ['int'])),
                                                            ('ip_encap_parent', (YLeaf(YType.uint32, 'ip-encap-parent'), ['int'])),
                                                            ('ip_encap_parent_type', (YLeaf(YType.uint32, 'ip-encap-parent-type'), ['int'])),
                                                        ])
                                                        self.ip_encap_hdr_count = None
                                                        self.ip_encap_locks = None
                                                        self.ip_encap_transport_tbl = None
                                                        self.ipe_transport_vrf_name = None
                                                        self.ip_encap_transport_af = None
                                                        self.ip_encap_payload_af = None
                                                        self.ip_encap_payload_mtu = None
                                                        self.ip_encap_parent = None
                                                        self.ip_encap_parent_type = None

                                                        self.ip_encap_hdr = YList(self)
                                                        self._segment_path = lambda: "spd-ipencap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap, ['ip_encap_hdr_count', 'ip_encap_locks', 'ip_encap_transport_tbl', 'ipe_transport_vrf_name', 'ip_encap_transport_af', 'ip_encap_payload_af', 'ip_encap_payload_mtu', 'ip_encap_parent', 'ip_encap_parent_type'], name, value)


                                                    class IpEncapHdr(Entity):
                                                        """
                                                        Headers
                                                        
                                                        .. attribute:: ip_encap_hdr_type
                                                        
                                                        	Header Type
                                                        	**type**\:  :py:class:`FibShIpencapHdr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibShIpencapHdr>`
                                                        
                                                        .. attribute:: ip_encap_hdrp
                                                        
                                                        	Static Header
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: ip_encap_hdr_dyn
                                                        
                                                        	Dynamic Header Fields
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap.IpEncapHdr, self).__init__()

                                                            self.yang_name = "ip-encap-hdr"
                                                            self.yang_parent_name = "spd-ipencap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ip_encap_hdr_type', (YLeaf(YType.enumeration, 'ip-encap-hdr-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibShIpencapHdr', '')])),
                                                                ('ip_encap_hdrp', (YLeaf(YType.str, 'ip-encap-hdrp'), ['str'])),
                                                                ('ip_encap_hdr_dyn', (YLeaf(YType.uint32, 'ip-encap-hdr-dyn'), ['int'])),
                                                            ])
                                                            self.ip_encap_hdr_type = None
                                                            self.ip_encap_hdrp = None
                                                            self.ip_encap_hdr_dyn = None
                                                            self._segment_path = lambda: "ip-encap-hdr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap.IpEncapHdr, ['ip_encap_hdr_type', 'ip_encap_hdrp', 'ip_encap_hdr_dyn'], name, value)


                                                class NextNextHop(Entity):
                                                    """
                                                    Next Next hop sets
                                                    
                                                    .. attribute:: next_next_hop_index
                                                    
                                                    	Next next hop index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: next_next_hop_prefix
                                                    
                                                    	Next next hop prefix
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..52
                                                    
                                                    .. attribute:: next_next_hop_interface
                                                    
                                                    	Next next hop interface index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath.NextNextHop, self).__init__()

                                                        self.yang_name = "next-next-hop"
                                                        self.yang_parent_name = "more-detail-about-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('next_next_hop_index', (YLeaf(YType.uint8, 'next-next-hop-index'), ['int'])),
                                                            ('next_next_hop_prefix', (YLeaf(YType.str, 'next-next-hop-prefix'), ['str'])),
                                                            ('next_next_hop_interface', (YLeaf(YType.uint32, 'next-next-hop-interface'), ['int'])),
                                                        ])
                                                        self.next_next_hop_index = None
                                                        self.next_next_hop_prefix = None
                                                        self.next_next_hop_interface = None
                                                        self._segment_path = lambda: "next-next-hop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MoreDetailAboutPath.NextNextHop, ['next_next_hop_index', 'next_next_hop_prefix', 'next_next_hop_interface'], name, value)


                                            class MplsInformationForPath(Entity):
                                                """
                                                mpls info for this path entry
                                                
                                                .. attribute:: local_lable
                                                
                                                	LocalLable
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: recursive_fwd_chain
                                                
                                                	RecursiveFwdChain
                                                	**type**\: bool
                                                
                                                .. attribute:: number_of_igp_paths
                                                
                                                	NumberOfIGPPaths
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: remote_backup
                                                
                                                	RemoteBackupPath
                                                	**type**\: bool
                                                
                                                .. attribute:: recursive_lbl_stack
                                                
                                                	Recursive Label(s)
                                                	**type**\: list of  		 :py:class:`RecursiveLblStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath.RecursiveLblStack>`
                                                
                                                .. attribute:: igp_label_stack_array
                                                
                                                	igp label stack array
                                                	**type**\: list of  		 :py:class:`IgpLabelStackArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath, self).__init__()

                                                    self.yang_name = "mpls-information-for-path"
                                                    self.yang_parent_name = "fib-sh-tbl-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("recursive-lbl-stack", ("recursive_lbl_stack", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath.RecursiveLblStack)), ("igp-label-stack-array", ("igp_label_stack_array", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray))])
                                                    self._leafs = OrderedDict([
                                                        ('local_lable', (YLeaf(YType.uint32, 'local-lable'), ['int'])),
                                                        ('recursive_fwd_chain', (YLeaf(YType.boolean, 'recursive-fwd-chain'), ['bool'])),
                                                        ('number_of_igp_paths', (YLeaf(YType.uint32, 'number-of-igp-paths'), ['int'])),
                                                        ('remote_backup', (YLeaf(YType.boolean, 'remote-backup'), ['bool'])),
                                                    ])
                                                    self.local_lable = None
                                                    self.recursive_fwd_chain = None
                                                    self.number_of_igp_paths = None
                                                    self.remote_backup = None

                                                    self.recursive_lbl_stack = YList(self)
                                                    self.igp_label_stack_array = YList(self)
                                                    self._segment_path = lambda: "mpls-information-for-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath, ['local_lable', 'recursive_fwd_chain', 'number_of_igp_paths', 'remote_backup'], name, value)


                                                class RecursiveLblStack(Entity):
                                                    """
                                                    Recursive Label(s)
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath.RecursiveLblStack, self).__init__()

                                                        self.yang_name = "recursive-lbl-stack"
                                                        self.yang_parent_name = "mpls-information-for-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "recursive-lbl-stack"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath.RecursiveLblStack, ['entry'], name, value)


                                                class IgpLabelStackArray(Entity):
                                                    """
                                                    igp label stack array
                                                    
                                                    .. attribute:: number_of_labels
                                                    
                                                    	NumberOfLabels
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: out_interface
                                                    
                                                    	OutInterface
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: nh_address
                                                    
                                                    	NHAddress
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..52
                                                    
                                                    .. attribute:: lstack
                                                    
                                                    	lstack
                                                    	**type**\: list of  		 :py:class:`Lstack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray.Lstack>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray, self).__init__()

                                                        self.yang_name = "igp-label-stack-array"
                                                        self.yang_parent_name = "mpls-information-for-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("lstack", ("lstack", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray.Lstack))])
                                                        self._leafs = OrderedDict([
                                                            ('number_of_labels', (YLeaf(YType.uint32, 'number-of-labels'), ['int'])),
                                                            ('out_interface', (YLeaf(YType.str, 'out-interface'), ['str'])),
                                                            ('nh_address', (YLeaf(YType.str, 'nh-address'), ['str'])),
                                                        ])
                                                        self.number_of_labels = None
                                                        self.out_interface = None
                                                        self.nh_address = None

                                                        self.lstack = YList(self)
                                                        self._segment_path = lambda: "igp-label-stack-array"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray, ['number_of_labels', 'out_interface', 'nh_address'], name, value)


                                                    class Lstack(Entity):
                                                        """
                                                        lstack
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray.Lstack, self).__init__()

                                                            self.yang_name = "lstack"
                                                            self.yang_parent_name = "igp-label-stack-array"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "lstack"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray.Lstack, ['entry'], name, value)


                                    class ExtensionObject(Entity):
                                        """
                                        Leaf Extension Object List
                                        
                                        .. attribute:: sfecd_le
                                        
                                        	sfecd le
                                        	**type**\:  :py:class:`SfecdLe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.ExtensionObject.SfecdLe>`
                                        
                                        .. attribute:: type
                                        
                                        	type
                                        	**type**\:  :py:class:`FibShTblFibExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibShTblFibExtBag>`
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.ExtensionObject, self).__init__()

                                            self.yang_name = "extension-object"
                                            self.yang_parent_name = "ip-prefix-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sfecd-le", ("sfecd_le", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.ExtensionObject.SfecdLe))])
                                            self._leafs = OrderedDict([
                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibShTblFibExtBag', '')])),
                                            ])
                                            self.type = None

                                            self.sfecd_le = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.ExtensionObject.SfecdLe()
                                            self.sfecd_le.parent = self
                                            self._children_name_map["sfecd_le"] = "sfecd-le"
                                            self._segment_path = lambda: "extension-object"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.ExtensionObject, ['type'], name, value)


                                        class SfecdLe(Entity):
                                            """
                                            sfecd le
                                            
                                            .. attribute:: context_label_flag
                                            
                                            	Context Label Exist
                                            	**type**\: bool
                                            
                                            .. attribute:: context_label
                                            
                                            	Context Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.ExtensionObject.SfecdLe, self).__init__()

                                                self.yang_name = "sfecd-le"
                                                self.yang_parent_name = "extension-object"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('context_label_flag', (YLeaf(YType.boolean, 'context-label-flag'), ['bool'])),
                                                    ('context_label', (YLeaf(YType.uint32, 'context-label'), ['int'])),
                                                ])
                                                self.context_label_flag = None
                                                self.context_label = None
                                                self._segment_path = lambda: "sfecd-le"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.IpPrefixBriefs.IpPrefixBrief.ExtensionObject.SfecdLe, ['context_label_flag', 'context_label'], name, value)


                            class NhInfoDetailHardwareIngress(Entity):
                                """
                                NHInfoTable is accessed by two keys;
                                {NHInterface,NHAddress}
                                
                                .. attribute:: nh_info_remote_detail_hardware_ingresses
                                
                                	Detailed hardware ingress info for remote NHInfo table
                                	**type**\:  :py:class:`NhInfoRemoteDetailHardwareIngresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses>`
                                
                                .. attribute:: nh_info_local_detail_hardware_ingresses
                                
                                	Local (non\-remote) nhinfo
                                	**type**\:  :py:class:`NhInfoLocalDetailHardwareIngresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses>`
                                
                                .. attribute:: nh_info_special_detail_hardware_ingress
                                
                                	Special nhinfo
                                	**type**\:  :py:class:`NhInfoSpecialDetailHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress, self).__init__()

                                    self.yang_name = "nh-info-detail-hardware-ingress"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("nh-info-remote-detail-hardware-ingresses", ("nh_info_remote_detail_hardware_ingresses", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses)), ("nh-info-local-detail-hardware-ingresses", ("nh_info_local_detail_hardware_ingresses", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses)), ("nh-info-special-detail-hardware-ingress", ("nh_info_special_detail_hardware_ingress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress))])
                                    self._leafs = OrderedDict()

                                    self.nh_info_remote_detail_hardware_ingresses = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses()
                                    self.nh_info_remote_detail_hardware_ingresses.parent = self
                                    self._children_name_map["nh_info_remote_detail_hardware_ingresses"] = "nh-info-remote-detail-hardware-ingresses"

                                    self.nh_info_local_detail_hardware_ingresses = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses()
                                    self.nh_info_local_detail_hardware_ingresses.parent = self
                                    self._children_name_map["nh_info_local_detail_hardware_ingresses"] = "nh-info-local-detail-hardware-ingresses"

                                    self.nh_info_special_detail_hardware_ingress = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress()
                                    self.nh_info_special_detail_hardware_ingress.parent = self
                                    self._children_name_map["nh_info_special_detail_hardware_ingress"] = "nh-info-special-detail-hardware-ingress"
                                    self._segment_path = lambda: "nh-info-detail-hardware-ingress"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress, [], name, value)


                                class NhInfoRemoteDetailHardwareIngresses(Entity):
                                    """
                                    Detailed hardware ingress info for remote
                                    NHInfo table
                                    
                                    .. attribute:: nh_info_remote_detail_hardware_ingress
                                    
                                    	Detail NHinfo entry
                                    	**type**\: list of  		 :py:class:`NhInfoRemoteDetailHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses, self).__init__()

                                        self.yang_name = "nh-info-remote-detail-hardware-ingresses"
                                        self.yang_parent_name = "nh-info-detail-hardware-ingress"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("nh-info-remote-detail-hardware-ingress", ("nh_info_remote_detail_hardware_ingress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress))])
                                        self._leafs = OrderedDict()

                                        self.nh_info_remote_detail_hardware_ingress = YList(self)
                                        self._segment_path = lambda: "nh-info-remote-detail-hardware-ingresses"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses, [], name, value)


                                    class NhInfoRemoteDetailHardwareIngress(Entity):
                                        """
                                        Detail NHinfo entry
                                        
                                        .. attribute:: nh_interface_name
                                        
                                        	Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: nh_proto
                                        
                                        	Next\-hop proto
                                        	**type**\:  :py:class:`FibProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibProtocol>`
                                        
                                        .. attribute:: nh_pfx_length
                                        
                                        	Next\-hop prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_address
                                        
                                        	Next\-hop address in string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress, self).__init__()

                                            self.yang_name = "nh-info-remote-detail-hardware-ingress"
                                            self.yang_parent_name = "nh-info-remote-detail-hardware-ingresses"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('nh_interface_name', (YLeaf(YType.str, 'nh-interface-name'), ['str'])),
                                                ('nh_proto', (YLeaf(YType.enumeration, 'nh-proto'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibProtocol', '')])),
                                                ('nh_pfx_length', (YLeaf(YType.uint32, 'nh-pfx-length'), ['int'])),
                                                ('nh_address', (YLeaf(YType.str, 'nh-address'), ['str'])),
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.nh_interface_name = None
                                            self.nh_proto = None
                                            self.nh_pfx_length = None
                                            self.nh_address = None
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-remote-detail-hardware-ingress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress, ['nh_interface_name', 'nh_proto', 'nh_pfx_length', 'nh_address', 'si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-remote-detail-hardware-ingress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-remote-detail-hardware-ingress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoRemoteDetailHardwareIngresses.NhInfoRemoteDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                class NhInfoLocalDetailHardwareIngresses(Entity):
                                    """
                                    Local (non\-remote) nhinfo
                                    
                                    .. attribute:: nh_info_local_detail_hardware_ingress
                                    
                                    	Detail NHinfo entry
                                    	**type**\: list of  		 :py:class:`NhInfoLocalDetailHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses, self).__init__()

                                        self.yang_name = "nh-info-local-detail-hardware-ingresses"
                                        self.yang_parent_name = "nh-info-detail-hardware-ingress"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("nh-info-local-detail-hardware-ingress", ("nh_info_local_detail_hardware_ingress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress))])
                                        self._leafs = OrderedDict()

                                        self.nh_info_local_detail_hardware_ingress = YList(self)
                                        self._segment_path = lambda: "nh-info-local-detail-hardware-ingresses"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses, [], name, value)


                                    class NhInfoLocalDetailHardwareIngress(Entity):
                                        """
                                        Detail NHinfo entry
                                        
                                        .. attribute:: nh_interface_name
                                        
                                        	Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: nh_proto
                                        
                                        	Next\-hop proto
                                        	**type**\:  :py:class:`FibProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibProtocol>`
                                        
                                        .. attribute:: nh_pfx_length
                                        
                                        	Next\-hop prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_address
                                        
                                        	Next\-hop address in string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress, self).__init__()

                                            self.yang_name = "nh-info-local-detail-hardware-ingress"
                                            self.yang_parent_name = "nh-info-local-detail-hardware-ingresses"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('nh_interface_name', (YLeaf(YType.str, 'nh-interface-name'), ['str'])),
                                                ('nh_proto', (YLeaf(YType.enumeration, 'nh-proto'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibProtocol', '')])),
                                                ('nh_pfx_length', (YLeaf(YType.uint32, 'nh-pfx-length'), ['int'])),
                                                ('nh_address', (YLeaf(YType.str, 'nh-address'), ['str'])),
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.nh_interface_name = None
                                            self.nh_proto = None
                                            self.nh_pfx_length = None
                                            self.nh_address = None
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-local-detail-hardware-ingress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress, ['nh_interface_name', 'nh_proto', 'nh_pfx_length', 'nh_address', 'si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-local-detail-hardware-ingress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-local-detail-hardware-ingress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoLocalDetailHardwareIngresses.NhInfoLocalDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                class NhInfoSpecialDetailHardwareIngress(Entity):
                                    """
                                    Special nhinfo
                                    
                                    .. attribute:: nh_info_special_punt_detail_hardware_ingress
                                    
                                    	Detail hardware ingress info for special\-punt NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialPuntDetailHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress>`
                                    
                                    .. attribute:: nh_info_special_null_detail_hardware_ingress
                                    
                                    	Detail hardware ingress info for special\-null NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialNullDetailHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress>`
                                    
                                    .. attribute:: nh_info_special_drop_detail_hardware_ingress
                                    
                                    	Detail hardware ingress info for special\-drop NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialDropDetailHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress>`
                                    
                                    .. attribute:: nh_info_special_discard_detail_hardware_ingress
                                    
                                    	Detail hardware ingress info for special\-discard NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialDiscardDetailHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress, self).__init__()

                                        self.yang_name = "nh-info-special-detail-hardware-ingress"
                                        self.yang_parent_name = "nh-info-detail-hardware-ingress"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("nh-info-special-punt-detail-hardware-ingress", ("nh_info_special_punt_detail_hardware_ingress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress)), ("nh-info-special-null-detail-hardware-ingress", ("nh_info_special_null_detail_hardware_ingress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress)), ("nh-info-special-drop-detail-hardware-ingress", ("nh_info_special_drop_detail_hardware_ingress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress)), ("nh-info-special-discard-detail-hardware-ingress", ("nh_info_special_discard_detail_hardware_ingress", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress))])
                                        self._leafs = OrderedDict()

                                        self.nh_info_special_punt_detail_hardware_ingress = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress()
                                        self.nh_info_special_punt_detail_hardware_ingress.parent = self
                                        self._children_name_map["nh_info_special_punt_detail_hardware_ingress"] = "nh-info-special-punt-detail-hardware-ingress"

                                        self.nh_info_special_null_detail_hardware_ingress = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress()
                                        self.nh_info_special_null_detail_hardware_ingress.parent = self
                                        self._children_name_map["nh_info_special_null_detail_hardware_ingress"] = "nh-info-special-null-detail-hardware-ingress"

                                        self.nh_info_special_drop_detail_hardware_ingress = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress()
                                        self.nh_info_special_drop_detail_hardware_ingress.parent = self
                                        self._children_name_map["nh_info_special_drop_detail_hardware_ingress"] = "nh-info-special-drop-detail-hardware-ingress"

                                        self.nh_info_special_discard_detail_hardware_ingress = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress()
                                        self.nh_info_special_discard_detail_hardware_ingress.parent = self
                                        self._children_name_map["nh_info_special_discard_detail_hardware_ingress"] = "nh-info-special-discard-detail-hardware-ingress"
                                        self._segment_path = lambda: "nh-info-special-detail-hardware-ingress"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress, [], name, value)


                                    class NhInfoSpecialPuntDetailHardwareIngress(Entity):
                                        """
                                        Detail hardware ingress info for
                                        special\-punt NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress, self).__init__()

                                            self.yang_name = "nh-info-special-punt-detail-hardware-ingress"
                                            self.yang_parent_name = "nh-info-special-detail-hardware-ingress"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-punt-detail-hardware-ingress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-punt-detail-hardware-ingress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-punt-detail-hardware-ingress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialPuntDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                    class NhInfoSpecialNullDetailHardwareIngress(Entity):
                                        """
                                        Detail hardware ingress info for
                                        special\-null NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress, self).__init__()

                                            self.yang_name = "nh-info-special-null-detail-hardware-ingress"
                                            self.yang_parent_name = "nh-info-special-detail-hardware-ingress"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-null-detail-hardware-ingress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-null-detail-hardware-ingress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-null-detail-hardware-ingress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialNullDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                    class NhInfoSpecialDropDetailHardwareIngress(Entity):
                                        """
                                        Detail hardware ingress info for
                                        special\-drop NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress, self).__init__()

                                            self.yang_name = "nh-info-special-drop-detail-hardware-ingress"
                                            self.yang_parent_name = "nh-info-special-detail-hardware-ingress"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-drop-detail-hardware-ingress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-drop-detail-hardware-ingress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-drop-detail-hardware-ingress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDropDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                    class NhInfoSpecialDiscardDetailHardwareIngress(Entity):
                                        """
                                        Detail hardware ingress info for
                                        special\-discard NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress, self).__init__()

                                            self.yang_name = "nh-info-special-discard-detail-hardware-ingress"
                                            self.yang_parent_name = "nh-info-special-detail-hardware-ingress"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-discard-detail-hardware-ingress"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-discard-detail-hardware-ingress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-discard-detail-hardware-ingress"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoDetailHardwareIngress.NhInfoSpecialDetailHardwareIngress.NhInfoSpecialDiscardDetailHardwareIngress.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                            class NhInfoBrief(Entity):
                                """
                                NHInfoTable is accessed by two keys;
                                {NHInterface,NHAddress}
                                
                                .. attribute:: nh_info_special_brief
                                
                                	Special nhinfo
                                	**type**\:  :py:class:`NhInfoSpecialBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief>`
                                
                                .. attribute:: nh_info_remote_briefs
                                
                                	remote nhinfo
                                	**type**\:  :py:class:`NhInfoRemoteBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs>`
                                
                                .. attribute:: nh_info_local_briefs
                                
                                	Local (non\-remote) nhinfo
                                	**type**\:  :py:class:`NhInfoLocalBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief, self).__init__()

                                    self.yang_name = "nh-info-brief"
                                    self.yang_parent_name = "vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("nh-info-special-brief", ("nh_info_special_brief", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief)), ("nh-info-remote-briefs", ("nh_info_remote_briefs", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs)), ("nh-info-local-briefs", ("nh_info_local_briefs", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs))])
                                    self._leafs = OrderedDict()

                                    self.nh_info_special_brief = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief()
                                    self.nh_info_special_brief.parent = self
                                    self._children_name_map["nh_info_special_brief"] = "nh-info-special-brief"

                                    self.nh_info_remote_briefs = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs()
                                    self.nh_info_remote_briefs.parent = self
                                    self._children_name_map["nh_info_remote_briefs"] = "nh-info-remote-briefs"

                                    self.nh_info_local_briefs = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs()
                                    self.nh_info_local_briefs.parent = self
                                    self._children_name_map["nh_info_local_briefs"] = "nh-info-local-briefs"
                                    self._segment_path = lambda: "nh-info-brief"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief, [], name, value)


                                class NhInfoSpecialBrief(Entity):
                                    """
                                    Special nhinfo
                                    
                                    .. attribute:: nh_info_special_discard_brief
                                    
                                    	Brief special\-discard NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialDiscardBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief>`
                                    
                                    .. attribute:: nh_info_special_null_brief
                                    
                                    	Brief special\-null NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialNullBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief>`
                                    
                                    .. attribute:: nh_info_special_punt_brief
                                    
                                    	Brief special\-punt NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialPuntBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief>`
                                    
                                    .. attribute:: nh_info_special_drop_brief
                                    
                                    	Brief special\-drop NHInfo entry
                                    	**type**\:  :py:class:`NhInfoSpecialDropBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief, self).__init__()

                                        self.yang_name = "nh-info-special-brief"
                                        self.yang_parent_name = "nh-info-brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("nh-info-special-discard-brief", ("nh_info_special_discard_brief", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief)), ("nh-info-special-null-brief", ("nh_info_special_null_brief", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief)), ("nh-info-special-punt-brief", ("nh_info_special_punt_brief", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief)), ("nh-info-special-drop-brief", ("nh_info_special_drop_brief", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief))])
                                        self._leafs = OrderedDict()

                                        self.nh_info_special_discard_brief = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief()
                                        self.nh_info_special_discard_brief.parent = self
                                        self._children_name_map["nh_info_special_discard_brief"] = "nh-info-special-discard-brief"

                                        self.nh_info_special_null_brief = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief()
                                        self.nh_info_special_null_brief.parent = self
                                        self._children_name_map["nh_info_special_null_brief"] = "nh-info-special-null-brief"

                                        self.nh_info_special_punt_brief = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief()
                                        self.nh_info_special_punt_brief.parent = self
                                        self._children_name_map["nh_info_special_punt_brief"] = "nh-info-special-punt-brief"

                                        self.nh_info_special_drop_brief = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief()
                                        self.nh_info_special_drop_brief.parent = self
                                        self._children_name_map["nh_info_special_drop_brief"] = "nh-info-special-drop-brief"
                                        self._segment_path = lambda: "nh-info-special-brief"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief, [], name, value)


                                    class NhInfoSpecialDiscardBrief(Entity):
                                        """
                                        Brief special\-discard NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief, self).__init__()

                                            self.yang_name = "nh-info-special-discard-brief"
                                            self.yang_parent_name = "nh-info-special-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-discard-brief"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-discard-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-discard-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDiscardBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                    class NhInfoSpecialNullBrief(Entity):
                                        """
                                        Brief special\-null NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief, self).__init__()

                                            self.yang_name = "nh-info-special-null-brief"
                                            self.yang_parent_name = "nh-info-special-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-null-brief"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-null-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-null-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialNullBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                    class NhInfoSpecialPuntBrief(Entity):
                                        """
                                        Brief special\-punt NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief, self).__init__()

                                            self.yang_name = "nh-info-special-punt-brief"
                                            self.yang_parent_name = "nh-info-special-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-punt-brief"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-punt-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-punt-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialPuntBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                    class NhInfoSpecialDropBrief(Entity):
                                        """
                                        Brief special\-drop NHInfo entry
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief, self).__init__()

                                            self.yang_name = "nh-info-special-drop-brief"
                                            self.yang_parent_name = "nh-info-special-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-special-drop-brief"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief, ['si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-special-drop-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-special-drop-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoSpecialBrief.NhInfoSpecialDropBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                class NhInfoRemoteBriefs(Entity):
                                    """
                                    remote nhinfo
                                    
                                    .. attribute:: nh_info_remote_brief
                                    
                                    	Detail NHinfo entry
                                    	**type**\: list of  		 :py:class:`NhInfoRemoteBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs, self).__init__()

                                        self.yang_name = "nh-info-remote-briefs"
                                        self.yang_parent_name = "nh-info-brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("nh-info-remote-brief", ("nh_info_remote_brief", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief))])
                                        self._leafs = OrderedDict()

                                        self.nh_info_remote_brief = YList(self)
                                        self._segment_path = lambda: "nh-info-remote-briefs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs, [], name, value)


                                    class NhInfoRemoteBrief(Entity):
                                        """
                                        Detail NHinfo entry
                                        
                                        .. attribute:: nh_interface_name
                                        
                                        	Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: nh_proto
                                        
                                        	Next\-hop proto
                                        	**type**\:  :py:class:`FibProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibProtocol>`
                                        
                                        .. attribute:: nh_pfx_length
                                        
                                        	Next\-hop prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_address
                                        
                                        	Next\-hop address in string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief, self).__init__()

                                            self.yang_name = "nh-info-remote-brief"
                                            self.yang_parent_name = "nh-info-remote-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('nh_interface_name', (YLeaf(YType.str, 'nh-interface-name'), ['str'])),
                                                ('nh_proto', (YLeaf(YType.enumeration, 'nh-proto'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibProtocol', '')])),
                                                ('nh_pfx_length', (YLeaf(YType.uint32, 'nh-pfx-length'), ['int'])),
                                                ('nh_address', (YLeaf(YType.str, 'nh-address'), ['str'])),
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.nh_interface_name = None
                                            self.nh_proto = None
                                            self.nh_pfx_length = None
                                            self.nh_address = None
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-remote-brief"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief, ['nh_interface_name', 'nh_proto', 'nh_pfx_length', 'nh_address', 'si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-remote-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-remote-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoRemoteBriefs.NhInfoRemoteBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                                class NhInfoLocalBriefs(Entity):
                                    """
                                    Local (non\-remote) nhinfo
                                    
                                    .. attribute:: nh_info_local_brief
                                    
                                    	Brief NHinfo entry
                                    	**type**\: list of  		 :py:class:`NhInfoLocalBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs, self).__init__()

                                        self.yang_name = "nh-info-local-briefs"
                                        self.yang_parent_name = "nh-info-brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("nh-info-local-brief", ("nh_info_local_brief", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief))])
                                        self._leafs = OrderedDict()

                                        self.nh_info_local_brief = YList(self)
                                        self._segment_path = lambda: "nh-info-local-briefs"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs, [], name, value)


                                    class NhInfoLocalBrief(Entity):
                                        """
                                        Brief NHinfo entry
                                        
                                        .. attribute:: nh_interface_name
                                        
                                        	Interface Name
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: nh_proto
                                        
                                        	Next\-hop proto
                                        	**type**\:  :py:class:`FibProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibProtocol>`
                                        
                                        .. attribute:: nh_pfx_length
                                        
                                        	Next\-hop prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_address
                                        
                                        	Next\-hop address in string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: si_pwhe
                                        
                                        	PW\-HE interface extension
                                        	**type**\:  :py:class:`SiPwhe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.SiPwhe>`
                                        
                                        .. attribute:: nh_info_extension
                                        
                                        	NHinfo Extensions
                                        	**type**\:  :py:class:`NhInfoExtension <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension>`
                                        
                                        .. attribute:: si_link_proto
                                        
                                        	FIB Protocol Type for NHINFO linktype
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhinfo
                                        
                                        	NHinfo object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_nhtype
                                        
                                        	NHinfo Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ifh
                                        
                                        	Ifhndl assoc w nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_pfi_interface_type
                                        
                                        	Pamna Interface Type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_ptr
                                        
                                        	Adj Ptr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_present
                                        
                                        	nhinfo point to adj
                                        	**type**\: bool
                                        
                                        .. attribute:: si_special_type
                                        
                                        	nature of special nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_refcount
                                        
                                        	refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_flags
                                        
                                        	nhinfo flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_if
                                        
                                        	ADJ Interface
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx
                                        
                                        	Extension Prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_ext_pfx_len
                                        
                                        	Extension Prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_ext_pfx_proto
                                        
                                        	Extension Prefix Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_address
                                        
                                        	AIB L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_adj_addrlen
                                        
                                        	ADJ L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_addr_proto
                                        
                                        	ADJ L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw_len
                                        
                                        	Length of Macstring
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_adj_rw
                                        
                                        	Macstring for Adjacency
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_dep_nhinfo_type
                                        
                                        	Depenedent nhinfo type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo
                                        
                                        	Dependent nhinfo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_dep_nhinfo_ifh
                                        
                                        	Dependent nhinfo ifhndl
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_frr
                                        
                                        	pointer to Backup FRR obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_protect_frr
                                        
                                        	pointer to protect FRR object
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_nhinfo
                                        
                                        	Bacckup NHINFO obj
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_ifh
                                        
                                        	Bacckup IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr
                                        
                                        	Bkup L3 Address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_bkup_addrlen
                                        
                                        	BKup L3 address length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_bkup_addr_proto
                                        
                                        	BKup L3 address Protocol
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_frr_active
                                        
                                        	is FRR currently active
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_ext_mgd
                                        
                                        	NH is externally managed
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_incomp
                                        
                                        	NH is incomplete
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel
                                        
                                        	NH is assoc w a TE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_tunnel_srte
                                        
                                        	NH is assoc w a SRTE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_attr_is_gre_tunnel
                                        
                                        	NH is assoc w a GRE tunnel
                                        	**type**\: bool
                                        
                                        .. attribute:: si_gre_ti
                                        
                                        	GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_flags
                                        
                                        	Flags on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_refcnt
                                        
                                        	Refcount on GRE tunnel info
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_tos_propagate
                                        
                                        	Is GRE TOS propagate set
                                        	**type**\: bool
                                        
                                        .. attribute:: si_hardware
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhinfo_ptr
                                        
                                        	nhinfo pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_fnb_idb_ptr
                                        
                                        	pointer to idb
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_anc_ifh
                                        
                                        	Ancestor IFH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_ti_resolving_leafp
                                        
                                        	GRE resolving ip\-leaf
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_gre_dest_addr
                                        
                                        	GRE dest address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: si_nhid
                                        
                                        	NHID value in the TX NH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: si_upd_ts
                                        
                                        	NH update timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief, self).__init__()

                                            self.yang_name = "nh-info-local-brief"
                                            self.yang_parent_name = "nh-info-local-briefs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("si-pwhe", ("si_pwhe", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.SiPwhe)), ("nh-info-extension", ("nh_info_extension", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension))])
                                            self._leafs = OrderedDict([
                                                ('nh_interface_name', (YLeaf(YType.str, 'nh-interface-name'), ['str'])),
                                                ('nh_proto', (YLeaf(YType.enumeration, 'nh-proto'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibProtocol', '')])),
                                                ('nh_pfx_length', (YLeaf(YType.uint32, 'nh-pfx-length'), ['int'])),
                                                ('nh_address', (YLeaf(YType.str, 'nh-address'), ['str'])),
                                                ('si_link_proto', (YLeaf(YType.uint32, 'si-link-proto'), ['int'])),
                                                ('si_nhinfo', (YLeaf(YType.uint32, 'si-nhinfo'), ['int'])),
                                                ('si_nhtype', (YLeaf(YType.uint32, 'si-nhtype'), ['int'])),
                                                ('si_ifh', (YLeaf(YType.uint32, 'si-ifh'), ['int'])),
                                                ('si_pfi_interface_type', (YLeaf(YType.uint32, 'si-pfi-interface-type'), ['int'])),
                                                ('si_adj_ptr', (YLeaf(YType.uint32, 'si-adj-ptr'), ['int'])),
                                                ('si_adj_present', (YLeaf(YType.boolean, 'si-adj-present'), ['bool'])),
                                                ('si_special_type', (YLeaf(YType.uint32, 'si-special-type'), ['int'])),
                                                ('si_refcount', (YLeaf(YType.uint32, 'si-refcount'), ['int'])),
                                                ('si_flags', (YLeaf(YType.uint32, 'si-flags'), ['int'])),
                                                ('si_adj_if', (YLeaf(YType.uint32, 'si-adj-if'), ['int'])),
                                                ('si_ext_pfx', (YLeaf(YType.str, 'si-ext-pfx'), ['str'])),
                                                ('si_ext_pfx_len', (YLeaf(YType.uint32, 'si-ext-pfx-len'), ['int'])),
                                                ('si_ext_pfx_proto', (YLeaf(YType.uint32, 'si-ext-pfx-proto'), ['int'])),
                                                ('si_adj_address', (YLeaf(YType.str, 'si-adj-address'), ['str'])),
                                                ('si_adj_addrlen', (YLeaf(YType.uint32, 'si-adj-addrlen'), ['int'])),
                                                ('si_adj_addr_proto', (YLeaf(YType.uint32, 'si-adj-addr-proto'), ['int'])),
                                                ('si_adj_rw_len', (YLeaf(YType.uint32, 'si-adj-rw-len'), ['int'])),
                                                ('si_adj_rw', (YLeaf(YType.str, 'si-adj-rw'), ['str'])),
                                                ('si_dep_nhinfo_type', (YLeaf(YType.uint32, 'si-dep-nhinfo-type'), ['int'])),
                                                ('si_dep_nhinfo', (YLeaf(YType.uint32, 'si-dep-nhinfo'), ['int'])),
                                                ('si_dep_nhinfo_ifh', (YLeaf(YType.uint32, 'si-dep-nhinfo-ifh'), ['int'])),
                                                ('si_bkup_frr', (YLeaf(YType.uint32, 'si-bkup-frr'), ['int'])),
                                                ('si_protect_frr', (YLeaf(YType.uint32, 'si-protect-frr'), ['int'])),
                                                ('si_bkup_nhinfo', (YLeaf(YType.uint32, 'si-bkup-nhinfo'), ['int'])),
                                                ('si_bkup_ifh', (YLeaf(YType.uint32, 'si-bkup-ifh'), ['int'])),
                                                ('si_bkup_addr', (YLeaf(YType.str, 'si-bkup-addr'), ['str'])),
                                                ('si_bkup_addrlen', (YLeaf(YType.uint32, 'si-bkup-addrlen'), ['int'])),
                                                ('si_bkup_addr_proto', (YLeaf(YType.uint32, 'si-bkup-addr-proto'), ['int'])),
                                                ('si_frr_active', (YLeaf(YType.boolean, 'si-frr-active'), ['bool'])),
                                                ('si_attr_is_ext_mgd', (YLeaf(YType.boolean, 'si-attr-is-ext-mgd'), ['bool'])),
                                                ('si_attr_is_incomp', (YLeaf(YType.boolean, 'si-attr-is-incomp'), ['bool'])),
                                                ('si_attr_is_tunnel', (YLeaf(YType.boolean, 'si-attr-is-tunnel'), ['bool'])),
                                                ('si_attr_is_tunnel_srte', (YLeaf(YType.boolean, 'si-attr-is-tunnel-srte'), ['bool'])),
                                                ('si_attr_is_gre_tunnel', (YLeaf(YType.boolean, 'si-attr-is-gre-tunnel'), ['bool'])),
                                                ('si_gre_ti', (YLeaf(YType.uint32, 'si-gre-ti'), ['int'])),
                                                ('si_gre_ti_flags', (YLeaf(YType.uint32, 'si-gre-ti-flags'), ['int'])),
                                                ('si_gre_ti_refcnt', (YLeaf(YType.uint32, 'si-gre-ti-refcnt'), ['int'])),
                                                ('si_gre_tos_propagate', (YLeaf(YType.boolean, 'si-gre-tos-propagate'), ['bool'])),
                                                ('si_hardware', (YLeaf(YType.str, 'si-hardware'), ['str'])),
                                                ('si_nhinfo_ptr', (YLeaf(YType.uint32, 'si-nhinfo-ptr'), ['int'])),
                                                ('si_fnb_idb_ptr', (YLeaf(YType.uint32, 'si-fnb-idb-ptr'), ['int'])),
                                                ('si_anc_ifh', (YLeaf(YType.uint32, 'si-anc-ifh'), ['int'])),
                                                ('si_gre_ti_resolving_leafp', (YLeaf(YType.uint32, 'si-gre-ti-resolving-leafp'), ['int'])),
                                                ('si_gre_dest_addr', (YLeaf(YType.str, 'si-gre-dest-addr'), ['str'])),
                                                ('si_nhid', (YLeaf(YType.uint32, 'si-nhid'), ['int'])),
                                                ('si_upd_ts', (YLeaf(YType.uint64, 'si-upd-ts'), ['int'])),
                                            ])
                                            self.nh_interface_name = None
                                            self.nh_proto = None
                                            self.nh_pfx_length = None
                                            self.nh_address = None
                                            self.si_link_proto = None
                                            self.si_nhinfo = None
                                            self.si_nhtype = None
                                            self.si_ifh = None
                                            self.si_pfi_interface_type = None
                                            self.si_adj_ptr = None
                                            self.si_adj_present = None
                                            self.si_special_type = None
                                            self.si_refcount = None
                                            self.si_flags = None
                                            self.si_adj_if = None
                                            self.si_ext_pfx = None
                                            self.si_ext_pfx_len = None
                                            self.si_ext_pfx_proto = None
                                            self.si_adj_address = None
                                            self.si_adj_addrlen = None
                                            self.si_adj_addr_proto = None
                                            self.si_adj_rw_len = None
                                            self.si_adj_rw = None
                                            self.si_dep_nhinfo_type = None
                                            self.si_dep_nhinfo = None
                                            self.si_dep_nhinfo_ifh = None
                                            self.si_bkup_frr = None
                                            self.si_protect_frr = None
                                            self.si_bkup_nhinfo = None
                                            self.si_bkup_ifh = None
                                            self.si_bkup_addr = None
                                            self.si_bkup_addrlen = None
                                            self.si_bkup_addr_proto = None
                                            self.si_frr_active = None
                                            self.si_attr_is_ext_mgd = None
                                            self.si_attr_is_incomp = None
                                            self.si_attr_is_tunnel = None
                                            self.si_attr_is_tunnel_srte = None
                                            self.si_attr_is_gre_tunnel = None
                                            self.si_gre_ti = None
                                            self.si_gre_ti_flags = None
                                            self.si_gre_ti_refcnt = None
                                            self.si_gre_tos_propagate = None
                                            self.si_hardware = None
                                            self.si_nhinfo_ptr = None
                                            self.si_fnb_idb_ptr = None
                                            self.si_anc_ifh = None
                                            self.si_gre_ti_resolving_leafp = None
                                            self.si_gre_dest_addr = None
                                            self.si_nhid = None
                                            self.si_upd_ts = None

                                            self.si_pwhe = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.SiPwhe()
                                            self.si_pwhe.parent = self
                                            self._children_name_map["si_pwhe"] = "si-pwhe"

                                            self.nh_info_extension = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension()
                                            self.nh_info_extension.parent = self
                                            self._children_name_map["nh_info_extension"] = "nh-info-extension"
                                            self._segment_path = lambda: "nh-info-local-brief"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief, ['nh_interface_name', 'nh_proto', 'nh_pfx_length', 'nh_address', 'si_link_proto', 'si_nhinfo', 'si_nhtype', 'si_ifh', 'si_pfi_interface_type', 'si_adj_ptr', 'si_adj_present', 'si_special_type', 'si_refcount', 'si_flags', 'si_adj_if', 'si_ext_pfx', 'si_ext_pfx_len', 'si_ext_pfx_proto', 'si_adj_address', 'si_adj_addrlen', 'si_adj_addr_proto', 'si_adj_rw_len', 'si_adj_rw', 'si_dep_nhinfo_type', 'si_dep_nhinfo', 'si_dep_nhinfo_ifh', 'si_bkup_frr', 'si_protect_frr', 'si_bkup_nhinfo', 'si_bkup_ifh', 'si_bkup_addr', 'si_bkup_addrlen', 'si_bkup_addr_proto', 'si_frr_active', 'si_attr_is_ext_mgd', 'si_attr_is_incomp', 'si_attr_is_tunnel', 'si_attr_is_tunnel_srte', 'si_attr_is_gre_tunnel', 'si_gre_ti', 'si_gre_ti_flags', 'si_gre_ti_refcnt', 'si_gre_tos_propagate', 'si_hardware', 'si_nhinfo_ptr', 'si_fnb_idb_ptr', 'si_anc_ifh', 'si_gre_ti_resolving_leafp', 'si_gre_dest_addr', 'si_nhid', 'si_upd_ts'], name, value)


                                        class SiPwhe(Entity):
                                            """
                                            PW\-HE interface extension
                                            
                                            .. attribute:: pwhe_adjacency_client_data
                                            
                                            	PW\-HE specific client data in adjacency
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vctype
                                            
                                            	VC type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vc_internal_label
                                            
                                            	VC Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: cw_enabled
                                            
                                            	Is CW enabled?
                                            	**type**\: bool
                                            
                                            .. attribute:: l2_overhead_bytes
                                            
                                            	L2 overhead bytes for interface stats accounting
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: dot1q_vlan_tag
                                            
                                            	VLAN tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.SiPwhe, self).__init__()

                                                self.yang_name = "si-pwhe"
                                                self.yang_parent_name = "nh-info-local-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pwhe_adjacency_client_data', (YLeaf(YType.uint32, 'pwhe-adjacency-client-data'), ['int'])),
                                                    ('vctype', (YLeaf(YType.uint32, 'vctype'), ['int'])),
                                                    ('vc_internal_label', (YLeaf(YType.uint32, 'vc-internal-label'), ['int'])),
                                                    ('cw_enabled', (YLeaf(YType.boolean, 'cw-enabled'), ['bool'])),
                                                    ('l2_overhead_bytes', (YLeaf(YType.uint16, 'l2-overhead-bytes'), ['int'])),
                                                    ('dot1q_vlan_tag', (YLeaf(YType.uint32, 'dot1q-vlan-tag'), ['int'])),
                                                ])
                                                self.pwhe_adjacency_client_data = None
                                                self.vctype = None
                                                self.vc_internal_label = None
                                                self.cw_enabled = None
                                                self.l2_overhead_bytes = None
                                                self.dot1q_vlan_tag = None
                                                self._segment_path = lambda: "si-pwhe"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.SiPwhe, ['pwhe_adjacency_client_data', 'vctype', 'vc_internal_label', 'cw_enabled', 'l2_overhead_bytes', 'dot1q_vlan_tag'], name, value)


                                        class NhInfoExtension(Entity):
                                            """
                                            NHinfo Extensions
                                            
                                            .. attribute:: nh_info_extension_detail
                                            
                                            	NHINFO Extension Detail
                                            	**type**\: list of  		 :py:class:`NhInfoExtensionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension, self).__init__()

                                                self.yang_name = "nh-info-extension"
                                                self.yang_parent_name = "nh-info-local-brief"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail))])
                                                self._leafs = OrderedDict()

                                                self.nh_info_extension_detail = YList(self)
                                                self._segment_path = lambda: "nh-info-extension"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension, [], name, value)


                                            class NhInfoExtensionDetail(Entity):
                                                """
                                                NHINFO Extension Detail
                                                
                                                .. attribute:: nh_info_extension_base
                                                
                                                	NHINFO Extension object base information
                                                	**type**\:  :py:class:`NhInfoExtensionBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase>`
                                                
                                                .. attribute:: nh_info_extension_detail
                                                
                                                	NHINFO Extension Detail Information
                                                	**type**\:  :py:class:`NhInfoExtensionDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_>`
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail, self).__init__()

                                                    self.yang_name = "nh-info-extension-detail"
                                                    self.yang_parent_name = "nh-info-extension"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nh-info-extension-base", ("nh_info_extension_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase)), ("nh-info-extension-detail", ("nh_info_extension_detail", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_))])
                                                    self._leafs = OrderedDict()

                                                    self.nh_info_extension_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase()
                                                    self.nh_info_extension_base.parent = self
                                                    self._children_name_map["nh_info_extension_base"] = "nh-info-extension-base"

                                                    self.nh_info_extension_detail = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_()
                                                    self.nh_info_extension_detail.parent = self
                                                    self._children_name_map["nh_info_extension_detail"] = "nh-info-extension-detail"
                                                    self._segment_path = lambda: "nh-info-extension-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail, [], name, value)


                                                class NhInfoExtensionBase(Entity):
                                                    """
                                                    NHINFO Extension object base information
                                                    
                                                    .. attribute:: object_base
                                                    
                                                    	FIB Object Base information
                                                    	**type**\:  :py:class:`ObjectBase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase>`
                                                    
                                                    .. attribute:: parent_object_pointer
                                                    
                                                    	FIB Extension Object's parent pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: back_object_pointer
                                                    
                                                    	FIB Extension Object's back pointer
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, self).__init__()

                                                        self.yang_name = "nh-info-extension-base"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("object-base", ("object_base", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase))])
                                                        self._leafs = OrderedDict([
                                                            ('parent_object_pointer', (YLeaf(YType.uint64, 'parent-object-pointer'), ['int'])),
                                                            ('back_object_pointer', (YLeaf(YType.uint64, 'back-object-pointer'), ['int'])),
                                                        ])
                                                        self.parent_object_pointer = None
                                                        self.back_object_pointer = None

                                                        self.object_base = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase()
                                                        self.object_base.parent = self
                                                        self._children_name_map["object_base"] = "object-base"
                                                        self._segment_path = lambda: "nh-info-extension-base"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase, ['parent_object_pointer', 'back_object_pointer'], name, value)


                                                    class ObjectBase(Entity):
                                                        """
                                                        FIB Object Base information
                                                        
                                                        .. attribute:: object_reference_count
                                                        
                                                        	FIB Object Reference Count
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_flags
                                                        
                                                        	FIB Object flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: object_type
                                                        
                                                        	FIB Object type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: object_time_stamp
                                                        
                                                        	FIB Object TimeStamp in msec
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: object_pointer
                                                        
                                                        	FIB Object pointer
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, self).__init__()

                                                            self.yang_name = "object-base"
                                                            self.yang_parent_name = "nh-info-extension-base"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('object_reference_count', (YLeaf(YType.uint32, 'object-reference-count'), ['int'])),
                                                                ('object_flags', (YLeaf(YType.uint32, 'object-flags'), ['int'])),
                                                                ('object_type', (YLeaf(YType.uint8, 'object-type'), ['int'])),
                                                                ('object_time_stamp', (YLeaf(YType.uint64, 'object-time-stamp'), ['int'])),
                                                                ('object_pointer', (YLeaf(YType.uint64, 'object-pointer'), ['int'])),
                                                            ])
                                                            self.object_reference_count = None
                                                            self.object_flags = None
                                                            self.object_type = None
                                                            self.object_time_stamp = None
                                                            self.object_pointer = None
                                                            self._segment_path = lambda: "object-base"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionBase.ObjectBase, ['object_reference_count', 'object_flags', 'object_type', 'object_time_stamp', 'object_pointer'], name, value)


                                                class NhInfoExtensionDetail_(Entity):
                                                    """
                                                    NHINFO Extension Detail Information
                                                    
                                                    .. attribute:: snecd_nhr
                                                    
                                                    	snecd nhr
                                                    	**type**\:  :py:class:`SnecdNhr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr>`
                                                    
                                                    .. attribute:: type
                                                    
                                                    	type
                                                    	**type**\:  :py:class:`FibNhinfoExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNhinfoExtBag>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'fib-common-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, self).__init__()

                                                        self.yang_name = "nh-info-extension-detail"
                                                        self.yang_parent_name = "nh-info-extension-detail"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("snecd-nhr", ("snecd_nhr", Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr))])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNhinfoExtBag', '')])),
                                                        ])
                                                        self.type = None

                                                        self.snecd_nhr = Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr()
                                                        self.snecd_nhr.parent = self
                                                        self._children_name_map["snecd_nhr"] = "snecd-nhr"
                                                        self._segment_path = lambda: "nh-info-extension-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_, ['type'], name, value)


                                                    class SnecdNhr(Entity):
                                                        """
                                                        snecd nhr
                                                        
                                                        .. attribute:: nh_info_replicated_type
                                                        
                                                        	Replicated NHINFO type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: nh_info_replicated_nh_id
                                                        
                                                        	NHID of the replicated NHINFO
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nh_info_replicated_interface
                                                        
                                                        	Interface of the replicated NHINFO
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        

                                                        """

                                                        _prefix = 'fib-common-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, self).__init__()

                                                            self.yang_name = "snecd-nhr"
                                                            self.yang_parent_name = "nh-info-extension-detail"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nh_info_replicated_type', (YLeaf(YType.uint8, 'nh-info-replicated-type'), ['int'])),
                                                                ('nh_info_replicated_nh_id', (YLeaf(YType.uint32, 'nh-info-replicated-nh-id'), ['int'])),
                                                                ('nh_info_replicated_interface', (YLeaf(YType.str, 'nh-info-replicated-interface'), ['str'])),
                                                            ])
                                                            self.nh_info_replicated_type = None
                                                            self.nh_info_replicated_nh_id = None
                                                            self.nh_info_replicated_interface = None
                                                            self._segment_path = lambda: "snecd-nhr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Vrfs.Vrf.NhInfoBrief.NhInfoLocalBriefs.NhInfoLocalBrief.NhInfoExtension.NhInfoExtensionDetail.NhInfoExtensionDetail_.SnecdNhr, ['nh_info_replicated_type', 'nh_info_replicated_nh_id', 'nh_info_replicated_interface'], name, value)


                    class ExactRoutes(Entity):
                        """
                        Exact Route Table
                        
                        .. attribute:: exact_route
                        
                        	Exact route for the given source and destination addresses
                        	**type**\: list of  		 :py:class:`ExactRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes, self).__init__()

                            self.yang_name = "exact-routes"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("exact-route", ("exact_route", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute))])
                            self._leafs = OrderedDict()

                            self.exact_route = YList(self)
                            self._segment_path = lambda: "exact-routes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes, [], name, value)


                        class ExactRoute(Entity):
                            """
                            Exact route for the given source and
                            destination addresses
                            
                            .. attribute:: protocol_name
                            
                            	Protocol Name
                            	**type**\:  :py:class:`FibProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibProtocol>`
                            
                            .. attribute:: vrf_name
                            
                            	VRF Name
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: source
                            
                            	Source address
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: destination
                            
                            	Destination address
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: ipv6_flow_label
                            
                            	IPv6 flow label (applies only to and used only for IPv6)
                            	**type**\: int
                            
                            	**range:** 0..1048575
                            
                            .. attribute:: detail_fib_entry_information
                            
                            	Detailed FIB entry information
                            	**type**\:  :py:class:`DetailFibEntryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation>`
                            
                            .. attribute:: fib_entry_path
                            
                            	FIB entry path details
                            	**type**\:  :py:class:`FibEntryPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath>`
                            
                            .. attribute:: protocol_type_fib_entry
                            
                            	Proto type for this entry
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: platform_hardware
                            
                            	Platform Hardware info
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: number_of_referances_to_path_list
                            
                            	Number of references to the pathlist
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_list_flags
                            
                            	The pathlist flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_list_source
                            
                            	The pathlist source
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_referances_to_ldi
                            
                            	Number of references to the LDI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldi_flags
                            
                            	The LDI flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flags_external_ldi
                            
                            	The flags of ext assocaited with LDI 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pointer_external_ldi
                            
                            	The pointer to the ext assocaited with LDI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: exact_path_interface_handle
                            
                            	exact\-path interface handle
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: exact_path_gre_interface_handle
                            
                            	exact\-path GRE physical interface handle
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: exact_route_gre_phys_ifh_avail
                            
                            	exact\-route GRE phy ifh available
                            	**type**\: bool
                            
                            .. attribute:: exact_route_result
                            
                            	exact\-route result
                            	**type**\: bool
                            
                            .. attribute:: prefix_is_static_or_connected
                            
                            	Prefix is static or connected
                            	**type**\: bool
                            
                            .. attribute:: packet_should_recieve
                            
                            	Packet should always be received
                            	**type**\: bool
                            
                            .. attribute:: prefix_connected
                            
                            	Prefix is connected
                            	**type**\: bool
                            
                            .. attribute:: prefix_for_adjancency
                            
                            	Prefix is for an adjacency
                            	**type**\: bool
                            
                            .. attribute:: prefix_for_pic_next_hop
                            
                            	Prefix is for a PIC nexthop
                            	**type**\: bool
                            
                            .. attribute:: purgable_after_purge_interval
                            
                            	Purgable after the purge interval
                            	**type**\: bool
                            
                            .. attribute:: broadcast_recive_flag
                            
                            	Broadcast receive flag
                            	**type**\: bool
                            
                            .. attribute:: broadcast_forward_flag
                            
                            	Broadcast forward flag
                            	**type**\: bool
                            
                            .. attribute:: zero_by_zero_route_as_default
                            
                            	0/0 route added as default route
                            	**type**\: bool
                            
                            .. attribute:: external_switch_triggered
                            
                            	External switch function triggered
                            	**type**\: bool
                            
                            .. attribute:: route_attribute_flag
                            
                            	Route attributes summary flag
                            	**type**\: bool
                            
                            .. attribute:: dummy_real_zero_route
                            
                            	Dummy real zero route
                            	**type**\: bool
                            
                            .. attribute:: ldi_lw_flag
                            
                            	The LDI LW flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ref_counter_of_ldi_lw_ldi
                            
                            	The refcounter of LDI LW LDI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: type_of_ldi_lw_ldi
                            
                            	The type of LDI LW LDI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lspa_flags
                            
                            	The LSPA flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: version_of_route
                            
                            	The version of the route
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fib_route_download_priority
                            
                            	Priority at which the route was downloaded
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_of_last_update_in_msec
                            
                            	The time of last update in msec
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: l2_subscriber_route
                            
                            	Is L2 Subscriber route
                            	**type**\: bool
                            
                            .. attribute:: l2_subscriber_xconnect_id
                            
                            	XConnect\-id associated with L2 subscriber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: l2_subscriber_flags
                            
                            	Flags associated with L2 subscriber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: l2_subscriber_ip_protocol
                            
                            	IP protocol associated with L2 subscriber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: l2tpv3_cookie_length_bits
                            
                            	L2TPv3 cookie length for L2 subscriber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_for_external_reach_linecard_flag
                            
                            	Route destined for Line Card that support External Reach only
                            	**type**\: bool
                            
                            .. attribute:: route_is_sr_flag
                            
                            	Route is a MPLS Segment\-Routing prefix
                            	**type**\: bool
                            
                            .. attribute:: extension_object
                            
                            	Leaf Extension Object List
                            	**type**\: list of  		 :py:class:`ExtensionObject <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.ExtensionObject>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute, self).__init__()

                                self.yang_name = "exact-route"
                                self.yang_parent_name = "exact-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("detail-fib-entry-information", ("detail_fib_entry_information", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation)), ("fib-entry-path", ("fib_entry_path", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath)), ("extension-object", ("extension_object", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.ExtensionObject))])
                                self._leafs = OrderedDict([
                                    ('protocol_name', (YLeaf(YType.enumeration, 'protocol-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibProtocol', '')])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('source', (YLeaf(YType.str, 'source'), ['str'])),
                                    ('destination', (YLeaf(YType.str, 'destination'), ['str'])),
                                    ('ipv6_flow_label', (YLeaf(YType.uint32, 'ipv6-flow-label'), ['int'])),
                                    ('protocol_type_fib_entry', (YLeaf(YType.uint32, 'protocol-type-fib-entry'), ['int'])),
                                    ('platform_hardware', (YLeaf(YType.str, 'platform-hardware'), ['str'])),
                                    ('number_of_referances_to_path_list', (YLeaf(YType.uint32, 'number-of-referances-to-path-list'), ['int'])),
                                    ('path_list_flags', (YLeaf(YType.uint32, 'path-list-flags'), ['int'])),
                                    ('path_list_source', (YLeaf(YType.uint32, 'path-list-source'), ['int'])),
                                    ('number_of_referances_to_ldi', (YLeaf(YType.uint32, 'number-of-referances-to-ldi'), ['int'])),
                                    ('ldi_flags', (YLeaf(YType.uint32, 'ldi-flags'), ['int'])),
                                    ('flags_external_ldi', (YLeaf(YType.uint32, 'flags-external-ldi'), ['int'])),
                                    ('pointer_external_ldi', (YLeaf(YType.uint32, 'pointer-external-ldi'), ['int'])),
                                    ('exact_path_interface_handle', (YLeaf(YType.uint32, 'exact-path-interface-handle'), ['int'])),
                                    ('exact_path_gre_interface_handle', (YLeaf(YType.uint32, 'exact-path-gre-interface-handle'), ['int'])),
                                    ('exact_route_gre_phys_ifh_avail', (YLeaf(YType.boolean, 'exact-route-gre-phys-ifh-avail'), ['bool'])),
                                    ('exact_route_result', (YLeaf(YType.boolean, 'exact-route-result'), ['bool'])),
                                    ('prefix_is_static_or_connected', (YLeaf(YType.boolean, 'prefix-is-static-or-connected'), ['bool'])),
                                    ('packet_should_recieve', (YLeaf(YType.boolean, 'packet-should-recieve'), ['bool'])),
                                    ('prefix_connected', (YLeaf(YType.boolean, 'prefix-connected'), ['bool'])),
                                    ('prefix_for_adjancency', (YLeaf(YType.boolean, 'prefix-for-adjancency'), ['bool'])),
                                    ('prefix_for_pic_next_hop', (YLeaf(YType.boolean, 'prefix-for-pic-next-hop'), ['bool'])),
                                    ('purgable_after_purge_interval', (YLeaf(YType.boolean, 'purgable-after-purge-interval'), ['bool'])),
                                    ('broadcast_recive_flag', (YLeaf(YType.boolean, 'broadcast-recive-flag'), ['bool'])),
                                    ('broadcast_forward_flag', (YLeaf(YType.boolean, 'broadcast-forward-flag'), ['bool'])),
                                    ('zero_by_zero_route_as_default', (YLeaf(YType.boolean, 'zero-by-zero-route-as-default'), ['bool'])),
                                    ('external_switch_triggered', (YLeaf(YType.boolean, 'external-switch-triggered'), ['bool'])),
                                    ('route_attribute_flag', (YLeaf(YType.boolean, 'route-attribute-flag'), ['bool'])),
                                    ('dummy_real_zero_route', (YLeaf(YType.boolean, 'dummy-real-zero-route'), ['bool'])),
                                    ('ldi_lw_flag', (YLeaf(YType.uint32, 'ldi-lw-flag'), ['int'])),
                                    ('ref_counter_of_ldi_lw_ldi', (YLeaf(YType.uint32, 'ref-counter-of-ldi-lw-ldi'), ['int'])),
                                    ('type_of_ldi_lw_ldi', (YLeaf(YType.uint32, 'type-of-ldi-lw-ldi'), ['int'])),
                                    ('lspa_flags', (YLeaf(YType.uint32, 'lspa-flags'), ['int'])),
                                    ('version_of_route', (YLeaf(YType.uint64, 'version-of-route'), ['int'])),
                                    ('fib_route_download_priority', (YLeaf(YType.uint32, 'fib-route-download-priority'), ['int'])),
                                    ('time_of_last_update_in_msec', (YLeaf(YType.uint64, 'time-of-last-update-in-msec'), ['int'])),
                                    ('l2_subscriber_route', (YLeaf(YType.boolean, 'l2-subscriber-route'), ['bool'])),
                                    ('l2_subscriber_xconnect_id', (YLeaf(YType.uint32, 'l2-subscriber-xconnect-id'), ['int'])),
                                    ('l2_subscriber_flags', (YLeaf(YType.uint32, 'l2-subscriber-flags'), ['int'])),
                                    ('l2_subscriber_ip_protocol', (YLeaf(YType.uint32, 'l2-subscriber-ip-protocol'), ['int'])),
                                    ('l2tpv3_cookie_length_bits', (YLeaf(YType.uint32, 'l2tpv3-cookie-length-bits'), ['int'])),
                                    ('route_for_external_reach_linecard_flag', (YLeaf(YType.boolean, 'route-for-external-reach-linecard-flag'), ['bool'])),
                                    ('route_is_sr_flag', (YLeaf(YType.boolean, 'route-is-sr-flag'), ['bool'])),
                                ])
                                self.protocol_name = None
                                self.vrf_name = None
                                self.source = None
                                self.destination = None
                                self.ipv6_flow_label = None
                                self.protocol_type_fib_entry = None
                                self.platform_hardware = None
                                self.number_of_referances_to_path_list = None
                                self.path_list_flags = None
                                self.path_list_source = None
                                self.number_of_referances_to_ldi = None
                                self.ldi_flags = None
                                self.flags_external_ldi = None
                                self.pointer_external_ldi = None
                                self.exact_path_interface_handle = None
                                self.exact_path_gre_interface_handle = None
                                self.exact_route_gre_phys_ifh_avail = None
                                self.exact_route_result = None
                                self.prefix_is_static_or_connected = None
                                self.packet_should_recieve = None
                                self.prefix_connected = None
                                self.prefix_for_adjancency = None
                                self.prefix_for_pic_next_hop = None
                                self.purgable_after_purge_interval = None
                                self.broadcast_recive_flag = None
                                self.broadcast_forward_flag = None
                                self.zero_by_zero_route_as_default = None
                                self.external_switch_triggered = None
                                self.route_attribute_flag = None
                                self.dummy_real_zero_route = None
                                self.ldi_lw_flag = None
                                self.ref_counter_of_ldi_lw_ldi = None
                                self.type_of_ldi_lw_ldi = None
                                self.lspa_flags = None
                                self.version_of_route = None
                                self.fib_route_download_priority = None
                                self.time_of_last_update_in_msec = None
                                self.l2_subscriber_route = None
                                self.l2_subscriber_xconnect_id = None
                                self.l2_subscriber_flags = None
                                self.l2_subscriber_ip_protocol = None
                                self.l2tpv3_cookie_length_bits = None
                                self.route_for_external_reach_linecard_flag = None
                                self.route_is_sr_flag = None

                                self.detail_fib_entry_information = Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation()
                                self.detail_fib_entry_information.parent = self
                                self._children_name_map["detail_fib_entry_information"] = "detail-fib-entry-information"

                                self.fib_entry_path = Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath()
                                self.fib_entry_path.parent = self
                                self._children_name_map["fib_entry_path"] = "fib-entry-path"

                                self.extension_object = YList(self)
                                self._segment_path = lambda: "exact-route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute, ['protocol_name', 'vrf_name', 'source', 'destination', 'ipv6_flow_label', 'protocol_type_fib_entry', 'platform_hardware', 'number_of_referances_to_path_list', 'path_list_flags', 'path_list_source', 'number_of_referances_to_ldi', 'ldi_flags', 'flags_external_ldi', 'pointer_external_ldi', 'exact_path_interface_handle', 'exact_path_gre_interface_handle', 'exact_route_gre_phys_ifh_avail', 'exact_route_result', 'prefix_is_static_or_connected', 'packet_should_recieve', 'prefix_connected', 'prefix_for_adjancency', 'prefix_for_pic_next_hop', 'purgable_after_purge_interval', 'broadcast_recive_flag', 'broadcast_forward_flag', 'zero_by_zero_route_as_default', 'external_switch_triggered', 'route_attribute_flag', 'dummy_real_zero_route', 'ldi_lw_flag', 'ref_counter_of_ldi_lw_ldi', 'type_of_ldi_lw_ldi', 'lspa_flags', 'version_of_route', 'fib_route_download_priority', 'time_of_last_update_in_msec', 'l2_subscriber_route', 'l2_subscriber_xconnect_id', 'l2_subscriber_flags', 'l2_subscriber_ip_protocol', 'l2tpv3_cookie_length_bits', 'route_for_external_reach_linecard_flag', 'route_is_sr_flag'], name, value)


                            class DetailFibEntryInformation(Entity):
                                """
                                Detailed FIB entry information
                                
                                .. attribute:: loadshare_information
                                
                                	Detailed Loadshare info
                                	**type**\:  :py:class:`LoadshareInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation>`
                                
                                .. attribute:: fib_entry_version
                                
                                	FIB entry version number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: per_prefix_accounting
                                
                                	Per Prefix Accounting
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: load_sharing_type
                                
                                	Load sharing type
                                	**type**\:  :py:class:`FibLoadshareShow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibLoadshareShow>`
                                
                                .. attribute:: fib_entry_adjacency_type
                                
                                	FIB entry adjacency type
                                	**type**\:  :py:class:`FibAdjacencyShow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibAdjacencyShow>`
                                
                                .. attribute:: fib_protocol_type
                                
                                	FIB Protocol type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: afi_fib_protocol_type
                                
                                	AFI FIB protocol type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aib_l3_address
                                
                                	AIB L3 Address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: adjacency_address_length
                                
                                	ADJ ADDR LEN
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: adjacency_interface
                                
                                	ADJ IFH
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fib_special_nh_information_type
                                
                                	FIB Special NHINFO Type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fib_entry_adjacency_address
                                
                                	FIB entry adj address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: fib_entry_adjacency_interface
                                
                                	FIB entry adjacency interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: packets_through_fib_entry
                                
                                	Packets through this FIB entry
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bytes_through_fib_entry
                                
                                	Bytes through this FIB entry
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: detailed_prefix_length
                                
                                	Prefix length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_protocol
                                
                                	Prefix protocol
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: precedence_forpackets
                                
                                	Precedence for packets to this entry
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: traffic_index_for_packets
                                
                                	Traffic index for packets to this entry
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: switch_compontent_id
                                
                                	Switch function compontent ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fast_adjacency_flag
                                
                                	Fast adjacency flag
                                	**type**\: bool
                                
                                .. attribute:: illegal_fast_adjacency_flag
                                
                                	Illegal fast adjacency flag
                                	**type**\: bool
                                
                                .. attribute:: remote_adjacency_flag
                                
                                	Remote adjacency flag
                                	**type**\: bool
                                
                                .. attribute:: bgp_attribute_id
                                
                                	BGP attribute id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bgp_local_attribute_id
                                
                                	BGP local attribute id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bgp_attribute_origin_as
                                
                                	BGP attribute origin as
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bgp_attribute_next_hop_as
                                
                                	BGP attribute next hop as
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_string
                                
                                	As path string
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extcom_string
                                
                                	extcom st
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: com_string
                                
                                	com st
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extended_community
                                
                                	extended community
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qos_group
                                
                                	qos group
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_fec
                                
                                	mpls fec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qppb_qos_group_and_ip_precedence
                                
                                	qppb QOS group and IP precedence
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flow_tag
                                
                                	PBR flow\-tag
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: forward_class
                                
                                	SPP forwarding class ID
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: pl_time_of_last_update_in_msec
                                
                                	The time of last update for PL in msec
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ldi_time_of_last_update_in_msec
                                
                                	The time of last update for LDI in msec
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: lwldi_time_of_last_update_in_msec
                                
                                	The time of last update for LW\-LDI in msec
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pl_time_stamp_type
                                
                                	The type of time\-stamp on PL
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation, self).__init__()

                                    self.yang_name = "detail-fib-entry-information"
                                    self.yang_parent_name = "exact-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("loadshare-information", ("loadshare_information", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation))])
                                    self._leafs = OrderedDict([
                                        ('fib_entry_version', (YLeaf(YType.uint32, 'fib-entry-version'), ['int'])),
                                        ('per_prefix_accounting', (YLeaf(YType.uint8, 'per-prefix-accounting'), ['int'])),
                                        ('load_sharing_type', (YLeaf(YType.enumeration, 'load-sharing-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibLoadshareShow', '')])),
                                        ('fib_entry_adjacency_type', (YLeaf(YType.enumeration, 'fib-entry-adjacency-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibAdjacencyShow', '')])),
                                        ('fib_protocol_type', (YLeaf(YType.uint32, 'fib-protocol-type'), ['int'])),
                                        ('afi_fib_protocol_type', (YLeaf(YType.uint32, 'afi-fib-protocol-type'), ['int'])),
                                        ('aib_l3_address', (YLeaf(YType.str, 'aib-l3-address'), ['str'])),
                                        ('adjacency_address_length', (YLeaf(YType.uint32, 'adjacency-address-length'), ['int'])),
                                        ('adjacency_interface', (YLeaf(YType.uint32, 'adjacency-interface'), ['int'])),
                                        ('fib_special_nh_information_type', (YLeaf(YType.uint32, 'fib-special-nh-information-type'), ['int'])),
                                        ('fib_entry_adjacency_address', (YLeaf(YType.str, 'fib-entry-adjacency-address'), ['str'])),
                                        ('fib_entry_adjacency_interface', (YLeaf(YType.uint32, 'fib-entry-adjacency-interface'), ['int'])),
                                        ('packets_through_fib_entry', (YLeaf(YType.uint64, 'packets-through-fib-entry'), ['int'])),
                                        ('bytes_through_fib_entry', (YLeaf(YType.uint64, 'bytes-through-fib-entry'), ['int'])),
                                        ('detailed_prefix_length', (YLeaf(YType.uint32, 'detailed-prefix-length'), ['int'])),
                                        ('prefix_protocol', (YLeaf(YType.uint32, 'prefix-protocol'), ['int'])),
                                        ('precedence_forpackets', (YLeaf(YType.uint8, 'precedence-forpackets'), ['int'])),
                                        ('traffic_index_for_packets', (YLeaf(YType.uint8, 'traffic-index-for-packets'), ['int'])),
                                        ('switch_compontent_id', (YLeaf(YType.uint32, 'switch-compontent-id'), ['int'])),
                                        ('fast_adjacency_flag', (YLeaf(YType.boolean, 'fast-adjacency-flag'), ['bool'])),
                                        ('illegal_fast_adjacency_flag', (YLeaf(YType.boolean, 'illegal-fast-adjacency-flag'), ['bool'])),
                                        ('remote_adjacency_flag', (YLeaf(YType.boolean, 'remote-adjacency-flag'), ['bool'])),
                                        ('bgp_attribute_id', (YLeaf(YType.uint32, 'bgp-attribute-id'), ['int'])),
                                        ('bgp_local_attribute_id', (YLeaf(YType.uint32, 'bgp-local-attribute-id'), ['int'])),
                                        ('bgp_attribute_origin_as', (YLeaf(YType.uint32, 'bgp-attribute-origin-as'), ['int'])),
                                        ('bgp_attribute_next_hop_as', (YLeaf(YType.uint32, 'bgp-attribute-next-hop-as'), ['int'])),
                                        ('path_string', (YLeaf(YType.str, 'path-string'), ['str'])),
                                        ('extcom_string', (YLeaf(YType.str, 'extcom-string'), ['str'])),
                                        ('com_string', (YLeaf(YType.str, 'com-string'), ['str'])),
                                        ('extended_community', (YLeaf(YType.uint32, 'extended-community'), ['int'])),
                                        ('qos_group', (YLeaf(YType.uint32, 'qos-group'), ['int'])),
                                        ('mpls_fec', (YLeaf(YType.uint32, 'mpls-fec'), ['int'])),
                                        ('qppb_qos_group_and_ip_precedence', (YLeaf(YType.uint32, 'qppb-qos-group-and-ip-precedence'), ['int'])),
                                        ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                        ('forward_class', (YLeaf(YType.uint8, 'forward-class'), ['int'])),
                                        ('pl_time_of_last_update_in_msec', (YLeaf(YType.uint64, 'pl-time-of-last-update-in-msec'), ['int'])),
                                        ('ldi_time_of_last_update_in_msec', (YLeaf(YType.uint64, 'ldi-time-of-last-update-in-msec'), ['int'])),
                                        ('lwldi_time_of_last_update_in_msec', (YLeaf(YType.uint64, 'lwldi-time-of-last-update-in-msec'), ['int'])),
                                        ('pl_time_stamp_type', (YLeaf(YType.uint32, 'pl-time-stamp-type'), ['int'])),
                                    ])
                                    self.fib_entry_version = None
                                    self.per_prefix_accounting = None
                                    self.load_sharing_type = None
                                    self.fib_entry_adjacency_type = None
                                    self.fib_protocol_type = None
                                    self.afi_fib_protocol_type = None
                                    self.aib_l3_address = None
                                    self.adjacency_address_length = None
                                    self.adjacency_interface = None
                                    self.fib_special_nh_information_type = None
                                    self.fib_entry_adjacency_address = None
                                    self.fib_entry_adjacency_interface = None
                                    self.packets_through_fib_entry = None
                                    self.bytes_through_fib_entry = None
                                    self.detailed_prefix_length = None
                                    self.prefix_protocol = None
                                    self.precedence_forpackets = None
                                    self.traffic_index_for_packets = None
                                    self.switch_compontent_id = None
                                    self.fast_adjacency_flag = None
                                    self.illegal_fast_adjacency_flag = None
                                    self.remote_adjacency_flag = None
                                    self.bgp_attribute_id = None
                                    self.bgp_local_attribute_id = None
                                    self.bgp_attribute_origin_as = None
                                    self.bgp_attribute_next_hop_as = None
                                    self.path_string = None
                                    self.extcom_string = None
                                    self.com_string = None
                                    self.extended_community = None
                                    self.qos_group = None
                                    self.mpls_fec = None
                                    self.qppb_qos_group_and_ip_precedence = None
                                    self.flow_tag = None
                                    self.forward_class = None
                                    self.pl_time_of_last_update_in_msec = None
                                    self.ldi_time_of_last_update_in_msec = None
                                    self.lwldi_time_of_last_update_in_msec = None
                                    self.pl_time_stamp_type = None

                                    self.loadshare_information = Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation()
                                    self.loadshare_information.parent = self
                                    self._children_name_map["loadshare_information"] = "loadshare-information"
                                    self._segment_path = lambda: "detail-fib-entry-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation, ['fib_entry_version', 'per_prefix_accounting', 'load_sharing_type', 'fib_entry_adjacency_type', 'fib_protocol_type', 'afi_fib_protocol_type', 'aib_l3_address', 'adjacency_address_length', 'adjacency_interface', 'fib_special_nh_information_type', 'fib_entry_adjacency_address', 'fib_entry_adjacency_interface', 'packets_through_fib_entry', 'bytes_through_fib_entry', 'detailed_prefix_length', 'prefix_protocol', 'precedence_forpackets', 'traffic_index_for_packets', 'switch_compontent_id', 'fast_adjacency_flag', 'illegal_fast_adjacency_flag', 'remote_adjacency_flag', 'bgp_attribute_id', 'bgp_local_attribute_id', 'bgp_attribute_origin_as', 'bgp_attribute_next_hop_as', 'path_string', 'extcom_string', 'com_string', 'extended_community', 'qos_group', 'mpls_fec', 'qppb_qos_group_and_ip_precedence', 'flow_tag', 'forward_class', 'pl_time_of_last_update_in_msec', 'ldi_time_of_last_update_in_msec', 'lwldi_time_of_last_update_in_msec', 'pl_time_stamp_type'], name, value)


                                class LoadshareInformation(Entity):
                                    """
                                    Detailed Loadshare info
                                    
                                    .. attribute:: load_informtion_internal_data
                                    
                                    	Loadinfo internal data
                                    	**type**\:  :py:class:`LoadInformtionInternalData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData>`
                                    
                                    .. attribute:: packets_through_load_information
                                    
                                    	Packets through this loadinfo
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes_through_load_information
                                    
                                    	Bytes through this loadinfo
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: total_packets_through_load_information
                                    
                                    	Total packets through this loadinfo
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: total_bytes_through_load_information
                                    
                                    	Total bytes through this loadinfo
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: prefix_of_owner
                                    
                                    	Prefix of the owner
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mask_length_of_owner
                                    
                                    	Mask length of the owner
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: load_information_reference_count
                                    
                                    	Loadinfo reference count
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: per_dest_load_sharing_flag
                                    
                                    	Per destination load sharing flag
                                    	**type**\: bool
                                    
                                    .. attribute:: load_information_owner_deleted_flag
                                    
                                    	Loadinfo owner deleted flag
                                    	**type**\: bool
                                    
                                    .. attribute:: loadinfo_sanity_flag
                                    
                                    	Loadinfo sanity flag
                                    	**type**\: bool
                                    
                                    .. attribute:: is_owner
                                    
                                    	Owner flag
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation, self).__init__()

                                        self.yang_name = "loadshare-information"
                                        self.yang_parent_name = "detail-fib-entry-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("load-informtion-internal-data", ("load_informtion_internal_data", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData))])
                                        self._leafs = OrderedDict([
                                            ('packets_through_load_information', (YLeaf(YType.uint64, 'packets-through-load-information'), ['int'])),
                                            ('bytes_through_load_information', (YLeaf(YType.uint64, 'bytes-through-load-information'), ['int'])),
                                            ('total_packets_through_load_information', (YLeaf(YType.uint64, 'total-packets-through-load-information'), ['int'])),
                                            ('total_bytes_through_load_information', (YLeaf(YType.uint64, 'total-bytes-through-load-information'), ['int'])),
                                            ('prefix_of_owner', (YLeaf(YType.uint32, 'prefix-of-owner'), ['int'])),
                                            ('mask_length_of_owner', (YLeaf(YType.uint32, 'mask-length-of-owner'), ['int'])),
                                            ('load_information_reference_count', (YLeaf(YType.uint16, 'load-information-reference-count'), ['int'])),
                                            ('per_dest_load_sharing_flag', (YLeaf(YType.boolean, 'per-dest-load-sharing-flag'), ['bool'])),
                                            ('load_information_owner_deleted_flag', (YLeaf(YType.boolean, 'load-information-owner-deleted-flag'), ['bool'])),
                                            ('loadinfo_sanity_flag', (YLeaf(YType.boolean, 'loadinfo-sanity-flag'), ['bool'])),
                                            ('is_owner', (YLeaf(YType.boolean, 'is-owner'), ['bool'])),
                                        ])
                                        self.packets_through_load_information = None
                                        self.bytes_through_load_information = None
                                        self.total_packets_through_load_information = None
                                        self.total_bytes_through_load_information = None
                                        self.prefix_of_owner = None
                                        self.mask_length_of_owner = None
                                        self.load_information_reference_count = None
                                        self.per_dest_load_sharing_flag = None
                                        self.load_information_owner_deleted_flag = None
                                        self.loadinfo_sanity_flag = None
                                        self.is_owner = None

                                        self.load_informtion_internal_data = Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData()
                                        self.load_informtion_internal_data.parent = self
                                        self._children_name_map["load_informtion_internal_data"] = "load-informtion-internal-data"
                                        self._segment_path = lambda: "loadshare-information"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation, ['packets_through_load_information', 'bytes_through_load_information', 'total_packets_through_load_information', 'total_bytes_through_load_information', 'prefix_of_owner', 'mask_length_of_owner', 'load_information_reference_count', 'per_dest_load_sharing_flag', 'load_information_owner_deleted_flag', 'loadinfo_sanity_flag', 'is_owner'], name, value)


                                    class LoadInformtionInternalData(Entity):
                                        """
                                        Loadinfo internal data
                                        
                                        .. attribute:: level_ofldis
                                        
                                        	level of ldis
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: number_of_ldis
                                        
                                        	no. of ldis
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: maximum_index_arrays
                                        
                                        	Maximum index of the arrays
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_indices
                                        
                                        	Path indices
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: path_ldi_numbers
                                        
                                        	Path indices
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: maximum_slots
                                        
                                        	Maximum slots
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: normalized_weights
                                        
                                        	Normalized weights
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: tunnel_class_value
                                        
                                        	Tunnel class value
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: is_pbts_info_valid
                                        
                                        	PBTS info valid flag
                                        	**type**\: bool
                                        
                                        .. attribute:: pbts_class_offset
                                        
                                        	PBTS class offset
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: pbts_class_num_paths
                                        
                                        	PBTS class num paths
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: pbts_fallback_mapped_class
                                        
                                        	PBTS class falls back to class
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: round_robin_disable
                                        
                                        	Round Robin Disable
                                        	**type**\: bool
                                        
                                        .. attribute:: ldi_next_hop_buckets
                                        
                                        	Number of LDI next hop buckets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: platform_hardware_information
                                        
                                        	Platform Hardware info
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: sanity_flag
                                        
                                        	Sanity flag
                                        	**type**\: list of  		 :py:class:`SanityFlag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.SanityFlag>`
                                        
                                        .. attribute:: interface_handle
                                        
                                        	Interface handle
                                        	**type**\: list of  		 :py:class:`InterfaceHandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.InterfaceHandle>`
                                        
                                        .. attribute:: weights_of_path
                                        
                                        	Weights of paths
                                        	**type**\: list of  		 :py:class:`WeightsOfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.WeightsOfPath>`
                                        
                                        .. attribute:: adjacency_address
                                        
                                        	Adjacency address
                                        	**type**\: list of  		 :py:class:`AdjacencyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.AdjacencyAddress>`
                                        
                                        .. attribute:: pbts_class_is_fallback_mapped
                                        
                                        	Does PBTS class fall back to drop or any class
                                        	**type**\: list of  		 :py:class:`PbtsClassIsFallbackMapped <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsClassIsFallbackMapped>`
                                        
                                        .. attribute:: pbts_fallback_to_drop
                                        
                                        	PBTS class falls back to drop
                                        	**type**\: list of  		 :py:class:`PbtsFallbackToDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsFallbackToDrop>`
                                        
                                        .. attribute:: tunnel_is_forward_class
                                        
                                        	Tunnel is forward class
                                        	**type**\: list of  		 :py:class:`TunnelIsForwardClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.TunnelIsForwardClass>`
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData, self).__init__()

                                            self.yang_name = "load-informtion-internal-data"
                                            self.yang_parent_name = "loadshare-information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("sanity-flag", ("sanity_flag", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.SanityFlag)), ("interface-handle", ("interface_handle", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.InterfaceHandle)), ("weights-of-path", ("weights_of_path", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.WeightsOfPath)), ("adjacency-address", ("adjacency_address", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.AdjacencyAddress)), ("pbts-class-is-fallback-mapped", ("pbts_class_is_fallback_mapped", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsClassIsFallbackMapped)), ("pbts-fallback-to-drop", ("pbts_fallback_to_drop", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsFallbackToDrop)), ("tunnel-is-forward-class", ("tunnel_is_forward_class", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.TunnelIsForwardClass))])
                                            self._leafs = OrderedDict([
                                                ('level_ofldis', (YLeaf(YType.uint8, 'level-ofldis'), ['int'])),
                                                ('number_of_ldis', (YLeaf(YType.uint8, 'number-of-ldis'), ['int'])),
                                                ('maximum_index_arrays', (YLeaf(YType.uint32, 'maximum-index-arrays'), ['int'])),
                                                ('path_indices', (YLeaf(YType.str, 'path-indices'), ['str'])),
                                                ('path_ldi_numbers', (YLeaf(YType.str, 'path-ldi-numbers'), ['str'])),
                                                ('maximum_slots', (YLeaf(YType.uint32, 'maximum-slots'), ['int'])),
                                                ('normalized_weights', (YLeaf(YType.str, 'normalized-weights'), ['str'])),
                                                ('tunnel_class_value', (YLeaf(YType.str, 'tunnel-class-value'), ['str'])),
                                                ('is_pbts_info_valid', (YLeaf(YType.boolean, 'is-pbts-info-valid'), ['bool'])),
                                                ('pbts_class_offset', (YLeaf(YType.str, 'pbts-class-offset'), ['str'])),
                                                ('pbts_class_num_paths', (YLeaf(YType.str, 'pbts-class-num-paths'), ['str'])),
                                                ('pbts_fallback_mapped_class', (YLeaf(YType.str, 'pbts-fallback-mapped-class'), ['str'])),
                                                ('round_robin_disable', (YLeaf(YType.boolean, 'round-robin-disable'), ['bool'])),
                                                ('ldi_next_hop_buckets', (YLeaf(YType.uint8, 'ldi-next-hop-buckets'), ['int'])),
                                                ('platform_hardware_information', (YLeaf(YType.str, 'platform-hardware-information'), ['str'])),
                                            ])
                                            self.level_ofldis = None
                                            self.number_of_ldis = None
                                            self.maximum_index_arrays = None
                                            self.path_indices = None
                                            self.path_ldi_numbers = None
                                            self.maximum_slots = None
                                            self.normalized_weights = None
                                            self.tunnel_class_value = None
                                            self.is_pbts_info_valid = None
                                            self.pbts_class_offset = None
                                            self.pbts_class_num_paths = None
                                            self.pbts_fallback_mapped_class = None
                                            self.round_robin_disable = None
                                            self.ldi_next_hop_buckets = None
                                            self.platform_hardware_information = None

                                            self.sanity_flag = YList(self)
                                            self.interface_handle = YList(self)
                                            self.weights_of_path = YList(self)
                                            self.adjacency_address = YList(self)
                                            self.pbts_class_is_fallback_mapped = YList(self)
                                            self.pbts_fallback_to_drop = YList(self)
                                            self.tunnel_is_forward_class = YList(self)
                                            self._segment_path = lambda: "load-informtion-internal-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData, ['level_ofldis', 'number_of_ldis', 'maximum_index_arrays', 'path_indices', 'path_ldi_numbers', 'maximum_slots', 'normalized_weights', 'tunnel_class_value', 'is_pbts_info_valid', 'pbts_class_offset', 'pbts_class_num_paths', 'pbts_fallback_mapped_class', 'round_robin_disable', 'ldi_next_hop_buckets', 'platform_hardware_information'], name, value)


                                        class SanityFlag(Entity):
                                            """
                                            Sanity flag
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.SanityFlag, self).__init__()

                                                self.yang_name = "sanity-flag"
                                                self.yang_parent_name = "load-informtion-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "sanity-flag"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.SanityFlag, ['entry'], name, value)


                                        class InterfaceHandle(Entity):
                                            """
                                            Interface handle
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.InterfaceHandle, self).__init__()

                                                self.yang_name = "interface-handle"
                                                self.yang_parent_name = "load-informtion-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "interface-handle"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.InterfaceHandle, ['entry'], name, value)


                                        class WeightsOfPath(Entity):
                                            """
                                            Weights of paths
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.WeightsOfPath, self).__init__()

                                                self.yang_name = "weights-of-path"
                                                self.yang_parent_name = "load-informtion-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "weights-of-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.WeightsOfPath, ['entry'], name, value)


                                        class AdjacencyAddress(Entity):
                                            """
                                            Adjacency address
                                            
                                            .. attribute:: address
                                            
                                            	address
                                            	**type**\: str
                                            
                                            	**length:** 0..60
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.AdjacencyAddress, self).__init__()

                                                self.yang_name = "adjacency-address"
                                                self.yang_parent_name = "load-informtion-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                ])
                                                self.address = None
                                                self._segment_path = lambda: "adjacency-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.AdjacencyAddress, ['address'], name, value)


                                        class PbtsClassIsFallbackMapped(Entity):
                                            """
                                            Does PBTS class fall back to drop or any class
                                            
                                            .. attribute:: entry
                                            
                                            	Array entry
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsClassIsFallbackMapped, self).__init__()

                                                self.yang_name = "pbts-class-is-fallback-mapped"
                                                self.yang_parent_name = "load-informtion-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "pbts-class-is-fallback-mapped"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsClassIsFallbackMapped, ['entry'], name, value)


                                        class PbtsFallbackToDrop(Entity):
                                            """
                                            PBTS class falls back to drop
                                            
                                            .. attribute:: entry
                                            
                                            	Array entry
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsFallbackToDrop, self).__init__()

                                                self.yang_name = "pbts-fallback-to-drop"
                                                self.yang_parent_name = "load-informtion-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "pbts-fallback-to-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.PbtsFallbackToDrop, ['entry'], name, value)


                                        class TunnelIsForwardClass(Entity):
                                            """
                                            Tunnel is forward class
                                            
                                            .. attribute:: entry
                                            
                                            	Array entry
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.TunnelIsForwardClass, self).__init__()

                                                self.yang_name = "tunnel-is-forward-class"
                                                self.yang_parent_name = "load-informtion-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "tunnel-is-forward-class"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.DetailFibEntryInformation.LoadshareInformation.LoadInformtionInternalData.TunnelIsForwardClass, ['entry'], name, value)


                            class FibEntryPath(Entity):
                                """
                                FIB entry path details
                                
                                .. attribute:: fib_sh_tbl_path
                                
                                	fib sh tbl path
                                	**type**\: list of  		 :py:class:`FibShTblPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath, self).__init__()

                                    self.yang_name = "fib-entry-path"
                                    self.yang_parent_name = "exact-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("fib-sh-tbl-path", ("fib_sh_tbl_path", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath))])
                                    self._leafs = OrderedDict()

                                    self.fib_sh_tbl_path = YList(self)
                                    self._segment_path = lambda: "fib-entry-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath, [], name, value)


                                class FibShTblPath(Entity):
                                    """
                                    fib sh tbl path
                                    
                                    .. attribute:: more_detail_about_path
                                    
                                    	More detail about this path entry
                                    	**type**\:  :py:class:`MoreDetailAboutPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath>`
                                    
                                    .. attribute:: mpls_information_for_path
                                    
                                    	mpls info for this path entry
                                    	**type**\:  :py:class:`MplsInformationForPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath>`
                                    
                                    .. attribute:: hardware_information
                                    
                                    	Hardware info
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: brief_interface_handle
                                    
                                    	Interface handle
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: brief_next_hop_prefix
                                    
                                    	Next hop prefix
                                    	**type**\: str
                                    
                                    	**length:** 0..52
                                    
                                    .. attribute:: via_label_to_recurse
                                    
                                    	Local label to recurse over
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brief_pnode_address
                                    
                                    	P\-node address
                                    	**type**\: str
                                    
                                    	**length:** 0..52
                                    
                                    .. attribute:: brief_qnode_address
                                    
                                    	Q\-node address
                                    	**type**\: str
                                    
                                    	**length:** 0..52
                                    
                                    .. attribute:: brief_lfa_protection_type
                                    
                                    	LFA protection type
                                    	**type**\:  :py:class:`FibUpdatePathLfaProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibUpdatePathLfaProtection>`
                                    
                                    .. attribute:: resolved_path
                                    
                                    	Resolved path
                                    	**type**\: bool
                                    
                                    .. attribute:: recursive_path
                                    
                                    	Recursive path
                                    	**type**\: bool
                                    
                                    .. attribute:: packets_received_path
                                    
                                    	Packets received on this path
                                    	**type**\: bool
                                    
                                    .. attribute:: attached_path
                                    
                                    	Attached path
                                    	**type**\: bool
                                    
                                    .. attribute:: backup_path
                                    
                                    	Backup path
                                    	**type**\: bool
                                    
                                    .. attribute:: best_external_path
                                    
                                    	Best external path
                                    	**type**\: bool
                                    
                                    .. attribute:: protect_ignore
                                    
                                    	Is protection ignored
                                    	**type**\: bool
                                    
                                    .. attribute:: path_dlb
                                    
                                    	Is this the path used for DLB
                                    	**type**\: bool
                                    
                                    .. attribute:: path_flags
                                    
                                    	Path flags
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_info_flags
                                    
                                    	Path Info flags
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: path_index
                                    
                                    	Path index
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_index
                                    
                                    	Backup path index
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: next_hop_index
                                    
                                    	Next Hop Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_interface_handle
                                    
                                    	Parent Interface Handle
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: recursionvia_len
                                    
                                    	recursion via /N constraint
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath, self).__init__()

                                        self.yang_name = "fib-sh-tbl-path"
                                        self.yang_parent_name = "fib-entry-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("more-detail-about-path", ("more_detail_about_path", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath)), ("mpls-information-for-path", ("mpls_information_for_path", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath))])
                                        self._leafs = OrderedDict([
                                            ('hardware_information', (YLeaf(YType.str, 'hardware-information'), ['str'])),
                                            ('brief_interface_handle', (YLeaf(YType.str, 'brief-interface-handle'), ['str'])),
                                            ('brief_next_hop_prefix', (YLeaf(YType.str, 'brief-next-hop-prefix'), ['str'])),
                                            ('via_label_to_recurse', (YLeaf(YType.uint32, 'via-label-to-recurse'), ['int'])),
                                            ('brief_pnode_address', (YLeaf(YType.str, 'brief-pnode-address'), ['str'])),
                                            ('brief_qnode_address', (YLeaf(YType.str, 'brief-qnode-address'), ['str'])),
                                            ('brief_lfa_protection_type', (YLeaf(YType.enumeration, 'brief-lfa-protection-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibUpdatePathLfaProtection', '')])),
                                            ('resolved_path', (YLeaf(YType.boolean, 'resolved-path'), ['bool'])),
                                            ('recursive_path', (YLeaf(YType.boolean, 'recursive-path'), ['bool'])),
                                            ('packets_received_path', (YLeaf(YType.boolean, 'packets-received-path'), ['bool'])),
                                            ('attached_path', (YLeaf(YType.boolean, 'attached-path'), ['bool'])),
                                            ('backup_path', (YLeaf(YType.boolean, 'backup-path'), ['bool'])),
                                            ('best_external_path', (YLeaf(YType.boolean, 'best-external-path'), ['bool'])),
                                            ('protect_ignore', (YLeaf(YType.boolean, 'protect-ignore'), ['bool'])),
                                            ('path_dlb', (YLeaf(YType.boolean, 'path-dlb'), ['bool'])),
                                            ('path_flags', (YLeaf(YType.uint32, 'path-flags'), ['int'])),
                                            ('path_info_flags', (YLeaf(YType.uint16, 'path-info-flags'), ['int'])),
                                            ('path_index', (YLeaf(YType.uint8, 'path-index'), ['int'])),
                                            ('backup_index', (YLeaf(YType.uint8, 'backup-index'), ['int'])),
                                            ('next_hop_index', (YLeaf(YType.uint32, 'next-hop-index'), ['int'])),
                                            ('parent_interface_handle', (YLeaf(YType.str, 'parent-interface-handle'), ['str'])),
                                            ('recursionvia_len', (YLeaf(YType.uint8, 'recursionvia-len'), ['int'])),
                                        ])
                                        self.hardware_information = None
                                        self.brief_interface_handle = None
                                        self.brief_next_hop_prefix = None
                                        self.via_label_to_recurse = None
                                        self.brief_pnode_address = None
                                        self.brief_qnode_address = None
                                        self.brief_lfa_protection_type = None
                                        self.resolved_path = None
                                        self.recursive_path = None
                                        self.packets_received_path = None
                                        self.attached_path = None
                                        self.backup_path = None
                                        self.best_external_path = None
                                        self.protect_ignore = None
                                        self.path_dlb = None
                                        self.path_flags = None
                                        self.path_info_flags = None
                                        self.path_index = None
                                        self.backup_index = None
                                        self.next_hop_index = None
                                        self.parent_interface_handle = None
                                        self.recursionvia_len = None

                                        self.more_detail_about_path = Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath()
                                        self.more_detail_about_path.parent = self
                                        self._children_name_map["more_detail_about_path"] = "more-detail-about-path"

                                        self.mpls_information_for_path = Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath()
                                        self.mpls_information_for_path.parent = self
                                        self._children_name_map["mpls_information_for_path"] = "mpls-information-for-path"
                                        self._segment_path = lambda: "fib-sh-tbl-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath, ['hardware_information', 'brief_interface_handle', 'brief_next_hop_prefix', 'via_label_to_recurse', 'brief_pnode_address', 'brief_qnode_address', 'brief_lfa_protection_type', 'resolved_path', 'recursive_path', 'packets_received_path', 'attached_path', 'backup_path', 'best_external_path', 'protect_ignore', 'path_dlb', 'path_flags', 'path_info_flags', 'path_index', 'backup_index', 'next_hop_index', 'parent_interface_handle', 'recursionvia_len'], name, value)


                                    class MoreDetailAboutPath(Entity):
                                        """
                                        More detail about this path entry
                                        
                                        .. attribute:: ip_address_to_recurse
                                        
                                        	IP address to recurse to
                                        	**type**\: str
                                        
                                        	**length:** 0..52
                                        
                                        .. attribute:: label_to_recurse
                                        
                                        	Local label to recurse over
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: detail_next_hop_prefix
                                        
                                        	Next hop prefix
                                        	**type**\: str
                                        
                                        	**length:** 0..52
                                        
                                        .. attribute:: next_hop_mask_length
                                        
                                        	Next hop mask length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: interface_associated_path
                                        
                                        	Interface associated with this path
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: next_hop_interface
                                        
                                        	Next hop interface
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: next_hop_vrf
                                        
                                        	Next hop VRF
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: tunnle_endpoint_id
                                        
                                        	Tunnel endpoint id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lisprlocid
                                        
                                        	LISP RLOC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_dependencies_this_path
                                        
                                        	No. of dependents for this path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: robin_reset_value
                                        
                                        	Round robin reset value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: recurse_prefix_object
                                        
                                        	Is recursion object a leaf?
                                        	**type**\: bool
                                        
                                        .. attribute:: next_prefix_recursion
                                        
                                        	Next prefix recursion in the path
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: next_prefix_length
                                        
                                        	Next prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: recurse_prefix_object2
                                        
                                        	Recursion has two leaves (e.g. implicit\-null path)
                                        	**type**\: bool
                                        
                                        .. attribute:: next_prefix_recursion2
                                        
                                        	Next prefix2 recursion in the path
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: next_prefix_length2
                                        
                                        	Next prefix2 length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: detail_fib_adjacency_type
                                        
                                        	FIB entry adjacency type
                                        	**type**\:  :py:class:`FibAdjacencyShow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibAdjacencyShow>`
                                        
                                        .. attribute:: current_path_flag
                                        
                                        	Current path flag
                                        	**type**\: bool
                                        
                                        .. attribute:: recursive_path_information
                                        
                                        	Recursive path information is available
                                        	**type**\: bool
                                        
                                        .. attribute:: external_adjacency
                                        
                                        	Path is an external adjacency
                                        	**type**\: bool
                                        
                                        .. attribute:: fib_path_nh_information_type
                                        
                                        	FIB Nhinfo type
                                        	**type**\:  :py:class:`FibNeh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNeh>`
                                        
                                        .. attribute:: fib_path_nh_information_type_special
                                        
                                        	FIB Nhinfo type special
                                        	**type**\:  :py:class:`FibNehSpecial <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibNehSpecial>`
                                        
                                        .. attribute:: weight_of_path
                                        
                                        	Weight of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_class
                                        
                                        	Tunnel class of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tunnel_is_forward_class
                                        
                                        	Tunnel is forward class
                                        	**type**\: bool
                                        
                                        .. attribute:: spd_ipencap
                                        
                                        	IP Encap
                                        	**type**\: list of  		 :py:class:`SpdIpencap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap>`
                                        
                                        .. attribute:: next_next_hop
                                        
                                        	Next Next hop sets
                                        	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath.NextNextHop>`
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath, self).__init__()

                                            self.yang_name = "more-detail-about-path"
                                            self.yang_parent_name = "fib-sh-tbl-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("spd-ipencap", ("spd_ipencap", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap)), ("next-next-hop", ("next_next_hop", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath.NextNextHop))])
                                            self._leafs = OrderedDict([
                                                ('ip_address_to_recurse', (YLeaf(YType.str, 'ip-address-to-recurse'), ['str'])),
                                                ('label_to_recurse', (YLeaf(YType.uint32, 'label-to-recurse'), ['int'])),
                                                ('detail_next_hop_prefix', (YLeaf(YType.str, 'detail-next-hop-prefix'), ['str'])),
                                                ('next_hop_mask_length', (YLeaf(YType.uint8, 'next-hop-mask-length'), ['int'])),
                                                ('interface_associated_path', (YLeaf(YType.str, 'interface-associated-path'), ['str'])),
                                                ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                                ('next_hop_vrf', (YLeaf(YType.str, 'next-hop-vrf'), ['str'])),
                                                ('tunnle_endpoint_id', (YLeaf(YType.uint32, 'tunnle-endpoint-id'), ['int'])),
                                                ('lisprlocid', (YLeaf(YType.uint32, 'lisprlocid'), ['int'])),
                                                ('number_of_dependencies_this_path', (YLeaf(YType.uint32, 'number-of-dependencies-this-path'), ['int'])),
                                                ('robin_reset_value', (YLeaf(YType.uint8, 'robin-reset-value'), ['int'])),
                                                ('recurse_prefix_object', (YLeaf(YType.boolean, 'recurse-prefix-object'), ['bool'])),
                                                ('next_prefix_recursion', (YLeaf(YType.str, 'next-prefix-recursion'), ['str'])),
                                                ('next_prefix_length', (YLeaf(YType.uint8, 'next-prefix-length'), ['int'])),
                                                ('recurse_prefix_object2', (YLeaf(YType.boolean, 'recurse-prefix-object2'), ['bool'])),
                                                ('next_prefix_recursion2', (YLeaf(YType.str, 'next-prefix-recursion2'), ['str'])),
                                                ('next_prefix_length2', (YLeaf(YType.uint8, 'next-prefix-length2'), ['int'])),
                                                ('detail_fib_adjacency_type', (YLeaf(YType.enumeration, 'detail-fib-adjacency-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibAdjacencyShow', '')])),
                                                ('current_path_flag', (YLeaf(YType.boolean, 'current-path-flag'), ['bool'])),
                                                ('recursive_path_information', (YLeaf(YType.boolean, 'recursive-path-information'), ['bool'])),
                                                ('external_adjacency', (YLeaf(YType.boolean, 'external-adjacency'), ['bool'])),
                                                ('fib_path_nh_information_type', (YLeaf(YType.enumeration, 'fib-path-nh-information-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNeh', '')])),
                                                ('fib_path_nh_information_type_special', (YLeaf(YType.enumeration, 'fib-path-nh-information-type-special'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibNehSpecial', '')])),
                                                ('weight_of_path', (YLeaf(YType.uint32, 'weight-of-path'), ['int'])),
                                                ('tunnel_class', (YLeaf(YType.uint8, 'tunnel-class'), ['int'])),
                                                ('tunnel_is_forward_class', (YLeaf(YType.boolean, 'tunnel-is-forward-class'), ['bool'])),
                                            ])
                                            self.ip_address_to_recurse = None
                                            self.label_to_recurse = None
                                            self.detail_next_hop_prefix = None
                                            self.next_hop_mask_length = None
                                            self.interface_associated_path = None
                                            self.next_hop_interface = None
                                            self.next_hop_vrf = None
                                            self.tunnle_endpoint_id = None
                                            self.lisprlocid = None
                                            self.number_of_dependencies_this_path = None
                                            self.robin_reset_value = None
                                            self.recurse_prefix_object = None
                                            self.next_prefix_recursion = None
                                            self.next_prefix_length = None
                                            self.recurse_prefix_object2 = None
                                            self.next_prefix_recursion2 = None
                                            self.next_prefix_length2 = None
                                            self.detail_fib_adjacency_type = None
                                            self.current_path_flag = None
                                            self.recursive_path_information = None
                                            self.external_adjacency = None
                                            self.fib_path_nh_information_type = None
                                            self.fib_path_nh_information_type_special = None
                                            self.weight_of_path = None
                                            self.tunnel_class = None
                                            self.tunnel_is_forward_class = None

                                            self.spd_ipencap = YList(self)
                                            self.next_next_hop = YList(self)
                                            self._segment_path = lambda: "more-detail-about-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath, ['ip_address_to_recurse', 'label_to_recurse', 'detail_next_hop_prefix', 'next_hop_mask_length', 'interface_associated_path', 'next_hop_interface', 'next_hop_vrf', 'tunnle_endpoint_id', 'lisprlocid', 'number_of_dependencies_this_path', 'robin_reset_value', 'recurse_prefix_object', 'next_prefix_recursion', 'next_prefix_length', 'recurse_prefix_object2', 'next_prefix_recursion2', 'next_prefix_length2', 'detail_fib_adjacency_type', 'current_path_flag', 'recursive_path_information', 'external_adjacency', 'fib_path_nh_information_type', 'fib_path_nh_information_type_special', 'weight_of_path', 'tunnel_class', 'tunnel_is_forward_class'], name, value)


                                        class SpdIpencap(Entity):
                                            """
                                            IP Encap
                                            
                                            .. attribute:: ip_encap_hdr_count
                                            
                                            	Header Count
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ip_encap_locks
                                            
                                            	IPEncap Object Locks
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ip_encap_transport_tbl
                                            
                                            	Transport Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ipe_transport_vrf_name
                                            
                                            	Transport VRF name
                                            	**type**\: str
                                            
                                            .. attribute:: ip_encap_transport_af
                                            
                                            	Transport AF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ip_encap_payload_af
                                            
                                            	Payload AF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ip_encap_payload_mtu
                                            
                                            	Payload MTU
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ip_encap_parent
                                            
                                            	Pointer to parent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ip_encap_parent_type
                                            
                                            	Parent type enumeration
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ip_encap_hdr
                                            
                                            	Headers
                                            	**type**\: list of  		 :py:class:`IpEncapHdr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap.IpEncapHdr>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap, self).__init__()

                                                self.yang_name = "spd-ipencap"
                                                self.yang_parent_name = "more-detail-about-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ip-encap-hdr", ("ip_encap_hdr", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap.IpEncapHdr))])
                                                self._leafs = OrderedDict([
                                                    ('ip_encap_hdr_count', (YLeaf(YType.uint8, 'ip-encap-hdr-count'), ['int'])),
                                                    ('ip_encap_locks', (YLeaf(YType.uint32, 'ip-encap-locks'), ['int'])),
                                                    ('ip_encap_transport_tbl', (YLeaf(YType.uint32, 'ip-encap-transport-tbl'), ['int'])),
                                                    ('ipe_transport_vrf_name', (YLeaf(YType.str, 'ipe-transport-vrf-name'), ['str'])),
                                                    ('ip_encap_transport_af', (YLeaf(YType.uint32, 'ip-encap-transport-af'), ['int'])),
                                                    ('ip_encap_payload_af', (YLeaf(YType.uint32, 'ip-encap-payload-af'), ['int'])),
                                                    ('ip_encap_payload_mtu', (YLeaf(YType.uint16, 'ip-encap-payload-mtu'), ['int'])),
                                                    ('ip_encap_parent', (YLeaf(YType.uint32, 'ip-encap-parent'), ['int'])),
                                                    ('ip_encap_parent_type', (YLeaf(YType.uint32, 'ip-encap-parent-type'), ['int'])),
                                                ])
                                                self.ip_encap_hdr_count = None
                                                self.ip_encap_locks = None
                                                self.ip_encap_transport_tbl = None
                                                self.ipe_transport_vrf_name = None
                                                self.ip_encap_transport_af = None
                                                self.ip_encap_payload_af = None
                                                self.ip_encap_payload_mtu = None
                                                self.ip_encap_parent = None
                                                self.ip_encap_parent_type = None

                                                self.ip_encap_hdr = YList(self)
                                                self._segment_path = lambda: "spd-ipencap"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap, ['ip_encap_hdr_count', 'ip_encap_locks', 'ip_encap_transport_tbl', 'ipe_transport_vrf_name', 'ip_encap_transport_af', 'ip_encap_payload_af', 'ip_encap_payload_mtu', 'ip_encap_parent', 'ip_encap_parent_type'], name, value)


                                            class IpEncapHdr(Entity):
                                                """
                                                Headers
                                                
                                                .. attribute:: ip_encap_hdr_type
                                                
                                                	Header Type
                                                	**type**\:  :py:class:`FibShIpencapHdr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibShIpencapHdr>`
                                                
                                                .. attribute:: ip_encap_hdrp
                                                
                                                	Static Header
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: ip_encap_hdr_dyn
                                                
                                                	Dynamic Header Fields
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap.IpEncapHdr, self).__init__()

                                                    self.yang_name = "ip-encap-hdr"
                                                    self.yang_parent_name = "spd-ipencap"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ip_encap_hdr_type', (YLeaf(YType.enumeration, 'ip-encap-hdr-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibShIpencapHdr', '')])),
                                                        ('ip_encap_hdrp', (YLeaf(YType.str, 'ip-encap-hdrp'), ['str'])),
                                                        ('ip_encap_hdr_dyn', (YLeaf(YType.uint32, 'ip-encap-hdr-dyn'), ['int'])),
                                                    ])
                                                    self.ip_encap_hdr_type = None
                                                    self.ip_encap_hdrp = None
                                                    self.ip_encap_hdr_dyn = None
                                                    self._segment_path = lambda: "ip-encap-hdr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath.SpdIpencap.IpEncapHdr, ['ip_encap_hdr_type', 'ip_encap_hdrp', 'ip_encap_hdr_dyn'], name, value)


                                        class NextNextHop(Entity):
                                            """
                                            Next Next hop sets
                                            
                                            .. attribute:: next_next_hop_index
                                            
                                            	Next next hop index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: next_next_hop_prefix
                                            
                                            	Next next hop prefix
                                            	**type**\: str
                                            
                                            	**length:** 0..52
                                            
                                            .. attribute:: next_next_hop_interface
                                            
                                            	Next next hop interface index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath.NextNextHop, self).__init__()

                                                self.yang_name = "next-next-hop"
                                                self.yang_parent_name = "more-detail-about-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('next_next_hop_index', (YLeaf(YType.uint8, 'next-next-hop-index'), ['int'])),
                                                    ('next_next_hop_prefix', (YLeaf(YType.str, 'next-next-hop-prefix'), ['str'])),
                                                    ('next_next_hop_interface', (YLeaf(YType.uint32, 'next-next-hop-interface'), ['int'])),
                                                ])
                                                self.next_next_hop_index = None
                                                self.next_next_hop_prefix = None
                                                self.next_next_hop_interface = None
                                                self._segment_path = lambda: "next-next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MoreDetailAboutPath.NextNextHop, ['next_next_hop_index', 'next_next_hop_prefix', 'next_next_hop_interface'], name, value)


                                    class MplsInformationForPath(Entity):
                                        """
                                        mpls info for this path entry
                                        
                                        .. attribute:: local_lable
                                        
                                        	LocalLable
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: recursive_fwd_chain
                                        
                                        	RecursiveFwdChain
                                        	**type**\: bool
                                        
                                        .. attribute:: number_of_igp_paths
                                        
                                        	NumberOfIGPPaths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_backup
                                        
                                        	RemoteBackupPath
                                        	**type**\: bool
                                        
                                        .. attribute:: recursive_lbl_stack
                                        
                                        	Recursive Label(s)
                                        	**type**\: list of  		 :py:class:`RecursiveLblStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath.RecursiveLblStack>`
                                        
                                        .. attribute:: igp_label_stack_array
                                        
                                        	igp label stack array
                                        	**type**\: list of  		 :py:class:`IgpLabelStackArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray>`
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath, self).__init__()

                                            self.yang_name = "mpls-information-for-path"
                                            self.yang_parent_name = "fib-sh-tbl-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("recursive-lbl-stack", ("recursive_lbl_stack", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath.RecursiveLblStack)), ("igp-label-stack-array", ("igp_label_stack_array", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray))])
                                            self._leafs = OrderedDict([
                                                ('local_lable', (YLeaf(YType.uint32, 'local-lable'), ['int'])),
                                                ('recursive_fwd_chain', (YLeaf(YType.boolean, 'recursive-fwd-chain'), ['bool'])),
                                                ('number_of_igp_paths', (YLeaf(YType.uint32, 'number-of-igp-paths'), ['int'])),
                                                ('remote_backup', (YLeaf(YType.boolean, 'remote-backup'), ['bool'])),
                                            ])
                                            self.local_lable = None
                                            self.recursive_fwd_chain = None
                                            self.number_of_igp_paths = None
                                            self.remote_backup = None

                                            self.recursive_lbl_stack = YList(self)
                                            self.igp_label_stack_array = YList(self)
                                            self._segment_path = lambda: "mpls-information-for-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath, ['local_lable', 'recursive_fwd_chain', 'number_of_igp_paths', 'remote_backup'], name, value)


                                        class RecursiveLblStack(Entity):
                                            """
                                            Recursive Label(s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath.RecursiveLblStack, self).__init__()

                                                self.yang_name = "recursive-lbl-stack"
                                                self.yang_parent_name = "mpls-information-for-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "recursive-lbl-stack"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath.RecursiveLblStack, ['entry'], name, value)


                                        class IgpLabelStackArray(Entity):
                                            """
                                            igp label stack array
                                            
                                            .. attribute:: number_of_labels
                                            
                                            	NumberOfLabels
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: out_interface
                                            
                                            	OutInterface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: nh_address
                                            
                                            	NHAddress
                                            	**type**\: str
                                            
                                            	**length:** 0..52
                                            
                                            .. attribute:: lstack
                                            
                                            	lstack
                                            	**type**\: list of  		 :py:class:`Lstack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray.Lstack>`
                                            
                                            

                                            """

                                            _prefix = 'fib-common-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray, self).__init__()

                                                self.yang_name = "igp-label-stack-array"
                                                self.yang_parent_name = "mpls-information-for-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lstack", ("lstack", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray.Lstack))])
                                                self._leafs = OrderedDict([
                                                    ('number_of_labels', (YLeaf(YType.uint32, 'number-of-labels'), ['int'])),
                                                    ('out_interface', (YLeaf(YType.str, 'out-interface'), ['str'])),
                                                    ('nh_address', (YLeaf(YType.str, 'nh-address'), ['str'])),
                                                ])
                                                self.number_of_labels = None
                                                self.out_interface = None
                                                self.nh_address = None

                                                self.lstack = YList(self)
                                                self._segment_path = lambda: "igp-label-stack-array"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray, ['number_of_labels', 'out_interface', 'nh_address'], name, value)


                                            class Lstack(Entity):
                                                """
                                                lstack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'fib-common-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray.Lstack, self).__init__()

                                                    self.yang_name = "lstack"
                                                    self.yang_parent_name = "igp-label-stack-array"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "lstack"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.FibEntryPath.FibShTblPath.MplsInformationForPath.IgpLabelStackArray.Lstack, ['entry'], name, value)


                            class ExtensionObject(Entity):
                                """
                                Leaf Extension Object List
                                
                                .. attribute:: sfecd_le
                                
                                	sfecd le
                                	**type**\:  :py:class:`SfecdLe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.ExtensionObject.SfecdLe>`
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:  :py:class:`FibShTblFibExtBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibShTblFibExtBag>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.ExtensionObject, self).__init__()

                                    self.yang_name = "extension-object"
                                    self.yang_parent_name = "exact-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sfecd-le", ("sfecd_le", Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.ExtensionObject.SfecdLe))])
                                    self._leafs = OrderedDict([
                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibShTblFibExtBag', '')])),
                                    ])
                                    self.type = None

                                    self.sfecd_le = Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.ExtensionObject.SfecdLe()
                                    self.sfecd_le.parent = self
                                    self._children_name_map["sfecd_le"] = "sfecd-le"
                                    self._segment_path = lambda: "extension-object"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.ExtensionObject, ['type'], name, value)


                                class SfecdLe(Entity):
                                    """
                                    sfecd le
                                    
                                    .. attribute:: context_label_flag
                                    
                                    	Context Label Exist
                                    	**type**\: bool
                                    
                                    .. attribute:: context_label
                                    
                                    	Context Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.ExtensionObject.SfecdLe, self).__init__()

                                        self.yang_name = "sfecd-le"
                                        self.yang_parent_name = "extension-object"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('context_label_flag', (YLeaf(YType.boolean, 'context-label-flag'), ['bool'])),
                                            ('context_label', (YLeaf(YType.uint32, 'context-label'), ['int'])),
                                        ])
                                        self.context_label_flag = None
                                        self.context_label = None
                                        self._segment_path = lambda: "sfecd-le"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExactRoutes.ExactRoute.ExtensionObject.SfecdLe, ['context_label_flag', 'context_label'], name, value)


                    class ProtocolGlobal(Entity):
                        """
                        FIB ipv6 global information
                        
                        .. attribute:: segment_routing
                        
                        	FIB ipv6 global segment routing information
                        	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal, self).__init__()

                            self.yang_name = "protocol-global"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("segment-routing", ("segment_routing", Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting))])
                            self._leafs = OrderedDict()

                            self.segment_routing = Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting()
                            self.segment_routing.parent = self
                            self._children_name_map["segment_routing"] = "segment-routing"
                            self._segment_path = lambda: "protocol-global"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal, [], name, value)


                        class SegmentRouting(Entity):
                            """
                            FIB ipv6 global segment routing information
                            
                            .. attribute:: srv6
                            
                            	FIB ipv6 global segment routing srv6 information
                            	**type**\:  :py:class:`Srv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting.Srv6>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting, self).__init__()

                                self.yang_name = "segment-routing"
                                self.yang_parent_name = "protocol-global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("srv6", ("srv6", Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting.Srv6))])
                                self._leafs = OrderedDict()

                                self.srv6 = Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting.Srv6()
                                self.srv6.parent = self
                                self._children_name_map["srv6"] = "srv6"
                                self._segment_path = lambda: "segment-routing"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting, [], name, value)


                            class Srv6(Entity):
                                """
                                FIB ipv6 global segment routing srv6
                                information
                                
                                .. attribute:: srv6_enabled
                                
                                	Is SRv6 enabled?
                                	**type**\: bool
                                
                                .. attribute:: encap_source_address
                                
                                	Encap Source Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: locator_count
                                
                                	Locator Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: locator
                                
                                	Locator Array
                                	**type**\: list of  		 :py:class:`Locator <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting.Srv6.Locator>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting.Srv6, self).__init__()

                                    self.yang_name = "srv6"
                                    self.yang_parent_name = "segment-routing"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("locator", ("locator", Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting.Srv6.Locator))])
                                    self._leafs = OrderedDict([
                                        ('srv6_enabled', (YLeaf(YType.boolean, 'srv6-enabled'), ['bool'])),
                                        ('encap_source_address', (YLeaf(YType.str, 'encap-source-address'), ['str'])),
                                        ('locator_count', (YLeaf(YType.uint32, 'locator-count'), ['int'])),
                                    ])
                                    self.srv6_enabled = None
                                    self.encap_source_address = None
                                    self.locator_count = None

                                    self.locator = YList(self)
                                    self._segment_path = lambda: "srv6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting.Srv6, ['srv6_enabled', 'encap_source_address', 'locator_count'], name, value)


                                class Locator(Entity):
                                    """
                                    Locator Array
                                    
                                    .. attribute:: name
                                    
                                    	Locator name
                                    	**type**\: str
                                    
                                    .. attribute:: prefix
                                    
                                    	Locator prefix
                                    	**type**\: str
                                    
                                    .. attribute:: locator
                                    
                                    	Locator
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting.Srv6.Locator, self).__init__()

                                        self.yang_name = "locator"
                                        self.yang_parent_name = "srv6"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                            ('locator', (YLeaf(YType.str, 'locator'), ['str'])),
                                        ])
                                        self.name = None
                                        self.prefix = None
                                        self.locator = None
                                        self._segment_path = lambda: "locator"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ProtocolGlobal.SegmentRouting.Srv6.Locator, ['name', 'prefix', 'locator'], name, value)


                    class NhIds(Entity):
                        """
                        NHIdTable is accessed by two keys; {NHId}
                        and/or {NHInterface,NHAddress
                        
                        .. attribute:: nh_id
                        
                        	NextHopId table entry
                        	**type**\: list of  		 :py:class:`NhId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.NhIds.NhId>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Protocols.Protocol.NhIds, self).__init__()

                            self.yang_name = "nh-ids"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nh-id", ("nh_id", Fib.Nodes.Node.Protocols.Protocol.NhIds.NhId))])
                            self._leafs = OrderedDict()

                            self.nh_id = YList(self)
                            self._segment_path = lambda: "nh-ids"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.NhIds, [], name, value)


                        class NhId(Entity):
                            """
                            NextHopId table entry
                            
                            .. attribute:: nh_id
                            
                            	NexthopId Value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nh_interface_name
                            
                            	Interface Name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: nh_address
                            
                            	Next\-hop address in string format (e.g., 1 .2.3.4)
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: nh_interface_name_xr
                            
                            	Next\-hop interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: nh_address_xr
                            
                            	Next\-hop address
                            	**type**\: str
                            
                            .. attribute:: nh_protocol
                            
                            	Next\-hop address protocol, IPv4/IPv6
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nh_link_type
                            
                            	Payload linktype
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nh_table_id
                            
                            	Table\-ID entry notified for
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nh_id_xr
                            
                            	NHID value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nh_id_application
                            
                            	NHID application type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: version
                            
                            	RIB version
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: time_of_last_update_in_msec
                            
                            	The time of last update in msec
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.NhIds.NhId, self).__init__()

                                self.yang_name = "nh-id"
                                self.yang_parent_name = "nh-ids"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('nh_id', (YLeaf(YType.uint32, 'nh-id'), ['int'])),
                                    ('nh_interface_name', (YLeaf(YType.str, 'nh-interface-name'), ['str'])),
                                    ('nh_address', (YLeaf(YType.str, 'nh-address'), ['str'])),
                                    ('nh_interface_name_xr', (YLeaf(YType.str, 'nh-interface-name-xr'), ['str'])),
                                    ('nh_address_xr', (YLeaf(YType.str, 'nh-address-xr'), ['str'])),
                                    ('nh_protocol', (YLeaf(YType.uint8, 'nh-protocol'), ['int'])),
                                    ('nh_link_type', (YLeaf(YType.uint8, 'nh-link-type'), ['int'])),
                                    ('nh_table_id', (YLeaf(YType.uint32, 'nh-table-id'), ['int'])),
                                    ('nh_id_xr', (YLeaf(YType.uint32, 'nh-id-xr'), ['int'])),
                                    ('nh_id_application', (YLeaf(YType.uint8, 'nh-id-application'), ['int'])),
                                    ('version', (YLeaf(YType.uint64, 'version'), ['int'])),
                                    ('time_of_last_update_in_msec', (YLeaf(YType.uint64, 'time-of-last-update-in-msec'), ['int'])),
                                ])
                                self.nh_id = None
                                self.nh_interface_name = None
                                self.nh_address = None
                                self.nh_interface_name_xr = None
                                self.nh_address_xr = None
                                self.nh_protocol = None
                                self.nh_link_type = None
                                self.nh_table_id = None
                                self.nh_id_xr = None
                                self.nh_id_application = None
                                self.version = None
                                self.time_of_last_update_in_msec = None
                                self._segment_path = lambda: "nh-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.NhIds.NhId, ['nh_id', 'nh_interface_name', 'nh_address', 'nh_interface_name_xr', 'nh_address_xr', 'nh_protocol', 'nh_link_type', 'nh_table_id', 'nh_id_xr', 'nh_id_application', 'version', 'time_of_last_update_in_msec'], name, value)


                    class ExternalClientSummaries(Entity):
                        """
                        External Client Summary Table
                        
                        .. attribute:: external_client_summary
                        
                        	Summary of the external clients
                        	**type**\: list of  		 :py:class:`ExternalClientSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries.ExternalClientSummary>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries, self).__init__()

                            self.yang_name = "external-client-summaries"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("external-client-summary", ("external_client_summary", Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries.ExternalClientSummary))])
                            self._leafs = OrderedDict()

                            self.external_client_summary = YList(self)
                            self._segment_path = lambda: "external-client-summaries"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries, [], name, value)


                        class ExternalClientSummary(Entity):
                            """
                            Summary of the external clients
                            
                            .. attribute:: ecd_ver
                            
                            	Ecd Version
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: id
                            
                            	ID of the client\: ECDv1 is component id, ECDv2 is client id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ses_pl_sum
                            
                            	ECD pathlist summary
                            	**type**\:  :py:class:`SesPlSum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries.ExternalClientSummary.SesPlSum>`
                            
                            .. attribute:: ses_client_name
                            
                            	External client name
                            	**type**\: str
                            
                            .. attribute:: ses_feci_fib_proto
                            
                            	Registration proto
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ses_num_regs
                            
                            	Number of registrations
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ses_num_pending
                            
                            	Number of pending notifs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ses_client_pulsed_time
                            
                            	Client pulsed timestamp
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ses_comp_id
                            
                            	component\-id of the client
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ses_ecd_version
                            
                            	ECD version
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries.ExternalClientSummary, self).__init__()

                                self.yang_name = "external-client-summary"
                                self.yang_parent_name = "external-client-summaries"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ses-pl-sum", ("ses_pl_sum", Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries.ExternalClientSummary.SesPlSum))])
                                self._leafs = OrderedDict([
                                    ('ecd_ver', (YLeaf(YType.uint32, 'ecd-ver'), ['int'])),
                                    ('id', (YLeaf(YType.uint32, 'id'), ['int'])),
                                    ('ses_client_name', (YLeaf(YType.str, 'ses-client-name'), ['str'])),
                                    ('ses_feci_fib_proto', (YLeaf(YType.uint32, 'ses-feci-fib-proto'), ['int'])),
                                    ('ses_num_regs', (YLeaf(YType.uint32, 'ses-num-regs'), ['int'])),
                                    ('ses_num_pending', (YLeaf(YType.uint32, 'ses-num-pending'), ['int'])),
                                    ('ses_client_pulsed_time', (YLeaf(YType.uint64, 'ses-client-pulsed-time'), ['int'])),
                                    ('ses_comp_id', (YLeaf(YType.uint32, 'ses-comp-id'), ['int'])),
                                    ('ses_ecd_version', (YLeaf(YType.uint32, 'ses-ecd-version'), ['int'])),
                                ])
                                self.ecd_ver = None
                                self.id = None
                                self.ses_client_name = None
                                self.ses_feci_fib_proto = None
                                self.ses_num_regs = None
                                self.ses_num_pending = None
                                self.ses_client_pulsed_time = None
                                self.ses_comp_id = None
                                self.ses_ecd_version = None

                                self.ses_pl_sum = Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries.ExternalClientSummary.SesPlSum()
                                self.ses_pl_sum.parent = self
                                self._children_name_map["ses_pl_sum"] = "ses-pl-sum"
                                self._segment_path = lambda: "external-client-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries.ExternalClientSummary, ['ecd_ver', 'id', 'ses_client_name', 'ses_feci_fib_proto', 'ses_num_regs', 'ses_num_pending', 'ses_client_pulsed_time', 'ses_comp_id', 'ses_ecd_version'], name, value)


                            class SesPlSum(Entity):
                                """
                                ECD pathlist summary
                                
                                .. attribute:: sep_num_ecd_pathlist
                                
                                	Number of ECD pathlists
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sep_num_ecd_pl_unresolved
                                
                                	Number of ECD pathlists unresolved
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sep_num_ecd_pl_per_interest
                                
                                	Number of ECD pathlists per interest
                                	**type**\: list of  		 :py:class:`SepNumEcdPlPerInterest <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries.ExternalClientSummary.SesPlSum.SepNumEcdPlPerInterest>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries.ExternalClientSummary.SesPlSum, self).__init__()

                                    self.yang_name = "ses-pl-sum"
                                    self.yang_parent_name = "external-client-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sep-num-ecd-pl-per-interest", ("sep_num_ecd_pl_per_interest", Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries.ExternalClientSummary.SesPlSum.SepNumEcdPlPerInterest))])
                                    self._leafs = OrderedDict([
                                        ('sep_num_ecd_pathlist', (YLeaf(YType.uint32, 'sep-num-ecd-pathlist'), ['int'])),
                                        ('sep_num_ecd_pl_unresolved', (YLeaf(YType.uint32, 'sep-num-ecd-pl-unresolved'), ['int'])),
                                    ])
                                    self.sep_num_ecd_pathlist = None
                                    self.sep_num_ecd_pl_unresolved = None

                                    self.sep_num_ecd_pl_per_interest = YList(self)
                                    self._segment_path = lambda: "ses-pl-sum"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries.ExternalClientSummary.SesPlSum, ['sep_num_ecd_pathlist', 'sep_num_ecd_pl_unresolved'], name, value)


                                class SepNumEcdPlPerInterest(Entity):
                                    """
                                    Number of ECD pathlists per interest
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries.ExternalClientSummary.SesPlSum.SepNumEcdPlPerInterest, self).__init__()

                                        self.yang_name = "sep-num-ecd-pl-per-interest"
                                        self.yang_parent_name = "ses-pl-sum"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "sep-num-ecd-pl-per-interest"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.ExternalClientSummaries.ExternalClientSummary.SesPlSum.SepNumEcdPlPerInterest, ['entry'], name, value)


                    class Misc(Entity):
                        """
                        CEF misc hidden data
                        
                        .. attribute:: mi_issu_state
                        
                        	FIB ISSU state
                        	**type**\:  :py:class:`MiIssuState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiIssuState>`
                        
                        .. attribute:: mi_plat_capabilities
                        
                        	FIB platform capabilities
                        	**type**\:  :py:class:`MiPlatCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities>`
                        
                        .. attribute:: mi_pfi_ifh_upd
                        
                        	number of pfi ifh create notif
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: mi_pfi_ifh_del
                        
                        	number of pfi ifh delete notif
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: mi_pfi_ifh_stale
                        
                        	number of stale ifh removed
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: mi_tot_plat_upd_time
                        
                        	total platform update time
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: mi_tot_gtrie_time
                        
                        	total time spent in gtrie operations
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: mi_tot_dnld_time
                        
                        	total download time
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: mi_clock_time
                        
                        	clock download time
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: mi_cpu_time
                        
                        	CPU download time
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: mi_shm_reset_ts
                        
                        	Last FIB shared memory reset time stamp
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: mi_idb_recycle_count
                        
                        	Number of idbs that hit ifh recycle
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mi_idb_recycle_cleanup_count
                        
                        	Number of idb cleaned up after hitting ifh recycle
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mi_num_mgmt_list
                        
                        	Number of management interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mi_num_virtual_ll_addresses_added
                        
                        	mi num virtual ll addresses added
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mi_num_virtual_ll_addresses_deleted
                        
                        	mi num virtual ll addresses deleted
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mi_num_virtual_ll_addresses_dropped
                        
                        	mi num virtual ll addresses dropped
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mi_num_virtual_ll_addresses_cached
                        
                        	mi num virtual ll addresses cached
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mi_cpuless_init
                        
                        	cpuless node list init
                        	**type**\: bool
                        
                        .. attribute:: mi_cpuless_count
                        
                        	count of cpuless line cards
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mi_prefer_aib_routes_over_rib_oper
                        
                        	Prefer AIB routes over RIB/LSD operational state
                        	**type**\: bool
                        
                        .. attribute:: mi_prefer_aib_routes_over_rib_cfg
                        
                        	Prefer AIB routes over RIB/LSD configured state
                        	**type**\: bool
                        
                        .. attribute:: mi_xpl_ldi_enabled
                        
                        	XPL loadinfo is enabled
                        	**type**\: bool
                        
                        .. attribute:: mi_frr_follow_bgp_pic
                        
                        	fast\-reroute follow BGP\-PIC configured
                        	**type**\: bool
                        
                        .. attribute:: mi_encap_sharing_disable
                        
                        	MPLS encapsulation sharing disabled
                        	**type**\: bool
                        
                        .. attribute:: mi_lba_hash_recover
                        
                        	Consistent\-hashing auto\-recovery
                        	**type**\: bool
                        
                        .. attribute:: mi_idb_ext_cleanup_failed_count
                        
                        	Number of recycled idb extensions that failed  cleanup
                        	**type**\: list of  		 :py:class:`MiIdbExtCleanupFailedCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbExtCleanupFailedCount>`
                        
                        .. attribute:: mi_lrpf_stats_fail
                        
                        	Per protocol Failure stats for label RPF
                        	**type**\: list of  		 :py:class:`MiLrpfStatsFail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiLrpfStatsFail>`
                        
                        .. attribute:: mi_lrpf_stats_act
                        
                        	Per protocol actions stats for label RPF
                        	**type**\: list of  		 :py:class:`MiLrpfStatsAct <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiLrpfStatsAct>`
                        
                        .. attribute:: mi_lrpf_num
                        
                        	Per protocol number of label RPFs
                        	**type**\: list of  		 :py:class:`MiLrpfNum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiLrpfNum>`
                        
                        .. attribute:: mi_idb_lsec_enabled_num
                        
                        	Number of interfaces having label security  enabled
                        	**type**\: list of  		 :py:class:`MiIdbLsecEnabledNum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbLsecEnabledNum>`
                        
                        .. attribute:: mi_num_lisp_eid
                        
                        	number of LISP EID prefixes
                        	**type**\: list of  		 :py:class:`MiNumLispEid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiNumLispEid>`
                        
                        .. attribute:: mi_num_lisp_valid_eid
                        
                        	number of LISP EID prefixes eligible for  forwarding
                        	**type**\: list of  		 :py:class:`MiNumLispValidEid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiNumLispValidEid>`
                        
                        .. attribute:: mi_cpuless_node
                        
                        	list of cpuless line cards
                        	**type**\: list of  		 :py:class:`MiCpulessNode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiCpulessNode>`
                        
                        .. attribute:: mi_proto_dbg_stat
                        
                        	Per protocol debug stats
                        	**type**\: list of  		 :py:class:`MiProtoDbgStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat>`
                        
                        .. attribute:: mi_idb_purge_cntr
                        
                        	the number of counters used for purge counter stats
                        	**type**\: list of  		 :py:class:`MiIdbPurgeCntr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbPurgeCntr>`
                        
                        .. attribute:: mi_del
                        
                        	Timestamps of deleted routes
                        	**type**\: list of  		 :py:class:`MiDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiDel>`
                        
                        .. attribute:: mi_frr_stat
                        
                        	FRR statistics
                        	**type**\: list of  		 :py:class:`MiFrrStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiFrrStat>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Protocols.Protocol.Misc, self).__init__()

                            self.yang_name = "misc"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mi-issu-state", ("mi_issu_state", Fib.Nodes.Node.Protocols.Protocol.Misc.MiIssuState)), ("mi-plat-capabilities", ("mi_plat_capabilities", Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities)), ("mi-idb-ext-cleanup-failed-count", ("mi_idb_ext_cleanup_failed_count", Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbExtCleanupFailedCount)), ("mi-lrpf-stats-fail", ("mi_lrpf_stats_fail", Fib.Nodes.Node.Protocols.Protocol.Misc.MiLrpfStatsFail)), ("mi-lrpf-stats-act", ("mi_lrpf_stats_act", Fib.Nodes.Node.Protocols.Protocol.Misc.MiLrpfStatsAct)), ("mi-lrpf-num", ("mi_lrpf_num", Fib.Nodes.Node.Protocols.Protocol.Misc.MiLrpfNum)), ("mi-idb-lsec-enabled-num", ("mi_idb_lsec_enabled_num", Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbLsecEnabledNum)), ("mi-num-lisp-eid", ("mi_num_lisp_eid", Fib.Nodes.Node.Protocols.Protocol.Misc.MiNumLispEid)), ("mi-num-lisp-valid-eid", ("mi_num_lisp_valid_eid", Fib.Nodes.Node.Protocols.Protocol.Misc.MiNumLispValidEid)), ("mi-cpuless-node", ("mi_cpuless_node", Fib.Nodes.Node.Protocols.Protocol.Misc.MiCpulessNode)), ("mi-proto-dbg-stat", ("mi_proto_dbg_stat", Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat)), ("mi-idb-purge-cntr", ("mi_idb_purge_cntr", Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbPurgeCntr)), ("mi-del", ("mi_del", Fib.Nodes.Node.Protocols.Protocol.Misc.MiDel)), ("mi-frr-stat", ("mi_frr_stat", Fib.Nodes.Node.Protocols.Protocol.Misc.MiFrrStat))])
                            self._leafs = OrderedDict([
                                ('mi_pfi_ifh_upd', (YLeaf(YType.uint64, 'mi-pfi-ifh-upd'), ['int'])),
                                ('mi_pfi_ifh_del', (YLeaf(YType.uint64, 'mi-pfi-ifh-del'), ['int'])),
                                ('mi_pfi_ifh_stale', (YLeaf(YType.uint64, 'mi-pfi-ifh-stale'), ['int'])),
                                ('mi_tot_plat_upd_time', (YLeaf(YType.uint64, 'mi-tot-plat-upd-time'), ['int'])),
                                ('mi_tot_gtrie_time', (YLeaf(YType.uint64, 'mi-tot-gtrie-time'), ['int'])),
                                ('mi_tot_dnld_time', (YLeaf(YType.uint64, 'mi-tot-dnld-time'), ['int'])),
                                ('mi_clock_time', (YLeaf(YType.uint64, 'mi-clock-time'), ['int'])),
                                ('mi_cpu_time', (YLeaf(YType.uint64, 'mi-cpu-time'), ['int'])),
                                ('mi_shm_reset_ts', (YLeaf(YType.uint64, 'mi-shm-reset-ts'), ['int'])),
                                ('mi_idb_recycle_count', (YLeaf(YType.uint32, 'mi-idb-recycle-count'), ['int'])),
                                ('mi_idb_recycle_cleanup_count', (YLeaf(YType.uint32, 'mi-idb-recycle-cleanup-count'), ['int'])),
                                ('mi_num_mgmt_list', (YLeaf(YType.uint32, 'mi-num-mgmt-list'), ['int'])),
                                ('mi_num_virtual_ll_addresses_added', (YLeaf(YType.uint32, 'mi-num-virtual-ll-addresses-added'), ['int'])),
                                ('mi_num_virtual_ll_addresses_deleted', (YLeaf(YType.uint32, 'mi-num-virtual-ll-addresses-deleted'), ['int'])),
                                ('mi_num_virtual_ll_addresses_dropped', (YLeaf(YType.uint32, 'mi-num-virtual-ll-addresses-dropped'), ['int'])),
                                ('mi_num_virtual_ll_addresses_cached', (YLeaf(YType.uint32, 'mi-num-virtual-ll-addresses-cached'), ['int'])),
                                ('mi_cpuless_init', (YLeaf(YType.boolean, 'mi-cpuless-init'), ['bool'])),
                                ('mi_cpuless_count', (YLeaf(YType.uint32, 'mi-cpuless-count'), ['int'])),
                                ('mi_prefer_aib_routes_over_rib_oper', (YLeaf(YType.boolean, 'mi-prefer-aib-routes-over-rib-oper'), ['bool'])),
                                ('mi_prefer_aib_routes_over_rib_cfg', (YLeaf(YType.boolean, 'mi-prefer-aib-routes-over-rib-cfg'), ['bool'])),
                                ('mi_xpl_ldi_enabled', (YLeaf(YType.boolean, 'mi-xpl-ldi-enabled'), ['bool'])),
                                ('mi_frr_follow_bgp_pic', (YLeaf(YType.boolean, 'mi-frr-follow-bgp-pic'), ['bool'])),
                                ('mi_encap_sharing_disable', (YLeaf(YType.boolean, 'mi-encap-sharing-disable'), ['bool'])),
                                ('mi_lba_hash_recover', (YLeaf(YType.boolean, 'mi-lba-hash-recover'), ['bool'])),
                            ])
                            self.mi_pfi_ifh_upd = None
                            self.mi_pfi_ifh_del = None
                            self.mi_pfi_ifh_stale = None
                            self.mi_tot_plat_upd_time = None
                            self.mi_tot_gtrie_time = None
                            self.mi_tot_dnld_time = None
                            self.mi_clock_time = None
                            self.mi_cpu_time = None
                            self.mi_shm_reset_ts = None
                            self.mi_idb_recycle_count = None
                            self.mi_idb_recycle_cleanup_count = None
                            self.mi_num_mgmt_list = None
                            self.mi_num_virtual_ll_addresses_added = None
                            self.mi_num_virtual_ll_addresses_deleted = None
                            self.mi_num_virtual_ll_addresses_dropped = None
                            self.mi_num_virtual_ll_addresses_cached = None
                            self.mi_cpuless_init = None
                            self.mi_cpuless_count = None
                            self.mi_prefer_aib_routes_over_rib_oper = None
                            self.mi_prefer_aib_routes_over_rib_cfg = None
                            self.mi_xpl_ldi_enabled = None
                            self.mi_frr_follow_bgp_pic = None
                            self.mi_encap_sharing_disable = None
                            self.mi_lba_hash_recover = None

                            self.mi_issu_state = Fib.Nodes.Node.Protocols.Protocol.Misc.MiIssuState()
                            self.mi_issu_state.parent = self
                            self._children_name_map["mi_issu_state"] = "mi-issu-state"

                            self.mi_plat_capabilities = Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities()
                            self.mi_plat_capabilities.parent = self
                            self._children_name_map["mi_plat_capabilities"] = "mi-plat-capabilities"

                            self.mi_idb_ext_cleanup_failed_count = YList(self)
                            self.mi_lrpf_stats_fail = YList(self)
                            self.mi_lrpf_stats_act = YList(self)
                            self.mi_lrpf_num = YList(self)
                            self.mi_idb_lsec_enabled_num = YList(self)
                            self.mi_num_lisp_eid = YList(self)
                            self.mi_num_lisp_valid_eid = YList(self)
                            self.mi_cpuless_node = YList(self)
                            self.mi_proto_dbg_stat = YList(self)
                            self.mi_idb_purge_cntr = YList(self)
                            self.mi_del = YList(self)
                            self.mi_frr_stat = YList(self)
                            self._segment_path = lambda: "misc"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc, ['mi_pfi_ifh_upd', 'mi_pfi_ifh_del', 'mi_pfi_ifh_stale', 'mi_tot_plat_upd_time', 'mi_tot_gtrie_time', 'mi_tot_dnld_time', 'mi_clock_time', 'mi_cpu_time', 'mi_shm_reset_ts', 'mi_idb_recycle_count', 'mi_idb_recycle_cleanup_count', 'mi_num_mgmt_list', 'mi_num_virtual_ll_addresses_added', 'mi_num_virtual_ll_addresses_deleted', 'mi_num_virtual_ll_addresses_dropped', 'mi_num_virtual_ll_addresses_cached', 'mi_cpuless_init', 'mi_cpuless_count', 'mi_prefer_aib_routes_over_rib_oper', 'mi_prefer_aib_routes_over_rib_cfg', 'mi_xpl_ldi_enabled', 'mi_frr_follow_bgp_pic', 'mi_encap_sharing_disable', 'mi_lba_hash_recover'], name, value)


                        class MiIssuState(Entity):
                            """
                            FIB ISSU state
                            
                            .. attribute:: imdr_support
                            
                            	IMDR supported
                            	**type**\: bool
                            
                            .. attribute:: slc_support
                            
                            	SLC supported
                            	**type**\: bool
                            
                            .. attribute:: fis_issu_restart
                            
                            	ISSU restart
                            	**type**\: bool
                            
                            .. attribute:: imdr_eoc_implicit
                            
                            	IMDR End\-of\-config implicit
                            	**type**\: bool
                            
                            .. attribute:: slc_eoc_implicit
                            
                            	SLC End\-of\-config implicit
                            	**type**\: bool
                            
                            .. attribute:: eoc_received_imdr_time_stamp
                            
                            	End\-of\-config received from IMDR timestamp
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: eoc_received_slc_time_stamp
                            
                            	End\-of\-config received from SLC timestamp
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: eod_received_im_time_stamp
                            
                            	End\-of\-download received from IM timestamp
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: eod_sent_imdr_time_stamp
                            
                            	End\-of\-download send to IMDR timestamp
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: eod_sent_slc_time_stamp
                            
                            	End\-of\-download send to SLC timestamp
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: fis_issu_error_ts
                            
                            	ISSU error sent to ISSUMGR timetstamp
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fis_proto_state
                            
                            	IMDR state for the protocols
                            	**type**\: list of  		 :py:class:`FisProtoState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiIssuState.FisProtoState>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiIssuState, self).__init__()

                                self.yang_name = "mi-issu-state"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("fis-proto-state", ("fis_proto_state", Fib.Nodes.Node.Protocols.Protocol.Misc.MiIssuState.FisProtoState))])
                                self._leafs = OrderedDict([
                                    ('imdr_support', (YLeaf(YType.boolean, 'imdr-support'), ['bool'])),
                                    ('slc_support', (YLeaf(YType.boolean, 'slc-support'), ['bool'])),
                                    ('fis_issu_restart', (YLeaf(YType.boolean, 'fis-issu-restart'), ['bool'])),
                                    ('imdr_eoc_implicit', (YLeaf(YType.boolean, 'imdr-eoc-implicit'), ['bool'])),
                                    ('slc_eoc_implicit', (YLeaf(YType.boolean, 'slc-eoc-implicit'), ['bool'])),
                                    ('eoc_received_imdr_time_stamp', (YLeaf(YType.str, 'eoc-received-imdr-time-stamp'), ['str'])),
                                    ('eoc_received_slc_time_stamp', (YLeaf(YType.str, 'eoc-received-slc-time-stamp'), ['str'])),
                                    ('eod_received_im_time_stamp', (YLeaf(YType.str, 'eod-received-im-time-stamp'), ['str'])),
                                    ('eod_sent_imdr_time_stamp', (YLeaf(YType.str, 'eod-sent-imdr-time-stamp'), ['str'])),
                                    ('eod_sent_slc_time_stamp', (YLeaf(YType.str, 'eod-sent-slc-time-stamp'), ['str'])),
                                    ('fis_issu_error_ts', (YLeaf(YType.uint64, 'fis-issu-error-ts'), ['int'])),
                                ])
                                self.imdr_support = None
                                self.slc_support = None
                                self.fis_issu_restart = None
                                self.imdr_eoc_implicit = None
                                self.slc_eoc_implicit = None
                                self.eoc_received_imdr_time_stamp = None
                                self.eoc_received_slc_time_stamp = None
                                self.eod_received_im_time_stamp = None
                                self.eod_sent_imdr_time_stamp = None
                                self.eod_sent_slc_time_stamp = None
                                self.fis_issu_error_ts = None

                                self.fis_proto_state = YList(self)
                                self._segment_path = lambda: "mi-issu-state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiIssuState, ['imdr_support', 'slc_support', 'fis_issu_restart', 'imdr_eoc_implicit', 'slc_eoc_implicit', 'eoc_received_imdr_time_stamp', 'eoc_received_slc_time_stamp', 'eod_received_im_time_stamp', 'eod_sent_imdr_time_stamp', 'eod_sent_slc_time_stamp', 'fis_issu_error_ts'], name, value)


                            class FisProtoState(Entity):
                                """
                                IMDR state for the protocols
                                
                                .. attribute:: protocol_name
                                
                                	Protocol name
                                	**type**\: str
                                
                                	**length:** 0..6
                                
                                .. attribute:: aib_eod_time_stamp
                                
                                	AIB EODTimeStamp
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                .. attribute:: rsi_eod_valid
                                
                                	RSI EOD expected/valid
                                	**type**\: bool
                                
                                .. attribute:: rsi_eod_time_stamp
                                
                                	RSI EOD received timestamp
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                .. attribute:: lsd_eod_valid
                                
                                	LSD EOD expected/valid
                                	**type**\: bool
                                
                                .. attribute:: lsd_eod_time_stamp
                                
                                	LSD EOD received timestamp
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                .. attribute:: lmrib_eod_valid
                                
                                	LMRIB EOD expected/valid
                                	**type**\: bool
                                
                                .. attribute:: lmrib_eod_time_stamp
                                
                                	LMRIB EOD received timestamp
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                .. attribute:: rib_info_valid
                                
                                	RIB table info valid
                                	**type**\: bool
                                
                                .. attribute:: bcdl_tables
                                
                                	Number of BCDL tables
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: converged_tables
                                
                                	Number of tables converged
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_tables_converged_time_stamp
                                
                                	All RIB tables converged timestamp
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                .. attribute:: protocol_eod_valid
                                
                                	Protocol EOD expected/valid
                                	**type**\: bool
                                
                                .. attribute:: protocol_eod_time_stamp
                                
                                	Protocol EOD sent timestamp
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiIssuState.FisProtoState, self).__init__()

                                    self.yang_name = "fis-proto-state"
                                    self.yang_parent_name = "mi-issu-state"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                        ('aib_eod_time_stamp', (YLeaf(YType.str, 'aib-eod-time-stamp'), ['str'])),
                                        ('rsi_eod_valid', (YLeaf(YType.boolean, 'rsi-eod-valid'), ['bool'])),
                                        ('rsi_eod_time_stamp', (YLeaf(YType.str, 'rsi-eod-time-stamp'), ['str'])),
                                        ('lsd_eod_valid', (YLeaf(YType.boolean, 'lsd-eod-valid'), ['bool'])),
                                        ('lsd_eod_time_stamp', (YLeaf(YType.str, 'lsd-eod-time-stamp'), ['str'])),
                                        ('lmrib_eod_valid', (YLeaf(YType.boolean, 'lmrib-eod-valid'), ['bool'])),
                                        ('lmrib_eod_time_stamp', (YLeaf(YType.str, 'lmrib-eod-time-stamp'), ['str'])),
                                        ('rib_info_valid', (YLeaf(YType.boolean, 'rib-info-valid'), ['bool'])),
                                        ('bcdl_tables', (YLeaf(YType.uint32, 'bcdl-tables'), ['int'])),
                                        ('converged_tables', (YLeaf(YType.uint32, 'converged-tables'), ['int'])),
                                        ('rib_tables_converged_time_stamp', (YLeaf(YType.str, 'rib-tables-converged-time-stamp'), ['str'])),
                                        ('protocol_eod_valid', (YLeaf(YType.boolean, 'protocol-eod-valid'), ['bool'])),
                                        ('protocol_eod_time_stamp', (YLeaf(YType.str, 'protocol-eod-time-stamp'), ['str'])),
                                    ])
                                    self.protocol_name = None
                                    self.aib_eod_time_stamp = None
                                    self.rsi_eod_valid = None
                                    self.rsi_eod_time_stamp = None
                                    self.lsd_eod_valid = None
                                    self.lsd_eod_time_stamp = None
                                    self.lmrib_eod_valid = None
                                    self.lmrib_eod_time_stamp = None
                                    self.rib_info_valid = None
                                    self.bcdl_tables = None
                                    self.converged_tables = None
                                    self.rib_tables_converged_time_stamp = None
                                    self.protocol_eod_valid = None
                                    self.protocol_eod_time_stamp = None
                                    self._segment_path = lambda: "fis-proto-state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiIssuState.FisProtoState, ['protocol_name', 'aib_eod_time_stamp', 'rsi_eod_valid', 'rsi_eod_time_stamp', 'lsd_eod_valid', 'lsd_eod_time_stamp', 'lmrib_eod_valid', 'lmrib_eod_time_stamp', 'rib_info_valid', 'bcdl_tables', 'converged_tables', 'rib_tables_converged_time_stamp', 'protocol_eod_valid', 'protocol_eod_time_stamp'], name, value)


                        class MiPlatCapabilities(Entity):
                            """
                            FIB platform capabilities
                            
                            .. attribute:: fpc_num_l3_lbl_levels
                            
                            	L3 LBL levels
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: fpc_num_l3_lbl_paths
                            
                            	L3 Hash buckets
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: fpc_num_l3_lbl_rec_paths
                            
                            	L3 Recursive Hash buckets
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: fpc_num_l3_ucmp_paths
                            
                            	L3 Unequal cost hash buckets
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: fpc_num_fwding_stages
                            
                            	Forwarding stages
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: fpc_local_label_split
                            
                            	Label split
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fpc_stats_support
                            
                            	Statistics support
                            	**type**\: bool
                            
                            .. attribute:: fpc_platf_ready_cb_wait
                            
                            	Plat ready cb register
                            	**type**\: bool
                            
                            .. attribute:: fpc_num_paths_per_pbts_class
                            
                            	Path per tunnel class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: fpc_platf_v4_upd_disable
                            
                            	V4 update disable
                            	**type**\: bool
                            
                            .. attribute:: fpc_platf_v6_upd_disable
                            
                            	V6 update disable
                            	**type**\: bool
                            
                            .. attribute:: fpc_lba_tuples_default
                            
                            	LBA tuples
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fpc_mraps_support
                            
                            	MRAPS support
                            	**type**\: bool
                            
                            .. attribute:: fpc_pbts_defclass_support
                            
                            	PBTS default class support
                            	**type**\: bool
                            
                            .. attribute:: fpc_loadinfo_filter_support
                            
                            	loadinfo filter support
                            	**type**\: bool
                            
                            .. attribute:: fpc_nhid
                            
                            	NHID support
                            	**type**\: bool
                            
                            .. attribute:: fpc_platf_temp_back_walk_reqd
                            
                            	Backwalk dependents is required
                            	**type**\: bool
                            
                            .. attribute:: fpc_link_mpls_nhinfo_in_ipv6_thread_support
                            
                            	Link MPLS IPv6 NH support
                            	**type**\: bool
                            
                            .. attribute:: fpc_exclude_deag_bkup
                            
                            	Exclude Deag backup Paths
                            	**type**\: bool
                            
                            .. attribute:: fpc_dlb_support
                            
                            	Per\-destination load\-balancing support
                            	**type**\: bool
                            
                            .. attribute:: fpc_prefix_filter_support
                            
                            	Prefix filter level of support
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: fpc_slowpath_ingress_inject_reqd
                            
                            	Slowpath ingress inject required
                            	**type**\: bool
                            
                            .. attribute:: fpc_cofo_support
                            
                            	COFO supported
                            	**type**\: bool
                            
                            .. attribute:: fpc_srv6_support
                            
                            	SRv6 supported
                            	**type**\: bool
                            
                            .. attribute:: fpc_v4v6_ldi_collapse_support
                            
                            	IPv4 over IPV6 Collapse LDI support
                            	**type**\: bool
                            
                            .. attribute:: fpc_lisp_decap_over_v4
                            
                            	LISP Decap over 4
                            	**type**\: list of  		 :py:class:`FpcLispDecapOverV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcLispDecapOverV4>`
                            
                            .. attribute:: fpc_lisp_decap_over_v6
                            
                            	LISP Decap over 6
                            	**type**\: list of  		 :py:class:`FpcLispDecapOverV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcLispDecapOverV6>`
                            
                            .. attribute:: fpc_lisp_ucmp
                            
                            	LISP UCMP support
                            	**type**\: list of  		 :py:class:`FpcLispUcmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcLispUcmp>`
                            
                            .. attribute:: fpc_resolve_via_table
                            
                            	Fallback VRF support
                            	**type**\: list of  		 :py:class:`FpcResolveViaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcResolveViaTable>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities, self).__init__()

                                self.yang_name = "mi-plat-capabilities"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("fpc-lisp-decap-over-v4", ("fpc_lisp_decap_over_v4", Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcLispDecapOverV4)), ("fpc-lisp-decap-over-v6", ("fpc_lisp_decap_over_v6", Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcLispDecapOverV6)), ("fpc-lisp-ucmp", ("fpc_lisp_ucmp", Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcLispUcmp)), ("fpc-resolve-via-table", ("fpc_resolve_via_table", Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcResolveViaTable))])
                                self._leafs = OrderedDict([
                                    ('fpc_num_l3_lbl_levels', (YLeaf(YType.uint8, 'fpc-num-l3-lbl-levels'), ['int'])),
                                    ('fpc_num_l3_lbl_paths', (YLeaf(YType.uint8, 'fpc-num-l3-lbl-paths'), ['int'])),
                                    ('fpc_num_l3_lbl_rec_paths', (YLeaf(YType.uint8, 'fpc-num-l3-lbl-rec-paths'), ['int'])),
                                    ('fpc_num_l3_ucmp_paths', (YLeaf(YType.uint8, 'fpc-num-l3-ucmp-paths'), ['int'])),
                                    ('fpc_num_fwding_stages', (YLeaf(YType.uint8, 'fpc-num-fwding-stages'), ['int'])),
                                    ('fpc_local_label_split', (YLeaf(YType.uint32, 'fpc-local-label-split'), ['int'])),
                                    ('fpc_stats_support', (YLeaf(YType.boolean, 'fpc-stats-support'), ['bool'])),
                                    ('fpc_platf_ready_cb_wait', (YLeaf(YType.boolean, 'fpc-platf-ready-cb-wait'), ['bool'])),
                                    ('fpc_num_paths_per_pbts_class', (YLeaf(YType.uint8, 'fpc-num-paths-per-pbts-class'), ['int'])),
                                    ('fpc_platf_v4_upd_disable', (YLeaf(YType.boolean, 'fpc-platf-v4-upd-disable'), ['bool'])),
                                    ('fpc_platf_v6_upd_disable', (YLeaf(YType.boolean, 'fpc-platf-v6-upd-disable'), ['bool'])),
                                    ('fpc_lba_tuples_default', (YLeaf(YType.uint32, 'fpc-lba-tuples-default'), ['int'])),
                                    ('fpc_mraps_support', (YLeaf(YType.boolean, 'fpc-mraps-support'), ['bool'])),
                                    ('fpc_pbts_defclass_support', (YLeaf(YType.boolean, 'fpc-pbts-defclass-support'), ['bool'])),
                                    ('fpc_loadinfo_filter_support', (YLeaf(YType.boolean, 'fpc-loadinfo-filter-support'), ['bool'])),
                                    ('fpc_nhid', (YLeaf(YType.boolean, 'fpc-nhid'), ['bool'])),
                                    ('fpc_platf_temp_back_walk_reqd', (YLeaf(YType.boolean, 'fpc-platf-temp-back-walk-reqd'), ['bool'])),
                                    ('fpc_link_mpls_nhinfo_in_ipv6_thread_support', (YLeaf(YType.boolean, 'fpc-link-mpls-nhinfo-in-ipv6-thread-support'), ['bool'])),
                                    ('fpc_exclude_deag_bkup', (YLeaf(YType.boolean, 'fpc-exclude-deag-bkup'), ['bool'])),
                                    ('fpc_dlb_support', (YLeaf(YType.boolean, 'fpc-dlb-support'), ['bool'])),
                                    ('fpc_prefix_filter_support', (YLeaf(YType.uint8, 'fpc-prefix-filter-support'), ['int'])),
                                    ('fpc_slowpath_ingress_inject_reqd', (YLeaf(YType.boolean, 'fpc-slowpath-ingress-inject-reqd'), ['bool'])),
                                    ('fpc_cofo_support', (YLeaf(YType.boolean, 'fpc-cofo-support'), ['bool'])),
                                    ('fpc_srv6_support', (YLeaf(YType.boolean, 'fpc-srv6-support'), ['bool'])),
                                    ('fpc_v4v6_ldi_collapse_support', (YLeaf(YType.boolean, 'fpc-v4v6-ldi-collapse-support'), ['bool'])),
                                ])
                                self.fpc_num_l3_lbl_levels = None
                                self.fpc_num_l3_lbl_paths = None
                                self.fpc_num_l3_lbl_rec_paths = None
                                self.fpc_num_l3_ucmp_paths = None
                                self.fpc_num_fwding_stages = None
                                self.fpc_local_label_split = None
                                self.fpc_stats_support = None
                                self.fpc_platf_ready_cb_wait = None
                                self.fpc_num_paths_per_pbts_class = None
                                self.fpc_platf_v4_upd_disable = None
                                self.fpc_platf_v6_upd_disable = None
                                self.fpc_lba_tuples_default = None
                                self.fpc_mraps_support = None
                                self.fpc_pbts_defclass_support = None
                                self.fpc_loadinfo_filter_support = None
                                self.fpc_nhid = None
                                self.fpc_platf_temp_back_walk_reqd = None
                                self.fpc_link_mpls_nhinfo_in_ipv6_thread_support = None
                                self.fpc_exclude_deag_bkup = None
                                self.fpc_dlb_support = None
                                self.fpc_prefix_filter_support = None
                                self.fpc_slowpath_ingress_inject_reqd = None
                                self.fpc_cofo_support = None
                                self.fpc_srv6_support = None
                                self.fpc_v4v6_ldi_collapse_support = None

                                self.fpc_lisp_decap_over_v4 = YList(self)
                                self.fpc_lisp_decap_over_v6 = YList(self)
                                self.fpc_lisp_ucmp = YList(self)
                                self.fpc_resolve_via_table = YList(self)
                                self._segment_path = lambda: "mi-plat-capabilities"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities, ['fpc_num_l3_lbl_levels', 'fpc_num_l3_lbl_paths', 'fpc_num_l3_lbl_rec_paths', 'fpc_num_l3_ucmp_paths', 'fpc_num_fwding_stages', 'fpc_local_label_split', 'fpc_stats_support', 'fpc_platf_ready_cb_wait', 'fpc_num_paths_per_pbts_class', 'fpc_platf_v4_upd_disable', 'fpc_platf_v6_upd_disable', 'fpc_lba_tuples_default', 'fpc_mraps_support', 'fpc_pbts_defclass_support', 'fpc_loadinfo_filter_support', 'fpc_nhid', 'fpc_platf_temp_back_walk_reqd', 'fpc_link_mpls_nhinfo_in_ipv6_thread_support', 'fpc_exclude_deag_bkup', 'fpc_dlb_support', 'fpc_prefix_filter_support', 'fpc_slowpath_ingress_inject_reqd', 'fpc_cofo_support', 'fpc_srv6_support', 'fpc_v4v6_ldi_collapse_support'], name, value)


                            class FpcLispDecapOverV4(Entity):
                                """
                                LISP Decap over 4
                                
                                .. attribute:: entry
                                
                                	Array entry
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcLispDecapOverV4, self).__init__()

                                    self.yang_name = "fpc-lisp-decap-over-v4"
                                    self.yang_parent_name = "mi-plat-capabilities"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "fpc-lisp-decap-over-v4"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcLispDecapOverV4, ['entry'], name, value)


                            class FpcLispDecapOverV6(Entity):
                                """
                                LISP Decap over 6
                                
                                .. attribute:: entry
                                
                                	Array entry
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcLispDecapOverV6, self).__init__()

                                    self.yang_name = "fpc-lisp-decap-over-v6"
                                    self.yang_parent_name = "mi-plat-capabilities"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "fpc-lisp-decap-over-v6"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcLispDecapOverV6, ['entry'], name, value)


                            class FpcLispUcmp(Entity):
                                """
                                LISP UCMP support
                                
                                .. attribute:: entry
                                
                                	Array entry
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcLispUcmp, self).__init__()

                                    self.yang_name = "fpc-lisp-ucmp"
                                    self.yang_parent_name = "mi-plat-capabilities"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "fpc-lisp-ucmp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcLispUcmp, ['entry'], name, value)


                            class FpcResolveViaTable(Entity):
                                """
                                Fallback VRF support
                                
                                .. attribute:: entry
                                
                                	Array entry
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcResolveViaTable, self).__init__()

                                    self.yang_name = "fpc-resolve-via-table"
                                    self.yang_parent_name = "mi-plat-capabilities"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "fpc-resolve-via-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiPlatCapabilities.FpcResolveViaTable, ['entry'], name, value)


                        class MiIdbExtCleanupFailedCount(Entity):
                            """
                            Number of recycled idb extensions that failed
                            
                            cleanup
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbExtCleanupFailedCount, self).__init__()

                                self.yang_name = "mi-idb-ext-cleanup-failed-count"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "mi-idb-ext-cleanup-failed-count"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbExtCleanupFailedCount, ['entry'], name, value)


                        class MiLrpfStatsFail(Entity):
                            """
                            Per protocol Failure stats for label RPF
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiLrpfStatsFail, self).__init__()

                                self.yang_name = "mi-lrpf-stats-fail"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "mi-lrpf-stats-fail"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiLrpfStatsFail, ['entry'], name, value)


                        class MiLrpfStatsAct(Entity):
                            """
                            Per protocol actions stats for label RPF
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiLrpfStatsAct, self).__init__()

                                self.yang_name = "mi-lrpf-stats-act"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "mi-lrpf-stats-act"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiLrpfStatsAct, ['entry'], name, value)


                        class MiLrpfNum(Entity):
                            """
                            Per protocol number of label RPFs
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiLrpfNum, self).__init__()

                                self.yang_name = "mi-lrpf-num"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "mi-lrpf-num"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiLrpfNum, ['entry'], name, value)


                        class MiIdbLsecEnabledNum(Entity):
                            """
                            Number of interfaces having label security
                            
                            enabled
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbLsecEnabledNum, self).__init__()

                                self.yang_name = "mi-idb-lsec-enabled-num"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "mi-idb-lsec-enabled-num"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbLsecEnabledNum, ['entry'], name, value)


                        class MiNumLispEid(Entity):
                            """
                            number of LISP EID prefixes
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiNumLispEid, self).__init__()

                                self.yang_name = "mi-num-lisp-eid"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "mi-num-lisp-eid"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiNumLispEid, ['entry'], name, value)


                        class MiNumLispValidEid(Entity):
                            """
                            number of LISP EID prefixes eligible for
                            
                            forwarding
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiNumLispValidEid, self).__init__()

                                self.yang_name = "mi-num-lisp-valid-eid"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "mi-num-lisp-valid-eid"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiNumLispValidEid, ['entry'], name, value)


                        class MiCpulessNode(Entity):
                            """
                            list of cpuless line cards
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiCpulessNode, self).__init__()

                                self.yang_name = "mi-cpuless-node"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "mi-cpuless-node"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiCpulessNode, ['entry'], name, value)


                        class MiProtoDbgStat(Entity):
                            """
                            Per protocol debug stats
                            
                            .. attribute:: fpd_platf_upd_stats
                            
                            	platform update statistics
                            	**type**\:  :py:class:`FpdPlatfUpdStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdPlatfUpdStats>`
                            
                            .. attribute:: fpd_gtrie_timing
                            
                            	Gtrie timing statistics
                            	**type**\:  :py:class:`FpdGtrieTiming <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdGtrieTiming>`
                            
                            .. attribute:: fpd_gbltbl_entries
                            
                            	the number of fib entries in global tbl
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_gbltbl_rej_entries
                            
                            	the number of fib entries in global retry tbl
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_vrftbl_entries
                            
                            	the number of fib entries in vrf tbls
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_vrftbl_rej_entries
                            
                            	the number of fib entries in vrf retry tbls
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_num_tbls
                            
                            	the number of tables in table set
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fpd_bcdl_msgs
                            
                            	the number of bcdl msgs
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_route_upd
                            
                            	the number of route updates
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_route_del
                            
                            	the number of route deletes
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_route_rcv
                            
                            	the number of routes received
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_route_drops
                            
                            	the number of routes dropped
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_lbl_recycled
                            
                            	the number of routes handled with recycled label
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_version_mismatch_drops
                            
                            	the number of routes dropped because of version mismatch
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_adj_upd
                            
                            	the number of adjacency updates
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_adj_del
                            
                            	the number of adjacency deletes
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_adj_upd_tx
                            
                            	number of TX adjacency updates from AIB
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_adj_upd_tx_nh_found
                            
                            	number of TX adjacency updates that found or created NH
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_adj_upd_tx_retry_created
                            
                            	number of TX adjacency updates that went to retry
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_adj_tx_retry_nh_found
                            
                            	number of TX adj retries that found or created NH
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_adj_tx_retry_obj_reinit
                            
                            	number of times TX NH retry objects updated
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_adj_drops
                            
                            	 number of adj updates dropped because of OOR
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_adj_msg
                            
                            	number of AIB messages
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_te_rcv
                            
                            	the number of TE upds received
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_te_version_mismatch_drops
                            
                            	the number of TE upds dropped because of version mismatch
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_num_retry_touts
                            
                            	the number of retry timeouts
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_ldi_num_fixedup
                            
                            	the number of fixup LDIs
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_ldi_num_correct_fixup
                            
                            	the number of corrected fixup LDIs
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_pl_num_queued_fixedup
                            
                            	the number of PL queued for fixup
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_pl_num_correct_fixup
                            
                            	the number of corrected fixup PLs
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_pl_retry_add_exist
                            
                            	the number PLs added to retry while already in retry
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_pl_inline_res_q
                            
                            	the number of PLs linked to resolving tables for inline res
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_pl_with_backup_create_count
                            
                            	number of pl creates with backu path
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_pl_with_backup_del_count
                            
                            	number of pl deletes with backup path
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_pl_backup_enable_count
                            
                            	number of PLs marked to include backup path
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_pl_backup_disable_count
                            
                            	 number of PLs unmarked to include backup path
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_pl_fast_nfn_count
                            
                            	number of PLs visited on fast notification
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_ldi_backup_activate_count
                            
                            	number of ldi backup path activications
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_ldi_last_backup_activate_time
                            
                            	ldi mod time for last backup activation
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_ldi_max_backup_activate_time
                            
                            	max ldi mod time for backup activation
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_ldi_min_backup_activate_time
                            
                            	min ldi mod time for backup activation
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_ldi_total_backup_activate_time
                            
                            	total ldi mod time for backup activation
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_ldi_avg_backup_activate_time
                            
                            	avg ldi mod time for backup activation
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_recursion_constraint_count
                            
                            	number of resolution failures because of recursion constraint
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_ldi_num_del_refcnt
                            
                            	the number of deleted with non\-zero refcount
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_retryq_size
                            
                            	the number of elements in retryq
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fpd_num_allocs
                            
                            	the number of allocs for this proto
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_num_frees
                            
                            	the number of frees for this proto
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: fpd_retryq_timeout
                            
                            	timeout value in msec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fpd_retryq_sched_time
                            
                            	Scheduler time period in msec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fpd_gbltbl_src_entry
                            
                            	Number of global routes from                      each route source
                            	**type**\: list of  		 :py:class:`FpdGbltblSrcEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdGbltblSrcEntry>`
                            
                            .. attribute:: fpd_vrftbl_src_entry
                            
                            	Number of vrf routes from                         each route source
                            	**type**\: list of  		 :py:class:`FpdVrftblSrcEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdVrftblSrcEntry>`
                            
                            .. attribute:: fpd_num_retry
                            
                            	the number of retries of each type
                            	**type**\: list of  		 :py:class:`FpdNumRetry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdNumRetry>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat, self).__init__()

                                self.yang_name = "mi-proto-dbg-stat"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("fpd-platf-upd-stats", ("fpd_platf_upd_stats", Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdPlatfUpdStats)), ("fpd-gtrie-timing", ("fpd_gtrie_timing", Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdGtrieTiming)), ("fpd-gbltbl-src-entry", ("fpd_gbltbl_src_entry", Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdGbltblSrcEntry)), ("fpd-vrftbl-src-entry", ("fpd_vrftbl_src_entry", Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdVrftblSrcEntry)), ("fpd-num-retry", ("fpd_num_retry", Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdNumRetry))])
                                self._leafs = OrderedDict([
                                    ('fpd_gbltbl_entries', (YLeaf(YType.uint64, 'fpd-gbltbl-entries'), ['int'])),
                                    ('fpd_gbltbl_rej_entries', (YLeaf(YType.uint64, 'fpd-gbltbl-rej-entries'), ['int'])),
                                    ('fpd_vrftbl_entries', (YLeaf(YType.uint64, 'fpd-vrftbl-entries'), ['int'])),
                                    ('fpd_vrftbl_rej_entries', (YLeaf(YType.uint64, 'fpd-vrftbl-rej-entries'), ['int'])),
                                    ('fpd_num_tbls', (YLeaf(YType.uint32, 'fpd-num-tbls'), ['int'])),
                                    ('fpd_bcdl_msgs', (YLeaf(YType.uint64, 'fpd-bcdl-msgs'), ['int'])),
                                    ('fpd_route_upd', (YLeaf(YType.uint64, 'fpd-route-upd'), ['int'])),
                                    ('fpd_route_del', (YLeaf(YType.uint64, 'fpd-route-del'), ['int'])),
                                    ('fpd_route_rcv', (YLeaf(YType.uint64, 'fpd-route-rcv'), ['int'])),
                                    ('fpd_route_drops', (YLeaf(YType.uint64, 'fpd-route-drops'), ['int'])),
                                    ('fpd_lbl_recycled', (YLeaf(YType.uint64, 'fpd-lbl-recycled'), ['int'])),
                                    ('fpd_version_mismatch_drops', (YLeaf(YType.uint64, 'fpd-version-mismatch-drops'), ['int'])),
                                    ('fpd_adj_upd', (YLeaf(YType.uint64, 'fpd-adj-upd'), ['int'])),
                                    ('fpd_adj_del', (YLeaf(YType.uint64, 'fpd-adj-del'), ['int'])),
                                    ('fpd_adj_upd_tx', (YLeaf(YType.uint64, 'fpd-adj-upd-tx'), ['int'])),
                                    ('fpd_adj_upd_tx_nh_found', (YLeaf(YType.uint64, 'fpd-adj-upd-tx-nh-found'), ['int'])),
                                    ('fpd_adj_upd_tx_retry_created', (YLeaf(YType.uint64, 'fpd-adj-upd-tx-retry-created'), ['int'])),
                                    ('fpd_adj_tx_retry_nh_found', (YLeaf(YType.uint64, 'fpd-adj-tx-retry-nh-found'), ['int'])),
                                    ('fpd_adj_tx_retry_obj_reinit', (YLeaf(YType.uint64, 'fpd-adj-tx-retry-obj-reinit'), ['int'])),
                                    ('fpd_adj_drops', (YLeaf(YType.uint64, 'fpd-adj-drops'), ['int'])),
                                    ('fpd_adj_msg', (YLeaf(YType.uint64, 'fpd-adj-msg'), ['int'])),
                                    ('fpd_te_rcv', (YLeaf(YType.uint64, 'fpd-te-rcv'), ['int'])),
                                    ('fpd_te_version_mismatch_drops', (YLeaf(YType.uint64, 'fpd-te-version-mismatch-drops'), ['int'])),
                                    ('fpd_num_retry_touts', (YLeaf(YType.uint64, 'fpd-num-retry-touts'), ['int'])),
                                    ('fpd_ldi_num_fixedup', (YLeaf(YType.uint64, 'fpd-ldi-num-fixedup'), ['int'])),
                                    ('fpd_ldi_num_correct_fixup', (YLeaf(YType.uint64, 'fpd-ldi-num-correct-fixup'), ['int'])),
                                    ('fpd_pl_num_queued_fixedup', (YLeaf(YType.uint64, 'fpd-pl-num-queued-fixedup'), ['int'])),
                                    ('fpd_pl_num_correct_fixup', (YLeaf(YType.uint64, 'fpd-pl-num-correct-fixup'), ['int'])),
                                    ('fpd_pl_retry_add_exist', (YLeaf(YType.uint64, 'fpd-pl-retry-add-exist'), ['int'])),
                                    ('fpd_pl_inline_res_q', (YLeaf(YType.uint64, 'fpd-pl-inline-res-q'), ['int'])),
                                    ('fpd_pl_with_backup_create_count', (YLeaf(YType.uint64, 'fpd-pl-with-backup-create-count'), ['int'])),
                                    ('fpd_pl_with_backup_del_count', (YLeaf(YType.uint64, 'fpd-pl-with-backup-del-count'), ['int'])),
                                    ('fpd_pl_backup_enable_count', (YLeaf(YType.uint64, 'fpd-pl-backup-enable-count'), ['int'])),
                                    ('fpd_pl_backup_disable_count', (YLeaf(YType.uint64, 'fpd-pl-backup-disable-count'), ['int'])),
                                    ('fpd_pl_fast_nfn_count', (YLeaf(YType.uint64, 'fpd-pl-fast-nfn-count'), ['int'])),
                                    ('fpd_ldi_backup_activate_count', (YLeaf(YType.uint64, 'fpd-ldi-backup-activate-count'), ['int'])),
                                    ('fpd_ldi_last_backup_activate_time', (YLeaf(YType.uint64, 'fpd-ldi-last-backup-activate-time'), ['int'])),
                                    ('fpd_ldi_max_backup_activate_time', (YLeaf(YType.uint64, 'fpd-ldi-max-backup-activate-time'), ['int'])),
                                    ('fpd_ldi_min_backup_activate_time', (YLeaf(YType.uint64, 'fpd-ldi-min-backup-activate-time'), ['int'])),
                                    ('fpd_ldi_total_backup_activate_time', (YLeaf(YType.uint64, 'fpd-ldi-total-backup-activate-time'), ['int'])),
                                    ('fpd_ldi_avg_backup_activate_time', (YLeaf(YType.uint64, 'fpd-ldi-avg-backup-activate-time'), ['int'])),
                                    ('fpd_recursion_constraint_count', (YLeaf(YType.uint64, 'fpd-recursion-constraint-count'), ['int'])),
                                    ('fpd_ldi_num_del_refcnt', (YLeaf(YType.uint64, 'fpd-ldi-num-del-refcnt'), ['int'])),
                                    ('fpd_retryq_size', (YLeaf(YType.uint32, 'fpd-retryq-size'), ['int'])),
                                    ('fpd_num_allocs', (YLeaf(YType.uint64, 'fpd-num-allocs'), ['int'])),
                                    ('fpd_num_frees', (YLeaf(YType.uint64, 'fpd-num-frees'), ['int'])),
                                    ('fpd_retryq_timeout', (YLeaf(YType.uint32, 'fpd-retryq-timeout'), ['int'])),
                                    ('fpd_retryq_sched_time', (YLeaf(YType.uint32, 'fpd-retryq-sched-time'), ['int'])),
                                ])
                                self.fpd_gbltbl_entries = None
                                self.fpd_gbltbl_rej_entries = None
                                self.fpd_vrftbl_entries = None
                                self.fpd_vrftbl_rej_entries = None
                                self.fpd_num_tbls = None
                                self.fpd_bcdl_msgs = None
                                self.fpd_route_upd = None
                                self.fpd_route_del = None
                                self.fpd_route_rcv = None
                                self.fpd_route_drops = None
                                self.fpd_lbl_recycled = None
                                self.fpd_version_mismatch_drops = None
                                self.fpd_adj_upd = None
                                self.fpd_adj_del = None
                                self.fpd_adj_upd_tx = None
                                self.fpd_adj_upd_tx_nh_found = None
                                self.fpd_adj_upd_tx_retry_created = None
                                self.fpd_adj_tx_retry_nh_found = None
                                self.fpd_adj_tx_retry_obj_reinit = None
                                self.fpd_adj_drops = None
                                self.fpd_adj_msg = None
                                self.fpd_te_rcv = None
                                self.fpd_te_version_mismatch_drops = None
                                self.fpd_num_retry_touts = None
                                self.fpd_ldi_num_fixedup = None
                                self.fpd_ldi_num_correct_fixup = None
                                self.fpd_pl_num_queued_fixedup = None
                                self.fpd_pl_num_correct_fixup = None
                                self.fpd_pl_retry_add_exist = None
                                self.fpd_pl_inline_res_q = None
                                self.fpd_pl_with_backup_create_count = None
                                self.fpd_pl_with_backup_del_count = None
                                self.fpd_pl_backup_enable_count = None
                                self.fpd_pl_backup_disable_count = None
                                self.fpd_pl_fast_nfn_count = None
                                self.fpd_ldi_backup_activate_count = None
                                self.fpd_ldi_last_backup_activate_time = None
                                self.fpd_ldi_max_backup_activate_time = None
                                self.fpd_ldi_min_backup_activate_time = None
                                self.fpd_ldi_total_backup_activate_time = None
                                self.fpd_ldi_avg_backup_activate_time = None
                                self.fpd_recursion_constraint_count = None
                                self.fpd_ldi_num_del_refcnt = None
                                self.fpd_retryq_size = None
                                self.fpd_num_allocs = None
                                self.fpd_num_frees = None
                                self.fpd_retryq_timeout = None
                                self.fpd_retryq_sched_time = None

                                self.fpd_platf_upd_stats = Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdPlatfUpdStats()
                                self.fpd_platf_upd_stats.parent = self
                                self._children_name_map["fpd_platf_upd_stats"] = "fpd-platf-upd-stats"

                                self.fpd_gtrie_timing = Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdGtrieTiming()
                                self.fpd_gtrie_timing.parent = self
                                self._children_name_map["fpd_gtrie_timing"] = "fpd-gtrie-timing"

                                self.fpd_gbltbl_src_entry = YList(self)
                                self.fpd_vrftbl_src_entry = YList(self)
                                self.fpd_num_retry = YList(self)
                                self._segment_path = lambda: "mi-proto-dbg-stat"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat, ['fpd_gbltbl_entries', 'fpd_gbltbl_rej_entries', 'fpd_vrftbl_entries', 'fpd_vrftbl_rej_entries', 'fpd_num_tbls', 'fpd_bcdl_msgs', 'fpd_route_upd', 'fpd_route_del', 'fpd_route_rcv', 'fpd_route_drops', 'fpd_lbl_recycled', 'fpd_version_mismatch_drops', 'fpd_adj_upd', 'fpd_adj_del', 'fpd_adj_upd_tx', 'fpd_adj_upd_tx_nh_found', 'fpd_adj_upd_tx_retry_created', 'fpd_adj_tx_retry_nh_found', 'fpd_adj_tx_retry_obj_reinit', 'fpd_adj_drops', 'fpd_adj_msg', 'fpd_te_rcv', 'fpd_te_version_mismatch_drops', 'fpd_num_retry_touts', 'fpd_ldi_num_fixedup', 'fpd_ldi_num_correct_fixup', 'fpd_pl_num_queued_fixedup', 'fpd_pl_num_correct_fixup', 'fpd_pl_retry_add_exist', 'fpd_pl_inline_res_q', 'fpd_pl_with_backup_create_count', 'fpd_pl_with_backup_del_count', 'fpd_pl_backup_enable_count', 'fpd_pl_backup_disable_count', 'fpd_pl_fast_nfn_count', 'fpd_ldi_backup_activate_count', 'fpd_ldi_last_backup_activate_time', 'fpd_ldi_max_backup_activate_time', 'fpd_ldi_min_backup_activate_time', 'fpd_ldi_total_backup_activate_time', 'fpd_ldi_avg_backup_activate_time', 'fpd_recursion_constraint_count', 'fpd_ldi_num_del_refcnt', 'fpd_retryq_size', 'fpd_num_allocs', 'fpd_num_frees', 'fpd_retryq_timeout', 'fpd_retryq_sched_time'], name, value)


                            class FpdPlatfUpdStats(Entity):
                                """
                                platform update statistics
                                
                                .. attribute:: fpus_num_success
                                
                                	Number of successful updates
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: fpus_num_failure
                                
                                	Number of unsuccessful updates
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: fpus_upd_total_time
                                
                                	Total time for all pd updates
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: fpus_obj_stat
                                
                                	Array of max time info indexed by object type
                                	**type**\: list of  		 :py:class:`FpusObjStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdPlatfUpdStats.FpusObjStat>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdPlatfUpdStats, self).__init__()

                                    self.yang_name = "fpd-platf-upd-stats"
                                    self.yang_parent_name = "mi-proto-dbg-stat"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("fpus-obj-stat", ("fpus_obj_stat", Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdPlatfUpdStats.FpusObjStat))])
                                    self._leafs = OrderedDict([
                                        ('fpus_num_success', (YLeaf(YType.uint64, 'fpus-num-success'), ['int'])),
                                        ('fpus_num_failure', (YLeaf(YType.uint64, 'fpus-num-failure'), ['int'])),
                                        ('fpus_upd_total_time', (YLeaf(YType.uint64, 'fpus-upd-total-time'), ['int'])),
                                    ])
                                    self.fpus_num_success = None
                                    self.fpus_num_failure = None
                                    self.fpus_upd_total_time = None

                                    self.fpus_obj_stat = YList(self)
                                    self._segment_path = lambda: "fpd-platf-upd-stats"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdPlatfUpdStats, ['fpus_num_success', 'fpus_num_failure', 'fpus_upd_total_time'], name, value)


                                class FpusObjStat(Entity):
                                    """
                                    Array of max time info indexed by object type
                                    
                                    .. attribute:: fos_tot_updates
                                    
                                    	Total number of updates
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: fos_tot_upd_time
                                    
                                    	Total time for updates
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: fos_obj_act_stat
                                    
                                    	Array of max time info indexed by action type
                                    	**type**\: list of  		 :py:class:`FosObjActStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdPlatfUpdStats.FpusObjStat.FosObjActStat>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdPlatfUpdStats.FpusObjStat, self).__init__()

                                        self.yang_name = "fpus-obj-stat"
                                        self.yang_parent_name = "fpd-platf-upd-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("fos-obj-act-stat", ("fos_obj_act_stat", Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdPlatfUpdStats.FpusObjStat.FosObjActStat))])
                                        self._leafs = OrderedDict([
                                            ('fos_tot_updates', (YLeaf(YType.uint64, 'fos-tot-updates'), ['int'])),
                                            ('fos_tot_upd_time', (YLeaf(YType.uint64, 'fos-tot-upd-time'), ['int'])),
                                        ])
                                        self.fos_tot_updates = None
                                        self.fos_tot_upd_time = None

                                        self.fos_obj_act_stat = YList(self)
                                        self._segment_path = lambda: "fpus-obj-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdPlatfUpdStats.FpusObjStat, ['fos_tot_updates', 'fos_tot_upd_time'], name, value)


                                    class FosObjActStat(Entity):
                                        """
                                        Array of max time info indexed by action type
                                        
                                        .. attribute:: foas_tot_updates
                                        
                                        	Total number of updates
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: foas_tot_upd_time
                                        
                                        	Total time for updates
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: foas_tot_updates_zero
                                        
                                        	Total number of updates that took zero time
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: foas_num_success
                                        
                                        	Total number of successful updates
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: foas_num_failure
                                        
                                        	Total number of failed updates
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: foas_max_time
                                        
                                        	Time for the update
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: foas_max_tstamp
                                        
                                        	Time stamp of max update
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdPlatfUpdStats.FpusObjStat.FosObjActStat, self).__init__()

                                            self.yang_name = "fos-obj-act-stat"
                                            self.yang_parent_name = "fpus-obj-stat"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('foas_tot_updates', (YLeaf(YType.uint64, 'foas-tot-updates'), ['int'])),
                                                ('foas_tot_upd_time', (YLeaf(YType.uint64, 'foas-tot-upd-time'), ['int'])),
                                                ('foas_tot_updates_zero', (YLeaf(YType.uint64, 'foas-tot-updates-zero'), ['int'])),
                                                ('foas_num_success', (YLeaf(YType.uint64, 'foas-num-success'), ['int'])),
                                                ('foas_num_failure', (YLeaf(YType.uint64, 'foas-num-failure'), ['int'])),
                                                ('foas_max_time', (YLeaf(YType.uint64, 'foas-max-time'), ['int'])),
                                                ('foas_max_tstamp', (YLeaf(YType.uint64, 'foas-max-tstamp'), ['int'])),
                                            ])
                                            self.foas_tot_updates = None
                                            self.foas_tot_upd_time = None
                                            self.foas_tot_updates_zero = None
                                            self.foas_num_success = None
                                            self.foas_num_failure = None
                                            self.foas_max_time = None
                                            self.foas_max_tstamp = None
                                            self._segment_path = lambda: "fos-obj-act-stat"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdPlatfUpdStats.FpusObjStat.FosObjActStat, ['foas_tot_updates', 'foas_tot_upd_time', 'foas_tot_updates_zero', 'foas_num_success', 'foas_num_failure', 'foas_max_time', 'foas_max_tstamp'], name, value)


                            class FpdGtrieTiming(Entity):
                                """
                                Gtrie timing statistics
                                
                                .. attribute:: fgt_num_success
                                
                                	Number of successful updates
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: fgt_num_failure
                                
                                	Number of unsuccessful updates
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: fgt_upd_total_time
                                
                                	Total time for all pd updates
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: fgt_gtrie_fn_timing
                                
                                	Array of max time info indexed by gtrie function
                                	**type**\: list of  		 :py:class:`FgtGtrieFnTiming <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdGtrieTiming.FgtGtrieFnTiming>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdGtrieTiming, self).__init__()

                                    self.yang_name = "fpd-gtrie-timing"
                                    self.yang_parent_name = "mi-proto-dbg-stat"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("fgt-gtrie-fn-timing", ("fgt_gtrie_fn_timing", Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdGtrieTiming.FgtGtrieFnTiming))])
                                    self._leafs = OrderedDict([
                                        ('fgt_num_success', (YLeaf(YType.uint64, 'fgt-num-success'), ['int'])),
                                        ('fgt_num_failure', (YLeaf(YType.uint64, 'fgt-num-failure'), ['int'])),
                                        ('fgt_upd_total_time', (YLeaf(YType.uint64, 'fgt-upd-total-time'), ['int'])),
                                    ])
                                    self.fgt_num_success = None
                                    self.fgt_num_failure = None
                                    self.fgt_upd_total_time = None

                                    self.fgt_gtrie_fn_timing = YList(self)
                                    self._segment_path = lambda: "fpd-gtrie-timing"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdGtrieTiming, ['fgt_num_success', 'fgt_num_failure', 'fgt_upd_total_time'], name, value)


                                class FgtGtrieFnTiming(Entity):
                                    """
                                    Array of max time info indexed by gtrie function
                                    
                                    .. attribute:: fgft_fn
                                    
                                    	Gtrie operation
                                    	**type**\: str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: fgft_tot_updates
                                    
                                    	Total number of updates
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: fgft_tot_updates_zero
                                    
                                    	Total number of updates with zero timing (due to timestamp granularity)
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: fgft_tot_upd_time
                                    
                                    	Total time for updates
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: fgft_max_time
                                    
                                    	Time for the update
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: fgft_max_tstamp
                                    
                                    	Time stamp of max update
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdGtrieTiming.FgtGtrieFnTiming, self).__init__()

                                        self.yang_name = "fgt-gtrie-fn-timing"
                                        self.yang_parent_name = "fpd-gtrie-timing"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fgft_fn', (YLeaf(YType.str, 'fgft-fn'), ['str'])),
                                            ('fgft_tot_updates', (YLeaf(YType.uint64, 'fgft-tot-updates'), ['int'])),
                                            ('fgft_tot_updates_zero', (YLeaf(YType.uint64, 'fgft-tot-updates-zero'), ['int'])),
                                            ('fgft_tot_upd_time', (YLeaf(YType.uint64, 'fgft-tot-upd-time'), ['int'])),
                                            ('fgft_max_time', (YLeaf(YType.uint64, 'fgft-max-time'), ['int'])),
                                            ('fgft_max_tstamp', (YLeaf(YType.uint64, 'fgft-max-tstamp'), ['int'])),
                                        ])
                                        self.fgft_fn = None
                                        self.fgft_tot_updates = None
                                        self.fgft_tot_updates_zero = None
                                        self.fgft_tot_upd_time = None
                                        self.fgft_max_time = None
                                        self.fgft_max_tstamp = None
                                        self._segment_path = lambda: "fgt-gtrie-fn-timing"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdGtrieTiming.FgtGtrieFnTiming, ['fgft_fn', 'fgft_tot_updates', 'fgft_tot_updates_zero', 'fgft_tot_upd_time', 'fgft_max_time', 'fgft_max_tstamp'], name, value)


                            class FpdGbltblSrcEntry(Entity):
                                """
                                Number of global routes from                    
                                
                                each route source
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdGbltblSrcEntry, self).__init__()

                                    self.yang_name = "fpd-gbltbl-src-entry"
                                    self.yang_parent_name = "mi-proto-dbg-stat"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint64, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "fpd-gbltbl-src-entry"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdGbltblSrcEntry, ['entry'], name, value)


                            class FpdVrftblSrcEntry(Entity):
                                """
                                Number of vrf routes from                       
                                
                                each route source
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdVrftblSrcEntry, self).__init__()

                                    self.yang_name = "fpd-vrftbl-src-entry"
                                    self.yang_parent_name = "mi-proto-dbg-stat"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint64, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "fpd-vrftbl-src-entry"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdVrftblSrcEntry, ['entry'], name, value)


                            class FpdNumRetry(Entity):
                                """
                                the number of retries of each type
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdNumRetry, self).__init__()

                                    self.yang_name = "fpd-num-retry"
                                    self.yang_parent_name = "mi-proto-dbg-stat"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint64, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "fpd-num-retry"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiProtoDbgStat.FpdNumRetry, ['entry'], name, value)


                        class MiIdbPurgeCntr(Entity):
                            """
                            the number of counters used for purge counter
                            stats
                            
                            .. attribute:: fpp_cntr
                            
                            	the number of frees for this proto
                            	**type**\: list of  		 :py:class:`FppCntr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbPurgeCntr.FppCntr>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbPurgeCntr, self).__init__()

                                self.yang_name = "mi-idb-purge-cntr"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("fpp-cntr", ("fpp_cntr", Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbPurgeCntr.FppCntr))])
                                self._leafs = OrderedDict()

                                self.fpp_cntr = YList(self)
                                self._segment_path = lambda: "mi-idb-purge-cntr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbPurgeCntr, [], name, value)


                            class FppCntr(Entity):
                                """
                                the number of frees for this proto
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbPurgeCntr.FppCntr, self).__init__()

                                    self.yang_name = "fpp-cntr"
                                    self.yang_parent_name = "mi-idb-purge-cntr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "fpp-cntr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiIdbPurgeCntr.FppCntr, ['entry'], name, value)


                        class MiDel(Entity):
                            """
                            Timestamps of deleted routes
                            
                            .. attribute:: tableid
                            
                            	tableid
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prfx
                            
                            	prfx
                            	**type**\: str
                            
                            	**length:** 0..16
                            
                            .. attribute:: prfx_len
                            
                            	prfx len
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: prfx_proto
                            
                            	prfx proto
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: msec_time
                            
                            	msec time
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiDel, self).__init__()

                                self.yang_name = "mi-del"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('tableid', (YLeaf(YType.uint32, 'tableid'), ['int'])),
                                    ('prfx', (YLeaf(YType.str, 'prfx'), ['str'])),
                                    ('prfx_len', (YLeaf(YType.uint16, 'prfx-len'), ['int'])),
                                    ('prfx_proto', (YLeaf(YType.uint16, 'prfx-proto'), ['int'])),
                                    ('msec_time', (YLeaf(YType.uint64, 'msec-time'), ['int'])),
                                ])
                                self.tableid = None
                                self.prfx = None
                                self.prfx_len = None
                                self.prfx_proto = None
                                self.msec_time = None
                                self._segment_path = lambda: "mi-del"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiDel, ['tableid', 'prfx', 'prfx_len', 'prfx_proto', 'msec_time'], name, value)


                        class MiFrrStat(Entity):
                            """
                            FRR statistics
                            
                            .. attribute:: mi_num_intf_frr
                            
                            	number of FRR events sent on nh interface down
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_parent_intf_frr
                            
                            	number of FRR events sent on nh parent interface down
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_pfi_intf_down
                            
                            	number of interface down FRR events from PFI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_bfd_down
                            
                            	number of NH down FRR events frm BFD
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_prot_frr_objects
                            
                            	total number of prot FRR objects
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_bkup_frr_objects
                            
                            	total number of backup FRR objects
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_tunid_allocs
                            
                            	total number of successful FRR tunnel ID allocations
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_tunid_alloc_failures
                            
                            	total number of FRR tunnel ID allocation failures
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_tunid_frees
                            
                            	total number of successful FRR tunnel ID frees
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_tunid_free_failures
                            
                            	total number of FRR tunnel ID free failures
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_frr_reset_queue_adds
                            
                            	number of frr reset queue adds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_frr_reset_queue_remove
                            
                            	number of frr reset queue deletes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_frr_reset
                            
                            	number of frr resets
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_frr_proto_events
                            
                            	number of frr events received in proto thread
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mi_num_frr_logs
                            
                            	frr log size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.Misc.MiFrrStat, self).__init__()

                                self.yang_name = "mi-frr-stat"
                                self.yang_parent_name = "misc"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mi_num_intf_frr', (YLeaf(YType.uint32, 'mi-num-intf-frr'), ['int'])),
                                    ('mi_num_parent_intf_frr', (YLeaf(YType.uint32, 'mi-num-parent-intf-frr'), ['int'])),
                                    ('mi_num_pfi_intf_down', (YLeaf(YType.uint32, 'mi-num-pfi-intf-down'), ['int'])),
                                    ('mi_num_bfd_down', (YLeaf(YType.uint32, 'mi-num-bfd-down'), ['int'])),
                                    ('mi_num_prot_frr_objects', (YLeaf(YType.uint32, 'mi-num-prot-frr-objects'), ['int'])),
                                    ('mi_num_bkup_frr_objects', (YLeaf(YType.uint32, 'mi-num-bkup-frr-objects'), ['int'])),
                                    ('mi_num_tunid_allocs', (YLeaf(YType.uint32, 'mi-num-tunid-allocs'), ['int'])),
                                    ('mi_num_tunid_alloc_failures', (YLeaf(YType.uint32, 'mi-num-tunid-alloc-failures'), ['int'])),
                                    ('mi_num_tunid_frees', (YLeaf(YType.uint32, 'mi-num-tunid-frees'), ['int'])),
                                    ('mi_num_tunid_free_failures', (YLeaf(YType.uint32, 'mi-num-tunid-free-failures'), ['int'])),
                                    ('mi_num_frr_reset_queue_adds', (YLeaf(YType.uint32, 'mi-num-frr-reset-queue-adds'), ['int'])),
                                    ('mi_num_frr_reset_queue_remove', (YLeaf(YType.uint32, 'mi-num-frr-reset-queue-remove'), ['int'])),
                                    ('mi_num_frr_reset', (YLeaf(YType.uint32, 'mi-num-frr-reset'), ['int'])),
                                    ('mi_num_frr_proto_events', (YLeaf(YType.uint32, 'mi-num-frr-proto-events'), ['int'])),
                                    ('mi_num_frr_logs', (YLeaf(YType.uint32, 'mi-num-frr-logs'), ['int'])),
                                ])
                                self.mi_num_intf_frr = None
                                self.mi_num_parent_intf_frr = None
                                self.mi_num_pfi_intf_down = None
                                self.mi_num_bfd_down = None
                                self.mi_num_prot_frr_objects = None
                                self.mi_num_bkup_frr_objects = None
                                self.mi_num_tunid_allocs = None
                                self.mi_num_tunid_alloc_failures = None
                                self.mi_num_tunid_frees = None
                                self.mi_num_tunid_free_failures = None
                                self.mi_num_frr_reset_queue_adds = None
                                self.mi_num_frr_reset_queue_remove = None
                                self.mi_num_frr_reset = None
                                self.mi_num_frr_proto_events = None
                                self.mi_num_frr_logs = None
                                self._segment_path = lambda: "mi-frr-stat"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.Misc.MiFrrStat, ['mi_num_intf_frr', 'mi_num_parent_intf_frr', 'mi_num_pfi_intf_down', 'mi_num_bfd_down', 'mi_num_prot_frr_objects', 'mi_num_bkup_frr_objects', 'mi_num_tunid_allocs', 'mi_num_tunid_alloc_failures', 'mi_num_tunid_frees', 'mi_num_tunid_free_failures', 'mi_num_frr_reset_queue_adds', 'mi_num_frr_reset_queue_remove', 'mi_num_frr_reset', 'mi_num_frr_proto_events', 'mi_num_frr_logs'], name, value)


                    class LocalLabel(Entity):
                        """
                        Local label
                        
                        .. attribute:: conflicts
                        
                        	FIB Local\-label conflicts database
                        	**type**\:  :py:class:`Conflicts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Fib.Nodes.Node.Protocols.Protocol.LocalLabel, self).__init__()

                            self.yang_name = "local-label"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("conflicts", ("conflicts", Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts))])
                            self._leafs = OrderedDict()

                            self.conflicts = Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts()
                            self.conflicts.parent = self
                            self._children_name_map["conflicts"] = "conflicts"
                            self._segment_path = lambda: "local-label"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.LocalLabel, [], name, value)


                        class Conflicts(Entity):
                            """
                            FIB Local\-label conflicts database
                            
                            .. attribute:: conflict
                            
                            	CEF Local\-label conflicts entry
                            	**type**\: list of  		 :py:class:`Conflict <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts, self).__init__()

                                self.yang_name = "conflicts"
                                self.yang_parent_name = "local-label"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("conflict", ("conflict", Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict))])
                                self._leafs = OrderedDict()

                                self.conflict = YList(self)
                                self._segment_path = lambda: "conflicts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts, [], name, value)


                            class Conflict(Entity):
                                """
                                CEF Local\-label conflicts entry
                                
                                .. attribute:: label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 16..1048575
                                
                                .. attribute:: source
                                
                                	Route source
                                	**type**\:  :py:class:`FibRouteSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibRouteSource>`
                                
                                .. attribute:: ll_ctype
                                
                                	Type of entry
                                	**type**\:  :py:class:`FibllcEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibllcEntry>`
                                
                                .. attribute:: pfx_tbl_id
                                
                                	Table ID of IP prefix
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix
                                
                                	IP Prefix
                                	**type**\: str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: prefix_len
                                
                                	Length of IP Prefix
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ext
                                
                                	ext
                                	**type**\:  :py:class:`Ext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext>`
                                
                                .. attribute:: local_label
                                
                                	local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: source_xr
                                
                                	source xr
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_ts
                                
                                	update ts
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: retry_ts
                                
                                	retry ts
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: num_retries
                                
                                	num retries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict, self).__init__()

                                    self.yang_name = "conflict"
                                    self.yang_parent_name = "conflicts"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ext", ("ext", Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext))])
                                    self._leafs = OrderedDict([
                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                        ('source', (YLeaf(YType.enumeration, 'source'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibRouteSource', '')])),
                                        ('ll_ctype', (YLeaf(YType.enumeration, 'll-ctype'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibllcEntry', '')])),
                                        ('pfx_tbl_id', (YLeaf(YType.uint32, 'pfx-tbl-id'), ['int'])),
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                        ('prefix_len', (YLeaf(YType.uint32, 'prefix-len'), ['int'])),
                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                        ('source_xr', (YLeaf(YType.uint32, 'source-xr'), ['int'])),
                                        ('update_ts', (YLeaf(YType.uint64, 'update-ts'), ['int'])),
                                        ('retry_ts', (YLeaf(YType.uint64, 'retry-ts'), ['int'])),
                                        ('num_retries', (YLeaf(YType.uint32, 'num-retries'), ['int'])),
                                    ])
                                    self.label = None
                                    self.source = None
                                    self.ll_ctype = None
                                    self.pfx_tbl_id = None
                                    self.prefix = None
                                    self.prefix_len = None
                                    self.local_label = None
                                    self.source_xr = None
                                    self.update_ts = None
                                    self.retry_ts = None
                                    self.num_retries = None

                                    self.ext = Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext()
                                    self.ext.parent = self
                                    self._children_name_map["ext"] = "ext"
                                    self._segment_path = lambda: "conflict"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict, ['label', 'source', 'll_ctype', 'pfx_tbl_id', 'prefix', 'prefix_len', 'local_label', 'source_xr', 'update_ts', 'retry_ts', 'num_retries'], name, value)


                                class Ext(Entity):
                                    """
                                    ext
                                    
                                    .. attribute:: pfx
                                    
                                    	pfx
                                    	**type**\:  :py:class:`Pfx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext.Pfx>`
                                    
                                    .. attribute:: lsm
                                    
                                    	lsm
                                    	**type**\:  :py:class:`Lsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext.Lsm>`
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:  :py:class:`FibMplsLlcEntryBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.FibMplsLlcEntryBag>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext, self).__init__()

                                        self.yang_name = "ext"
                                        self.yang_parent_name = "conflict"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("pfx", ("pfx", Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext.Pfx)), ("lsm", ("lsm", Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext.Lsm))])
                                        self._leafs = OrderedDict([
                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'FibMplsLlcEntryBag', '')])),
                                        ])
                                        self.type = None

                                        self.pfx = Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext.Pfx()
                                        self.pfx.parent = self
                                        self._children_name_map["pfx"] = "pfx"

                                        self.lsm = Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext.Lsm()
                                        self.lsm.parent = self
                                        self._children_name_map["lsm"] = "lsm"
                                        self._segment_path = lambda: "ext"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext, ['type'], name, value)


                                    class Pfx(Entity):
                                        """
                                        pfx
                                        
                                        .. attribute:: pfx
                                        
                                        	pfx
                                        	**type**\: str
                                        
                                        	**length:** 0..52
                                        
                                        .. attribute:: tbl_id
                                        
                                        	tbl id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext.Pfx, self).__init__()

                                            self.yang_name = "pfx"
                                            self.yang_parent_name = "ext"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pfx', (YLeaf(YType.str, 'pfx'), ['str'])),
                                                ('tbl_id', (YLeaf(YType.uint32, 'tbl-id'), ['int'])),
                                            ])
                                            self.pfx = None
                                            self.tbl_id = None
                                            self._segment_path = lambda: "pfx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext.Pfx, ['pfx', 'tbl_id'], name, value)


                                    class Lsm(Entity):
                                        """
                                        lsm
                                        
                                        .. attribute:: nh
                                        
                                        	nh
                                        	**type**\: str
                                        
                                        	**length:** 0..52
                                        
                                        .. attribute:: mcast_id
                                        
                                        	mcast id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext.Lsm, self).__init__()

                                            self.yang_name = "lsm"
                                            self.yang_parent_name = "ext"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('nh', (YLeaf(YType.str, 'nh'), ['str'])),
                                                ('mcast_id', (YLeaf(YType.uint32, 'mcast-id'), ['int'])),
                                            ])
                                            self.nh = None
                                            self.mcast_id = None
                                            self._segment_path = lambda: "lsm"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Fib.Nodes.Node.Protocols.Protocol.LocalLabel.Conflicts.Conflict.Ext.Lsm, ['nh', 'mcast_id'], name, value)

    def clone_ptr(self):
        self._top_entity = Fib()
        return self._top_entity

class OcAftL3(Entity):
    """
    oc aft l3
    
    .. attribute:: vrfs
    
    	Table VRFs \- openconfig network\-instances
    	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs>`
    
    

    """

    _prefix = 'fib-common-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(OcAftL3, self).__init__()
        self._top_entity = None

        self.yang_name = "oc-aft-l3"
        self.yang_parent_name = "Cisco-IOS-XR-fib-common-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("vrfs", ("vrfs", OcAftL3.Vrfs))])
        self._leafs = OrderedDict()

        self.vrfs = OcAftL3.Vrfs()
        self.vrfs.parent = self
        self._children_name_map["vrfs"] = "vrfs"
        self._segment_path = lambda: "Cisco-IOS-XR-fib-common-oper:oc-aft-l3"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(OcAftL3, [], name, value)


    class Vrfs(Entity):
        """
        Table VRFs \- openconfig network\-instances
        
        .. attribute:: vrf
        
        	VRF/network\-instace table
        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf>`
        
        

        """

        _prefix = 'fib-common-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(OcAftL3.Vrfs, self).__init__()

            self.yang_name = "vrfs"
            self.yang_parent_name = "oc-aft-l3"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("vrf", ("vrf", OcAftL3.Vrfs.Vrf))])
            self._leafs = OrderedDict()

            self.vrf = YList(self)
            self._segment_path = lambda: "vrfs"
            self._absolute_path = lambda: "Cisco-IOS-XR-fib-common-oper:oc-aft-l3/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(OcAftL3.Vrfs, [], name, value)


        class Vrf(Entity):
            """
            VRF/network\-instace table
            
            .. attribute:: vrf_name  (key)
            
            	Network Instance Name
            	**type**\: str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: abstract_forwarding_tables
            
            	Abstract forwarding table per FIB protocol
            	**type**\:  :py:class:`AbstractForwardingTables <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables>`
            
            

            """

            _prefix = 'fib-common-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(OcAftL3.Vrfs.Vrf, self).__init__()

                self.yang_name = "vrf"
                self.yang_parent_name = "vrfs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['vrf_name']
                self._child_classes = OrderedDict([("abstract-forwarding-tables", ("abstract_forwarding_tables", OcAftL3.Vrfs.Vrf.AbstractForwardingTables))])
                self._leafs = OrderedDict([
                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                ])
                self.vrf_name = None

                self.abstract_forwarding_tables = OcAftL3.Vrfs.Vrf.AbstractForwardingTables()
                self.abstract_forwarding_tables.parent = self
                self._children_name_map["abstract_forwarding_tables"] = "abstract-forwarding-tables"
                self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-fib-common-oper:oc-aft-l3/vrfs/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(OcAftL3.Vrfs.Vrf, ['vrf_name'], name, value)


            class AbstractForwardingTables(Entity):
                """
                Abstract forwarding table per FIB protocol
                
                .. attribute:: mpls
                
                	MPLS abstract forwarding table
                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls>`
                
                .. attribute:: ipv6_unicast
                
                	IPv6 abstract forwarding table
                	**type**\:  :py:class:`Ipv6Unicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast>`
                
                .. attribute:: ipv4_unicast
                
                	IPv4 abstract forwarding table
                	**type**\:  :py:class:`Ipv4Unicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast>`
                
                

                """

                _prefix = 'fib-common-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables, self).__init__()

                    self.yang_name = "abstract-forwarding-tables"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mpls", ("mpls", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls)), ("ipv6-unicast", ("ipv6_unicast", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast)), ("ipv4-unicast", ("ipv4_unicast", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast))])
                    self._leafs = OrderedDict()

                    self.mpls = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"

                    self.ipv6_unicast = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast()
                    self.ipv6_unicast.parent = self
                    self._children_name_map["ipv6_unicast"] = "ipv6-unicast"

                    self.ipv4_unicast = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast()
                    self.ipv4_unicast.parent = self
                    self._children_name_map["ipv4_unicast"] = "ipv4-unicast"
                    self._segment_path = lambda: "abstract-forwarding-tables"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables, [], name, value)


                class Mpls(Entity):
                    """
                    MPLS abstract forwarding table
                    
                    .. attribute:: label_entries
                    
                    	Table of MPLS labels
                    	**type**\:  :py:class:`LabelEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "abstract-forwarding-tables"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("label-entries", ("label_entries", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries))])
                        self._leafs = OrderedDict()

                        self.label_entries = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries()
                        self.label_entries.parent = self
                        self._children_name_map["label_entries"] = "label-entries"
                        self._segment_path = lambda: "mpls"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls, [], name, value)


                    class LabelEntries(Entity):
                        """
                        Table of MPLS labels
                        
                        .. attribute:: label_entry
                        
                        	Label data
                        	**type**\: list of  		 :py:class:`LabelEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries, self).__init__()

                            self.yang_name = "label-entries"
                            self.yang_parent_name = "mpls"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("label-entry", ("label_entry", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry))])
                            self._leafs = OrderedDict()

                            self.label_entry = YList(self)
                            self._segment_path = lambda: "label-entries"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries, [], name, value)


                        class LabelEntry(Entity):
                            """
                            Label data
                            
                            .. attribute:: label  (key)
                            
                            	MPLS label
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: label_length  (key)
                            
                            	Internal representation of a mask\-length of MPLS label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.State>`
                            
                            .. attribute:: next_hop
                            
                            	Next hops
                            	**type**\: list of  		 :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry, self).__init__()

                                self.yang_name = "label-entry"
                                self.yang_parent_name = "label-entries"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['label','label_length']
                                self._child_classes = OrderedDict([("state", ("state", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.State)), ("next-hop", ("next_hop", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop))])
                                self._leafs = OrderedDict([
                                    ('label', (YLeaf(YType.str, 'label'), ['str'])),
                                    ('label_length', (YLeaf(YType.uint32, 'label-length'), ['int'])),
                                ])
                                self.label = None
                                self.label_length = None

                                self.state = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.next_hop = YList(self)
                                self._segment_path = lambda: "label-entry" + "[label='" + str(self.label) + "']" + "[label-length='" + str(self.label_length) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry, ['label', 'label_length'], name, value)


                            class State(Entity):
                                """
                                State
                                
                                .. attribute:: prefix_index
                                
                                	IP prefix
                                	**type**\: str
                                
                                .. attribute:: label_index
                                
                                	MPLS label
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "label-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix_index', (YLeaf(YType.str, 'prefix-index'), ['str'])),
                                        ('label_index', (YLeaf(YType.str, 'label-index'), ['str'])),
                                    ])
                                    self.prefix_index = None
                                    self.label_index = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.State, [u'prefix_index', u'label_index'], name, value)


                            class NextHop(Entity):
                                """
                                Next hops
                                
                                .. attribute:: state
                                
                                	OC AFT entry next\-hop state
                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.State>`
                                
                                .. attribute:: interface_ref
                                
                                	AFT entry next\-hop interface ref
                                	**type**\:  :py:class:`InterfaceRef <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.InterfaceRef>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "label-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("state", ("state", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.State)), ("interface-ref", ("interface_ref", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.InterfaceRef))])
                                    self._leafs = OrderedDict()

                                    self.state = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.interface_ref = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.InterfaceRef()
                                    self.interface_ref.parent = self
                                    self._children_name_map["interface_ref"] = "interface-ref"
                                    self._segment_path = lambda: "next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop, [], name, value)


                                class State(Entity):
                                    """
                                    OC AFT entry next\-hop state
                                    
                                    .. attribute:: index
                                    
                                    	Index
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: weight
                                    
                                    	Weight
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ip_address
                                    
                                    	IP address
                                    	**type**\: str
                                    
                                    .. attribute:: network_instance
                                    
                                    	VRF name where the nexthop is resolved
                                    	**type**\: str
                                    
                                    .. attribute:: popped_mpls_label_stack
                                    
                                    	Popped mpls label stack
                                    	**type**\: list of str
                                    
                                    .. attribute:: pushed_mpls_label_stack
                                    
                                    	Pushed mpls label stack
                                    	**type**\: list of str
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                            ('network_instance', (YLeaf(YType.str, 'network-instance'), ['str'])),
                                            ('popped_mpls_label_stack', (YLeafList(YType.str, 'popped-mpls-label-stack'), ['str'])),
                                            ('pushed_mpls_label_stack', (YLeafList(YType.str, 'pushed-mpls-label-stack'), ['str'])),
                                        ])
                                        self.index = None
                                        self.weight = None
                                        self.ip_address = None
                                        self.network_instance = None
                                        self.popped_mpls_label_stack = []
                                        self.pushed_mpls_label_stack = []
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.State, [u'index', u'weight', u'ip_address', u'network_instance', u'popped_mpls_label_stack', u'pushed_mpls_label_stack'], name, value)


                                class InterfaceRef(Entity):
                                    """
                                    AFT entry next\-hop interface ref
                                    
                                    .. attribute:: state
                                    
                                    	AFT entry interface ref state
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.InterfaceRef.State>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.InterfaceRef, self).__init__()

                                        self.yang_name = "interface-ref"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.InterfaceRef.State))])
                                        self._leafs = OrderedDict()

                                        self.state = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.InterfaceRef.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "interface-ref"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.InterfaceRef, [], name, value)


                                    class State(Entity):
                                        """
                                        AFT entry interface ref state
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        .. attribute:: subinterface
                                        
                                        	Sub\-Interface index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.InterfaceRef.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "interface-ref"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('subinterface', (YLeaf(YType.uint32, 'subinterface'), ['int'])),
                                            ])
                                            self.interface = None
                                            self.subinterface = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Mpls.LabelEntries.LabelEntry.NextHop.InterfaceRef.State, [u'interface', u'subinterface'], name, value)


                class Ipv6Unicast(Entity):
                    """
                    IPv6 abstract forwarding table
                    
                    .. attribute:: prefix_entries
                    
                    	Table of IP prefixes
                    	**type**\:  :py:class:`PrefixEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast, self).__init__()

                        self.yang_name = "ipv6-unicast"
                        self.yang_parent_name = "abstract-forwarding-tables"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix-entries", ("prefix_entries", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries))])
                        self._leafs = OrderedDict()

                        self.prefix_entries = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries()
                        self.prefix_entries.parent = self
                        self._children_name_map["prefix_entries"] = "prefix-entries"
                        self._segment_path = lambda: "ipv6-unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast, [], name, value)


                    class PrefixEntries(Entity):
                        """
                        Table of IP prefixes
                        
                        .. attribute:: prefix_entry
                        
                        	Prefix data
                        	**type**\: list of  		 :py:class:`PrefixEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries, self).__init__()

                            self.yang_name = "prefix-entries"
                            self.yang_parent_name = "ipv6-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix-entry", ("prefix_entry", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry))])
                            self._leafs = OrderedDict()

                            self.prefix_entry = YList(self)
                            self._segment_path = lambda: "prefix-entries"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries, [], name, value)


                        class PrefixEntry(Entity):
                            """
                            Prefix data
                            
                            .. attribute:: network  (key)
                            
                            	Network address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.State>`
                            
                            .. attribute:: next_hop
                            
                            	Next hops
                            	**type**\: list of  		 :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry, self).__init__()

                                self.yang_name = "prefix-entry"
                                self.yang_parent_name = "prefix-entries"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['network']
                                self._child_classes = OrderedDict([("state", ("state", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.State)), ("next-hop", ("next_hop", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop))])
                                self._leafs = OrderedDict([
                                    ('network', (YLeaf(YType.str, 'network'), ['str','str'])),
                                ])
                                self.network = None

                                self.state = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.next_hop = YList(self)
                                self._segment_path = lambda: "prefix-entry" + "[network='" + str(self.network) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry, ['network'], name, value)


                            class State(Entity):
                                """
                                State
                                
                                .. attribute:: prefix_index
                                
                                	IP prefix
                                	**type**\: str
                                
                                .. attribute:: label_index
                                
                                	MPLS label
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "prefix-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix_index', (YLeaf(YType.str, 'prefix-index'), ['str'])),
                                        ('label_index', (YLeaf(YType.str, 'label-index'), ['str'])),
                                    ])
                                    self.prefix_index = None
                                    self.label_index = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.State, [u'prefix_index', u'label_index'], name, value)


                            class NextHop(Entity):
                                """
                                Next hops
                                
                                .. attribute:: state
                                
                                	OC AFT entry next\-hop state
                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.State>`
                                
                                .. attribute:: interface_ref
                                
                                	AFT entry next\-hop interface ref
                                	**type**\:  :py:class:`InterfaceRef <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "prefix-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("state", ("state", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.State)), ("interface-ref", ("interface_ref", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef))])
                                    self._leafs = OrderedDict()

                                    self.state = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.interface_ref = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef()
                                    self.interface_ref.parent = self
                                    self._children_name_map["interface_ref"] = "interface-ref"
                                    self._segment_path = lambda: "next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop, [], name, value)


                                class State(Entity):
                                    """
                                    OC AFT entry next\-hop state
                                    
                                    .. attribute:: index
                                    
                                    	Index
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: weight
                                    
                                    	Weight
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ip_address
                                    
                                    	IP address
                                    	**type**\: str
                                    
                                    .. attribute:: network_instance
                                    
                                    	VRF name where the nexthop is resolved
                                    	**type**\: str
                                    
                                    .. attribute:: popped_mpls_label_stack
                                    
                                    	Popped mpls label stack
                                    	**type**\: list of str
                                    
                                    .. attribute:: pushed_mpls_label_stack
                                    
                                    	Pushed mpls label stack
                                    	**type**\: list of str
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                            ('network_instance', (YLeaf(YType.str, 'network-instance'), ['str'])),
                                            ('popped_mpls_label_stack', (YLeafList(YType.str, 'popped-mpls-label-stack'), ['str'])),
                                            ('pushed_mpls_label_stack', (YLeafList(YType.str, 'pushed-mpls-label-stack'), ['str'])),
                                        ])
                                        self.index = None
                                        self.weight = None
                                        self.ip_address = None
                                        self.network_instance = None
                                        self.popped_mpls_label_stack = []
                                        self.pushed_mpls_label_stack = []
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.State, [u'index', u'weight', u'ip_address', u'network_instance', u'popped_mpls_label_stack', u'pushed_mpls_label_stack'], name, value)


                                class InterfaceRef(Entity):
                                    """
                                    AFT entry next\-hop interface ref
                                    
                                    .. attribute:: state
                                    
                                    	AFT entry interface ref state
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef.State>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef, self).__init__()

                                        self.yang_name = "interface-ref"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef.State))])
                                        self._leafs = OrderedDict()

                                        self.state = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "interface-ref"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef, [], name, value)


                                    class State(Entity):
                                        """
                                        AFT entry interface ref state
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        .. attribute:: subinterface
                                        
                                        	Sub\-Interface index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "interface-ref"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('subinterface', (YLeaf(YType.uint32, 'subinterface'), ['int'])),
                                            ])
                                            self.interface = None
                                            self.subinterface = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv6Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef.State, [u'interface', u'subinterface'], name, value)


                class Ipv4Unicast(Entity):
                    """
                    IPv4 abstract forwarding table
                    
                    .. attribute:: prefix_entries
                    
                    	Table of IP prefixes
                    	**type**\:  :py:class:`PrefixEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast, self).__init__()

                        self.yang_name = "ipv4-unicast"
                        self.yang_parent_name = "abstract-forwarding-tables"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("prefix-entries", ("prefix_entries", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries))])
                        self._leafs = OrderedDict()

                        self.prefix_entries = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries()
                        self.prefix_entries.parent = self
                        self._children_name_map["prefix_entries"] = "prefix-entries"
                        self._segment_path = lambda: "ipv4-unicast"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast, [], name, value)


                    class PrefixEntries(Entity):
                        """
                        Table of IP prefixes
                        
                        .. attribute:: prefix_entry
                        
                        	Prefix data
                        	**type**\: list of  		 :py:class:`PrefixEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries, self).__init__()

                            self.yang_name = "prefix-entries"
                            self.yang_parent_name = "ipv4-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("prefix-entry", ("prefix_entry", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry))])
                            self._leafs = OrderedDict()

                            self.prefix_entry = YList(self)
                            self._segment_path = lambda: "prefix-entries"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries, [], name, value)


                        class PrefixEntry(Entity):
                            """
                            Prefix data
                            
                            .. attribute:: network  (key)
                            
                            	Network address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.State>`
                            
                            .. attribute:: next_hop
                            
                            	Next hops
                            	**type**\: list of  		 :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry, self).__init__()

                                self.yang_name = "prefix-entry"
                                self.yang_parent_name = "prefix-entries"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['network']
                                self._child_classes = OrderedDict([("state", ("state", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.State)), ("next-hop", ("next_hop", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop))])
                                self._leafs = OrderedDict([
                                    ('network', (YLeaf(YType.str, 'network'), ['str','str'])),
                                ])
                                self.network = None

                                self.state = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.next_hop = YList(self)
                                self._segment_path = lambda: "prefix-entry" + "[network='" + str(self.network) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry, ['network'], name, value)


                            class State(Entity):
                                """
                                State
                                
                                .. attribute:: prefix_index
                                
                                	IP prefix
                                	**type**\: str
                                
                                .. attribute:: label_index
                                
                                	MPLS label
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.State, self).__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "prefix-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('prefix_index', (YLeaf(YType.str, 'prefix-index'), ['str'])),
                                        ('label_index', (YLeaf(YType.str, 'label-index'), ['str'])),
                                    ])
                                    self.prefix_index = None
                                    self.label_index = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.State, [u'prefix_index', u'label_index'], name, value)


                            class NextHop(Entity):
                                """
                                Next hops
                                
                                .. attribute:: state
                                
                                	OC AFT entry next\-hop state
                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.State>`
                                
                                .. attribute:: interface_ref
                                
                                	AFT entry next\-hop interface ref
                                	**type**\:  :py:class:`InterfaceRef <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "prefix-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("state", ("state", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.State)), ("interface-ref", ("interface_ref", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef))])
                                    self._leafs = OrderedDict()

                                    self.state = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.interface_ref = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef()
                                    self.interface_ref.parent = self
                                    self._children_name_map["interface_ref"] = "interface-ref"
                                    self._segment_path = lambda: "next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop, [], name, value)


                                class State(Entity):
                                    """
                                    OC AFT entry next\-hop state
                                    
                                    .. attribute:: index
                                    
                                    	Index
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: weight
                                    
                                    	Weight
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ip_address
                                    
                                    	IP address
                                    	**type**\: str
                                    
                                    .. attribute:: network_instance
                                    
                                    	VRF name where the nexthop is resolved
                                    	**type**\: str
                                    
                                    .. attribute:: popped_mpls_label_stack
                                    
                                    	Popped mpls label stack
                                    	**type**\: list of str
                                    
                                    .. attribute:: pushed_mpls_label_stack
                                    
                                    	Pushed mpls label stack
                                    	**type**\: list of str
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                            ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str'])),
                                            ('network_instance', (YLeaf(YType.str, 'network-instance'), ['str'])),
                                            ('popped_mpls_label_stack', (YLeafList(YType.str, 'popped-mpls-label-stack'), ['str'])),
                                            ('pushed_mpls_label_stack', (YLeafList(YType.str, 'pushed-mpls-label-stack'), ['str'])),
                                        ])
                                        self.index = None
                                        self.weight = None
                                        self.ip_address = None
                                        self.network_instance = None
                                        self.popped_mpls_label_stack = []
                                        self.pushed_mpls_label_stack = []
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.State, [u'index', u'weight', u'ip_address', u'network_instance', u'popped_mpls_label_stack', u'pushed_mpls_label_stack'], name, value)


                                class InterfaceRef(Entity):
                                    """
                                    AFT entry next\-hop interface ref
                                    
                                    .. attribute:: state
                                    
                                    	AFT entry interface ref state
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef.State>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef, self).__init__()

                                        self.yang_name = "interface-ref"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef.State))])
                                        self._leafs = OrderedDict()

                                        self.state = OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "interface-ref"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef, [], name, value)


                                    class State(Entity):
                                        """
                                        AFT entry interface ref state
                                        
                                        .. attribute:: interface
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        .. attribute:: subinterface
                                        
                                        	Sub\-Interface index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "interface-ref"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('subinterface', (YLeaf(YType.uint32, 'subinterface'), ['int'])),
                                            ])
                                            self.interface = None
                                            self.subinterface = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcAftL3.Vrfs.Vrf.AbstractForwardingTables.Ipv4Unicast.PrefixEntries.PrefixEntry.NextHop.InterfaceRef.State, [u'interface', u'subinterface'], name, value)

    def clone_ptr(self):
        self._top_entity = OcAftL3()
        return self._top_entity

class MplsForwarding(Entity):
    """
    mpls forwarding
    
    .. attribute:: nodes
    
    	Table of Nodes
    	**type**\:  :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes>`
    
    

    """

    _prefix = 'fib-common-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(MplsForwarding, self).__init__()
        self._top_entity = None

        self.yang_name = "mpls-forwarding"
        self.yang_parent_name = "Cisco-IOS-XR-fib-common-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("nodes", ("nodes", MplsForwarding.Nodes))])
        self._leafs = OrderedDict()

        self.nodes = MplsForwarding.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._segment_path = lambda: "Cisco-IOS-XR-fib-common-oper:mpls-forwarding"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(MplsForwarding, [], name, value)


    class Nodes(Entity):
        """
        Table of Nodes
        
        .. attribute:: node
        
        	Operational data for a specific Node
        	**type**\: list of  		 :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node>`
        
        

        """

        _prefix = 'fib-common-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(MplsForwarding.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "mpls-forwarding"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("node", ("node", MplsForwarding.Nodes.Node))])
            self._leafs = OrderedDict()

            self.node = YList(self)
            self._segment_path = lambda: "nodes"
            self._absolute_path = lambda: "Cisco-IOS-XR-fib-common-oper:mpls-forwarding/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(MplsForwarding.Nodes, [], name, value)


        class Node(Entity):
            """
            Operational data for a specific Node
            
            .. attribute:: node_name  (key)
            
            	Node ID
            	**type**\: str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: forwarding_summary
            
            	MPLS forwarding summary
            	**type**\:  :py:class:`ForwardingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.ForwardingSummary>`
            
            .. attribute:: frr_logs
            
            	FRR Log Table
            	**type**\:  :py:class:`FrrLogs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrLogs>`
            
            .. attribute:: label_fib
            
            	Labels For FIB
            	**type**\:  :py:class:`LabelFib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib>`
            
            .. attribute:: tunnel
            
            	TE Tunnel information
            	**type**\:  :py:class:`Tunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.Tunnel>`
            
            .. attribute:: frr_database
            
            	MPLS forwarding FRR Database
            	**type**\:  :py:class:`FrrDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase>`
            
            

            """

            _prefix = 'fib-common-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(MplsForwarding.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['node_name']
                self._child_classes = OrderedDict([("forwarding-summary", ("forwarding_summary", MplsForwarding.Nodes.Node.ForwardingSummary)), ("frr-logs", ("frr_logs", MplsForwarding.Nodes.Node.FrrLogs)), ("label-fib", ("label_fib", MplsForwarding.Nodes.Node.LabelFib)), ("tunnel", ("tunnel", MplsForwarding.Nodes.Node.Tunnel)), ("frr-database", ("frr_database", MplsForwarding.Nodes.Node.FrrDatabase))])
                self._leafs = OrderedDict([
                    ('node_name', (YLeaf(YType.str, 'node-name'), ['str'])),
                ])
                self.node_name = None

                self.forwarding_summary = MplsForwarding.Nodes.Node.ForwardingSummary()
                self.forwarding_summary.parent = self
                self._children_name_map["forwarding_summary"] = "forwarding-summary"

                self.frr_logs = MplsForwarding.Nodes.Node.FrrLogs()
                self.frr_logs.parent = self
                self._children_name_map["frr_logs"] = "frr-logs"

                self.label_fib = MplsForwarding.Nodes.Node.LabelFib()
                self.label_fib.parent = self
                self._children_name_map["label_fib"] = "label-fib"

                self.tunnel = MplsForwarding.Nodes.Node.Tunnel()
                self.tunnel.parent = self
                self._children_name_map["tunnel"] = "tunnel"

                self.frr_database = MplsForwarding.Nodes.Node.FrrDatabase()
                self.frr_database.parent = self
                self._children_name_map["frr_database"] = "frr-database"
                self._segment_path = lambda: "node" + "[node-name='" + str(self.node_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-fib-common-oper:mpls-forwarding/nodes/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(MplsForwarding.Nodes.Node, ['node_name'], name, value)


            class ForwardingSummary(Entity):
                """
                MPLS forwarding summary
                
                .. attribute:: ipv4_imposition_entries
                
                	Number of IPv4 imposition entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: reserved_label_entries
                
                	Number of reserved label entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: label_switched_entries
                
                	Number of label swap/disposition entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: deleted_stale_entries
                
                	Number of delete stale label entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: te_head_entries
                
                	Number of TE tunnel head imposition entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: te_frr_head_entries
                
                	Number of TE FRR tunnel head imposition entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: te_frr_interface_entries
                
                	Number of TE FRR protected interface entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: te_frr_next_hop_entries
                
                	Number of TE FRR protected next\-hop entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: te_mid_points_entries
                
                	Number of TE MidPoints forwarding entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: te_frr_mid_points_entries
                
                	Number of TE FRR MidPoints forwarding entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: te_internal_entries
                
                	Number of TE internal forwarding entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: te_frr_internal_entries
                
                	Number of TE internal forwarding entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_forwarding_updates
                
                	Total forwarding updates from LSD to LFDs
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_forwarding_update_messages
                
                	Total forwarding update messages from LSD to LFDs
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_p2mp_forwarding_updates
                
                	Total forwarding updates from MRIB to LFDs
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_p2mp_forwarding_added_or_modify_messages
                
                	Total p2mp forwarding add/modify messages from MRIB to LFDs
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_p2mp_forwarding_delete_messages
                
                	Total p2mp forwarding del messages from MRIB to LFDs
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_p2mp_forwarding_drop_messages
                
                	Total p2mp forwarding messages dropped from MRIB to LFDs
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_p2mp_iir_forwarding_drop_messages
                
                	Total IIR triggered p2mp forwarding MRIB messages dropped
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: lowest_label
                
                	Lowest label in use
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: highest_label
                
                	Highest Label in use
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ignore_protect
                
                	Number of TE tunnels treated as non\-protected
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mte_head_entries
                
                	Number of MTE tunnel head entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mte_ll_entries
                
                	Number of MTE local entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: mte_midpoint_entries
                
                	Number of MTE midpoint entries
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: global_dropped_packets
                
                	Number of global FIB packets dropped
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: global_fragmented_packets
                
                	Number of global FIB packets fragmented
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: global_failed_lookups
                
                	Number of global failed lookups
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: lrpf_entries
                
                	Number of labels with RPF
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'fib-common-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsForwarding.Nodes.Node.ForwardingSummary, self).__init__()

                    self.yang_name = "forwarding-summary"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('ipv4_imposition_entries', (YLeaf(YType.uint32, 'ipv4-imposition-entries'), ['int'])),
                        ('reserved_label_entries', (YLeaf(YType.uint32, 'reserved-label-entries'), ['int'])),
                        ('label_switched_entries', (YLeaf(YType.uint32, 'label-switched-entries'), ['int'])),
                        ('deleted_stale_entries', (YLeaf(YType.uint32, 'deleted-stale-entries'), ['int'])),
                        ('te_head_entries', (YLeaf(YType.uint32, 'te-head-entries'), ['int'])),
                        ('te_frr_head_entries', (YLeaf(YType.uint32, 'te-frr-head-entries'), ['int'])),
                        ('te_frr_interface_entries', (YLeaf(YType.uint32, 'te-frr-interface-entries'), ['int'])),
                        ('te_frr_next_hop_entries', (YLeaf(YType.uint32, 'te-frr-next-hop-entries'), ['int'])),
                        ('te_mid_points_entries', (YLeaf(YType.uint32, 'te-mid-points-entries'), ['int'])),
                        ('te_frr_mid_points_entries', (YLeaf(YType.uint32, 'te-frr-mid-points-entries'), ['int'])),
                        ('te_internal_entries', (YLeaf(YType.uint32, 'te-internal-entries'), ['int'])),
                        ('te_frr_internal_entries', (YLeaf(YType.uint32, 'te-frr-internal-entries'), ['int'])),
                        ('total_forwarding_updates', (YLeaf(YType.uint32, 'total-forwarding-updates'), ['int'])),
                        ('total_forwarding_update_messages', (YLeaf(YType.uint32, 'total-forwarding-update-messages'), ['int'])),
                        ('total_p2mp_forwarding_updates', (YLeaf(YType.uint32, 'total-p2mp-forwarding-updates'), ['int'])),
                        ('total_p2mp_forwarding_added_or_modify_messages', (YLeaf(YType.uint32, 'total-p2mp-forwarding-added-or-modify-messages'), ['int'])),
                        ('total_p2mp_forwarding_delete_messages', (YLeaf(YType.uint32, 'total-p2mp-forwarding-delete-messages'), ['int'])),
                        ('total_p2mp_forwarding_drop_messages', (YLeaf(YType.uint32, 'total-p2mp-forwarding-drop-messages'), ['int'])),
                        ('total_p2mp_iir_forwarding_drop_messages', (YLeaf(YType.uint32, 'total-p2mp-iir-forwarding-drop-messages'), ['int'])),
                        ('lowest_label', (YLeaf(YType.uint32, 'lowest-label'), ['int'])),
                        ('highest_label', (YLeaf(YType.uint32, 'highest-label'), ['int'])),
                        ('ignore_protect', (YLeaf(YType.uint32, 'ignore-protect'), ['int'])),
                        ('mte_head_entries', (YLeaf(YType.uint32, 'mte-head-entries'), ['int'])),
                        ('mte_ll_entries', (YLeaf(YType.uint32, 'mte-ll-entries'), ['int'])),
                        ('mte_midpoint_entries', (YLeaf(YType.uint32, 'mte-midpoint-entries'), ['int'])),
                        ('global_dropped_packets', (YLeaf(YType.uint64, 'global-dropped-packets'), ['int'])),
                        ('global_fragmented_packets', (YLeaf(YType.uint64, 'global-fragmented-packets'), ['int'])),
                        ('global_failed_lookups', (YLeaf(YType.uint64, 'global-failed-lookups'), ['int'])),
                        ('lrpf_entries', (YLeaf(YType.uint32, 'lrpf-entries'), ['int'])),
                    ])
                    self.ipv4_imposition_entries = None
                    self.reserved_label_entries = None
                    self.label_switched_entries = None
                    self.deleted_stale_entries = None
                    self.te_head_entries = None
                    self.te_frr_head_entries = None
                    self.te_frr_interface_entries = None
                    self.te_frr_next_hop_entries = None
                    self.te_mid_points_entries = None
                    self.te_frr_mid_points_entries = None
                    self.te_internal_entries = None
                    self.te_frr_internal_entries = None
                    self.total_forwarding_updates = None
                    self.total_forwarding_update_messages = None
                    self.total_p2mp_forwarding_updates = None
                    self.total_p2mp_forwarding_added_or_modify_messages = None
                    self.total_p2mp_forwarding_delete_messages = None
                    self.total_p2mp_forwarding_drop_messages = None
                    self.total_p2mp_iir_forwarding_drop_messages = None
                    self.lowest_label = None
                    self.highest_label = None
                    self.ignore_protect = None
                    self.mte_head_entries = None
                    self.mte_ll_entries = None
                    self.mte_midpoint_entries = None
                    self.global_dropped_packets = None
                    self.global_fragmented_packets = None
                    self.global_failed_lookups = None
                    self.lrpf_entries = None
                    self._segment_path = lambda: "forwarding-summary"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsForwarding.Nodes.Node.ForwardingSummary, ['ipv4_imposition_entries', 'reserved_label_entries', 'label_switched_entries', 'deleted_stale_entries', 'te_head_entries', 'te_frr_head_entries', 'te_frr_interface_entries', 'te_frr_next_hop_entries', 'te_mid_points_entries', 'te_frr_mid_points_entries', 'te_internal_entries', 'te_frr_internal_entries', 'total_forwarding_updates', 'total_forwarding_update_messages', 'total_p2mp_forwarding_updates', 'total_p2mp_forwarding_added_or_modify_messages', 'total_p2mp_forwarding_delete_messages', 'total_p2mp_forwarding_drop_messages', 'total_p2mp_iir_forwarding_drop_messages', 'lowest_label', 'highest_label', 'ignore_protect', 'mte_head_entries', 'mte_ll_entries', 'mte_midpoint_entries', 'global_dropped_packets', 'global_fragmented_packets', 'global_failed_lookups', 'lrpf_entries'], name, value)


            class FrrLogs(Entity):
                """
                FRR Log Table
                
                .. attribute:: frr_log
                
                	FRR Log information
                	**type**\: list of  		 :py:class:`FrrLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrLogs.FrrLog>`
                
                

                """

                _prefix = 'fib-common-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsForwarding.Nodes.Node.FrrLogs, self).__init__()

                    self.yang_name = "frr-logs"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("frr-log", ("frr_log", MplsForwarding.Nodes.Node.FrrLogs.FrrLog))])
                    self._leafs = OrderedDict()

                    self.frr_log = YList(self)
                    self._segment_path = lambda: "frr-logs"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsForwarding.Nodes.Node.FrrLogs, [], name, value)


                class FrrLog(Entity):
                    """
                    FRR Log information
                    
                    .. attribute:: event_id  (key)
                    
                    	Event ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: start_time
                    
                    	Time of FRR event processing start, Seconds in UTC, and Nano Seconds
                    	**type**\:  :py:class:`StartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrLogs.FrrLog.StartTime>`
                    
                    .. attribute:: protected_frr_interface_name
                    
                    	Interface
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: next_hop
                    
                    	Next Hop
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_rewrites_affected
                    
                    	Number of rewrites affected
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: switching_time_nsecs
                    
                    	Time to switch rewrites [nsecs]
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: main_processing
                    
                    	Main Processing for FRR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fast_bundle_member_down_interface
                    
                    	Fast Bundle Member Down Interface
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: frr_event_node_id
                    
                    	Node on which the FRR event happened
                    	**type**\: str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsForwarding.Nodes.Node.FrrLogs.FrrLog, self).__init__()

                        self.yang_name = "frr-log"
                        self.yang_parent_name = "frr-logs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['event_id']
                        self._child_classes = OrderedDict([("start-time", ("start_time", MplsForwarding.Nodes.Node.FrrLogs.FrrLog.StartTime))])
                        self._leafs = OrderedDict([
                            ('event_id', (YLeaf(YType.uint32, 'event-id'), ['int'])),
                            ('protected_frr_interface_name', (YLeaf(YType.str, 'protected-frr-interface-name'), ['str'])),
                            ('next_hop', (YLeaf(YType.uint32, 'next-hop'), ['int'])),
                            ('number_of_rewrites_affected', (YLeaf(YType.uint32, 'number-of-rewrites-affected'), ['int'])),
                            ('switching_time_nsecs', (YLeaf(YType.uint32, 'switching-time-nsecs'), ['int'])),
                            ('main_processing', (YLeaf(YType.uint32, 'main-processing'), ['int'])),
                            ('fast_bundle_member_down_interface', (YLeaf(YType.uint32, 'fast-bundle-member-down-interface'), ['int'])),
                            ('frr_event_node_id', (YLeaf(YType.str, 'frr-event-node-id'), ['str'])),
                        ])
                        self.event_id = None
                        self.protected_frr_interface_name = None
                        self.next_hop = None
                        self.number_of_rewrites_affected = None
                        self.switching_time_nsecs = None
                        self.main_processing = None
                        self.fast_bundle_member_down_interface = None
                        self.frr_event_node_id = None

                        self.start_time = MplsForwarding.Nodes.Node.FrrLogs.FrrLog.StartTime()
                        self.start_time.parent = self
                        self._children_name_map["start_time"] = "start-time"
                        self._segment_path = lambda: "frr-log" + "[event-id='" + str(self.event_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrLogs.FrrLog, ['event_id', u'protected_frr_interface_name', u'next_hop', u'number_of_rewrites_affected', u'switching_time_nsecs', u'main_processing', u'fast_bundle_member_down_interface', u'frr_event_node_id'], name, value)


                    class StartTime(Entity):
                        """
                        Time of FRR event processing start, Seconds in
                        UTC, and Nano Seconds
                        
                        .. attribute:: seconds
                        
                        	Seconds part of time valueiin UTC
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: nanoseconds
                        
                        	Nanoseconds part of time value
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsForwarding.Nodes.Node.FrrLogs.FrrLog.StartTime, self).__init__()

                            self.yang_name = "start-time"
                            self.yang_parent_name = "frr-log"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.int32, 'seconds'), ['int'])),
                                ('nanoseconds', (YLeaf(YType.int32, 'nanoseconds'), ['int'])),
                            ])
                            self.seconds = None
                            self.nanoseconds = None
                            self._segment_path = lambda: "start-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsForwarding.Nodes.Node.FrrLogs.FrrLog.StartTime, [u'seconds', u'nanoseconds'], name, value)


            class LabelFib(Entity):
                """
                Labels For FIB
                
                .. attribute:: forwarding_details
                
                	MPLS Forwarding Detail table
                	**type**\:  :py:class:`ForwardingDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails>`
                
                .. attribute:: informations
                
                	Forwarding filtering details
                	**type**\:  :py:class:`Informations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.Informations>`
                
                .. attribute:: label_security
                
                	MPLS label security
                	**type**\:  :py:class:`LabelSecurity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.LabelSecurity>`
                
                

                """

                _prefix = 'fib-common-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsForwarding.Nodes.Node.LabelFib, self).__init__()

                    self.yang_name = "label-fib"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("forwarding-details", ("forwarding_details", MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails)), ("informations", ("informations", MplsForwarding.Nodes.Node.LabelFib.Informations)), ("label-security", ("label_security", MplsForwarding.Nodes.Node.LabelFib.LabelSecurity))])
                    self._leafs = OrderedDict()

                    self.forwarding_details = MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails()
                    self.forwarding_details.parent = self
                    self._children_name_map["forwarding_details"] = "forwarding-details"

                    self.informations = MplsForwarding.Nodes.Node.LabelFib.Informations()
                    self.informations.parent = self
                    self._children_name_map["informations"] = "informations"

                    self.label_security = MplsForwarding.Nodes.Node.LabelFib.LabelSecurity()
                    self.label_security.parent = self
                    self._children_name_map["label_security"] = "label-security"
                    self._segment_path = lambda: "label-fib"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib, [], name, value)


                class ForwardingDetails(Entity):
                    """
                    MPLS Forwarding Detail table
                    
                    .. attribute:: forwarding_detail
                    
                    	MPLS forwarding details
                    	**type**\: list of  		 :py:class:`ForwardingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails, self).__init__()

                        self.yang_name = "forwarding-details"
                        self.yang_parent_name = "label-fib"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding-detail", ("forwarding_detail", MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail))])
                        self._leafs = OrderedDict()

                        self.forwarding_detail = YList(self)
                        self._segment_path = lambda: "forwarding-details"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails, [], name, value)


                    class ForwardingDetail(Entity):
                        """
                        MPLS forwarding details
                        
                        .. attribute:: label_value
                        
                        	Local label value
                        	**type**\: int
                        
                        	**range:** 16..1048575
                        
                        .. attribute:: eos
                        
                        	End of stack flag
                        	**type**\:  :py:class:`Mplseos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Mplseos>`
                        
                        .. attribute:: ldi_information
                        
                        	LDI\-info in FIB leaf
                        	**type**\:  :py:class:`LdiInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LdiInformation>`
                        
                        .. attribute:: multicast_information
                        
                        	The multicast info
                        	**type**\:  :py:class:`MulticastInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.MulticastInformation>`
                        
                        .. attribute:: leaf_local_label
                        
                        	Local label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: eos_bit
                        
                        	EOS bit
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hardware_information
                        
                        	Hardware info
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: leaf_referance_count
                        
                        	Number of references to the leaf
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: leaf_flags
                        
                        	The leaf flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_list_referance_count
                        
                        	Number of references to the pathlist
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_list_flags
                        
                        	The pathlist flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldi_referance_count
                        
                        	Number of references to the LDI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldi_flags
                        
                        	The LDI flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldi_type
                        
                        	The LDI type
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldi_pointer
                        
                        	The pointer to the LDI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lw_ldi_type
                        
                        	The LW\-LDI type
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lw_ldi_pointer
                        
                        	The pointer to the LW\-LDI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lw_ldi_refernace_count
                        
                        	The LW\-LDI refcounter
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lw_shared_ldi_pointer
                        
                        	The pointer to the shared LDI in LW\-LDI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lspa_flags
                        
                        	The LSPA flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: afi_table_id
                        
                        	The AFI table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multicast_label
                        
                        	The unicast or multicast label
                        	**type**\: bool
                        
                        .. attribute:: leaf_time_in_milli_seconds
                        
                        	The time of last update in msec
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: label_information
                        
                        	Label\-infos in FIB leaf
                        	**type**\: list of  		 :py:class:`LabelInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail, self).__init__()

                            self.yang_name = "forwarding-detail"
                            self.yang_parent_name = "forwarding-details"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ldi-information", ("ldi_information", MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LdiInformation)), ("multicast-information", ("multicast_information", MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.MulticastInformation)), ("label-information", ("label_information", MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation))])
                            self._leafs = OrderedDict([
                                ('label_value', (YLeaf(YType.uint32, 'label-value'), ['int'])),
                                ('eos', (YLeaf(YType.enumeration, 'eos'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'Mplseos', '')])),
                                ('leaf_local_label', (YLeaf(YType.uint32, 'leaf-local-label'), ['int'])),
                                ('eos_bit', (YLeaf(YType.uint32, 'eos-bit'), ['int'])),
                                ('hardware_information', (YLeaf(YType.str, 'hardware-information'), ['str'])),
                                ('leaf_referance_count', (YLeaf(YType.uint32, 'leaf-referance-count'), ['int'])),
                                ('leaf_flags', (YLeaf(YType.uint32, 'leaf-flags'), ['int'])),
                                ('path_list_referance_count', (YLeaf(YType.uint32, 'path-list-referance-count'), ['int'])),
                                ('path_list_flags', (YLeaf(YType.uint32, 'path-list-flags'), ['int'])),
                                ('ldi_referance_count', (YLeaf(YType.uint32, 'ldi-referance-count'), ['int'])),
                                ('ldi_flags', (YLeaf(YType.uint32, 'ldi-flags'), ['int'])),
                                ('ldi_type', (YLeaf(YType.uint32, 'ldi-type'), ['int'])),
                                ('ldi_pointer', (YLeaf(YType.uint32, 'ldi-pointer'), ['int'])),
                                ('lw_ldi_type', (YLeaf(YType.uint32, 'lw-ldi-type'), ['int'])),
                                ('lw_ldi_pointer', (YLeaf(YType.uint32, 'lw-ldi-pointer'), ['int'])),
                                ('lw_ldi_refernace_count', (YLeaf(YType.uint32, 'lw-ldi-refernace-count'), ['int'])),
                                ('lw_shared_ldi_pointer', (YLeaf(YType.uint32, 'lw-shared-ldi-pointer'), ['int'])),
                                ('lspa_flags', (YLeaf(YType.uint32, 'lspa-flags'), ['int'])),
                                ('afi_table_id', (YLeaf(YType.uint32, 'afi-table-id'), ['int'])),
                                ('multicast_label', (YLeaf(YType.boolean, 'multicast-label'), ['bool'])),
                                ('leaf_time_in_milli_seconds', (YLeaf(YType.uint64, 'leaf-time-in-milli-seconds'), ['int'])),
                            ])
                            self.label_value = None
                            self.eos = None
                            self.leaf_local_label = None
                            self.eos_bit = None
                            self.hardware_information = None
                            self.leaf_referance_count = None
                            self.leaf_flags = None
                            self.path_list_referance_count = None
                            self.path_list_flags = None
                            self.ldi_referance_count = None
                            self.ldi_flags = None
                            self.ldi_type = None
                            self.ldi_pointer = None
                            self.lw_ldi_type = None
                            self.lw_ldi_pointer = None
                            self.lw_ldi_refernace_count = None
                            self.lw_shared_ldi_pointer = None
                            self.lspa_flags = None
                            self.afi_table_id = None
                            self.multicast_label = None
                            self.leaf_time_in_milli_seconds = None

                            self.ldi_information = MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LdiInformation()
                            self.ldi_information.parent = self
                            self._children_name_map["ldi_information"] = "ldi-information"

                            self.multicast_information = MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.MulticastInformation()
                            self.multicast_information.parent = self
                            self._children_name_map["multicast_information"] = "multicast-information"

                            self.label_information = YList(self)
                            self._segment_path = lambda: "forwarding-detail"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail, ['label_value', 'eos', 'leaf_local_label', 'eos_bit', 'hardware_information', 'leaf_referance_count', 'leaf_flags', 'path_list_referance_count', 'path_list_flags', 'ldi_referance_count', 'ldi_flags', 'ldi_type', 'ldi_pointer', 'lw_ldi_type', 'lw_ldi_pointer', 'lw_ldi_refernace_count', 'lw_shared_ldi_pointer', 'lspa_flags', 'afi_table_id', 'multicast_label', 'leaf_time_in_milli_seconds'], name, value)


                        class LdiInformation(Entity):
                            """
                            LDI\-info in FIB leaf
                            
                            .. attribute:: ldi_hardware_information
                            
                            	Hardware info
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LdiInformation, self).__init__()

                                self.yang_name = "ldi-information"
                                self.yang_parent_name = "forwarding-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ldi_hardware_information', (YLeaf(YType.str, 'ldi-hardware-information'), ['str'])),
                                ])
                                self.ldi_hardware_information = None
                                self._segment_path = lambda: "ldi-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LdiInformation, ['ldi_hardware_information'], name, value)


                        class MulticastInformation(Entity):
                            """
                            The multicast info
                            
                            .. attribute:: multicast_mol_base_flags
                            
                            	MOL base flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_mol_flags
                            
                            	MOL flags
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: multicast_mol_referance_count
                            
                            	MOL refcount
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: multicast_tunnel_interface_handler
                            
                            	multicast mpls tunnel
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: multicast_tunnel_id
                            
                            	multicast mpls P2MP\-TE tunnel id or MLDP Tunnel LSMID on all nodes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_tunnel_next_hop_information
                            
                            	multicast nhinfo for p2mp TE Head
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_tunnel_lspvif
                            
                            	multicast LSPVIF for MLDP Tunnels
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_mpls_output_paths
                            
                            	num multicast mpls output paths 
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: multicast_mpls_protocol_output_paths
                            
                            	num multicast mpls prot output paths 
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: multicast_mpls_local_output_paths
                            
                            	num multicast mpls local output paths
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: multicast_rpf_id
                            
                            	The multicast RPF\-ID 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_encap_id
                            
                            	The multicast ENCAP\-ID 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_platform_data_length
                            
                            	The multicast platform data len
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: multicast_platform_data
                            
                            	The multicast platform data
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.MulticastInformation, self).__init__()

                                self.yang_name = "multicast-information"
                                self.yang_parent_name = "forwarding-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('multicast_mol_base_flags', (YLeaf(YType.uint32, 'multicast-mol-base-flags'), ['int'])),
                                    ('multicast_mol_flags', (YLeaf(YType.uint16, 'multicast-mol-flags'), ['int'])),
                                    ('multicast_mol_referance_count', (YLeaf(YType.uint16, 'multicast-mol-referance-count'), ['int'])),
                                    ('multicast_tunnel_interface_handler', (YLeaf(YType.str, 'multicast-tunnel-interface-handler'), ['str'])),
                                    ('multicast_tunnel_id', (YLeaf(YType.uint32, 'multicast-tunnel-id'), ['int'])),
                                    ('multicast_tunnel_next_hop_information', (YLeaf(YType.uint32, 'multicast-tunnel-next-hop-information'), ['int'])),
                                    ('multicast_tunnel_lspvif', (YLeaf(YType.uint32, 'multicast-tunnel-lspvif'), ['int'])),
                                    ('multicast_mpls_output_paths', (YLeaf(YType.uint16, 'multicast-mpls-output-paths'), ['int'])),
                                    ('multicast_mpls_protocol_output_paths', (YLeaf(YType.uint16, 'multicast-mpls-protocol-output-paths'), ['int'])),
                                    ('multicast_mpls_local_output_paths', (YLeaf(YType.uint16, 'multicast-mpls-local-output-paths'), ['int'])),
                                    ('multicast_rpf_id', (YLeaf(YType.uint32, 'multicast-rpf-id'), ['int'])),
                                    ('multicast_encap_id', (YLeaf(YType.uint32, 'multicast-encap-id'), ['int'])),
                                    ('multicast_platform_data_length', (YLeaf(YType.uint8, 'multicast-platform-data-length'), ['int'])),
                                    ('multicast_platform_data', (YLeaf(YType.str, 'multicast-platform-data'), ['str'])),
                                ])
                                self.multicast_mol_base_flags = None
                                self.multicast_mol_flags = None
                                self.multicast_mol_referance_count = None
                                self.multicast_tunnel_interface_handler = None
                                self.multicast_tunnel_id = None
                                self.multicast_tunnel_next_hop_information = None
                                self.multicast_tunnel_lspvif = None
                                self.multicast_mpls_output_paths = None
                                self.multicast_mpls_protocol_output_paths = None
                                self.multicast_mpls_local_output_paths = None
                                self.multicast_rpf_id = None
                                self.multicast_encap_id = None
                                self.multicast_platform_data_length = None
                                self.multicast_platform_data = None
                                self._segment_path = lambda: "multicast-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.MulticastInformation, ['multicast_mol_base_flags', 'multicast_mol_flags', 'multicast_mol_referance_count', 'multicast_tunnel_interface_handler', 'multicast_tunnel_id', 'multicast_tunnel_next_hop_information', 'multicast_tunnel_lspvif', 'multicast_mpls_output_paths', 'multicast_mpls_protocol_output_paths', 'multicast_mpls_local_output_paths', 'multicast_rpf_id', 'multicast_encap_id', 'multicast_platform_data_length', 'multicast_platform_data'], name, value)


                        class LabelInformation(Entity):
                            """
                            Label\-infos in FIB leaf
                            
                            .. attribute:: label_information_detail
                            
                            	Detail label info
                            	**type**\:  :py:class:`LabelInformationDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.LabelInformationDetail>`
                            
                            .. attribute:: exact_route_hash_info
                            
                            	Path's Hash info in case of exact\-route command
                            	**type**\:  :py:class:`ExactRouteHashInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.ExactRouteHashInfo>`
                            
                            .. attribute:: label_information_type
                            
                            	Label\-Info type
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_label
                            
                            	Local label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: outgoing_label
                            
                            	Outgoing label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mpls_adjacency_flags
                            
                            	MPLS Adjacency flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_id_present
                            
                            	Tunnel id present?
                            	**type**\: bool
                            
                            .. attribute:: outgoing_interface
                            
                            	Outgoing interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: outgoing_physical_interface
                            
                            	Outgoing Physical Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: outgoing_parent_interface
                            
                            	Outgoing Parent Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: tunnel_interface
                            
                            	Tunnel Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: label_information_path_index
                            
                            	LabelInformationPathIndex
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_information_next_hop_type
                            
                            	NHinfo Type
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.NextHop>`
                            
                            .. attribute:: label_information_next_hop_protocol
                            
                            	The address family (v4/v6) 
                            	**type**\:  :py:class:`Proto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Proto>`
                            
                            .. attribute:: tx_bytes
                            
                            	Bytes transmitted per LSP
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: byte
                            
                            .. attribute:: tx_packets
                            
                            	Packets transmitted per LSP
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: outgoing_interface_string
                            
                            	Output Interface in string format
                            	**type**\: str
                            
                            .. attribute:: outgoing_label_string
                            
                            	Output Label in string format
                            	**type**\: str
                            
                            .. attribute:: prefix_or_id
                            
                            	Prefix Or ID
                            	**type**\: str
                            
                            .. attribute:: label_information_next_hop_string
                            
                            	Next hop address in string format
                            	**type**\: str
                            
                            .. attribute:: label_information_route_version
                            
                            	The version of the route
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: label_information_time_in_milli_seconds
                            
                            	The time of last update in msec
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation, self).__init__()

                                self.yang_name = "label-information"
                                self.yang_parent_name = "forwarding-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("label-information-detail", ("label_information_detail", MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.LabelInformationDetail)), ("exact-route-hash-info", ("exact_route_hash_info", MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.ExactRouteHashInfo))])
                                self._leafs = OrderedDict([
                                    ('label_information_type', (YLeaf(YType.uint32, 'label-information-type'), ['int'])),
                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                    ('outgoing_label', (YLeaf(YType.uint32, 'outgoing-label'), ['int'])),
                                    ('mpls_adjacency_flags', (YLeaf(YType.uint32, 'mpls-adjacency-flags'), ['int'])),
                                    ('tunnel_id_present', (YLeaf(YType.boolean, 'tunnel-id-present'), ['bool'])),
                                    ('outgoing_interface', (YLeaf(YType.str, 'outgoing-interface'), ['str'])),
                                    ('outgoing_physical_interface', (YLeaf(YType.str, 'outgoing-physical-interface'), ['str'])),
                                    ('outgoing_parent_interface', (YLeaf(YType.str, 'outgoing-parent-interface'), ['str'])),
                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                    ('label_information_path_index', (YLeaf(YType.uint32, 'label-information-path-index'), ['int'])),
                                    ('label_information_next_hop_type', (YLeaf(YType.enumeration, 'label-information-next-hop-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'NextHop', '')])),
                                    ('label_information_next_hop_protocol', (YLeaf(YType.enumeration, 'label-information-next-hop-protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'Proto', '')])),
                                    ('tx_bytes', (YLeaf(YType.uint64, 'tx-bytes'), ['int'])),
                                    ('tx_packets', (YLeaf(YType.uint64, 'tx-packets'), ['int'])),
                                    ('outgoing_interface_string', (YLeaf(YType.str, 'outgoing-interface-string'), ['str'])),
                                    ('outgoing_label_string', (YLeaf(YType.str, 'outgoing-label-string'), ['str'])),
                                    ('prefix_or_id', (YLeaf(YType.str, 'prefix-or-id'), ['str'])),
                                    ('label_information_next_hop_string', (YLeaf(YType.str, 'label-information-next-hop-string'), ['str'])),
                                    ('label_information_route_version', (YLeaf(YType.uint64, 'label-information-route-version'), ['int'])),
                                    ('label_information_time_in_milli_seconds', (YLeaf(YType.uint64, 'label-information-time-in-milli-seconds'), ['int'])),
                                ])
                                self.label_information_type = None
                                self.local_label = None
                                self.outgoing_label = None
                                self.mpls_adjacency_flags = None
                                self.tunnel_id_present = None
                                self.outgoing_interface = None
                                self.outgoing_physical_interface = None
                                self.outgoing_parent_interface = None
                                self.tunnel_interface = None
                                self.label_information_path_index = None
                                self.label_information_next_hop_type = None
                                self.label_information_next_hop_protocol = None
                                self.tx_bytes = None
                                self.tx_packets = None
                                self.outgoing_interface_string = None
                                self.outgoing_label_string = None
                                self.prefix_or_id = None
                                self.label_information_next_hop_string = None
                                self.label_information_route_version = None
                                self.label_information_time_in_milli_seconds = None

                                self.label_information_detail = MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.LabelInformationDetail()
                                self.label_information_detail.parent = self
                                self._children_name_map["label_information_detail"] = "label-information-detail"

                                self.exact_route_hash_info = MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.ExactRouteHashInfo()
                                self.exact_route_hash_info.parent = self
                                self._children_name_map["exact_route_hash_info"] = "exact-route-hash-info"
                                self._segment_path = lambda: "label-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation, ['label_information_type', 'local_label', 'outgoing_label', 'mpls_adjacency_flags', 'tunnel_id_present', 'outgoing_interface', 'outgoing_physical_interface', 'outgoing_parent_interface', 'tunnel_interface', 'label_information_path_index', 'label_information_next_hop_type', 'label_information_next_hop_protocol', 'tx_bytes', 'tx_packets', 'outgoing_interface_string', 'outgoing_label_string', 'prefix_or_id', 'label_information_next_hop_string', 'label_information_route_version', 'label_information_time_in_milli_seconds'], name, value)


                            class LabelInformationDetail(Entity):
                                """
                                Detail label info
                                
                                .. attribute:: l3_mtu
                                
                                	L3 MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_encapsulation_size
                                
                                	Total encapsulation size\: L2 + MPLS
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_size
                                
                                	Length of L2 encapsulation
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: transmit_number_of_packets_switched
                                
                                	Number of packets switched
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: transmit_number_of_bytes_switched
                                
                                	Number of Bytes switched
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: status
                                
                                	Status
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: next_hop_protocol
                                
                                	The address family (V4/V6) 
                                	**type**\:  :py:class:`Proto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Proto>`
                                
                                .. attribute:: next_hop_string
                                
                                	Next hop address in string format
                                	**type**\: str
                                
                                .. attribute:: label_stack
                                
                                	Label stack
                                	**type**\: list of  		 :py:class:`LabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.LabelInformationDetail.LabelStack>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.LabelInformationDetail, self).__init__()

                                    self.yang_name = "label-information-detail"
                                    self.yang_parent_name = "label-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("label-stack", ("label_stack", MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.LabelInformationDetail.LabelStack))])
                                    self._leafs = OrderedDict([
                                        ('l3_mtu', (YLeaf(YType.uint32, 'l3-mtu'), ['int'])),
                                        ('total_encapsulation_size', (YLeaf(YType.uint32, 'total-encapsulation-size'), ['int'])),
                                        ('mac_size', (YLeaf(YType.uint32, 'mac-size'), ['int'])),
                                        ('transmit_number_of_packets_switched', (YLeaf(YType.uint64, 'transmit-number-of-packets-switched'), ['int'])),
                                        ('transmit_number_of_bytes_switched', (YLeaf(YType.uint64, 'transmit-number-of-bytes-switched'), ['int'])),
                                        ('status', (YLeaf(YType.int32, 'status'), ['int'])),
                                        ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                        ('next_hop_protocol', (YLeaf(YType.enumeration, 'next-hop-protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'Proto', '')])),
                                        ('next_hop_string', (YLeaf(YType.str, 'next-hop-string'), ['str'])),
                                    ])
                                    self.l3_mtu = None
                                    self.total_encapsulation_size = None
                                    self.mac_size = None
                                    self.transmit_number_of_packets_switched = None
                                    self.transmit_number_of_bytes_switched = None
                                    self.status = None
                                    self.next_hop_interface = None
                                    self.next_hop_protocol = None
                                    self.next_hop_string = None

                                    self.label_stack = YList(self)
                                    self._segment_path = lambda: "label-information-detail"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.LabelInformationDetail, ['l3_mtu', 'total_encapsulation_size', 'mac_size', 'transmit_number_of_packets_switched', 'transmit_number_of_bytes_switched', 'status', 'next_hop_interface', 'next_hop_protocol', 'next_hop_string'], name, value)


                                class LabelStack(Entity):
                                    """
                                    Label stack
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.LabelInformationDetail.LabelStack, self).__init__()

                                        self.yang_name = "label-stack"
                                        self.yang_parent_name = "label-information-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "label-stack"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.LabelInformationDetail.LabelStack, ['entry'], name, value)


                            class ExactRouteHashInfo(Entity):
                                """
                                Path's Hash info in case of exact\-route command
                                
                                .. attribute:: hash_index_is_valid
                                
                                	Is Hash Index valid?
                                	**type**\: bool
                                
                                .. attribute:: hash_index
                                
                                	Hash Index value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.ExactRouteHashInfo, self).__init__()

                                    self.yang_name = "exact-route-hash-info"
                                    self.yang_parent_name = "label-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('hash_index_is_valid', (YLeaf(YType.boolean, 'hash-index-is-valid'), ['bool'])),
                                        ('hash_index', (YLeaf(YType.uint8, 'hash-index'), ['int'])),
                                    ])
                                    self.hash_index_is_valid = None
                                    self.hash_index = None
                                    self._segment_path = lambda: "exact-route-hash-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.ForwardingDetails.ForwardingDetail.LabelInformation.ExactRouteHashInfo, ['hash_index_is_valid', 'hash_index'], name, value)


                class Informations(Entity):
                    """
                    Forwarding filtering details
                    
                    .. attribute:: information
                    
                    	MPLS forwarding information
                    	**type**\: list of  		 :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.Informations.Information>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsForwarding.Nodes.Node.LabelFib.Informations, self).__init__()

                        self.yang_name = "informations"
                        self.yang_parent_name = "label-fib"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("information", ("information", MplsForwarding.Nodes.Node.LabelFib.Informations.Information))])
                        self._leafs = OrderedDict()

                        self.information = YList(self)
                        self._segment_path = lambda: "informations"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.Informations, [], name, value)


                    class Information(Entity):
                        """
                        MPLS forwarding information
                        
                        .. attribute:: label_value
                        
                        	Local label value
                        	**type**\: int
                        
                        	**range:** 16..1048575
                        
                        .. attribute:: eos
                        
                        	End of stack flag
                        	**type**\:  :py:class:`Mplseos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Mplseos>`
                        
                        .. attribute:: ldi_information
                        
                        	LDI\-info in FIB leaf
                        	**type**\:  :py:class:`LdiInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LdiInformation>`
                        
                        .. attribute:: multicast_information
                        
                        	The multicast info
                        	**type**\:  :py:class:`MulticastInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.Informations.Information.MulticastInformation>`
                        
                        .. attribute:: leaf_local_label
                        
                        	Local label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: eos_bit
                        
                        	EOS bit
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: hardware_information
                        
                        	Hardware info
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: leaf_referance_count
                        
                        	Number of references to the leaf
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: leaf_flags
                        
                        	The leaf flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_list_referance_count
                        
                        	Number of references to the pathlist
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: path_list_flags
                        
                        	The pathlist flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldi_referance_count
                        
                        	Number of references to the LDI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldi_flags
                        
                        	The LDI flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldi_type
                        
                        	The LDI type
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ldi_pointer
                        
                        	The pointer to the LDI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lw_ldi_type
                        
                        	The LW\-LDI type
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lw_ldi_pointer
                        
                        	The pointer to the LW\-LDI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lw_ldi_refernace_count
                        
                        	The LW\-LDI refcounter
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lw_shared_ldi_pointer
                        
                        	The pointer to the shared LDI in LW\-LDI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lspa_flags
                        
                        	The LSPA flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: afi_table_id
                        
                        	The AFI table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: multicast_label
                        
                        	The unicast or multicast label
                        	**type**\: bool
                        
                        .. attribute:: leaf_time_in_milli_seconds
                        
                        	The time of last update in msec
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: label_information
                        
                        	Label\-infos in FIB leaf
                        	**type**\: list of  		 :py:class:`LabelInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsForwarding.Nodes.Node.LabelFib.Informations.Information, self).__init__()

                            self.yang_name = "information"
                            self.yang_parent_name = "informations"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ldi-information", ("ldi_information", MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LdiInformation)), ("multicast-information", ("multicast_information", MplsForwarding.Nodes.Node.LabelFib.Informations.Information.MulticastInformation)), ("label-information", ("label_information", MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation))])
                            self._leafs = OrderedDict([
                                ('label_value', (YLeaf(YType.uint32, 'label-value'), ['int'])),
                                ('eos', (YLeaf(YType.enumeration, 'eos'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'Mplseos', '')])),
                                ('leaf_local_label', (YLeaf(YType.uint32, 'leaf-local-label'), ['int'])),
                                ('eos_bit', (YLeaf(YType.uint32, 'eos-bit'), ['int'])),
                                ('hardware_information', (YLeaf(YType.str, 'hardware-information'), ['str'])),
                                ('leaf_referance_count', (YLeaf(YType.uint32, 'leaf-referance-count'), ['int'])),
                                ('leaf_flags', (YLeaf(YType.uint32, 'leaf-flags'), ['int'])),
                                ('path_list_referance_count', (YLeaf(YType.uint32, 'path-list-referance-count'), ['int'])),
                                ('path_list_flags', (YLeaf(YType.uint32, 'path-list-flags'), ['int'])),
                                ('ldi_referance_count', (YLeaf(YType.uint32, 'ldi-referance-count'), ['int'])),
                                ('ldi_flags', (YLeaf(YType.uint32, 'ldi-flags'), ['int'])),
                                ('ldi_type', (YLeaf(YType.uint32, 'ldi-type'), ['int'])),
                                ('ldi_pointer', (YLeaf(YType.uint32, 'ldi-pointer'), ['int'])),
                                ('lw_ldi_type', (YLeaf(YType.uint32, 'lw-ldi-type'), ['int'])),
                                ('lw_ldi_pointer', (YLeaf(YType.uint32, 'lw-ldi-pointer'), ['int'])),
                                ('lw_ldi_refernace_count', (YLeaf(YType.uint32, 'lw-ldi-refernace-count'), ['int'])),
                                ('lw_shared_ldi_pointer', (YLeaf(YType.uint32, 'lw-shared-ldi-pointer'), ['int'])),
                                ('lspa_flags', (YLeaf(YType.uint32, 'lspa-flags'), ['int'])),
                                ('afi_table_id', (YLeaf(YType.uint32, 'afi-table-id'), ['int'])),
                                ('multicast_label', (YLeaf(YType.boolean, 'multicast-label'), ['bool'])),
                                ('leaf_time_in_milli_seconds', (YLeaf(YType.uint64, 'leaf-time-in-milli-seconds'), ['int'])),
                            ])
                            self.label_value = None
                            self.eos = None
                            self.leaf_local_label = None
                            self.eos_bit = None
                            self.hardware_information = None
                            self.leaf_referance_count = None
                            self.leaf_flags = None
                            self.path_list_referance_count = None
                            self.path_list_flags = None
                            self.ldi_referance_count = None
                            self.ldi_flags = None
                            self.ldi_type = None
                            self.ldi_pointer = None
                            self.lw_ldi_type = None
                            self.lw_ldi_pointer = None
                            self.lw_ldi_refernace_count = None
                            self.lw_shared_ldi_pointer = None
                            self.lspa_flags = None
                            self.afi_table_id = None
                            self.multicast_label = None
                            self.leaf_time_in_milli_seconds = None

                            self.ldi_information = MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LdiInformation()
                            self.ldi_information.parent = self
                            self._children_name_map["ldi_information"] = "ldi-information"

                            self.multicast_information = MplsForwarding.Nodes.Node.LabelFib.Informations.Information.MulticastInformation()
                            self.multicast_information.parent = self
                            self._children_name_map["multicast_information"] = "multicast-information"

                            self.label_information = YList(self)
                            self._segment_path = lambda: "information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.Informations.Information, ['label_value', 'eos', 'leaf_local_label', 'eos_bit', 'hardware_information', 'leaf_referance_count', 'leaf_flags', 'path_list_referance_count', 'path_list_flags', 'ldi_referance_count', 'ldi_flags', 'ldi_type', 'ldi_pointer', 'lw_ldi_type', 'lw_ldi_pointer', 'lw_ldi_refernace_count', 'lw_shared_ldi_pointer', 'lspa_flags', 'afi_table_id', 'multicast_label', 'leaf_time_in_milli_seconds'], name, value)


                        class LdiInformation(Entity):
                            """
                            LDI\-info in FIB leaf
                            
                            .. attribute:: ldi_hardware_information
                            
                            	Hardware info
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LdiInformation, self).__init__()

                                self.yang_name = "ldi-information"
                                self.yang_parent_name = "information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ldi_hardware_information', (YLeaf(YType.str, 'ldi-hardware-information'), ['str'])),
                                ])
                                self.ldi_hardware_information = None
                                self._segment_path = lambda: "ldi-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LdiInformation, ['ldi_hardware_information'], name, value)


                        class MulticastInformation(Entity):
                            """
                            The multicast info
                            
                            .. attribute:: multicast_mol_base_flags
                            
                            	MOL base flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_mol_flags
                            
                            	MOL flags
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: multicast_mol_referance_count
                            
                            	MOL refcount
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: multicast_tunnel_interface_handler
                            
                            	multicast mpls tunnel
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: multicast_tunnel_id
                            
                            	multicast mpls P2MP\-TE tunnel id or MLDP Tunnel LSMID on all nodes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_tunnel_next_hop_information
                            
                            	multicast nhinfo for p2mp TE Head
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_tunnel_lspvif
                            
                            	multicast LSPVIF for MLDP Tunnels
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_mpls_output_paths
                            
                            	num multicast mpls output paths 
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: multicast_mpls_protocol_output_paths
                            
                            	num multicast mpls prot output paths 
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: multicast_mpls_local_output_paths
                            
                            	num multicast mpls local output paths
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: multicast_rpf_id
                            
                            	The multicast RPF\-ID 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_encap_id
                            
                            	The multicast ENCAP\-ID 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_platform_data_length
                            
                            	The multicast platform data len
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: multicast_platform_data
                            
                            	The multicast platform data
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsForwarding.Nodes.Node.LabelFib.Informations.Information.MulticastInformation, self).__init__()

                                self.yang_name = "multicast-information"
                                self.yang_parent_name = "information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('multicast_mol_base_flags', (YLeaf(YType.uint32, 'multicast-mol-base-flags'), ['int'])),
                                    ('multicast_mol_flags', (YLeaf(YType.uint16, 'multicast-mol-flags'), ['int'])),
                                    ('multicast_mol_referance_count', (YLeaf(YType.uint16, 'multicast-mol-referance-count'), ['int'])),
                                    ('multicast_tunnel_interface_handler', (YLeaf(YType.str, 'multicast-tunnel-interface-handler'), ['str'])),
                                    ('multicast_tunnel_id', (YLeaf(YType.uint32, 'multicast-tunnel-id'), ['int'])),
                                    ('multicast_tunnel_next_hop_information', (YLeaf(YType.uint32, 'multicast-tunnel-next-hop-information'), ['int'])),
                                    ('multicast_tunnel_lspvif', (YLeaf(YType.uint32, 'multicast-tunnel-lspvif'), ['int'])),
                                    ('multicast_mpls_output_paths', (YLeaf(YType.uint16, 'multicast-mpls-output-paths'), ['int'])),
                                    ('multicast_mpls_protocol_output_paths', (YLeaf(YType.uint16, 'multicast-mpls-protocol-output-paths'), ['int'])),
                                    ('multicast_mpls_local_output_paths', (YLeaf(YType.uint16, 'multicast-mpls-local-output-paths'), ['int'])),
                                    ('multicast_rpf_id', (YLeaf(YType.uint32, 'multicast-rpf-id'), ['int'])),
                                    ('multicast_encap_id', (YLeaf(YType.uint32, 'multicast-encap-id'), ['int'])),
                                    ('multicast_platform_data_length', (YLeaf(YType.uint8, 'multicast-platform-data-length'), ['int'])),
                                    ('multicast_platform_data', (YLeaf(YType.str, 'multicast-platform-data'), ['str'])),
                                ])
                                self.multicast_mol_base_flags = None
                                self.multicast_mol_flags = None
                                self.multicast_mol_referance_count = None
                                self.multicast_tunnel_interface_handler = None
                                self.multicast_tunnel_id = None
                                self.multicast_tunnel_next_hop_information = None
                                self.multicast_tunnel_lspvif = None
                                self.multicast_mpls_output_paths = None
                                self.multicast_mpls_protocol_output_paths = None
                                self.multicast_mpls_local_output_paths = None
                                self.multicast_rpf_id = None
                                self.multicast_encap_id = None
                                self.multicast_platform_data_length = None
                                self.multicast_platform_data = None
                                self._segment_path = lambda: "multicast-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.Informations.Information.MulticastInformation, ['multicast_mol_base_flags', 'multicast_mol_flags', 'multicast_mol_referance_count', 'multicast_tunnel_interface_handler', 'multicast_tunnel_id', 'multicast_tunnel_next_hop_information', 'multicast_tunnel_lspvif', 'multicast_mpls_output_paths', 'multicast_mpls_protocol_output_paths', 'multicast_mpls_local_output_paths', 'multicast_rpf_id', 'multicast_encap_id', 'multicast_platform_data_length', 'multicast_platform_data'], name, value)


                        class LabelInformation(Entity):
                            """
                            Label\-infos in FIB leaf
                            
                            .. attribute:: label_information_detail
                            
                            	Detail label info
                            	**type**\:  :py:class:`LabelInformationDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.LabelInformationDetail>`
                            
                            .. attribute:: exact_route_hash_info
                            
                            	Path's Hash info in case of exact\-route command
                            	**type**\:  :py:class:`ExactRouteHashInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.ExactRouteHashInfo>`
                            
                            .. attribute:: label_information_type
                            
                            	Label\-Info type
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_label
                            
                            	Local label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: outgoing_label
                            
                            	Outgoing label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mpls_adjacency_flags
                            
                            	MPLS Adjacency flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_id_present
                            
                            	Tunnel id present?
                            	**type**\: bool
                            
                            .. attribute:: outgoing_interface
                            
                            	Outgoing interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: outgoing_physical_interface
                            
                            	Outgoing Physical Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: outgoing_parent_interface
                            
                            	Outgoing Parent Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: tunnel_interface
                            
                            	Tunnel Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: label_information_path_index
                            
                            	LabelInformationPathIndex
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_information_next_hop_type
                            
                            	NHinfo Type
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.NextHop>`
                            
                            .. attribute:: label_information_next_hop_protocol
                            
                            	The address family (v4/v6) 
                            	**type**\:  :py:class:`Proto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Proto>`
                            
                            .. attribute:: tx_bytes
                            
                            	Bytes transmitted per LSP
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: byte
                            
                            .. attribute:: tx_packets
                            
                            	Packets transmitted per LSP
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: outgoing_interface_string
                            
                            	Output Interface in string format
                            	**type**\: str
                            
                            .. attribute:: outgoing_label_string
                            
                            	Output Label in string format
                            	**type**\: str
                            
                            .. attribute:: prefix_or_id
                            
                            	Prefix Or ID
                            	**type**\: str
                            
                            .. attribute:: label_information_next_hop_string
                            
                            	Next hop address in string format
                            	**type**\: str
                            
                            .. attribute:: label_information_route_version
                            
                            	The version of the route
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: label_information_time_in_milli_seconds
                            
                            	The time of last update in msec
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation, self).__init__()

                                self.yang_name = "label-information"
                                self.yang_parent_name = "information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("label-information-detail", ("label_information_detail", MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.LabelInformationDetail)), ("exact-route-hash-info", ("exact_route_hash_info", MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.ExactRouteHashInfo))])
                                self._leafs = OrderedDict([
                                    ('label_information_type', (YLeaf(YType.uint32, 'label-information-type'), ['int'])),
                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                    ('outgoing_label', (YLeaf(YType.uint32, 'outgoing-label'), ['int'])),
                                    ('mpls_adjacency_flags', (YLeaf(YType.uint32, 'mpls-adjacency-flags'), ['int'])),
                                    ('tunnel_id_present', (YLeaf(YType.boolean, 'tunnel-id-present'), ['bool'])),
                                    ('outgoing_interface', (YLeaf(YType.str, 'outgoing-interface'), ['str'])),
                                    ('outgoing_physical_interface', (YLeaf(YType.str, 'outgoing-physical-interface'), ['str'])),
                                    ('outgoing_parent_interface', (YLeaf(YType.str, 'outgoing-parent-interface'), ['str'])),
                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                    ('label_information_path_index', (YLeaf(YType.uint32, 'label-information-path-index'), ['int'])),
                                    ('label_information_next_hop_type', (YLeaf(YType.enumeration, 'label-information-next-hop-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'NextHop', '')])),
                                    ('label_information_next_hop_protocol', (YLeaf(YType.enumeration, 'label-information-next-hop-protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'Proto', '')])),
                                    ('tx_bytes', (YLeaf(YType.uint64, 'tx-bytes'), ['int'])),
                                    ('tx_packets', (YLeaf(YType.uint64, 'tx-packets'), ['int'])),
                                    ('outgoing_interface_string', (YLeaf(YType.str, 'outgoing-interface-string'), ['str'])),
                                    ('outgoing_label_string', (YLeaf(YType.str, 'outgoing-label-string'), ['str'])),
                                    ('prefix_or_id', (YLeaf(YType.str, 'prefix-or-id'), ['str'])),
                                    ('label_information_next_hop_string', (YLeaf(YType.str, 'label-information-next-hop-string'), ['str'])),
                                    ('label_information_route_version', (YLeaf(YType.uint64, 'label-information-route-version'), ['int'])),
                                    ('label_information_time_in_milli_seconds', (YLeaf(YType.uint64, 'label-information-time-in-milli-seconds'), ['int'])),
                                ])
                                self.label_information_type = None
                                self.local_label = None
                                self.outgoing_label = None
                                self.mpls_adjacency_flags = None
                                self.tunnel_id_present = None
                                self.outgoing_interface = None
                                self.outgoing_physical_interface = None
                                self.outgoing_parent_interface = None
                                self.tunnel_interface = None
                                self.label_information_path_index = None
                                self.label_information_next_hop_type = None
                                self.label_information_next_hop_protocol = None
                                self.tx_bytes = None
                                self.tx_packets = None
                                self.outgoing_interface_string = None
                                self.outgoing_label_string = None
                                self.prefix_or_id = None
                                self.label_information_next_hop_string = None
                                self.label_information_route_version = None
                                self.label_information_time_in_milli_seconds = None

                                self.label_information_detail = MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.LabelInformationDetail()
                                self.label_information_detail.parent = self
                                self._children_name_map["label_information_detail"] = "label-information-detail"

                                self.exact_route_hash_info = MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.ExactRouteHashInfo()
                                self.exact_route_hash_info.parent = self
                                self._children_name_map["exact_route_hash_info"] = "exact-route-hash-info"
                                self._segment_path = lambda: "label-information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation, ['label_information_type', 'local_label', 'outgoing_label', 'mpls_adjacency_flags', 'tunnel_id_present', 'outgoing_interface', 'outgoing_physical_interface', 'outgoing_parent_interface', 'tunnel_interface', 'label_information_path_index', 'label_information_next_hop_type', 'label_information_next_hop_protocol', 'tx_bytes', 'tx_packets', 'outgoing_interface_string', 'outgoing_label_string', 'prefix_or_id', 'label_information_next_hop_string', 'label_information_route_version', 'label_information_time_in_milli_seconds'], name, value)


                            class LabelInformationDetail(Entity):
                                """
                                Detail label info
                                
                                .. attribute:: l3_mtu
                                
                                	L3 MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_encapsulation_size
                                
                                	Total encapsulation size\: L2 + MPLS
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_size
                                
                                	Length of L2 encapsulation
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: transmit_number_of_packets_switched
                                
                                	Number of packets switched
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: transmit_number_of_bytes_switched
                                
                                	Number of Bytes switched
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: status
                                
                                	Status
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: next_hop_interface
                                
                                	Next hop interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: next_hop_protocol
                                
                                	The address family (V4/V6) 
                                	**type**\:  :py:class:`Proto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Proto>`
                                
                                .. attribute:: next_hop_string
                                
                                	Next hop address in string format
                                	**type**\: str
                                
                                .. attribute:: label_stack
                                
                                	Label stack
                                	**type**\: list of  		 :py:class:`LabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.LabelInformationDetail.LabelStack>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.LabelInformationDetail, self).__init__()

                                    self.yang_name = "label-information-detail"
                                    self.yang_parent_name = "label-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("label-stack", ("label_stack", MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.LabelInformationDetail.LabelStack))])
                                    self._leafs = OrderedDict([
                                        ('l3_mtu', (YLeaf(YType.uint32, 'l3-mtu'), ['int'])),
                                        ('total_encapsulation_size', (YLeaf(YType.uint32, 'total-encapsulation-size'), ['int'])),
                                        ('mac_size', (YLeaf(YType.uint32, 'mac-size'), ['int'])),
                                        ('transmit_number_of_packets_switched', (YLeaf(YType.uint64, 'transmit-number-of-packets-switched'), ['int'])),
                                        ('transmit_number_of_bytes_switched', (YLeaf(YType.uint64, 'transmit-number-of-bytes-switched'), ['int'])),
                                        ('status', (YLeaf(YType.int32, 'status'), ['int'])),
                                        ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                        ('next_hop_protocol', (YLeaf(YType.enumeration, 'next-hop-protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'Proto', '')])),
                                        ('next_hop_string', (YLeaf(YType.str, 'next-hop-string'), ['str'])),
                                    ])
                                    self.l3_mtu = None
                                    self.total_encapsulation_size = None
                                    self.mac_size = None
                                    self.transmit_number_of_packets_switched = None
                                    self.transmit_number_of_bytes_switched = None
                                    self.status = None
                                    self.next_hop_interface = None
                                    self.next_hop_protocol = None
                                    self.next_hop_string = None

                                    self.label_stack = YList(self)
                                    self._segment_path = lambda: "label-information-detail"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.LabelInformationDetail, ['l3_mtu', 'total_encapsulation_size', 'mac_size', 'transmit_number_of_packets_switched', 'transmit_number_of_bytes_switched', 'status', 'next_hop_interface', 'next_hop_protocol', 'next_hop_string'], name, value)


                                class LabelStack(Entity):
                                    """
                                    Label stack
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.LabelInformationDetail.LabelStack, self).__init__()

                                        self.yang_name = "label-stack"
                                        self.yang_parent_name = "label-information-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "label-stack"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.LabelInformationDetail.LabelStack, ['entry'], name, value)


                            class ExactRouteHashInfo(Entity):
                                """
                                Path's Hash info in case of exact\-route command
                                
                                .. attribute:: hash_index_is_valid
                                
                                	Is Hash Index valid?
                                	**type**\: bool
                                
                                .. attribute:: hash_index
                                
                                	Hash Index value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.ExactRouteHashInfo, self).__init__()

                                    self.yang_name = "exact-route-hash-info"
                                    self.yang_parent_name = "label-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('hash_index_is_valid', (YLeaf(YType.boolean, 'hash-index-is-valid'), ['bool'])),
                                        ('hash_index', (YLeaf(YType.uint8, 'hash-index'), ['int'])),
                                    ])
                                    self.hash_index_is_valid = None
                                    self.hash_index = None
                                    self._segment_path = lambda: "exact-route-hash-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.Informations.Information.LabelInformation.ExactRouteHashInfo, ['hash_index_is_valid', 'hash_index'], name, value)


                class LabelSecurity(Entity):
                    """
                    MPLS label security
                    
                    .. attribute:: interfaces
                    
                    	MPLS label security interface table
                    	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Interfaces>`
                    
                    .. attribute:: summary
                    
                    	MPLS label security summary
                    	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Summary>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsForwarding.Nodes.Node.LabelFib.LabelSecurity, self).__init__()

                        self.yang_name = "label-security"
                        self.yang_parent_name = "label-fib"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interfaces", ("interfaces", MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Interfaces)), ("summary", ("summary", MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Summary))])
                        self._leafs = OrderedDict()

                        self.interfaces = MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"

                        self.summary = MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"
                        self._segment_path = lambda: "label-security"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.LabelSecurity, [], name, value)


                    class Interfaces(Entity):
                        """
                        MPLS label security interface table
                        
                        .. attribute:: interface
                        
                        	Specify interface Name
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Interfaces.Interface>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Interfaces, self).__init__()

                            self.yang_name = "interfaces"
                            self.yang_parent_name = "label-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Interfaces.Interface))])
                            self._leafs = OrderedDict()

                            self.interface = YList(self)
                            self._segment_path = lambda: "interfaces"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Interfaces, [], name, value)


                        class Interface(Entity):
                            """
                            Specify interface Name
                            
                            .. attribute:: interface_name  (key)
                            
                            	Interface Name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: rpf_enabled
                            
                            	RPF is enabled on interface
                            	**type**\: bool
                            
                            .. attribute:: rpf_supported
                            
                            	RPF stats supported per interface
                            	**type**\: bool
                            
                            .. attribute:: mld_enabled
                            
                            	Multi\-label drop is enabled on interface
                            	**type**\: bool
                            
                            .. attribute:: mld_supported
                            
                            	Multi\-label drop counters are supported per interface
                            	**type**\: bool
                            
                            .. attribute:: rpf_drops
                            
                            	RPF drops
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multi_label_drops
                            
                            	Multi\-label drops
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: rpfifh
                            
                            	RPF interface handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Interfaces.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('rpf_enabled', (YLeaf(YType.boolean, 'rpf-enabled'), ['bool'])),
                                    ('rpf_supported', (YLeaf(YType.boolean, 'rpf-supported'), ['bool'])),
                                    ('mld_enabled', (YLeaf(YType.boolean, 'mld-enabled'), ['bool'])),
                                    ('mld_supported', (YLeaf(YType.boolean, 'mld-supported'), ['bool'])),
                                    ('rpf_drops', (YLeaf(YType.uint64, 'rpf-drops'), ['int'])),
                                    ('multi_label_drops', (YLeaf(YType.uint64, 'multi-label-drops'), ['int'])),
                                    ('rpfifh', (YLeaf(YType.str, 'rpfifh'), ['str'])),
                                ])
                                self.interface_name = None
                                self.rpf_enabled = None
                                self.rpf_supported = None
                                self.mld_enabled = None
                                self.mld_supported = None
                                self.rpf_drops = None
                                self.multi_label_drops = None
                                self.rpfifh = None
                                self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Interfaces.Interface, ['interface_name', 'rpf_enabled', 'rpf_supported', 'mld_enabled', 'mld_supported', 'rpf_drops', 'multi_label_drops', 'rpfifh'], name, value)


                    class Summary(Entity):
                        """
                        MPLS label security summary
                        
                        .. attribute:: rpf_drops
                        
                        	RPF drops
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multi_label_drops
                        
                        	Multi\-label drops
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Summary, self).__init__()

                            self.yang_name = "summary"
                            self.yang_parent_name = "label-security"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('rpf_drops', (YLeaf(YType.uint64, 'rpf-drops'), ['int'])),
                                ('multi_label_drops', (YLeaf(YType.uint64, 'multi-label-drops'), ['int'])),
                            ])
                            self.rpf_drops = None
                            self.multi_label_drops = None
                            self._segment_path = lambda: "summary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsForwarding.Nodes.Node.LabelFib.LabelSecurity.Summary, ['rpf_drops', 'multi_label_drops'], name, value)


            class Tunnel(Entity):
                """
                TE Tunnel information
                
                .. attribute:: forwarding_tunnels
                
                	Forwarding details for TE tunnels
                	**type**\:  :py:class:`ForwardingTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels>`
                
                

                """

                _prefix = 'fib-common-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsForwarding.Nodes.Node.Tunnel, self).__init__()

                    self.yang_name = "tunnel"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("forwarding-tunnels", ("forwarding_tunnels", MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels))])
                    self._leafs = OrderedDict()

                    self.forwarding_tunnels = MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels()
                    self.forwarding_tunnels.parent = self
                    self._children_name_map["forwarding_tunnels"] = "forwarding-tunnels"
                    self._segment_path = lambda: "tunnel"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsForwarding.Nodes.Node.Tunnel, [], name, value)


                class ForwardingTunnels(Entity):
                    """
                    Forwarding details for TE tunnels
                    
                    .. attribute:: forwarding_tunnel
                    
                    	Forwarding information for the TE tunnel
                    	**type**\: list of  		 :py:class:`ForwardingTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels, self).__init__()

                        self.yang_name = "forwarding-tunnels"
                        self.yang_parent_name = "tunnel"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("forwarding-tunnel", ("forwarding_tunnel", MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel))])
                        self._leafs = OrderedDict()

                        self.forwarding_tunnel = YList(self)
                        self._segment_path = lambda: "forwarding-tunnels"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels, [], name, value)


                    class ForwardingTunnel(Entity):
                        """
                        Forwarding information for the TE tunnel
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface Name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: tunnel_info
                        
                        	Tunnel head information
                        	**type**\:  :py:class:`TunnelInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.TunnelInfo>`
                        
                        .. attribute:: fwdg
                        
                        	Tunnel forwarding information
                        	**type**\:  :py:class:`Fwdg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg>`
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel, self).__init__()

                            self.yang_name = "forwarding-tunnel"
                            self.yang_parent_name = "forwarding-tunnels"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("tunnel-info", ("tunnel_info", MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.TunnelInfo)), ("fwdg", ("fwdg", MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ])
                            self.interface_name = None

                            self.tunnel_info = MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.TunnelInfo()
                            self.tunnel_info.parent = self
                            self._children_name_map["tunnel_info"] = "tunnel-info"

                            self.fwdg = MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg()
                            self.fwdg.parent = self
                            self._children_name_map["fwdg"] = "fwdg"
                            self._segment_path = lambda: "forwarding-tunnel" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel, ['interface_name'], name, value)


                        class TunnelInfo(Entity):
                            """
                            Tunnel head information
                            
                            .. attribute:: tunnel_interface_name
                            
                            	Tunnel interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: tunnel_local_label
                            
                            	Tunnel Local label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_fwd_class
                            
                            	Tunnel Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tunnel_load_metric
                            
                            	 Tunnel Load Metric
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tunnel_is_srte
                            
                            	Is Tunnel SRTE
                            	**type**\: bool
                            
                            .. attribute:: tunnel_resolution_incomplete
                            
                            	Tunnel head resolution is incomplete
                            	**type**\: bool
                            
                            .. attribute:: tunnel_resolution_inconsistent
                            
                            	Tunnel head resolition is inconsitent b/w TEhead and Local label
                            	**type**\: bool
                            
                            .. attribute:: tunnel_is_programmed_to_drop
                            
                            	Is Tunnel programmed as drop
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.TunnelInfo, self).__init__()

                                self.yang_name = "tunnel-info"
                                self.yang_parent_name = "forwarding-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('tunnel_interface_name', (YLeaf(YType.str, 'tunnel-interface-name'), ['str'])),
                                    ('tunnel_local_label', (YLeaf(YType.uint32, 'tunnel-local-label'), ['int'])),
                                    ('tunnel_fwd_class', (YLeaf(YType.uint8, 'tunnel-fwd-class'), ['int'])),
                                    ('tunnel_load_metric', (YLeaf(YType.uint8, 'tunnel-load-metric'), ['int'])),
                                    ('tunnel_is_srte', (YLeaf(YType.boolean, 'tunnel-is-srte'), ['bool'])),
                                    ('tunnel_resolution_incomplete', (YLeaf(YType.boolean, 'tunnel-resolution-incomplete'), ['bool'])),
                                    ('tunnel_resolution_inconsistent', (YLeaf(YType.boolean, 'tunnel-resolution-inconsistent'), ['bool'])),
                                    ('tunnel_is_programmed_to_drop', (YLeaf(YType.boolean, 'tunnel-is-programmed-to-drop'), ['bool'])),
                                ])
                                self.tunnel_interface_name = None
                                self.tunnel_local_label = None
                                self.tunnel_fwd_class = None
                                self.tunnel_load_metric = None
                                self.tunnel_is_srte = None
                                self.tunnel_resolution_incomplete = None
                                self.tunnel_resolution_inconsistent = None
                                self.tunnel_is_programmed_to_drop = None
                                self._segment_path = lambda: "tunnel-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.TunnelInfo, [u'tunnel_interface_name', u'tunnel_local_label', u'tunnel_fwd_class', u'tunnel_load_metric', u'tunnel_is_srte', u'tunnel_resolution_incomplete', u'tunnel_resolution_inconsistent', u'tunnel_is_programmed_to_drop'], name, value)


                        class Fwdg(Entity):
                            """
                            Tunnel forwarding information
                            
                            .. attribute:: ldi_information
                            
                            	LDI\-info in FIB leaf
                            	**type**\:  :py:class:`LdiInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LdiInformation>`
                            
                            .. attribute:: multicast_information
                            
                            	The multicast info
                            	**type**\:  :py:class:`MulticastInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.MulticastInformation>`
                            
                            .. attribute:: leaf_local_label
                            
                            	Local label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: eos_bit
                            
                            	EOS bit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: hardware_information
                            
                            	Hardware info
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: leaf_referance_count
                            
                            	Number of references to the leaf
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: leaf_flags
                            
                            	The leaf flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_list_referance_count
                            
                            	Number of references to the pathlist
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_list_flags
                            
                            	The pathlist flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldi_referance_count
                            
                            	Number of references to the LDI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldi_flags
                            
                            	The LDI flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldi_type
                            
                            	The LDI type
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ldi_pointer
                            
                            	The pointer to the LDI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lw_ldi_type
                            
                            	The LW\-LDI type
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lw_ldi_pointer
                            
                            	The pointer to the LW\-LDI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lw_ldi_refernace_count
                            
                            	The LW\-LDI refcounter
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lw_shared_ldi_pointer
                            
                            	The pointer to the shared LDI in LW\-LDI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lspa_flags
                            
                            	The LSPA flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: afi_table_id
                            
                            	The AFI table ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_label
                            
                            	The unicast or multicast label
                            	**type**\: bool
                            
                            .. attribute:: leaf_time_in_milli_seconds
                            
                            	The time of last update in msec
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: label_information
                            
                            	Label\-infos in FIB leaf
                            	**type**\: list of  		 :py:class:`LabelInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg, self).__init__()

                                self.yang_name = "fwdg"
                                self.yang_parent_name = "forwarding-tunnel"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ldi-information", ("ldi_information", MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LdiInformation)), ("multicast-information", ("multicast_information", MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.MulticastInformation)), ("label-information", ("label_information", MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation))])
                                self._leafs = OrderedDict([
                                    ('leaf_local_label', (YLeaf(YType.uint32, 'leaf-local-label'), ['int'])),
                                    ('eos_bit', (YLeaf(YType.uint32, 'eos-bit'), ['int'])),
                                    ('hardware_information', (YLeaf(YType.str, 'hardware-information'), ['str'])),
                                    ('leaf_referance_count', (YLeaf(YType.uint32, 'leaf-referance-count'), ['int'])),
                                    ('leaf_flags', (YLeaf(YType.uint32, 'leaf-flags'), ['int'])),
                                    ('path_list_referance_count', (YLeaf(YType.uint32, 'path-list-referance-count'), ['int'])),
                                    ('path_list_flags', (YLeaf(YType.uint32, 'path-list-flags'), ['int'])),
                                    ('ldi_referance_count', (YLeaf(YType.uint32, 'ldi-referance-count'), ['int'])),
                                    ('ldi_flags', (YLeaf(YType.uint32, 'ldi-flags'), ['int'])),
                                    ('ldi_type', (YLeaf(YType.uint32, 'ldi-type'), ['int'])),
                                    ('ldi_pointer', (YLeaf(YType.uint32, 'ldi-pointer'), ['int'])),
                                    ('lw_ldi_type', (YLeaf(YType.uint32, 'lw-ldi-type'), ['int'])),
                                    ('lw_ldi_pointer', (YLeaf(YType.uint32, 'lw-ldi-pointer'), ['int'])),
                                    ('lw_ldi_refernace_count', (YLeaf(YType.uint32, 'lw-ldi-refernace-count'), ['int'])),
                                    ('lw_shared_ldi_pointer', (YLeaf(YType.uint32, 'lw-shared-ldi-pointer'), ['int'])),
                                    ('lspa_flags', (YLeaf(YType.uint32, 'lspa-flags'), ['int'])),
                                    ('afi_table_id', (YLeaf(YType.uint32, 'afi-table-id'), ['int'])),
                                    ('multicast_label', (YLeaf(YType.boolean, 'multicast-label'), ['bool'])),
                                    ('leaf_time_in_milli_seconds', (YLeaf(YType.uint64, 'leaf-time-in-milli-seconds'), ['int'])),
                                ])
                                self.leaf_local_label = None
                                self.eos_bit = None
                                self.hardware_information = None
                                self.leaf_referance_count = None
                                self.leaf_flags = None
                                self.path_list_referance_count = None
                                self.path_list_flags = None
                                self.ldi_referance_count = None
                                self.ldi_flags = None
                                self.ldi_type = None
                                self.ldi_pointer = None
                                self.lw_ldi_type = None
                                self.lw_ldi_pointer = None
                                self.lw_ldi_refernace_count = None
                                self.lw_shared_ldi_pointer = None
                                self.lspa_flags = None
                                self.afi_table_id = None
                                self.multicast_label = None
                                self.leaf_time_in_milli_seconds = None

                                self.ldi_information = MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LdiInformation()
                                self.ldi_information.parent = self
                                self._children_name_map["ldi_information"] = "ldi-information"

                                self.multicast_information = MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.MulticastInformation()
                                self.multicast_information.parent = self
                                self._children_name_map["multicast_information"] = "multicast-information"

                                self.label_information = YList(self)
                                self._segment_path = lambda: "fwdg"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg, ['leaf_local_label', 'eos_bit', 'hardware_information', 'leaf_referance_count', 'leaf_flags', 'path_list_referance_count', 'path_list_flags', 'ldi_referance_count', 'ldi_flags', 'ldi_type', 'ldi_pointer', 'lw_ldi_type', 'lw_ldi_pointer', 'lw_ldi_refernace_count', 'lw_shared_ldi_pointer', 'lspa_flags', 'afi_table_id', 'multicast_label', 'leaf_time_in_milli_seconds'], name, value)


                            class LdiInformation(Entity):
                                """
                                LDI\-info in FIB leaf
                                
                                .. attribute:: ldi_hardware_information
                                
                                	Hardware info
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LdiInformation, self).__init__()

                                    self.yang_name = "ldi-information"
                                    self.yang_parent_name = "fwdg"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ldi_hardware_information', (YLeaf(YType.str, 'ldi-hardware-information'), ['str'])),
                                    ])
                                    self.ldi_hardware_information = None
                                    self._segment_path = lambda: "ldi-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LdiInformation, ['ldi_hardware_information'], name, value)


                            class MulticastInformation(Entity):
                                """
                                The multicast info
                                
                                .. attribute:: multicast_mol_base_flags
                                
                                	MOL base flags
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multicast_mol_flags
                                
                                	MOL flags
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: multicast_mol_referance_count
                                
                                	MOL refcount
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: multicast_tunnel_interface_handler
                                
                                	multicast mpls tunnel
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: multicast_tunnel_id
                                
                                	multicast mpls P2MP\-TE tunnel id or MLDP Tunnel LSMID on all nodes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multicast_tunnel_next_hop_information
                                
                                	multicast nhinfo for p2mp TE Head
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multicast_tunnel_lspvif
                                
                                	multicast LSPVIF for MLDP Tunnels
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multicast_mpls_output_paths
                                
                                	num multicast mpls output paths 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: multicast_mpls_protocol_output_paths
                                
                                	num multicast mpls prot output paths 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: multicast_mpls_local_output_paths
                                
                                	num multicast mpls local output paths
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: multicast_rpf_id
                                
                                	The multicast RPF\-ID 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multicast_encap_id
                                
                                	The multicast ENCAP\-ID 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: multicast_platform_data_length
                                
                                	The multicast platform data len
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: multicast_platform_data
                                
                                	The multicast platform data
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.MulticastInformation, self).__init__()

                                    self.yang_name = "multicast-information"
                                    self.yang_parent_name = "fwdg"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('multicast_mol_base_flags', (YLeaf(YType.uint32, 'multicast-mol-base-flags'), ['int'])),
                                        ('multicast_mol_flags', (YLeaf(YType.uint16, 'multicast-mol-flags'), ['int'])),
                                        ('multicast_mol_referance_count', (YLeaf(YType.uint16, 'multicast-mol-referance-count'), ['int'])),
                                        ('multicast_tunnel_interface_handler', (YLeaf(YType.str, 'multicast-tunnel-interface-handler'), ['str'])),
                                        ('multicast_tunnel_id', (YLeaf(YType.uint32, 'multicast-tunnel-id'), ['int'])),
                                        ('multicast_tunnel_next_hop_information', (YLeaf(YType.uint32, 'multicast-tunnel-next-hop-information'), ['int'])),
                                        ('multicast_tunnel_lspvif', (YLeaf(YType.uint32, 'multicast-tunnel-lspvif'), ['int'])),
                                        ('multicast_mpls_output_paths', (YLeaf(YType.uint16, 'multicast-mpls-output-paths'), ['int'])),
                                        ('multicast_mpls_protocol_output_paths', (YLeaf(YType.uint16, 'multicast-mpls-protocol-output-paths'), ['int'])),
                                        ('multicast_mpls_local_output_paths', (YLeaf(YType.uint16, 'multicast-mpls-local-output-paths'), ['int'])),
                                        ('multicast_rpf_id', (YLeaf(YType.uint32, 'multicast-rpf-id'), ['int'])),
                                        ('multicast_encap_id', (YLeaf(YType.uint32, 'multicast-encap-id'), ['int'])),
                                        ('multicast_platform_data_length', (YLeaf(YType.uint8, 'multicast-platform-data-length'), ['int'])),
                                        ('multicast_platform_data', (YLeaf(YType.str, 'multicast-platform-data'), ['str'])),
                                    ])
                                    self.multicast_mol_base_flags = None
                                    self.multicast_mol_flags = None
                                    self.multicast_mol_referance_count = None
                                    self.multicast_tunnel_interface_handler = None
                                    self.multicast_tunnel_id = None
                                    self.multicast_tunnel_next_hop_information = None
                                    self.multicast_tunnel_lspvif = None
                                    self.multicast_mpls_output_paths = None
                                    self.multicast_mpls_protocol_output_paths = None
                                    self.multicast_mpls_local_output_paths = None
                                    self.multicast_rpf_id = None
                                    self.multicast_encap_id = None
                                    self.multicast_platform_data_length = None
                                    self.multicast_platform_data = None
                                    self._segment_path = lambda: "multicast-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.MulticastInformation, ['multicast_mol_base_flags', 'multicast_mol_flags', 'multicast_mol_referance_count', 'multicast_tunnel_interface_handler', 'multicast_tunnel_id', 'multicast_tunnel_next_hop_information', 'multicast_tunnel_lspvif', 'multicast_mpls_output_paths', 'multicast_mpls_protocol_output_paths', 'multicast_mpls_local_output_paths', 'multicast_rpf_id', 'multicast_encap_id', 'multicast_platform_data_length', 'multicast_platform_data'], name, value)


                            class LabelInformation(Entity):
                                """
                                Label\-infos in FIB leaf
                                
                                .. attribute:: label_information_detail
                                
                                	Detail label info
                                	**type**\:  :py:class:`LabelInformationDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.LabelInformationDetail>`
                                
                                .. attribute:: exact_route_hash_info
                                
                                	Path's Hash info in case of exact\-route command
                                	**type**\:  :py:class:`ExactRouteHashInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.ExactRouteHashInfo>`
                                
                                .. attribute:: label_information_type
                                
                                	Label\-Info type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: outgoing_label
                                
                                	Outgoing label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_adjacency_flags
                                
                                	MPLS Adjacency flags
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_id_present
                                
                                	Tunnel id present?
                                	**type**\: bool
                                
                                .. attribute:: outgoing_interface
                                
                                	Outgoing interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: outgoing_physical_interface
                                
                                	Outgoing Physical Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: outgoing_parent_interface
                                
                                	Outgoing Parent Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: tunnel_interface
                                
                                	Tunnel Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: label_information_path_index
                                
                                	LabelInformationPathIndex
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_information_next_hop_type
                                
                                	NHinfo Type
                                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.NextHop>`
                                
                                .. attribute:: label_information_next_hop_protocol
                                
                                	The address family (v4/v6) 
                                	**type**\:  :py:class:`Proto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Proto>`
                                
                                .. attribute:: tx_bytes
                                
                                	Bytes transmitted per LSP
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: tx_packets
                                
                                	Packets transmitted per LSP
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: outgoing_interface_string
                                
                                	Output Interface in string format
                                	**type**\: str
                                
                                .. attribute:: outgoing_label_string
                                
                                	Output Label in string format
                                	**type**\: str
                                
                                .. attribute:: prefix_or_id
                                
                                	Prefix Or ID
                                	**type**\: str
                                
                                .. attribute:: label_information_next_hop_string
                                
                                	Next hop address in string format
                                	**type**\: str
                                
                                .. attribute:: label_information_route_version
                                
                                	The version of the route
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: label_information_time_in_milli_seconds
                                
                                	The time of last update in msec
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation, self).__init__()

                                    self.yang_name = "label-information"
                                    self.yang_parent_name = "fwdg"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("label-information-detail", ("label_information_detail", MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.LabelInformationDetail)), ("exact-route-hash-info", ("exact_route_hash_info", MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.ExactRouteHashInfo))])
                                    self._leafs = OrderedDict([
                                        ('label_information_type', (YLeaf(YType.uint32, 'label-information-type'), ['int'])),
                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                        ('outgoing_label', (YLeaf(YType.uint32, 'outgoing-label'), ['int'])),
                                        ('mpls_adjacency_flags', (YLeaf(YType.uint32, 'mpls-adjacency-flags'), ['int'])),
                                        ('tunnel_id_present', (YLeaf(YType.boolean, 'tunnel-id-present'), ['bool'])),
                                        ('outgoing_interface', (YLeaf(YType.str, 'outgoing-interface'), ['str'])),
                                        ('outgoing_physical_interface', (YLeaf(YType.str, 'outgoing-physical-interface'), ['str'])),
                                        ('outgoing_parent_interface', (YLeaf(YType.str, 'outgoing-parent-interface'), ['str'])),
                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                        ('label_information_path_index', (YLeaf(YType.uint32, 'label-information-path-index'), ['int'])),
                                        ('label_information_next_hop_type', (YLeaf(YType.enumeration, 'label-information-next-hop-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'NextHop', '')])),
                                        ('label_information_next_hop_protocol', (YLeaf(YType.enumeration, 'label-information-next-hop-protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'Proto', '')])),
                                        ('tx_bytes', (YLeaf(YType.uint64, 'tx-bytes'), ['int'])),
                                        ('tx_packets', (YLeaf(YType.uint64, 'tx-packets'), ['int'])),
                                        ('outgoing_interface_string', (YLeaf(YType.str, 'outgoing-interface-string'), ['str'])),
                                        ('outgoing_label_string', (YLeaf(YType.str, 'outgoing-label-string'), ['str'])),
                                        ('prefix_or_id', (YLeaf(YType.str, 'prefix-or-id'), ['str'])),
                                        ('label_information_next_hop_string', (YLeaf(YType.str, 'label-information-next-hop-string'), ['str'])),
                                        ('label_information_route_version', (YLeaf(YType.uint64, 'label-information-route-version'), ['int'])),
                                        ('label_information_time_in_milli_seconds', (YLeaf(YType.uint64, 'label-information-time-in-milli-seconds'), ['int'])),
                                    ])
                                    self.label_information_type = None
                                    self.local_label = None
                                    self.outgoing_label = None
                                    self.mpls_adjacency_flags = None
                                    self.tunnel_id_present = None
                                    self.outgoing_interface = None
                                    self.outgoing_physical_interface = None
                                    self.outgoing_parent_interface = None
                                    self.tunnel_interface = None
                                    self.label_information_path_index = None
                                    self.label_information_next_hop_type = None
                                    self.label_information_next_hop_protocol = None
                                    self.tx_bytes = None
                                    self.tx_packets = None
                                    self.outgoing_interface_string = None
                                    self.outgoing_label_string = None
                                    self.prefix_or_id = None
                                    self.label_information_next_hop_string = None
                                    self.label_information_route_version = None
                                    self.label_information_time_in_milli_seconds = None

                                    self.label_information_detail = MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.LabelInformationDetail()
                                    self.label_information_detail.parent = self
                                    self._children_name_map["label_information_detail"] = "label-information-detail"

                                    self.exact_route_hash_info = MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.ExactRouteHashInfo()
                                    self.exact_route_hash_info.parent = self
                                    self._children_name_map["exact_route_hash_info"] = "exact-route-hash-info"
                                    self._segment_path = lambda: "label-information"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation, ['label_information_type', 'local_label', 'outgoing_label', 'mpls_adjacency_flags', 'tunnel_id_present', 'outgoing_interface', 'outgoing_physical_interface', 'outgoing_parent_interface', 'tunnel_interface', 'label_information_path_index', 'label_information_next_hop_type', 'label_information_next_hop_protocol', 'tx_bytes', 'tx_packets', 'outgoing_interface_string', 'outgoing_label_string', 'prefix_or_id', 'label_information_next_hop_string', 'label_information_route_version', 'label_information_time_in_milli_seconds'], name, value)


                                class LabelInformationDetail(Entity):
                                    """
                                    Detail label info
                                    
                                    .. attribute:: l3_mtu
                                    
                                    	L3 MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_encapsulation_size
                                    
                                    	Total encapsulation size\: L2 + MPLS
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_size
                                    
                                    	Length of L2 encapsulation
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: transmit_number_of_packets_switched
                                    
                                    	Number of packets switched
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: transmit_number_of_bytes_switched
                                    
                                    	Number of Bytes switched
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: status
                                    
                                    	Status
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: next_hop_interface
                                    
                                    	Next hop interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: next_hop_protocol
                                    
                                    	The address family (V4/V6) 
                                    	**type**\:  :py:class:`Proto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.Proto>`
                                    
                                    .. attribute:: next_hop_string
                                    
                                    	Next hop address in string format
                                    	**type**\: str
                                    
                                    .. attribute:: label_stack
                                    
                                    	Label stack
                                    	**type**\: list of  		 :py:class:`LabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.LabelInformationDetail.LabelStack>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.LabelInformationDetail, self).__init__()

                                        self.yang_name = "label-information-detail"
                                        self.yang_parent_name = "label-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("label-stack", ("label_stack", MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.LabelInformationDetail.LabelStack))])
                                        self._leafs = OrderedDict([
                                            ('l3_mtu', (YLeaf(YType.uint32, 'l3-mtu'), ['int'])),
                                            ('total_encapsulation_size', (YLeaf(YType.uint32, 'total-encapsulation-size'), ['int'])),
                                            ('mac_size', (YLeaf(YType.uint32, 'mac-size'), ['int'])),
                                            ('transmit_number_of_packets_switched', (YLeaf(YType.uint64, 'transmit-number-of-packets-switched'), ['int'])),
                                            ('transmit_number_of_bytes_switched', (YLeaf(YType.uint64, 'transmit-number-of-bytes-switched'), ['int'])),
                                            ('status', (YLeaf(YType.int32, 'status'), ['int'])),
                                            ('next_hop_interface', (YLeaf(YType.str, 'next-hop-interface'), ['str'])),
                                            ('next_hop_protocol', (YLeaf(YType.enumeration, 'next-hop-protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'Proto', '')])),
                                            ('next_hop_string', (YLeaf(YType.str, 'next-hop-string'), ['str'])),
                                        ])
                                        self.l3_mtu = None
                                        self.total_encapsulation_size = None
                                        self.mac_size = None
                                        self.transmit_number_of_packets_switched = None
                                        self.transmit_number_of_bytes_switched = None
                                        self.status = None
                                        self.next_hop_interface = None
                                        self.next_hop_protocol = None
                                        self.next_hop_string = None

                                        self.label_stack = YList(self)
                                        self._segment_path = lambda: "label-information-detail"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.LabelInformationDetail, ['l3_mtu', 'total_encapsulation_size', 'mac_size', 'transmit_number_of_packets_switched', 'transmit_number_of_bytes_switched', 'status', 'next_hop_interface', 'next_hop_protocol', 'next_hop_string'], name, value)


                                    class LabelStack(Entity):
                                        """
                                        Label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.LabelInformationDetail.LabelStack, self).__init__()

                                            self.yang_name = "label-stack"
                                            self.yang_parent_name = "label-information-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "label-stack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.LabelInformationDetail.LabelStack, ['entry'], name, value)


                                class ExactRouteHashInfo(Entity):
                                    """
                                    Path's Hash info in case of exact\-route command
                                    
                                    .. attribute:: hash_index_is_valid
                                    
                                    	Is Hash Index valid?
                                    	**type**\: bool
                                    
                                    .. attribute:: hash_index
                                    
                                    	Hash Index value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.ExactRouteHashInfo, self).__init__()

                                        self.yang_name = "exact-route-hash-info"
                                        self.yang_parent_name = "label-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hash_index_is_valid', (YLeaf(YType.boolean, 'hash-index-is-valid'), ['bool'])),
                                            ('hash_index', (YLeaf(YType.uint8, 'hash-index'), ['int'])),
                                        ])
                                        self.hash_index_is_valid = None
                                        self.hash_index = None
                                        self._segment_path = lambda: "exact-route-hash-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsForwarding.Nodes.Node.Tunnel.ForwardingTunnels.ForwardingTunnel.Fwdg.LabelInformation.ExactRouteHashInfo, ['hash_index_is_valid', 'hash_index'], name, value)


            class FrrDatabase(Entity):
                """
                MPLS forwarding FRR Database
                
                .. attribute:: frrdb_summary
                
                	MPLS forwarding FRR Database Summary
                	**type**\:  :py:class:`FrrdbSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbSummary>`
                
                .. attribute:: frrdb_protected_interface_table_summaries
                
                	MPLS forwarding FRR Database Protected Interface Summary Table
                	**type**\:  :py:class:`FrrdbProtectedInterfaceTableSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbProtectedInterfaceTableSummaries>`
                
                .. attribute:: frrdb_tunnel_midpoint_summary
                
                	MPLS forwarding FRR Database Tunnel Midpoint Summary
                	**type**\:  :py:class:`FrrdbTunnelMidpointSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpointSummary>`
                
                .. attribute:: frrdb_tunnel_midpoints
                
                	MPLS forwarding FRR Database Tunnel Midpoint Table
                	**type**\:  :py:class:`FrrdbTunnelMidpoints <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints>`
                
                .. attribute:: frrdb_tunnel_heads
                
                	MPLS forwarding FRR Database Tunnel Head Table
                	**type**\:  :py:class:`FrrdbTunnelHeads <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads>`
                
                .. attribute:: frrdb_tunnel_head_summary
                
                	MPLS forwarding FRR Database Tunnel Head Summary
                	**type**\:  :py:class:`FrrdbTunnelHeadSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeadSummary>`
                
                .. attribute:: frrdb_backup_interface_summaries
                
                	MPLS forwarding FRR Database Backup Interface Summary Table
                	**type**\:  :py:class:`FrrdbBackupInterfaceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbBackupInterfaceSummaries>`
                
                

                """

                _prefix = 'fib-common-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(MplsForwarding.Nodes.Node.FrrDatabase, self).__init__()

                    self.yang_name = "frr-database"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("frrdb-summary", ("frrdb_summary", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbSummary)), ("frrdb-protected-interface-table-summaries", ("frrdb_protected_interface_table_summaries", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbProtectedInterfaceTableSummaries)), ("frrdb-tunnel-midpoint-summary", ("frrdb_tunnel_midpoint_summary", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpointSummary)), ("frrdb-tunnel-midpoints", ("frrdb_tunnel_midpoints", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints)), ("frrdb-tunnel-heads", ("frrdb_tunnel_heads", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads)), ("frrdb-tunnel-head-summary", ("frrdb_tunnel_head_summary", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeadSummary)), ("frrdb-backup-interface-summaries", ("frrdb_backup_interface_summaries", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbBackupInterfaceSummaries))])
                    self._leafs = OrderedDict()

                    self.frrdb_summary = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbSummary()
                    self.frrdb_summary.parent = self
                    self._children_name_map["frrdb_summary"] = "frrdb-summary"

                    self.frrdb_protected_interface_table_summaries = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbProtectedInterfaceTableSummaries()
                    self.frrdb_protected_interface_table_summaries.parent = self
                    self._children_name_map["frrdb_protected_interface_table_summaries"] = "frrdb-protected-interface-table-summaries"

                    self.frrdb_tunnel_midpoint_summary = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpointSummary()
                    self.frrdb_tunnel_midpoint_summary.parent = self
                    self._children_name_map["frrdb_tunnel_midpoint_summary"] = "frrdb-tunnel-midpoint-summary"

                    self.frrdb_tunnel_midpoints = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints()
                    self.frrdb_tunnel_midpoints.parent = self
                    self._children_name_map["frrdb_tunnel_midpoints"] = "frrdb-tunnel-midpoints"

                    self.frrdb_tunnel_heads = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads()
                    self.frrdb_tunnel_heads.parent = self
                    self._children_name_map["frrdb_tunnel_heads"] = "frrdb-tunnel-heads"

                    self.frrdb_tunnel_head_summary = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeadSummary()
                    self.frrdb_tunnel_head_summary.parent = self
                    self._children_name_map["frrdb_tunnel_head_summary"] = "frrdb-tunnel-head-summary"

                    self.frrdb_backup_interface_summaries = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbBackupInterfaceSummaries()
                    self.frrdb_backup_interface_summaries.parent = self
                    self._children_name_map["frrdb_backup_interface_summaries"] = "frrdb-backup-interface-summaries"
                    self._segment_path = lambda: "frr-database"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase, [], name, value)


                class FrrdbSummary(Entity):
                    """
                    MPLS forwarding FRR Database Summary
                    
                    .. attribute:: active
                    
                    	Number of FRR rewrites in Active state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ready
                    
                    	Number of FRR rewrites in Ready state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: partial
                    
                    	Number of FRR rewrites in Partial state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: other
                    
                    	Number of FRR rewrites in an unrecognized state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbSummary, self).__init__()

                        self.yang_name = "frrdb-summary"
                        self.yang_parent_name = "frr-database"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('active', (YLeaf(YType.uint32, 'active'), ['int'])),
                            ('ready', (YLeaf(YType.uint32, 'ready'), ['int'])),
                            ('partial', (YLeaf(YType.uint32, 'partial'), ['int'])),
                            ('other', (YLeaf(YType.uint32, 'other'), ['int'])),
                        ])
                        self.active = None
                        self.ready = None
                        self.partial = None
                        self.other = None
                        self._segment_path = lambda: "frrdb-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbSummary, [u'active', u'ready', u'partial', u'other'], name, value)


                class FrrdbProtectedInterfaceTableSummaries(Entity):
                    """
                    MPLS forwarding FRR Database Protected
                    Interface Summary Table
                    
                    .. attribute:: frrdb_protected_interface_table_summary
                    
                    	MPLS forwarding FRR Database Protected Interface Summary
                    	**type**\: list of  		 :py:class:`FrrdbProtectedInterfaceTableSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbProtectedInterfaceTableSummaries.FrrdbProtectedInterfaceTableSummary>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbProtectedInterfaceTableSummaries, self).__init__()

                        self.yang_name = "frrdb-protected-interface-table-summaries"
                        self.yang_parent_name = "frr-database"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("frrdb-protected-interface-table-summary", ("frrdb_protected_interface_table_summary", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbProtectedInterfaceTableSummaries.FrrdbProtectedInterfaceTableSummary))])
                        self._leafs = OrderedDict()

                        self.frrdb_protected_interface_table_summary = YList(self)
                        self._segment_path = lambda: "frrdb-protected-interface-table-summaries"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbProtectedInterfaceTableSummaries, [], name, value)


                    class FrrdbProtectedInterfaceTableSummary(Entity):
                        """
                        MPLS forwarding FRR Database Protected
                        Interface Summary
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface Name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: active
                        
                        	Number of FRR rewrites in Active state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ready
                        
                        	Number of FRR rewrites in Ready state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: partial
                        
                        	Number of FRR rewrites in Partial state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: other
                        
                        	Number of FRR rewrites in an unrecognized state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbProtectedInterfaceTableSummaries.FrrdbProtectedInterfaceTableSummary, self).__init__()

                            self.yang_name = "frrdb-protected-interface-table-summary"
                            self.yang_parent_name = "frrdb-protected-interface-table-summaries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('active', (YLeaf(YType.uint32, 'active'), ['int'])),
                                ('ready', (YLeaf(YType.uint32, 'ready'), ['int'])),
                                ('partial', (YLeaf(YType.uint32, 'partial'), ['int'])),
                                ('other', (YLeaf(YType.uint32, 'other'), ['int'])),
                            ])
                            self.interface_name = None
                            self.active = None
                            self.ready = None
                            self.partial = None
                            self.other = None
                            self._segment_path = lambda: "frrdb-protected-interface-table-summary" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbProtectedInterfaceTableSummaries.FrrdbProtectedInterfaceTableSummary, ['interface_name', u'active', u'ready', u'partial', u'other'], name, value)


                class FrrdbTunnelMidpointSummary(Entity):
                    """
                    MPLS forwarding FRR Database Tunnel Midpoint
                    Summary
                    
                    .. attribute:: active
                    
                    	Number of FRR rewrites in Active state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ready
                    
                    	Number of FRR rewrites in Ready state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: partial
                    
                    	Number of FRR rewrites in Partial state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: other
                    
                    	Number of FRR rewrites in an unrecognized state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpointSummary, self).__init__()

                        self.yang_name = "frrdb-tunnel-midpoint-summary"
                        self.yang_parent_name = "frr-database"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('active', (YLeaf(YType.uint32, 'active'), ['int'])),
                            ('ready', (YLeaf(YType.uint32, 'ready'), ['int'])),
                            ('partial', (YLeaf(YType.uint32, 'partial'), ['int'])),
                            ('other', (YLeaf(YType.uint32, 'other'), ['int'])),
                        ])
                        self.active = None
                        self.ready = None
                        self.partial = None
                        self.other = None
                        self._segment_path = lambda: "frrdb-tunnel-midpoint-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpointSummary, [u'active', u'ready', u'partial', u'other'], name, value)


                class FrrdbTunnelMidpoints(Entity):
                    """
                    MPLS forwarding FRR Database Tunnel Midpoint
                    Table
                    
                    .. attribute:: frrdb_tunnel_midpoint
                    
                    	MPLS forwarding FRR Database Tunnel Midpoint Entry
                    	**type**\: list of  		 :py:class:`FrrdbTunnelMidpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints, self).__init__()

                        self.yang_name = "frrdb-tunnel-midpoints"
                        self.yang_parent_name = "frr-database"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("frrdb-tunnel-midpoint", ("frrdb_tunnel_midpoint", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint))])
                        self._leafs = OrderedDict()

                        self.frrdb_tunnel_midpoint = YList(self)
                        self._segment_path = lambda: "frrdb-tunnel-midpoints"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints, [], name, value)


                    class FrrdbTunnelMidpoint(Entity):
                        """
                        MPLS forwarding FRR Database Tunnel Midpoint
                        Entry
                        
                        .. attribute:: local_label  (key)
                        
                        	Local label value
                        	**type**\: int
                        
                        	**range:** 16..1048575
                        
                        .. attribute:: frr_db
                        
                        	FRR DB
                        	**type**\:  :py:class:`FrrDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb>`
                        
                        .. attribute:: outgoing_lable_string
                        
                        	Output label in string format
                        	**type**\: str
                        
                        .. attribute:: frr_lable_string
                        
                        	FRR label in string format
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint, self).__init__()

                            self.yang_name = "frrdb-tunnel-midpoint"
                            self.yang_parent_name = "frrdb-tunnel-midpoints"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['local_label']
                            self._child_classes = OrderedDict([("frr-db", ("frr_db", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb))])
                            self._leafs = OrderedDict([
                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                ('outgoing_lable_string', (YLeaf(YType.str, 'outgoing-lable-string'), ['str'])),
                                ('frr_lable_string', (YLeaf(YType.str, 'frr-lable-string'), ['str'])),
                            ])
                            self.local_label = None
                            self.outgoing_lable_string = None
                            self.frr_lable_string = None

                            self.frr_db = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb()
                            self.frr_db.parent = self
                            self._children_name_map["frr_db"] = "frr-db"
                            self._segment_path = lambda: "frrdb-tunnel-midpoint" + "[local-label='" + str(self.local_label) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint, ['local_label', 'outgoing_lable_string', 'frr_lable_string'], name, value)


                        class FrrDb(Entity):
                            """
                            FRR DB
                            
                            .. attribute:: frr_entry_id
                            
                            	FRR entry ID
                            	**type**\:  :py:class:`FrrEntryId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId>`
                            
                            .. attribute:: tunnel_interface_name
                            
                            	Tunnel interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: input_label
                            
                            	Input label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: outgoing_interface
                            
                            	Outgoing interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: outgoing_label
                            
                            	Outgoing label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: frr_interface_name
                            
                            	FRR interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: frr_label
                            
                            	FRR output label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: entry_frr_state
                            
                            	MPLS FRR entry state
                            	**type**\:  :py:class:`MgmtFibMplsFrrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MgmtFibMplsFrrState>`
                            
                            .. attribute:: frr_next_hop_ipv4_address
                            
                            	Next hop IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_mldp_lsp
                            
                            	MLDP or P2MP\-TE
                            	**type**\: bool
                            
                            .. attribute:: is_multicast_tunnel
                            
                            	Multicast tunnel
                            	**type**\: bool
                            
                            .. attribute:: multicast_tunnel_legs
                            
                            	Number of legs in MCAST tunnel
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_leg
                            
                            	MCAST legs
                            	**type**\: list of  		 :py:class:`MulticastLeg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb, self).__init__()

                                self.yang_name = "frr-db"
                                self.yang_parent_name = "frrdb-tunnel-midpoint"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("frr-entry-id", ("frr_entry_id", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId)), ("multicast-leg", ("multicast_leg", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg))])
                                self._leafs = OrderedDict([
                                    ('tunnel_interface_name', (YLeaf(YType.str, 'tunnel-interface-name'), ['str'])),
                                    ('input_label', (YLeaf(YType.uint32, 'input-label'), ['int'])),
                                    ('outgoing_interface', (YLeaf(YType.str, 'outgoing-interface'), ['str'])),
                                    ('outgoing_label', (YLeaf(YType.uint32, 'outgoing-label'), ['int'])),
                                    ('frr_interface_name', (YLeaf(YType.str, 'frr-interface-name'), ['str'])),
                                    ('frr_label', (YLeaf(YType.uint32, 'frr-label'), ['int'])),
                                    ('entry_frr_state', (YLeaf(YType.enumeration, 'entry-frr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'MgmtFibMplsFrrState', '')])),
                                    ('frr_next_hop_ipv4_address', (YLeaf(YType.str, 'frr-next-hop-ipv4-address'), ['str'])),
                                    ('is_mldp_lsp', (YLeaf(YType.boolean, 'is-mldp-lsp'), ['bool'])),
                                    ('is_multicast_tunnel', (YLeaf(YType.boolean, 'is-multicast-tunnel'), ['bool'])),
                                    ('multicast_tunnel_legs', (YLeaf(YType.uint32, 'multicast-tunnel-legs'), ['int'])),
                                ])
                                self.tunnel_interface_name = None
                                self.input_label = None
                                self.outgoing_interface = None
                                self.outgoing_label = None
                                self.frr_interface_name = None
                                self.frr_label = None
                                self.entry_frr_state = None
                                self.frr_next_hop_ipv4_address = None
                                self.is_mldp_lsp = None
                                self.is_multicast_tunnel = None
                                self.multicast_tunnel_legs = None

                                self.frr_entry_id = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId()
                                self.frr_entry_id.parent = self
                                self._children_name_map["frr_entry_id"] = "frr-entry-id"

                                self.multicast_leg = YList(self)
                                self._segment_path = lambda: "frr-db"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb, [u'tunnel_interface_name', u'input_label', u'outgoing_interface', u'outgoing_label', u'frr_interface_name', u'frr_label', u'entry_frr_state', u'frr_next_hop_ipv4_address', u'is_mldp_lsp', u'is_multicast_tunnel', u'multicast_tunnel_legs'], name, value)


                            class FrrEntryId(Entity):
                                """
                                FRR entry ID
                                
                                .. attribute:: head
                                
                                	head
                                	**type**\:  :py:class:`Head <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId.Head>`
                                
                                .. attribute:: midpoint
                                
                                	midpoint
                                	**type**\:  :py:class:`Midpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId.Midpoint>`
                                
                                .. attribute:: role
                                
                                	Role
                                	**type**\:  :py:class:`MgmtFibMplsLspRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MgmtFibMplsLspRole>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId, self).__init__()

                                    self.yang_name = "frr-entry-id"
                                    self.yang_parent_name = "frr-db"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("head", ("head", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId.Head)), ("midpoint", ("midpoint", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId.Midpoint))])
                                    self._leafs = OrderedDict([
                                        ('role', (YLeaf(YType.enumeration, 'role'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'MgmtFibMplsLspRole', '')])),
                                    ])
                                    self.role = None

                                    self.head = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId.Head()
                                    self.head.parent = self
                                    self._children_name_map["head"] = "head"

                                    self.midpoint = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId.Midpoint()
                                    self.midpoint.parent = self
                                    self._children_name_map["midpoint"] = "midpoint"
                                    self._segment_path = lambda: "frr-entry-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId, [u'role'], name, value)


                                class Head(Entity):
                                    """
                                    head
                                    
                                    .. attribute:: destination_prefix
                                    
                                    	Destination prefix
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: destination_prefix_length
                                    
                                    	Destination prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId.Head, self).__init__()

                                        self.yang_name = "head"
                                        self.yang_parent_name = "frr-entry-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('destination_prefix', (YLeaf(YType.str, 'destination-prefix'), ['str'])),
                                            ('destination_prefix_length', (YLeaf(YType.uint32, 'destination-prefix-length'), ['int'])),
                                        ])
                                        self.destination_prefix = None
                                        self.destination_prefix_length = None
                                        self._segment_path = lambda: "head"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId.Head, [u'destination_prefix', u'destination_prefix_length'], name, value)


                                class Midpoint(Entity):
                                    """
                                    midpoint
                                    
                                    .. attribute:: source_address
                                    
                                    	Source IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lspid
                                    
                                    	LSP ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tunnel_id
                                    
                                    	Tunnel ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId.Midpoint, self).__init__()

                                        self.yang_name = "midpoint"
                                        self.yang_parent_name = "frr-entry-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                            ('lspid', (YLeaf(YType.uint32, 'lspid'), ['int'])),
                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                        ])
                                        self.source_address = None
                                        self.lspid = None
                                        self.tunnel_id = None
                                        self._segment_path = lambda: "midpoint"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.FrrEntryId.Midpoint, [u'source_address', u'lspid', u'tunnel_id'], name, value)


                            class MulticastLeg(Entity):
                                """
                                MCAST legs
                                
                                .. attribute:: frr_entry_id
                                
                                	FRR entry ID
                                	**type**\:  :py:class:`FrrEntryId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId>`
                                
                                .. attribute:: tunnel_interface_name
                                
                                	Tunnel interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: input_label
                                
                                	Input label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: outgoing_interface
                                
                                	Outgoing interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: outgoing_label
                                
                                	Outgoing label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: frr_interface_name
                                
                                	FRR interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: frr_label
                                
                                	FRR output label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: entry_frr_state
                                
                                	MPLS FRR entry state
                                	**type**\:  :py:class:`MgmtFibMplsFrrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MgmtFibMplsFrrState>`
                                
                                .. attribute:: frr_next_hop_ipv4_address
                                
                                	Next hop IPv4 address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_mldp_lsp
                                
                                	MLDP or P2MP\-TE
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg, self).__init__()

                                    self.yang_name = "multicast-leg"
                                    self.yang_parent_name = "frr-db"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("frr-entry-id", ("frr_entry_id", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId))])
                                    self._leafs = OrderedDict([
                                        ('tunnel_interface_name', (YLeaf(YType.str, 'tunnel-interface-name'), ['str'])),
                                        ('input_label', (YLeaf(YType.uint32, 'input-label'), ['int'])),
                                        ('outgoing_interface', (YLeaf(YType.str, 'outgoing-interface'), ['str'])),
                                        ('outgoing_label', (YLeaf(YType.uint32, 'outgoing-label'), ['int'])),
                                        ('frr_interface_name', (YLeaf(YType.str, 'frr-interface-name'), ['str'])),
                                        ('frr_label', (YLeaf(YType.uint32, 'frr-label'), ['int'])),
                                        ('entry_frr_state', (YLeaf(YType.enumeration, 'entry-frr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'MgmtFibMplsFrrState', '')])),
                                        ('frr_next_hop_ipv4_address', (YLeaf(YType.str, 'frr-next-hop-ipv4-address'), ['str'])),
                                        ('is_mldp_lsp', (YLeaf(YType.boolean, 'is-mldp-lsp'), ['bool'])),
                                    ])
                                    self.tunnel_interface_name = None
                                    self.input_label = None
                                    self.outgoing_interface = None
                                    self.outgoing_label = None
                                    self.frr_interface_name = None
                                    self.frr_label = None
                                    self.entry_frr_state = None
                                    self.frr_next_hop_ipv4_address = None
                                    self.is_mldp_lsp = None

                                    self.frr_entry_id = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId()
                                    self.frr_entry_id.parent = self
                                    self._children_name_map["frr_entry_id"] = "frr-entry-id"
                                    self._segment_path = lambda: "multicast-leg"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg, [u'tunnel_interface_name', u'input_label', u'outgoing_interface', u'outgoing_label', u'frr_interface_name', u'frr_label', u'entry_frr_state', u'frr_next_hop_ipv4_address', u'is_mldp_lsp'], name, value)


                                class FrrEntryId(Entity):
                                    """
                                    FRR entry ID
                                    
                                    .. attribute:: head
                                    
                                    	head
                                    	**type**\:  :py:class:`Head <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId.Head>`
                                    
                                    .. attribute:: midpoint
                                    
                                    	midpoint
                                    	**type**\:  :py:class:`Midpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId.Midpoint>`
                                    
                                    .. attribute:: role
                                    
                                    	Role
                                    	**type**\:  :py:class:`MgmtFibMplsLspRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MgmtFibMplsLspRole>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId, self).__init__()

                                        self.yang_name = "frr-entry-id"
                                        self.yang_parent_name = "multicast-leg"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("head", ("head", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId.Head)), ("midpoint", ("midpoint", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId.Midpoint))])
                                        self._leafs = OrderedDict([
                                            ('role', (YLeaf(YType.enumeration, 'role'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'MgmtFibMplsLspRole', '')])),
                                        ])
                                        self.role = None

                                        self.head = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId.Head()
                                        self.head.parent = self
                                        self._children_name_map["head"] = "head"

                                        self.midpoint = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId.Midpoint()
                                        self.midpoint.parent = self
                                        self._children_name_map["midpoint"] = "midpoint"
                                        self._segment_path = lambda: "frr-entry-id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId, [u'role'], name, value)


                                    class Head(Entity):
                                        """
                                        head
                                        
                                        .. attribute:: destination_prefix
                                        
                                        	Destination prefix
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: destination_prefix_length
                                        
                                        	Destination prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId.Head, self).__init__()

                                            self.yang_name = "head"
                                            self.yang_parent_name = "frr-entry-id"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('destination_prefix', (YLeaf(YType.str, 'destination-prefix'), ['str'])),
                                                ('destination_prefix_length', (YLeaf(YType.uint32, 'destination-prefix-length'), ['int'])),
                                            ])
                                            self.destination_prefix = None
                                            self.destination_prefix_length = None
                                            self._segment_path = lambda: "head"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId.Head, [u'destination_prefix', u'destination_prefix_length'], name, value)


                                    class Midpoint(Entity):
                                        """
                                        midpoint
                                        
                                        .. attribute:: source_address
                                        
                                        	Source IPv4 address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: lspid
                                        
                                        	LSP ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId.Midpoint, self).__init__()

                                            self.yang_name = "midpoint"
                                            self.yang_parent_name = "frr-entry-id"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ('lspid', (YLeaf(YType.uint32, 'lspid'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                            ])
                                            self.source_address = None
                                            self.lspid = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "midpoint"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelMidpoints.FrrdbTunnelMidpoint.FrrDb.MulticastLeg.FrrEntryId.Midpoint, [u'source_address', u'lspid', u'tunnel_id'], name, value)


                class FrrdbTunnelHeads(Entity):
                    """
                    MPLS forwarding FRR Database Tunnel Head
                    Table
                    
                    .. attribute:: frrdb_tunnel_head
                    
                    	MPLS forwarding FRR Database Tunnel Head Entry
                    	**type**\: list of  		 :py:class:`FrrdbTunnelHead <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads, self).__init__()

                        self.yang_name = "frrdb-tunnel-heads"
                        self.yang_parent_name = "frr-database"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("frrdb-tunnel-head", ("frrdb_tunnel_head", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead))])
                        self._leafs = OrderedDict()

                        self.frrdb_tunnel_head = YList(self)
                        self._segment_path = lambda: "frrdb-tunnel-heads"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads, [], name, value)


                    class FrrdbTunnelHead(Entity):
                        """
                        MPLS forwarding FRR Database Tunnel Head
                        Entry
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface Name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: frr_db
                        
                        	FRR DB
                        	**type**\:  :py:class:`FrrDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb>`
                        
                        .. attribute:: outgoing_lable_string
                        
                        	Output label in string format
                        	**type**\: str
                        
                        .. attribute:: frr_lable_string
                        
                        	FRR label in string format
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead, self).__init__()

                            self.yang_name = "frrdb-tunnel-head"
                            self.yang_parent_name = "frrdb-tunnel-heads"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("frr-db", ("frr_db", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('outgoing_lable_string', (YLeaf(YType.str, 'outgoing-lable-string'), ['str'])),
                                ('frr_lable_string', (YLeaf(YType.str, 'frr-lable-string'), ['str'])),
                            ])
                            self.interface_name = None
                            self.outgoing_lable_string = None
                            self.frr_lable_string = None

                            self.frr_db = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb()
                            self.frr_db.parent = self
                            self._children_name_map["frr_db"] = "frr-db"
                            self._segment_path = lambda: "frrdb-tunnel-head" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead, ['interface_name', 'outgoing_lable_string', 'frr_lable_string'], name, value)


                        class FrrDb(Entity):
                            """
                            FRR DB
                            
                            .. attribute:: frr_entry_id
                            
                            	FRR entry ID
                            	**type**\:  :py:class:`FrrEntryId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId>`
                            
                            .. attribute:: tunnel_interface_name
                            
                            	Tunnel interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: input_label
                            
                            	Input label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: outgoing_interface
                            
                            	Outgoing interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: outgoing_label
                            
                            	Outgoing label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: frr_interface_name
                            
                            	FRR interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: frr_label
                            
                            	FRR output label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: entry_frr_state
                            
                            	MPLS FRR entry state
                            	**type**\:  :py:class:`MgmtFibMplsFrrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MgmtFibMplsFrrState>`
                            
                            .. attribute:: frr_next_hop_ipv4_address
                            
                            	Next hop IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_mldp_lsp
                            
                            	MLDP or P2MP\-TE
                            	**type**\: bool
                            
                            .. attribute:: is_multicast_tunnel
                            
                            	Multicast tunnel
                            	**type**\: bool
                            
                            .. attribute:: multicast_tunnel_legs
                            
                            	Number of legs in MCAST tunnel
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: multicast_leg
                            
                            	MCAST legs
                            	**type**\: list of  		 :py:class:`MulticastLeg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg>`
                            
                            

                            """

                            _prefix = 'fib-common-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb, self).__init__()

                                self.yang_name = "frr-db"
                                self.yang_parent_name = "frrdb-tunnel-head"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("frr-entry-id", ("frr_entry_id", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId)), ("multicast-leg", ("multicast_leg", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg))])
                                self._leafs = OrderedDict([
                                    ('tunnel_interface_name', (YLeaf(YType.str, 'tunnel-interface-name'), ['str'])),
                                    ('input_label', (YLeaf(YType.uint32, 'input-label'), ['int'])),
                                    ('outgoing_interface', (YLeaf(YType.str, 'outgoing-interface'), ['str'])),
                                    ('outgoing_label', (YLeaf(YType.uint32, 'outgoing-label'), ['int'])),
                                    ('frr_interface_name', (YLeaf(YType.str, 'frr-interface-name'), ['str'])),
                                    ('frr_label', (YLeaf(YType.uint32, 'frr-label'), ['int'])),
                                    ('entry_frr_state', (YLeaf(YType.enumeration, 'entry-frr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'MgmtFibMplsFrrState', '')])),
                                    ('frr_next_hop_ipv4_address', (YLeaf(YType.str, 'frr-next-hop-ipv4-address'), ['str'])),
                                    ('is_mldp_lsp', (YLeaf(YType.boolean, 'is-mldp-lsp'), ['bool'])),
                                    ('is_multicast_tunnel', (YLeaf(YType.boolean, 'is-multicast-tunnel'), ['bool'])),
                                    ('multicast_tunnel_legs', (YLeaf(YType.uint32, 'multicast-tunnel-legs'), ['int'])),
                                ])
                                self.tunnel_interface_name = None
                                self.input_label = None
                                self.outgoing_interface = None
                                self.outgoing_label = None
                                self.frr_interface_name = None
                                self.frr_label = None
                                self.entry_frr_state = None
                                self.frr_next_hop_ipv4_address = None
                                self.is_mldp_lsp = None
                                self.is_multicast_tunnel = None
                                self.multicast_tunnel_legs = None

                                self.frr_entry_id = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId()
                                self.frr_entry_id.parent = self
                                self._children_name_map["frr_entry_id"] = "frr-entry-id"

                                self.multicast_leg = YList(self)
                                self._segment_path = lambda: "frr-db"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb, [u'tunnel_interface_name', u'input_label', u'outgoing_interface', u'outgoing_label', u'frr_interface_name', u'frr_label', u'entry_frr_state', u'frr_next_hop_ipv4_address', u'is_mldp_lsp', u'is_multicast_tunnel', u'multicast_tunnel_legs'], name, value)


                            class FrrEntryId(Entity):
                                """
                                FRR entry ID
                                
                                .. attribute:: head
                                
                                	head
                                	**type**\:  :py:class:`Head <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId.Head>`
                                
                                .. attribute:: midpoint
                                
                                	midpoint
                                	**type**\:  :py:class:`Midpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId.Midpoint>`
                                
                                .. attribute:: role
                                
                                	Role
                                	**type**\:  :py:class:`MgmtFibMplsLspRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MgmtFibMplsLspRole>`
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId, self).__init__()

                                    self.yang_name = "frr-entry-id"
                                    self.yang_parent_name = "frr-db"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("head", ("head", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId.Head)), ("midpoint", ("midpoint", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId.Midpoint))])
                                    self._leafs = OrderedDict([
                                        ('role', (YLeaf(YType.enumeration, 'role'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'MgmtFibMplsLspRole', '')])),
                                    ])
                                    self.role = None

                                    self.head = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId.Head()
                                    self.head.parent = self
                                    self._children_name_map["head"] = "head"

                                    self.midpoint = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId.Midpoint()
                                    self.midpoint.parent = self
                                    self._children_name_map["midpoint"] = "midpoint"
                                    self._segment_path = lambda: "frr-entry-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId, [u'role'], name, value)


                                class Head(Entity):
                                    """
                                    head
                                    
                                    .. attribute:: destination_prefix
                                    
                                    	Destination prefix
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: destination_prefix_length
                                    
                                    	Destination prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId.Head, self).__init__()

                                        self.yang_name = "head"
                                        self.yang_parent_name = "frr-entry-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('destination_prefix', (YLeaf(YType.str, 'destination-prefix'), ['str'])),
                                            ('destination_prefix_length', (YLeaf(YType.uint32, 'destination-prefix-length'), ['int'])),
                                        ])
                                        self.destination_prefix = None
                                        self.destination_prefix_length = None
                                        self._segment_path = lambda: "head"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId.Head, [u'destination_prefix', u'destination_prefix_length'], name, value)


                                class Midpoint(Entity):
                                    """
                                    midpoint
                                    
                                    .. attribute:: source_address
                                    
                                    	Source IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lspid
                                    
                                    	LSP ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tunnel_id
                                    
                                    	Tunnel ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId.Midpoint, self).__init__()

                                        self.yang_name = "midpoint"
                                        self.yang_parent_name = "frr-entry-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                            ('lspid', (YLeaf(YType.uint32, 'lspid'), ['int'])),
                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                        ])
                                        self.source_address = None
                                        self.lspid = None
                                        self.tunnel_id = None
                                        self._segment_path = lambda: "midpoint"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.FrrEntryId.Midpoint, [u'source_address', u'lspid', u'tunnel_id'], name, value)


                            class MulticastLeg(Entity):
                                """
                                MCAST legs
                                
                                .. attribute:: frr_entry_id
                                
                                	FRR entry ID
                                	**type**\:  :py:class:`FrrEntryId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId>`
                                
                                .. attribute:: tunnel_interface_name
                                
                                	Tunnel interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: input_label
                                
                                	Input label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: outgoing_interface
                                
                                	Outgoing interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: outgoing_label
                                
                                	Outgoing label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: frr_interface_name
                                
                                	FRR interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: frr_label
                                
                                	FRR output label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: entry_frr_state
                                
                                	MPLS FRR entry state
                                	**type**\:  :py:class:`MgmtFibMplsFrrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MgmtFibMplsFrrState>`
                                
                                .. attribute:: frr_next_hop_ipv4_address
                                
                                	Next hop IPv4 address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_mldp_lsp
                                
                                	MLDP or P2MP\-TE
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'fib-common-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg, self).__init__()

                                    self.yang_name = "multicast-leg"
                                    self.yang_parent_name = "frr-db"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("frr-entry-id", ("frr_entry_id", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId))])
                                    self._leafs = OrderedDict([
                                        ('tunnel_interface_name', (YLeaf(YType.str, 'tunnel-interface-name'), ['str'])),
                                        ('input_label', (YLeaf(YType.uint32, 'input-label'), ['int'])),
                                        ('outgoing_interface', (YLeaf(YType.str, 'outgoing-interface'), ['str'])),
                                        ('outgoing_label', (YLeaf(YType.uint32, 'outgoing-label'), ['int'])),
                                        ('frr_interface_name', (YLeaf(YType.str, 'frr-interface-name'), ['str'])),
                                        ('frr_label', (YLeaf(YType.uint32, 'frr-label'), ['int'])),
                                        ('entry_frr_state', (YLeaf(YType.enumeration, 'entry-frr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'MgmtFibMplsFrrState', '')])),
                                        ('frr_next_hop_ipv4_address', (YLeaf(YType.str, 'frr-next-hop-ipv4-address'), ['str'])),
                                        ('is_mldp_lsp', (YLeaf(YType.boolean, 'is-mldp-lsp'), ['bool'])),
                                    ])
                                    self.tunnel_interface_name = None
                                    self.input_label = None
                                    self.outgoing_interface = None
                                    self.outgoing_label = None
                                    self.frr_interface_name = None
                                    self.frr_label = None
                                    self.entry_frr_state = None
                                    self.frr_next_hop_ipv4_address = None
                                    self.is_mldp_lsp = None

                                    self.frr_entry_id = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId()
                                    self.frr_entry_id.parent = self
                                    self._children_name_map["frr_entry_id"] = "frr-entry-id"
                                    self._segment_path = lambda: "multicast-leg"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg, [u'tunnel_interface_name', u'input_label', u'outgoing_interface', u'outgoing_label', u'frr_interface_name', u'frr_label', u'entry_frr_state', u'frr_next_hop_ipv4_address', u'is_mldp_lsp'], name, value)


                                class FrrEntryId(Entity):
                                    """
                                    FRR entry ID
                                    
                                    .. attribute:: head
                                    
                                    	head
                                    	**type**\:  :py:class:`Head <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId.Head>`
                                    
                                    .. attribute:: midpoint
                                    
                                    	midpoint
                                    	**type**\:  :py:class:`Midpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId.Midpoint>`
                                    
                                    .. attribute:: role
                                    
                                    	Role
                                    	**type**\:  :py:class:`MgmtFibMplsLspRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MgmtFibMplsLspRole>`
                                    
                                    

                                    """

                                    _prefix = 'fib-common-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId, self).__init__()

                                        self.yang_name = "frr-entry-id"
                                        self.yang_parent_name = "multicast-leg"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("head", ("head", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId.Head)), ("midpoint", ("midpoint", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId.Midpoint))])
                                        self._leafs = OrderedDict([
                                            ('role', (YLeaf(YType.enumeration, 'role'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper', 'MgmtFibMplsLspRole', '')])),
                                        ])
                                        self.role = None

                                        self.head = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId.Head()
                                        self.head.parent = self
                                        self._children_name_map["head"] = "head"

                                        self.midpoint = MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId.Midpoint()
                                        self.midpoint.parent = self
                                        self._children_name_map["midpoint"] = "midpoint"
                                        self._segment_path = lambda: "frr-entry-id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId, [u'role'], name, value)


                                    class Head(Entity):
                                        """
                                        head
                                        
                                        .. attribute:: destination_prefix
                                        
                                        	Destination prefix
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: destination_prefix_length
                                        
                                        	Destination prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId.Head, self).__init__()

                                            self.yang_name = "head"
                                            self.yang_parent_name = "frr-entry-id"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('destination_prefix', (YLeaf(YType.str, 'destination-prefix'), ['str'])),
                                                ('destination_prefix_length', (YLeaf(YType.uint32, 'destination-prefix-length'), ['int'])),
                                            ])
                                            self.destination_prefix = None
                                            self.destination_prefix_length = None
                                            self._segment_path = lambda: "head"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId.Head, [u'destination_prefix', u'destination_prefix_length'], name, value)


                                    class Midpoint(Entity):
                                        """
                                        midpoint
                                        
                                        .. attribute:: source_address
                                        
                                        	Source IPv4 address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: lspid
                                        
                                        	LSP ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'fib-common-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId.Midpoint, self).__init__()

                                            self.yang_name = "midpoint"
                                            self.yang_parent_name = "frr-entry-id"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ('lspid', (YLeaf(YType.uint32, 'lspid'), ['int'])),
                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                            ])
                                            self.source_address = None
                                            self.lspid = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "midpoint"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeads.FrrdbTunnelHead.FrrDb.MulticastLeg.FrrEntryId.Midpoint, [u'source_address', u'lspid', u'tunnel_id'], name, value)


                class FrrdbTunnelHeadSummary(Entity):
                    """
                    MPLS forwarding FRR Database Tunnel Head
                    Summary
                    
                    .. attribute:: active
                    
                    	Number of FRR rewrites in Active state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ready
                    
                    	Number of FRR rewrites in Ready state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: partial
                    
                    	Number of FRR rewrites in Partial state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: other
                    
                    	Number of FRR rewrites in an unrecognized state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeadSummary, self).__init__()

                        self.yang_name = "frrdb-tunnel-head-summary"
                        self.yang_parent_name = "frr-database"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('active', (YLeaf(YType.uint32, 'active'), ['int'])),
                            ('ready', (YLeaf(YType.uint32, 'ready'), ['int'])),
                            ('partial', (YLeaf(YType.uint32, 'partial'), ['int'])),
                            ('other', (YLeaf(YType.uint32, 'other'), ['int'])),
                        ])
                        self.active = None
                        self.ready = None
                        self.partial = None
                        self.other = None
                        self._segment_path = lambda: "frrdb-tunnel-head-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbTunnelHeadSummary, [u'active', u'ready', u'partial', u'other'], name, value)


                class FrrdbBackupInterfaceSummaries(Entity):
                    """
                    MPLS forwarding FRR Database Backup Interface
                    Summary Table
                    
                    .. attribute:: frrdb_backup_interface_summary
                    
                    	MPLS forwarding FRR Database Backup Interface Summary
                    	**type**\: list of  		 :py:class:`FrrdbBackupInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_fib_common_oper.MplsForwarding.Nodes.Node.FrrDatabase.FrrdbBackupInterfaceSummaries.FrrdbBackupInterfaceSummary>`
                    
                    

                    """

                    _prefix = 'fib-common-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbBackupInterfaceSummaries, self).__init__()

                        self.yang_name = "frrdb-backup-interface-summaries"
                        self.yang_parent_name = "frr-database"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("frrdb-backup-interface-summary", ("frrdb_backup_interface_summary", MplsForwarding.Nodes.Node.FrrDatabase.FrrdbBackupInterfaceSummaries.FrrdbBackupInterfaceSummary))])
                        self._leafs = OrderedDict()

                        self.frrdb_backup_interface_summary = YList(self)
                        self._segment_path = lambda: "frrdb-backup-interface-summaries"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbBackupInterfaceSummaries, [], name, value)


                    class FrrdbBackupInterfaceSummary(Entity):
                        """
                        MPLS forwarding FRR Database Backup
                        Interface Summary
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface Name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: active
                        
                        	Number of FRR rewrites in Active state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ready
                        
                        	Number of FRR rewrites in Ready state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: partial
                        
                        	Number of FRR rewrites in Partial state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: other
                        
                        	Number of FRR rewrites in an unrecognized state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'fib-common-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbBackupInterfaceSummaries.FrrdbBackupInterfaceSummary, self).__init__()

                            self.yang_name = "frrdb-backup-interface-summary"
                            self.yang_parent_name = "frrdb-backup-interface-summaries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('active', (YLeaf(YType.uint32, 'active'), ['int'])),
                                ('ready', (YLeaf(YType.uint32, 'ready'), ['int'])),
                                ('partial', (YLeaf(YType.uint32, 'partial'), ['int'])),
                                ('other', (YLeaf(YType.uint32, 'other'), ['int'])),
                            ])
                            self.interface_name = None
                            self.active = None
                            self.ready = None
                            self.partial = None
                            self.other = None
                            self._segment_path = lambda: "frrdb-backup-interface-summary" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(MplsForwarding.Nodes.Node.FrrDatabase.FrrdbBackupInterfaceSummaries.FrrdbBackupInterfaceSummary, ['interface_name', u'active', u'ready', u'partial', u'other'], name, value)

    def clone_ptr(self):
        self._top_entity = MplsForwarding()
        return self._top_entity

