""" Cisco_IOS_XR_ip_rib_ipv6_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ip\-rib\-ipv6 package operational data.

This module contains definitions
for the following management objects\:
  ipv6\-rib\: RIB operational data
  ipv6\-rib\-stdby\: ipv6 rib stdby

Copyright (c) 2013\-2018 by Cisco Systems, Inc.
All rights reserved.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class RibEdmNnh(Enum):
    """
    RibEdmNnh (Enum Class)

    Rib edm nnh

    .. data:: unknown = 0

    	Unknown - Invalid

    .. data:: ipv4_address = 1

    	IPv4 Address

    .. data:: if_index = 2

    	Interface Index

    """

    unknown = Enum.YLeaf(0, "unknown")

    ipv4_address = Enum.YLeaf(1, "ipv4-address")

    if_index = Enum.YLeaf(2, "if-index")



class Ipv6Rib(Entity):
    """
    RIB operational data
    
    .. attribute:: rib_table_ids
    
    	RIB table
    	**type**\:  :py:class:`RibTableIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds>`
    
    .. attribute:: vrfs
    
    	VRF table
    	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs>`
    
    

    """

    _prefix = 'ip-rib-ipv6-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(Ipv6Rib, self).__init__()
        self._top_entity = None

        self.yang_name = "ipv6-rib"
        self.yang_parent_name = "Cisco-IOS-XR-ip-rib-ipv6-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("rib-table-ids", ("rib_table_ids", Ipv6Rib.RibTableIds)), ("vrfs", ("vrfs", Ipv6Rib.Vrfs))])
        self._leafs = OrderedDict()

        self.rib_table_ids = Ipv6Rib.RibTableIds()
        self.rib_table_ids.parent = self
        self._children_name_map["rib_table_ids"] = "rib-table-ids"

        self.vrfs = Ipv6Rib.Vrfs()
        self.vrfs.parent = self
        self._children_name_map["vrfs"] = "vrfs"
        self._segment_path = lambda: "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(Ipv6Rib, [], name, value)


    class RibTableIds(Entity):
        """
        RIB table
        
        .. attribute:: rib_table_id
        
        	Specific Table
        	**type**\: list of  		 :py:class:`RibTableId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId>`
        
        

        """

        _prefix = 'ip-rib-ipv6-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Ipv6Rib.RibTableIds, self).__init__()

            self.yang_name = "rib-table-ids"
            self.yang_parent_name = "ipv6-rib"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("rib-table-id", ("rib_table_id", Ipv6Rib.RibTableIds.RibTableId))])
            self._leafs = OrderedDict()

            self.rib_table_id = YList(self)
            self._segment_path = lambda: "rib-table-ids"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Ipv6Rib.RibTableIds, [], name, value)


        class RibTableId(Entity):
            """
            Specific Table
            
            .. attribute:: tableid  (key)
            
            	Table ID
            	**type**\: str
            
            	**pattern:** [0\-9a\-fA\-F]{1,8}
            
            .. attribute:: information
            
            	Table related Information
            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.Information>`
            
            .. attribute:: summary_protos
            
            	RIB table summary
            	**type**\:  :py:class:`SummaryProtos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos>`
            
            .. attribute:: rib_table_itf_hndls
            
            	RIB table interface
            	**type**\:  :py:class:`RibTableItfHndls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls>`
            
            

            """

            _prefix = 'ip-rib-ipv6-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Ipv6Rib.RibTableIds.RibTableId, self).__init__()

                self.yang_name = "rib-table-id"
                self.yang_parent_name = "rib-table-ids"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['tableid']
                self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.RibTableIds.RibTableId.Information)), ("summary-protos", ("summary_protos", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos)), ("rib-table-itf-hndls", ("rib_table_itf_hndls", Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls))])
                self._leafs = OrderedDict([
                    ('tableid', (YLeaf(YType.str, 'tableid'), ['str'])),
                ])
                self.tableid = None

                self.information = Ipv6Rib.RibTableIds.RibTableId.Information()
                self.information.parent = self
                self._children_name_map["information"] = "information"

                self.summary_protos = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos()
                self.summary_protos.parent = self
                self._children_name_map["summary_protos"] = "summary-protos"

                self.rib_table_itf_hndls = Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls()
                self.rib_table_itf_hndls.parent = self
                self._children_name_map["rib_table_itf_hndls"] = "rib-table-itf-hndls"
                self._segment_path = lambda: "rib-table-id" + "[tableid='" + str(self.tableid) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib/rib-table-ids/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId, ['tableid'], name, value)


            class Information(Entity):
                """
                Table related Information
                
                .. attribute:: tableid
                
                	Table id
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: afi
                
                	Address Family
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: safi
                
                	sub Address Family
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_name
                
                	VRF Name of the table
                	**type**\: str
                
                .. attribute:: table_name
                
                	Name of the table
                	**type**\: str
                
                .. attribute:: version
                
                	Table version
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: conf_prefix_limit
                
                	Configured prefix limit
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: current_prefix_count
                
                	Num prefixes in table
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_svdlcl_prefix
                
                	Num SVD local prefixes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_svdrem_prefix
                
                	Num SVD remote prefixes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_version
                
                	Version no. of the table
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: prefix_limit_notified
                
                	Prefix limit state indicator
                	**type**\: bool
                
                .. attribute:: fwd_referenced
                
                	Table in fwd reference state?
                	**type**\: bool
                
                .. attribute:: deleted
                
                	Table deleted?
                	**type**\: bool
                
                .. attribute:: initial_converge
                
                	Table has reached convergence
                	**type**\: bool
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Rib.RibTableIds.RibTableId.Information, self).__init__()

                    self.yang_name = "information"
                    self.yang_parent_name = "rib-table-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('tableid', (YLeaf(YType.uint32, 'tableid'), ['int'])),
                        ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                        ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                        ('version', (YLeaf(YType.uint64, 'version'), ['int'])),
                        ('conf_prefix_limit', (YLeaf(YType.uint32, 'conf-prefix-limit'), ['int'])),
                        ('current_prefix_count', (YLeaf(YType.uint32, 'current-prefix-count'), ['int'])),
                        ('num_svdlcl_prefix', (YLeaf(YType.uint32, 'num-svdlcl-prefix'), ['int'])),
                        ('num_svdrem_prefix', (YLeaf(YType.uint32, 'num-svdrem-prefix'), ['int'])),
                        ('table_version', (YLeaf(YType.uint64, 'table-version'), ['int'])),
                        ('prefix_limit_notified', (YLeaf(YType.boolean, 'prefix-limit-notified'), ['bool'])),
                        ('fwd_referenced', (YLeaf(YType.boolean, 'fwd-referenced'), ['bool'])),
                        ('deleted', (YLeaf(YType.boolean, 'deleted'), ['bool'])),
                        ('initial_converge', (YLeaf(YType.boolean, 'initial-converge'), ['bool'])),
                    ])
                    self.tableid = None
                    self.afi = None
                    self.safi = None
                    self.vrf_name = None
                    self.table_name = None
                    self.version = None
                    self.conf_prefix_limit = None
                    self.current_prefix_count = None
                    self.num_svdlcl_prefix = None
                    self.num_svdrem_prefix = None
                    self.table_version = None
                    self.prefix_limit_notified = None
                    self.fwd_referenced = None
                    self.deleted = None
                    self.initial_converge = None
                    self._segment_path = lambda: "information"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.Information, ['tableid', 'afi', 'safi', 'vrf_name', 'table_name', 'version', 'conf_prefix_limit', 'current_prefix_count', 'num_svdlcl_prefix', 'num_svdrem_prefix', 'table_version', 'prefix_limit_notified', 'fwd_referenced', 'deleted', 'initial_converge'], name, value)


            class SummaryProtos(Entity):
                """
                RIB table summary
                
                .. attribute:: summary_proto
                
                	Route summary information for a specific table/protocol 
                	**type**\: list of  		 :py:class:`SummaryProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos, self).__init__()

                    self.yang_name = "summary-protos"
                    self.yang_parent_name = "rib-table-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("summary-proto", ("summary_proto", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto))])
                    self._leafs = OrderedDict()

                    self.summary_proto = YList(self)
                    self._segment_path = lambda: "summary-protos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos, [], name, value)


                class SummaryProto(Entity):
                    """
                    Route summary information for a specific
                    table/protocol 
                    
                    .. attribute:: protoid  (key)
                    
                    	Proto ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proto_route_count
                    
                    	Count for proto. instance
                    	**type**\:  :py:class:`ProtoRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount>`
                    
                    .. attribute:: rtype_none
                    
                    	No route type
                    	**type**\:  :py:class:`RtypeNone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone>`
                    
                    .. attribute:: rtype_other
                    
                    	Unknown route type
                    	**type**\:  :py:class:`RtypeOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther>`
                    
                    .. attribute:: rtype_ospf_intra
                    
                    	OSPF route within an area
                    	**type**\:  :py:class:`RtypeOspfIntra <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra>`
                    
                    .. attribute:: rtype_ospf_inter
                    
                    	OSPF route across diff. areas
                    	**type**\:  :py:class:`RtypeOspfInter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter>`
                    
                    .. attribute:: rtype_ospf_extern1
                    
                    	OSPF external route of type 1
                    	**type**\:  :py:class:`RtypeOspfExtern1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1>`
                    
                    .. attribute:: rtype_ospf_extern2
                    
                    	OSPF external route of type 2
                    	**type**\:  :py:class:`RtypeOspfExtern2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2>`
                    
                    .. attribute:: rtype_isis_sum
                    
                    	IS\-IS summary route
                    	**type**\:  :py:class:`RtypeIsisSum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum>`
                    
                    .. attribute:: rtype_isis_l1
                    
                    	IS\-IS level 1 route
                    	**type**\:  :py:class:`RtypeIsisL1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1>`
                    
                    .. attribute:: rtype_isis_l2
                    
                    	IS\-IS level 2 route
                    	**type**\:  :py:class:`RtypeIsisL2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2>`
                    
                    .. attribute:: rtype_isis_l1_ia
                    
                    	IS\-IS level1 inter\-area route
                    	**type**\:  :py:class:`RtypeIsisL1Ia <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia>`
                    
                    .. attribute:: rtype_bgp_int
                    
                    	iBGP route
                    	**type**\:  :py:class:`RtypeBgpInt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt>`
                    
                    .. attribute:: rtype_bgp_ext
                    
                    	eBGP route
                    	**type**\:  :py:class:`RtypeBgpExt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt>`
                    
                    .. attribute:: rtype_bgp_loc
                    
                    	BGP local route
                    	**type**\:  :py:class:`RtypeBgpLoc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc>`
                    
                    .. attribute:: rtype_ospf_nssa1
                    
                    	OSPF NSSA ext. route type 1
                    	**type**\:  :py:class:`RtypeOspfNssa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1>`
                    
                    .. attribute:: rtype_ospf_nssa2
                    
                    	OSPF NSSA ext. route type 2
                    	**type**\:  :py:class:`RtypeOspfNssa2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2>`
                    
                    .. attribute:: rtype_igrp2_int
                    
                    	EIGRP internal route
                    	**type**\:  :py:class:`RtypeIgrp2Int <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int>`
                    
                    .. attribute:: rtype_igrp2_ext
                    
                    	EIGRP external route
                    	**type**\:  :py:class:`RtypeIgrp2Ext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext>`
                    
                    .. attribute:: name
                    
                    	Proto name
                    	**type**\: str
                    
                    .. attribute:: instance
                    
                    	Instance
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto, self).__init__()

                        self.yang_name = "summary-proto"
                        self.yang_parent_name = "summary-protos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['protoid']
                        self._child_classes = OrderedDict([("proto-route-count", ("proto_route_count", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount)), ("rtype-none", ("rtype_none", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone)), ("rtype-other", ("rtype_other", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther)), ("rtype-ospf-intra", ("rtype_ospf_intra", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra)), ("rtype-ospf-inter", ("rtype_ospf_inter", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter)), ("rtype-ospf-extern1", ("rtype_ospf_extern1", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1)), ("rtype-ospf-extern2", ("rtype_ospf_extern2", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2)), ("rtype-isis-sum", ("rtype_isis_sum", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum)), ("rtype-isis-l1", ("rtype_isis_l1", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1)), ("rtype-isis-l2", ("rtype_isis_l2", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2)), ("rtype-isis-l1-ia", ("rtype_isis_l1_ia", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia)), ("rtype-bgp-int", ("rtype_bgp_int", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt)), ("rtype-bgp-ext", ("rtype_bgp_ext", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt)), ("rtype-bgp-loc", ("rtype_bgp_loc", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc)), ("rtype-ospf-nssa1", ("rtype_ospf_nssa1", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1)), ("rtype-ospf-nssa2", ("rtype_ospf_nssa2", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2)), ("rtype-igrp2-int", ("rtype_igrp2_int", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int)), ("rtype-igrp2-ext", ("rtype_igrp2_ext", Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext))])
                        self._leafs = OrderedDict([
                            ('protoid', (YLeaf(YType.uint32, 'protoid'), ['int'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                        ])
                        self.protoid = None
                        self.name = None
                        self.instance = None

                        self.proto_route_count = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount()
                        self.proto_route_count.parent = self
                        self._children_name_map["proto_route_count"] = "proto-route-count"

                        self.rtype_none = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone()
                        self.rtype_none.parent = self
                        self._children_name_map["rtype_none"] = "rtype-none"

                        self.rtype_other = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther()
                        self.rtype_other.parent = self
                        self._children_name_map["rtype_other"] = "rtype-other"

                        self.rtype_ospf_intra = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra()
                        self.rtype_ospf_intra.parent = self
                        self._children_name_map["rtype_ospf_intra"] = "rtype-ospf-intra"

                        self.rtype_ospf_inter = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter()
                        self.rtype_ospf_inter.parent = self
                        self._children_name_map["rtype_ospf_inter"] = "rtype-ospf-inter"

                        self.rtype_ospf_extern1 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1()
                        self.rtype_ospf_extern1.parent = self
                        self._children_name_map["rtype_ospf_extern1"] = "rtype-ospf-extern1"

                        self.rtype_ospf_extern2 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2()
                        self.rtype_ospf_extern2.parent = self
                        self._children_name_map["rtype_ospf_extern2"] = "rtype-ospf-extern2"

                        self.rtype_isis_sum = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum()
                        self.rtype_isis_sum.parent = self
                        self._children_name_map["rtype_isis_sum"] = "rtype-isis-sum"

                        self.rtype_isis_l1 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1()
                        self.rtype_isis_l1.parent = self
                        self._children_name_map["rtype_isis_l1"] = "rtype-isis-l1"

                        self.rtype_isis_l2 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2()
                        self.rtype_isis_l2.parent = self
                        self._children_name_map["rtype_isis_l2"] = "rtype-isis-l2"

                        self.rtype_isis_l1_ia = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia()
                        self.rtype_isis_l1_ia.parent = self
                        self._children_name_map["rtype_isis_l1_ia"] = "rtype-isis-l1-ia"

                        self.rtype_bgp_int = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt()
                        self.rtype_bgp_int.parent = self
                        self._children_name_map["rtype_bgp_int"] = "rtype-bgp-int"

                        self.rtype_bgp_ext = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt()
                        self.rtype_bgp_ext.parent = self
                        self._children_name_map["rtype_bgp_ext"] = "rtype-bgp-ext"

                        self.rtype_bgp_loc = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc()
                        self.rtype_bgp_loc.parent = self
                        self._children_name_map["rtype_bgp_loc"] = "rtype-bgp-loc"

                        self.rtype_ospf_nssa1 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1()
                        self.rtype_ospf_nssa1.parent = self
                        self._children_name_map["rtype_ospf_nssa1"] = "rtype-ospf-nssa1"

                        self.rtype_ospf_nssa2 = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2()
                        self.rtype_ospf_nssa2.parent = self
                        self._children_name_map["rtype_ospf_nssa2"] = "rtype-ospf-nssa2"

                        self.rtype_igrp2_int = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int()
                        self.rtype_igrp2_int.parent = self
                        self._children_name_map["rtype_igrp2_int"] = "rtype-igrp2-int"

                        self.rtype_igrp2_ext = Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext()
                        self.rtype_igrp2_ext.parent = self
                        self._children_name_map["rtype_igrp2_ext"] = "rtype-igrp2-ext"
                        self._segment_path = lambda: "summary-proto" + "[protoid='" + str(self.protoid) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto, ['protoid', 'name', 'instance'], name, value)


                    class ProtoRouteCount(Entity):
                        """
                        Count for proto. instance
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, self).__init__()

                            self.yang_name = "proto-route-count"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "proto-route-count"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeNone(Entity):
                        """
                        No route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, self).__init__()

                            self.yang_name = "rtype-none"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-none"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOther(Entity):
                        """
                        Unknown route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, self).__init__()

                            self.yang_name = "rtype-other"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-other"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOspfIntra(Entity):
                        """
                        OSPF route within an area
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, self).__init__()

                            self.yang_name = "rtype-ospf-intra"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-ospf-intra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOspfInter(Entity):
                        """
                        OSPF route across diff. areas
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, self).__init__()

                            self.yang_name = "rtype-ospf-inter"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-ospf-inter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOspfExtern1(Entity):
                        """
                        OSPF external route of type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, self).__init__()

                            self.yang_name = "rtype-ospf-extern1"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-ospf-extern1"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOspfExtern2(Entity):
                        """
                        OSPF external route of type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, self).__init__()

                            self.yang_name = "rtype-ospf-extern2"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-ospf-extern2"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeIsisSum(Entity):
                        """
                        IS\-IS summary route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, self).__init__()

                            self.yang_name = "rtype-isis-sum"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-isis-sum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeIsisL1(Entity):
                        """
                        IS\-IS level 1 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, self).__init__()

                            self.yang_name = "rtype-isis-l1"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-isis-l1"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeIsisL2(Entity):
                        """
                        IS\-IS level 2 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, self).__init__()

                            self.yang_name = "rtype-isis-l2"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-isis-l2"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeIsisL1Ia(Entity):
                        """
                        IS\-IS level1 inter\-area route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, self).__init__()

                            self.yang_name = "rtype-isis-l1-ia"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-isis-l1-ia"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeBgpInt(Entity):
                        """
                        iBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, self).__init__()

                            self.yang_name = "rtype-bgp-int"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-bgp-int"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeBgpExt(Entity):
                        """
                        eBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, self).__init__()

                            self.yang_name = "rtype-bgp-ext"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-bgp-ext"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeBgpLoc(Entity):
                        """
                        BGP local route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, self).__init__()

                            self.yang_name = "rtype-bgp-loc"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-bgp-loc"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOspfNssa1(Entity):
                        """
                        OSPF NSSA ext. route type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, self).__init__()

                            self.yang_name = "rtype-ospf-nssa1"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-ospf-nssa1"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOspfNssa2(Entity):
                        """
                        OSPF NSSA ext. route type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, self).__init__()

                            self.yang_name = "rtype-ospf-nssa2"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-ospf-nssa2"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeIgrp2Int(Entity):
                        """
                        EIGRP internal route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, self).__init__()

                            self.yang_name = "rtype-igrp2-int"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-igrp2-int"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeIgrp2Ext(Entity):
                        """
                        EIGRP external route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, self).__init__()

                            self.yang_name = "rtype-igrp2-ext"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-igrp2-ext"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


            class RibTableItfHndls(Entity):
                """
                RIB table interface
                
                .. attribute:: rib_table_itf_hndl
                
                	Interface handle
                	**type**\: list of  		 :py:class:`RibTableItfHndl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls, self).__init__()

                    self.yang_name = "rib-table-itf-hndls"
                    self.yang_parent_name = "rib-table-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rib-table-itf-hndl", ("rib_table_itf_hndl", Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl))])
                    self._leafs = OrderedDict()

                    self.rib_table_itf_hndl = YList(self)
                    self._segment_path = lambda: "rib-table-itf-hndls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls, [], name, value)


                class RibTableItfHndl(Entity):
                    """
                    Interface handle
                    
                    .. attribute:: handle  (key)
                    
                    	Itf Handle
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: itf_route
                    
                    	Route information for a specific table/interface 
                    	**type**\: list of  		 :py:class:`ItfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, self).__init__()

                        self.yang_name = "rib-table-itf-hndl"
                        self.yang_parent_name = "rib-table-itf-hndls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['handle']
                        self._child_classes = OrderedDict([("itf-route", ("itf_route", Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute))])
                        self._leafs = OrderedDict([
                            ('handle', (YLeaf(YType.uint32, 'handle'), ['int'])),
                        ])
                        self.handle = None

                        self.itf_route = YList(self)
                        self._segment_path = lambda: "rib-table-itf-hndl" + "[handle='" + str(self.handle) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, ['handle'], name, value)


                    class ItfRoute(Entity):
                        """
                        Route information for a specific
                        table/interface 
                        
                        .. attribute:: address  (key)
                        
                        	Network Address 
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: route_path
                        
                        	Path(s) of the route
                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath>`
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length_xr
                        
                        	Length of prefix
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_version
                        
                        	Route version
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol_id
                        
                        	Protocol advertising the route
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol_name
                        
                        	 Name of Protocol
                        	**type**\: str
                        
                        .. attribute:: instance
                        
                        	Instance name
                        	**type**\: str
                        
                        .. attribute:: client_id
                        
                        	Client adding the route to RIB
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_type
                        
                        	Route type
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	Route priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: svd_type
                        
                        	SVD Type of route
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: flags
                        
                        	Route flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: extended_flags
                        
                        	Extended Route flags
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: tag
                        
                        	Opaque proto specific info
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: distance
                        
                        	Distance of the route
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion_distance
                        
                        	Diversion distance of the route
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric
                        
                        	Route metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_count
                        
                        	Number of paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_identity
                        
                        	BGP Attribute ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: traffic_index
                        
                        	BGP Traffic Index
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_precedence
                        
                        	Route ip precedence
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: qos_group
                        
                        	Route qos group
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: flow_tag
                        
                        	Flow tag
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: fwd_class
                        
                        	Forward Class
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: pic_count
                        
                        	Number of pic paths in this route
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: active
                        
                        	Is the route active or backup
                        	**type**\: bool
                        
                        .. attribute:: diversion
                        
                        	Route has a diversion path
                        	**type**\: bool
                        
                        .. attribute:: diversion_proto_name
                        
                        	Diversion route protocol name
                        	**type**\: str
                        
                        .. attribute:: route_age
                        
                        	Age of route (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: route_label
                        
                        	Local label of the route
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: version
                        
                        	Route Version
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tbl_version
                        
                        	Table Version
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: route_modify_time
                        
                        	Route modification time(nanoseconds)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, self).__init__()

                            self.yang_name = "itf-route"
                            self.yang_parent_name = "rib-table-itf-hndl"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                            ])
                            self.address = None
                            self.prefix = None
                            self.prefix_length_xr = None
                            self.route_version = None
                            self.protocol_id = None
                            self.protocol_name = None
                            self.instance = None
                            self.client_id = None
                            self.route_type = None
                            self.priority = None
                            self.svd_type = None
                            self.flags = None
                            self.extended_flags = None
                            self.tag = None
                            self.distance = None
                            self.diversion_distance = None
                            self.metric = None
                            self.paths_count = None
                            self.attribute_identity = None
                            self.traffic_index = None
                            self.route_precedence = None
                            self.qos_group = None
                            self.flow_tag = None
                            self.fwd_class = None
                            self.pic_count = None
                            self.active = None
                            self.diversion = None
                            self.diversion_proto_name = None
                            self.route_age = None
                            self.route_label = None
                            self.version = None
                            self.tbl_version = None
                            self.route_modify_time = None

                            self.route_path = Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath()
                            self.route_path.parent = self
                            self._children_name_map["route_path"] = "route-path"
                            self._segment_path = lambda: "itf-route" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, ['address', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                        class RoutePath(Entity):
                            """
                            Path(s) of the route
                            
                            .. attribute:: ipv6_rib_edm_path
                            
                            	ipv6 rib edm path
                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv6-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, self).__init__()

                                self.yang_name = "route-path"
                                self.yang_parent_name = "itf-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath))])
                                self._leafs = OrderedDict()

                                self.ipv6_rib_edm_path = YList(self)
                                self._segment_path = lambda: "route-path"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, [], name, value)


                            class Ipv6RibEdmPath(Entity):
                                """
                                ipv6 rib edm path
                                
                                .. attribute:: address
                                
                                	Nexthop
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: information_source
                                
                                	Infosource
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: v6_nexthop
                                
                                	V6 nexthop
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: v6_information_source
                                
                                	V6 Infosource
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_name
                                
                                	Interface Name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: metric
                                
                                	Metrics
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: load_metric
                                
                                	Load Metrics
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flags64
                                
                                	Flags extended to 64 bits
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: flags
                                
                                	Flags
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: private_flags
                                
                                	Private Flags
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: looped
                                
                                	Looping path
                                	**type**\: bool
                                
                                .. attribute:: next_hop_table_id
                                
                                	Nexthop tableid
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_vrf_name
                                
                                	VRF Name of the nh table
                                	**type**\: str
                                
                                .. attribute:: next_hop_table_name
                                
                                	NH table name
                                	**type**\: str
                                
                                .. attribute:: next_hop_afi
                                
                                	NH afi
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_safi
                                
                                	NH safi
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_label
                                
                                	Label associated with this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_id
                                
                                	Tunnel ID associated with this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pathid
                                
                                	Path id of this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pathid
                                
                                	Path id of this path's backup
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ref_cnt_of_backup
                                
                                	Refcnt of backup
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_extended_communities
                                
                                	Number of extended communities
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mvpn_present
                                
                                	MVPN attribute present
                                	**type**\: bool
                                
                                .. attribute:: path_rt_present
                                
                                	Path RT present
                                	**type**\: bool
                                
                                .. attribute:: vrf_import_rt_present
                                
                                	VRFIMPORTRTPresent
                                	**type**\: bool
                                
                                .. attribute:: source_asrt_present
                                
                                	SOURCEASRTPresent
                                	**type**\: bool
                                
                                .. attribute:: source_rd_present
                                
                                	SOURCERDPresent
                                	**type**\: bool
                                
                                .. attribute:: segmented_nexthop_present
                                
                                	SegmentedNexthopPresent
                                	**type**\: bool
                                
                                .. attribute:: number_of_nnh
                                
                                	Number of Next Next Hops
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id
                                
                                	NHID associated with this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id_refcount
                                
                                	NHID references
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_area_id
                                
                                	OSPF area associated with the path
                                	**type**\: str
                                
                                .. attribute:: has_labelstk
                                
                                	Path has a label stack
                                	**type**\: bool
                                
                                .. attribute:: num_labels
                                
                                	Number of labels in stack
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: binding_label
                                
                                	binding Label for this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nhid_feid
                                
                                	Fib nhid encap id
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: mpls_feid
                                
                                	Fib mpls encap id
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: has_vxlan_network_id
                                
                                	VXLAN Network Identifier exists for this path
                                	**type**\: bool
                                
                                .. attribute:: vxlan_network_id
                                
                                	VXLAN Network Identifier for this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: has_xcid
                                
                                	L2 Cross Connect ID exists for this path
                                	**type**\: bool
                                
                                .. attribute:: xcid
                                
                                	L2 Cross Connect ID for this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: has_span_diag_interface
                                
                                	SPAN Diagnostics Interface exists for this path
                                	**type**\: bool
                                
                                .. attribute:: span_diag_interface
                                
                                	SPAN Diagnostics Interface for this path
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: has_subscriber_parent_interface
                                
                                	Subscriber Parent Interface exists for this path
                                	**type**\: bool
                                
                                .. attribute:: subscriber_parent_interface
                                
                                	Subscriber Parent Interface for this path
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: interface_index_present
                                
                                	Interface Index present
                                	**type**\: bool
                                
                                .. attribute:: interface_index_attribute
                                
                                	Interface Index attribute
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_backup_addr
                                
                                	Remote backup node address
                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                
                                .. attribute:: labelstk
                                
                                	Outgoing label stack for this path
                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                
                                .. attribute:: next_next_hop
                                
                                	List of Next Next Hops
                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                
                                

                                """

                                _prefix = 'ip-rib-ipv6-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                    self.yang_name = "ipv6-rib-edm-path"
                                    self.yang_parent_name = "route-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                    ])
                                    self.address = None
                                    self.information_source = None
                                    self.v6_nexthop = None
                                    self.v6_information_source = None
                                    self.interface_name = None
                                    self.metric = None
                                    self.load_metric = None
                                    self.flags64 = None
                                    self.flags = None
                                    self.private_flags = None
                                    self.looped = None
                                    self.next_hop_table_id = None
                                    self.next_hop_vrf_name = None
                                    self.next_hop_table_name = None
                                    self.next_hop_afi = None
                                    self.next_hop_safi = None
                                    self.route_label = None
                                    self.tunnel_id = None
                                    self.pathid = None
                                    self.backup_pathid = None
                                    self.ref_cnt_of_backup = None
                                    self.number_of_extended_communities = None
                                    self.mvpn_present = None
                                    self.path_rt_present = None
                                    self.vrf_import_rt_present = None
                                    self.source_asrt_present = None
                                    self.source_rd_present = None
                                    self.segmented_nexthop_present = None
                                    self.number_of_nnh = None
                                    self.next_hop_id = None
                                    self.next_hop_id_refcount = None
                                    self.ospf_area_id = None
                                    self.has_labelstk = None
                                    self.num_labels = None
                                    self.binding_label = None
                                    self.nhid_feid = None
                                    self.mpls_feid = None
                                    self.has_vxlan_network_id = None
                                    self.vxlan_network_id = None
                                    self.has_xcid = None
                                    self.xcid = None
                                    self.has_span_diag_interface = None
                                    self.span_diag_interface = None
                                    self.has_subscriber_parent_interface = None
                                    self.subscriber_parent_interface = None
                                    self.interface_index_present = None
                                    self.interface_index_attribute = None

                                    self.remote_backup_addr = YList(self)
                                    self.labelstk = YList(self)
                                    self.next_next_hop = YList(self)
                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                class RemoteBackupAddr(Entity):
                                    """
                                    Remote backup node address
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv6-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                        self.yang_name = "remote-backup-addr"
                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "remote-backup-addr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                class Labelstk(Entity):
                                    """
                                    Outgoing label stack for this path
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv6-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                        self.yang_name = "labelstk"
                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "labelstk"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                class NextNextHop(Entity):
                                    """
                                    List of Next Next Hops
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                    
                                    .. attribute:: unknownval
                                    
                                    	Unknown Value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_index
                                    
                                    	Interface Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv6-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                        self.yang_name = "next-next-hop"
                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                        ])
                                        self.type = None
                                        self.unknownval = None
                                        self.address = None
                                        self.interface_index = None
                                        self._segment_path = lambda: "next-next-hop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


    class Vrfs(Entity):
        """
        VRF table
        
        .. attribute:: vrf
        
        	Specific VRF
        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf>`
        
        

        """

        _prefix = 'ip-rib-ipv6-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Ipv6Rib.Vrfs, self).__init__()

            self.yang_name = "vrfs"
            self.yang_parent_name = "ipv6-rib"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("vrf", ("vrf", Ipv6Rib.Vrfs.Vrf))])
            self._leafs = OrderedDict()

            self.vrf = YList(self)
            self._segment_path = lambda: "vrfs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Ipv6Rib.Vrfs, [], name, value)


        class Vrf(Entity):
            """
            Specific VRF
            
            .. attribute:: vrf_name  (key)
            
            	Name of the VRF
            	**type**\: str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: afs
            
            	Address Family (AF) table
            	**type**\:  :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs>`
            
            

            """

            _prefix = 'ip-rib-ipv6-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Ipv6Rib.Vrfs.Vrf, self).__init__()

                self.yang_name = "vrf"
                self.yang_parent_name = "vrfs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['vrf_name']
                self._child_classes = OrderedDict([("afs", ("afs", Ipv6Rib.Vrfs.Vrf.Afs))])
                self._leafs = OrderedDict([
                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                ])
                self.vrf_name = None

                self.afs = Ipv6Rib.Vrfs.Vrf.Afs()
                self.afs.parent = self
                self._children_name_map["afs"] = "afs"
                self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib/vrfs/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Ipv6Rib.Vrfs.Vrf, ['vrf_name'], name, value)


            class Afs(Entity):
                """
                Address Family (AF) table
                
                .. attribute:: af
                
                	Specific AF information
                	**type**\: list of  		 :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6Rib.Vrfs.Vrf.Afs, self).__init__()

                    self.yang_name = "afs"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("af", ("af", Ipv6Rib.Vrfs.Vrf.Afs.Af))])
                    self._leafs = OrderedDict()

                    self.af = YList(self)
                    self._segment_path = lambda: "afs"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs, [], name, value)


                class Af(Entity):
                    """
                    Specific AF information
                    
                    .. attribute:: af_name  (key)
                    
                    	Name of the AF \- 'IPv6'
                    	**type**\: str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: safs
                    
                    	Subsequent Address Family (SAF) table
                    	**type**\:  :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af, self).__init__()

                        self.yang_name = "af"
                        self.yang_parent_name = "afs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['af_name']
                        self._child_classes = OrderedDict([("safs", ("safs", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs))])
                        self._leafs = OrderedDict([
                            ('af_name', (YLeaf(YType.str, 'af-name'), ['str'])),
                        ])
                        self.af_name = None

                        self.safs = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs()
                        self.safs.parent = self
                        self._children_name_map["safs"] = "safs"
                        self._segment_path = lambda: "af" + "[af-name='" + str(self.af_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                    class Safs(Entity):
                        """
                        Subsequent Address Family (SAF) table
                        
                        .. attribute:: saf
                        
                        	Specific SAF information
                        	**type**\: list of  		 :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf>`
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs, self).__init__()

                            self.yang_name = "safs"
                            self.yang_parent_name = "af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("saf", ("saf", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf))])
                            self._leafs = OrderedDict()

                            self.saf = YList(self)
                            self._segment_path = lambda: "safs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs, [], name, value)


                        class Saf(Entity):
                            """
                            Specific SAF information
                            
                            .. attribute:: saf_name  (key)
                            
                            	Name of the SAF
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: ip_rib_route_table_names
                            
                            	Global container of routes
                            	**type**\:  :py:class:`IpRibRouteTableNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv6-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf, self).__init__()

                                self.yang_name = "saf"
                                self.yang_parent_name = "safs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['saf_name']
                                self._child_classes = OrderedDict([("ip-rib-route-table-names", ("ip_rib_route_table_names", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames))])
                                self._leafs = OrderedDict([
                                    ('saf_name', (YLeaf(YType.str, 'saf-name'), ['str'])),
                                ])
                                self.saf_name = None

                                self.ip_rib_route_table_names = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames()
                                self.ip_rib_route_table_names.parent = self
                                self._children_name_map["ip_rib_route_table_names"] = "ip-rib-route-table-names"
                                self._segment_path = lambda: "saf" + "[saf-name='" + str(self.saf_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf, ['saf_name'], name, value)


                            class IpRibRouteTableNames(Entity):
                                """
                                Global container of routes
                                
                                .. attribute:: ip_rib_route_table_name
                                
                                	IP RIB Route table name for a topology
                                	**type**\: list of  		 :py:class:`IpRibRouteTableName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName>`
                                
                                

                                """

                                _prefix = 'ip-rib-ipv6-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, self).__init__()

                                    self.yang_name = "ip-rib-route-table-names"
                                    self.yang_parent_name = "saf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ip-rib-route-table-name", ("ip_rib_route_table_name", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName))])
                                    self._leafs = OrderedDict()

                                    self.ip_rib_route_table_name = YList(self)
                                    self._segment_path = lambda: "ip-rib-route-table-names"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, [], name, value)


                                class IpRibRouteTableName(Entity):
                                    """
                                    IP RIB Route table name for a topology
                                    
                                    .. attribute:: route_table_name  (key)
                                    
                                    	Name of the route table 
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: destination_kw
                                    
                                    	Destination KW
                                    	**type**\:  :py:class:`DestinationKw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw>`
                                    
                                    .. attribute:: adverts
                                    
                                    	Route advertiser information 
                                    	**type**\:  :py:class:`Adverts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts>`
                                    
                                    .. attribute:: deleted_routes
                                    
                                    	Deleted
                                    	**type**\:  :py:class:`DeletedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes>`
                                    
                                    .. attribute:: protocol
                                    
                                    	Contains the classification of routes by protocol
                                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol>`
                                    
                                    .. attribute:: routes
                                    
                                    	Route information 
                                    	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes>`
                                    
                                    .. attribute:: q_routes
                                    
                                    	Quarantine
                                    	**type**\:  :py:class:`QRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes>`
                                    
                                    .. attribute:: backup_routes
                                    
                                    	Backup route information for the given table
                                    	**type**\:  :py:class:`BackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes>`
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv6-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, self).__init__()

                                        self.yang_name = "ip-rib-route-table-name"
                                        self.yang_parent_name = "ip-rib-route-table-names"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['route_table_name']
                                        self._child_classes = OrderedDict([("destination-kw", ("destination_kw", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw)), ("adverts", ("adverts", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts)), ("deleted-routes", ("deleted_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes)), ("protocol", ("protocol", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol)), ("routes", ("routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes)), ("q-routes", ("q_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes)), ("backup-routes", ("backup_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes))])
                                        self._leafs = OrderedDict([
                                            ('route_table_name', (YLeaf(YType.str, 'route-table-name'), ['str'])),
                                        ])
                                        self.route_table_name = None

                                        self.destination_kw = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw()
                                        self.destination_kw.parent = self
                                        self._children_name_map["destination_kw"] = "destination-kw"

                                        self.adverts = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts()
                                        self.adverts.parent = self
                                        self._children_name_map["adverts"] = "adverts"

                                        self.deleted_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes()
                                        self.deleted_routes.parent = self
                                        self._children_name_map["deleted_routes"] = "deleted-routes"

                                        self.protocol = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol()
                                        self.protocol.parent = self
                                        self._children_name_map["protocol"] = "protocol"

                                        self.routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes()
                                        self.routes.parent = self
                                        self._children_name_map["routes"] = "routes"

                                        self.q_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes()
                                        self.q_routes.parent = self
                                        self._children_name_map["q_routes"] = "q-routes"

                                        self.backup_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes()
                                        self.backup_routes.parent = self
                                        self._children_name_map["backup_routes"] = "backup-routes"
                                        self._segment_path = lambda: "ip-rib-route-table-name" + "[route-table-name='" + str(self.route_table_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, ['route_table_name'], name, value)


                                    class DestinationKw(Entity):
                                        """
                                        Destination KW
                                        
                                        .. attribute:: dest_q_routes
                                        
                                        	Quarantine
                                        	**type**\:  :py:class:`DestQRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes>`
                                        
                                        .. attribute:: dest_backup_routes
                                        
                                        	Backup
                                        	**type**\:  :py:class:`DestBackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes>`
                                        
                                        .. attribute:: dest_best_routes
                                        
                                        	Best Local
                                        	**type**\:  :py:class:`DestBestRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes>`
                                        
                                        .. attribute:: dest_next_hop_routes
                                        
                                        	Resolving next hop
                                        	**type**\:  :py:class:`DestNextHopRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw, self).__init__()

                                            self.yang_name = "destination-kw"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dest-q-routes", ("dest_q_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes)), ("dest-backup-routes", ("dest_backup_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes)), ("dest-best-routes", ("dest_best_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes)), ("dest-next-hop-routes", ("dest_next_hop_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes))])
                                            self._leafs = OrderedDict()

                                            self.dest_q_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes()
                                            self.dest_q_routes.parent = self
                                            self._children_name_map["dest_q_routes"] = "dest-q-routes"

                                            self.dest_backup_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes()
                                            self.dest_backup_routes.parent = self
                                            self._children_name_map["dest_backup_routes"] = "dest-backup-routes"

                                            self.dest_best_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes()
                                            self.dest_best_routes.parent = self
                                            self._children_name_map["dest_best_routes"] = "dest-best-routes"

                                            self.dest_next_hop_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes()
                                            self.dest_next_hop_routes.parent = self
                                            self._children_name_map["dest_next_hop_routes"] = "dest-next-hop-routes"
                                            self._segment_path = lambda: "destination-kw"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw, [], name, value)


                                        class DestQRoutes(Entity):
                                            """
                                            Quarantine
                                            
                                            .. attribute:: dest_q_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of  		 :py:class:`DestQRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, self).__init__()

                                                self.yang_name = "dest-q-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dest-q-route", ("dest_q_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute))])
                                                self._leafs = OrderedDict()

                                                self.dest_q_route = YList(self)
                                                self._segment_path = lambda: "dest-q-routes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, [], name, value)


                                            class DestQRoute(Entity):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: address
                                                
                                                	Network Address 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length 
                                                	**type**\: int
                                                
                                                	**range:** 0..128
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath>`
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\: str
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\: str
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\: str
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, self).__init__()

                                                    self.yang_name = "dest-q-route"
                                                    self.yang_parent_name = "dest-q-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                        ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                        ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                        ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                        ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                        ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                        ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                        ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                        ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                        ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                        ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                        ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                        ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                        ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                        ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                        ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                        ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                        ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                        ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                        ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                        ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                        ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                        ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                        ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                    ])
                                                    self.address = None
                                                    self.prefix_length = None
                                                    self.prefix = None
                                                    self.prefix_length_xr = None
                                                    self.route_version = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.instance = None
                                                    self.client_id = None
                                                    self.route_type = None
                                                    self.priority = None
                                                    self.svd_type = None
                                                    self.flags = None
                                                    self.extended_flags = None
                                                    self.tag = None
                                                    self.distance = None
                                                    self.diversion_distance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.attribute_identity = None
                                                    self.traffic_index = None
                                                    self.route_precedence = None
                                                    self.qos_group = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.pic_count = None
                                                    self.active = None
                                                    self.diversion = None
                                                    self.diversion_proto_name = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.version = None
                                                    self.tbl_version = None
                                                    self.route_modify_time = None

                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._segment_path = lambda: "dest-q-route"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-q-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath))])
                                                        self._leafs = OrderedDict()

                                                        self.ipv6_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, [], name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: number_of_nnh
                                                        
                                                        	Number of Next Next Hops
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\: str
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_xcid
                                                        
                                                        	L2 Cross Connect ID exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: xcid
                                                        
                                                        	L2 Cross Connect ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: has_subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: interface_index_present
                                                        
                                                        	Interface Index present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: interface_index_attribute
                                                        
                                                        	Interface Index attribute
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: next_next_hop
                                                        
                                                        	List of Next Next Hops
                                                        	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.information_source = None
                                                            self.v6_nexthop = None
                                                            self.v6_information_source = None
                                                            self.interface_name = None
                                                            self.metric = None
                                                            self.load_metric = None
                                                            self.flags64 = None
                                                            self.flags = None
                                                            self.private_flags = None
                                                            self.looped = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_vrf_name = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_safi = None
                                                            self.route_label = None
                                                            self.tunnel_id = None
                                                            self.pathid = None
                                                            self.backup_pathid = None
                                                            self.ref_cnt_of_backup = None
                                                            self.number_of_extended_communities = None
                                                            self.mvpn_present = None
                                                            self.path_rt_present = None
                                                            self.vrf_import_rt_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.segmented_nexthop_present = None
                                                            self.number_of_nnh = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.ospf_area_id = None
                                                            self.has_labelstk = None
                                                            self.num_labels = None
                                                            self.binding_label = None
                                                            self.nhid_feid = None
                                                            self.mpls_feid = None
                                                            self.has_vxlan_network_id = None
                                                            self.vxlan_network_id = None
                                                            self.has_xcid = None
                                                            self.xcid = None
                                                            self.has_span_diag_interface = None
                                                            self.span_diag_interface = None
                                                            self.has_subscriber_parent_interface = None
                                                            self.subscriber_parent_interface = None
                                                            self.interface_index_present = None
                                                            self.interface_index_attribute = None

                                                            self.remote_backup_addr = YList(self)
                                                            self.labelstk = YList(self)
                                                            self.next_next_hop = YList(self)
                                                            self._segment_path = lambda: "ipv6-rib-edm-path"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "remote-backup-addr"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "labelstk"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class NextNextHop(Entity):
                                                            """
                                                            List of Next Next Hops
                                                            
                                                            .. attribute:: type
                                                            
                                                            	type
                                                            	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                            
                                                            .. attribute:: unknownval
                                                            
                                                            	Unknown Value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: address
                                                            
                                                            	IPv4 Address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: interface_index
                                                            
                                                            	Interface Index
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                self.yang_name = "next-next-hop"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                    ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                    ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                ])
                                                                self.type = None
                                                                self.unknownval = None
                                                                self.address = None
                                                                self.interface_index = None
                                                                self._segment_path = lambda: "next-next-hop"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class DestBackupRoutes(Entity):
                                            """
                                            Backup
                                            
                                            .. attribute:: dest_backup_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of  		 :py:class:`DestBackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, self).__init__()

                                                self.yang_name = "dest-backup-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dest-backup-route", ("dest_backup_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute))])
                                                self._leafs = OrderedDict()

                                                self.dest_backup_route = YList(self)
                                                self._segment_path = lambda: "dest-backup-routes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, [], name, value)


                                            class DestBackupRoute(Entity):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: address
                                                
                                                	Network Address 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length 
                                                	**type**\: int
                                                
                                                	**range:** 0..128
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath>`
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\: str
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\: str
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\: str
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, self).__init__()

                                                    self.yang_name = "dest-backup-route"
                                                    self.yang_parent_name = "dest-backup-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                        ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                        ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                        ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                        ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                        ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                        ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                        ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                        ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                        ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                        ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                        ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                        ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                        ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                        ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                        ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                        ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                        ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                        ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                        ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                        ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                        ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                        ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                        ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                    ])
                                                    self.address = None
                                                    self.prefix_length = None
                                                    self.prefix = None
                                                    self.prefix_length_xr = None
                                                    self.route_version = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.instance = None
                                                    self.client_id = None
                                                    self.route_type = None
                                                    self.priority = None
                                                    self.svd_type = None
                                                    self.flags = None
                                                    self.extended_flags = None
                                                    self.tag = None
                                                    self.distance = None
                                                    self.diversion_distance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.attribute_identity = None
                                                    self.traffic_index = None
                                                    self.route_precedence = None
                                                    self.qos_group = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.pic_count = None
                                                    self.active = None
                                                    self.diversion = None
                                                    self.diversion_proto_name = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.version = None
                                                    self.tbl_version = None
                                                    self.route_modify_time = None

                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._segment_path = lambda: "dest-backup-route"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-backup-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath))])
                                                        self._leafs = OrderedDict()

                                                        self.ipv6_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, [], name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: number_of_nnh
                                                        
                                                        	Number of Next Next Hops
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\: str
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_xcid
                                                        
                                                        	L2 Cross Connect ID exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: xcid
                                                        
                                                        	L2 Cross Connect ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: has_subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: interface_index_present
                                                        
                                                        	Interface Index present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: interface_index_attribute
                                                        
                                                        	Interface Index attribute
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: next_next_hop
                                                        
                                                        	List of Next Next Hops
                                                        	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.information_source = None
                                                            self.v6_nexthop = None
                                                            self.v6_information_source = None
                                                            self.interface_name = None
                                                            self.metric = None
                                                            self.load_metric = None
                                                            self.flags64 = None
                                                            self.flags = None
                                                            self.private_flags = None
                                                            self.looped = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_vrf_name = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_safi = None
                                                            self.route_label = None
                                                            self.tunnel_id = None
                                                            self.pathid = None
                                                            self.backup_pathid = None
                                                            self.ref_cnt_of_backup = None
                                                            self.number_of_extended_communities = None
                                                            self.mvpn_present = None
                                                            self.path_rt_present = None
                                                            self.vrf_import_rt_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.segmented_nexthop_present = None
                                                            self.number_of_nnh = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.ospf_area_id = None
                                                            self.has_labelstk = None
                                                            self.num_labels = None
                                                            self.binding_label = None
                                                            self.nhid_feid = None
                                                            self.mpls_feid = None
                                                            self.has_vxlan_network_id = None
                                                            self.vxlan_network_id = None
                                                            self.has_xcid = None
                                                            self.xcid = None
                                                            self.has_span_diag_interface = None
                                                            self.span_diag_interface = None
                                                            self.has_subscriber_parent_interface = None
                                                            self.subscriber_parent_interface = None
                                                            self.interface_index_present = None
                                                            self.interface_index_attribute = None

                                                            self.remote_backup_addr = YList(self)
                                                            self.labelstk = YList(self)
                                                            self.next_next_hop = YList(self)
                                                            self._segment_path = lambda: "ipv6-rib-edm-path"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "remote-backup-addr"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "labelstk"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class NextNextHop(Entity):
                                                            """
                                                            List of Next Next Hops
                                                            
                                                            .. attribute:: type
                                                            
                                                            	type
                                                            	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                            
                                                            .. attribute:: unknownval
                                                            
                                                            	Unknown Value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: address
                                                            
                                                            	IPv4 Address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: interface_index
                                                            
                                                            	Interface Index
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                self.yang_name = "next-next-hop"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                    ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                    ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                ])
                                                                self.type = None
                                                                self.unknownval = None
                                                                self.address = None
                                                                self.interface_index = None
                                                                self._segment_path = lambda: "next-next-hop"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class DestBestRoutes(Entity):
                                            """
                                            Best Local
                                            
                                            .. attribute:: dest_best_route
                                            
                                            	Best local route information for a specific Address 
                                            	**type**\: list of  		 :py:class:`DestBestRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, self).__init__()

                                                self.yang_name = "dest-best-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dest-best-route", ("dest_best_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute))])
                                                self._leafs = OrderedDict()

                                                self.dest_best_route = YList(self)
                                                self._segment_path = lambda: "dest-best-routes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, [], name, value)


                                            class DestBestRoute(Entity):
                                                """
                                                Best local route information for a
                                                specific Address 
                                                
                                                .. attribute:: address  (key)
                                                
                                                	Network Address 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath>`
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\: str
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\: str
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\: str
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, self).__init__()

                                                    self.yang_name = "dest-best-route"
                                                    self.yang_parent_name = "dest-best-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                        ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                        ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                        ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                        ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                        ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                        ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                        ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                        ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                        ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                        ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                        ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                        ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                        ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                        ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                        ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                        ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                        ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                        ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                        ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                        ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                        ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                        ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                        ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                    ])
                                                    self.address = None
                                                    self.prefix = None
                                                    self.prefix_length_xr = None
                                                    self.route_version = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.instance = None
                                                    self.client_id = None
                                                    self.route_type = None
                                                    self.priority = None
                                                    self.svd_type = None
                                                    self.flags = None
                                                    self.extended_flags = None
                                                    self.tag = None
                                                    self.distance = None
                                                    self.diversion_distance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.attribute_identity = None
                                                    self.traffic_index = None
                                                    self.route_precedence = None
                                                    self.qos_group = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.pic_count = None
                                                    self.active = None
                                                    self.diversion = None
                                                    self.diversion_proto_name = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.version = None
                                                    self.tbl_version = None
                                                    self.route_modify_time = None

                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._segment_path = lambda: "dest-best-route" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, ['address', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-best-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath))])
                                                        self._leafs = OrderedDict()

                                                        self.ipv6_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, [], name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: number_of_nnh
                                                        
                                                        	Number of Next Next Hops
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\: str
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_xcid
                                                        
                                                        	L2 Cross Connect ID exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: xcid
                                                        
                                                        	L2 Cross Connect ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: has_subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: interface_index_present
                                                        
                                                        	Interface Index present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: interface_index_attribute
                                                        
                                                        	Interface Index attribute
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: next_next_hop
                                                        
                                                        	List of Next Next Hops
                                                        	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.information_source = None
                                                            self.v6_nexthop = None
                                                            self.v6_information_source = None
                                                            self.interface_name = None
                                                            self.metric = None
                                                            self.load_metric = None
                                                            self.flags64 = None
                                                            self.flags = None
                                                            self.private_flags = None
                                                            self.looped = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_vrf_name = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_safi = None
                                                            self.route_label = None
                                                            self.tunnel_id = None
                                                            self.pathid = None
                                                            self.backup_pathid = None
                                                            self.ref_cnt_of_backup = None
                                                            self.number_of_extended_communities = None
                                                            self.mvpn_present = None
                                                            self.path_rt_present = None
                                                            self.vrf_import_rt_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.segmented_nexthop_present = None
                                                            self.number_of_nnh = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.ospf_area_id = None
                                                            self.has_labelstk = None
                                                            self.num_labels = None
                                                            self.binding_label = None
                                                            self.nhid_feid = None
                                                            self.mpls_feid = None
                                                            self.has_vxlan_network_id = None
                                                            self.vxlan_network_id = None
                                                            self.has_xcid = None
                                                            self.xcid = None
                                                            self.has_span_diag_interface = None
                                                            self.span_diag_interface = None
                                                            self.has_subscriber_parent_interface = None
                                                            self.subscriber_parent_interface = None
                                                            self.interface_index_present = None
                                                            self.interface_index_attribute = None

                                                            self.remote_backup_addr = YList(self)
                                                            self.labelstk = YList(self)
                                                            self.next_next_hop = YList(self)
                                                            self._segment_path = lambda: "ipv6-rib-edm-path"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "remote-backup-addr"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "labelstk"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class NextNextHop(Entity):
                                                            """
                                                            List of Next Next Hops
                                                            
                                                            .. attribute:: type
                                                            
                                                            	type
                                                            	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                            
                                                            .. attribute:: unknownval
                                                            
                                                            	Unknown Value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: address
                                                            
                                                            	IPv4 Address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: interface_index
                                                            
                                                            	Interface Index
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                self.yang_name = "next-next-hop"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                    ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                    ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                ])
                                                                self.type = None
                                                                self.unknownval = None
                                                                self.address = None
                                                                self.interface_index = None
                                                                self._segment_path = lambda: "next-next-hop"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class DestNextHopRoutes(Entity):
                                            """
                                            Resolving next hop
                                            
                                            .. attribute:: dest_next_hop_route
                                            
                                            	Nexthop information for a specific address
                                            	**type**\: list of  		 :py:class:`DestNextHopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, self).__init__()

                                                self.yang_name = "dest-next-hop-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dest-next-hop-route", ("dest_next_hop_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute))])
                                                self._leafs = OrderedDict()

                                                self.dest_next_hop_route = YList(self)
                                                self._segment_path = lambda: "dest-next-hop-routes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, [], name, value)


                                            class DestNextHopRoute(Entity):
                                                """
                                                Nexthop information for a specific
                                                address
                                                
                                                .. attribute:: address  (key)
                                                
                                                	Network Address 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath>`
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\: str
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\: str
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\: str
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, self).__init__()

                                                    self.yang_name = "dest-next-hop-route"
                                                    self.yang_parent_name = "dest-next-hop-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                        ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                        ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                        ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                        ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                        ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                        ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                        ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                        ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                        ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                        ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                        ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                        ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                        ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                        ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                        ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                        ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                        ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                        ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                        ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                        ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                        ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                        ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                        ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                    ])
                                                    self.address = None
                                                    self.prefix = None
                                                    self.prefix_length_xr = None
                                                    self.route_version = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.instance = None
                                                    self.client_id = None
                                                    self.route_type = None
                                                    self.priority = None
                                                    self.svd_type = None
                                                    self.flags = None
                                                    self.extended_flags = None
                                                    self.tag = None
                                                    self.distance = None
                                                    self.diversion_distance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.attribute_identity = None
                                                    self.traffic_index = None
                                                    self.route_precedence = None
                                                    self.qos_group = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.pic_count = None
                                                    self.active = None
                                                    self.diversion = None
                                                    self.diversion_proto_name = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.version = None
                                                    self.tbl_version = None
                                                    self.route_modify_time = None

                                                    self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._segment_path = lambda: "dest-next-hop-route" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, ['address', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-next-hop-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath))])
                                                        self._leafs = OrderedDict()

                                                        self.ipv6_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, [], name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: number_of_nnh
                                                        
                                                        	Number of Next Next Hops
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\: str
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_xcid
                                                        
                                                        	L2 Cross Connect ID exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: xcid
                                                        
                                                        	L2 Cross Connect ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: has_subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: interface_index_present
                                                        
                                                        	Interface Index present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: interface_index_attribute
                                                        
                                                        	Interface Index attribute
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: next_next_hop
                                                        
                                                        	List of Next Next Hops
                                                        	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.information_source = None
                                                            self.v6_nexthop = None
                                                            self.v6_information_source = None
                                                            self.interface_name = None
                                                            self.metric = None
                                                            self.load_metric = None
                                                            self.flags64 = None
                                                            self.flags = None
                                                            self.private_flags = None
                                                            self.looped = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_vrf_name = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_safi = None
                                                            self.route_label = None
                                                            self.tunnel_id = None
                                                            self.pathid = None
                                                            self.backup_pathid = None
                                                            self.ref_cnt_of_backup = None
                                                            self.number_of_extended_communities = None
                                                            self.mvpn_present = None
                                                            self.path_rt_present = None
                                                            self.vrf_import_rt_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.segmented_nexthop_present = None
                                                            self.number_of_nnh = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.ospf_area_id = None
                                                            self.has_labelstk = None
                                                            self.num_labels = None
                                                            self.binding_label = None
                                                            self.nhid_feid = None
                                                            self.mpls_feid = None
                                                            self.has_vxlan_network_id = None
                                                            self.vxlan_network_id = None
                                                            self.has_xcid = None
                                                            self.xcid = None
                                                            self.has_span_diag_interface = None
                                                            self.span_diag_interface = None
                                                            self.has_subscriber_parent_interface = None
                                                            self.subscriber_parent_interface = None
                                                            self.interface_index_present = None
                                                            self.interface_index_attribute = None

                                                            self.remote_backup_addr = YList(self)
                                                            self.labelstk = YList(self)
                                                            self.next_next_hop = YList(self)
                                                            self._segment_path = lambda: "ipv6-rib-edm-path"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "remote-backup-addr"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "labelstk"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class NextNextHop(Entity):
                                                            """
                                                            List of Next Next Hops
                                                            
                                                            .. attribute:: type
                                                            
                                                            	type
                                                            	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                            
                                                            .. attribute:: unknownval
                                                            
                                                            	Unknown Value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: address
                                                            
                                                            	IPv4 Address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: interface_index
                                                            
                                                            	Interface Index
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                self.yang_name = "next-next-hop"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                    ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                    ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                ])
                                                                self.type = None
                                                                self.unknownval = None
                                                                self.address = None
                                                                self.interface_index = None
                                                                self._segment_path = lambda: "next-next-hop"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                    class Adverts(Entity):
                                        """
                                        Route advertiser information 
                                        
                                        .. attribute:: advert
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of  		 :py:class:`Advert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, self).__init__()

                                            self.yang_name = "adverts"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advert", ("advert", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert))])
                                            self._leafs = OrderedDict()

                                            self.advert = YList(self)
                                            self._segment_path = lambda: "adverts"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, [], name, value)


                                        class Advert(Entity):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\: int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: ipv6_rib_edm_advert
                                            
                                            	ipv6 rib edm advert
                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmAdvert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, self).__init__()

                                                self.yang_name = "advert"
                                                self.yang_parent_name = "adverts"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv6-rib-edm-advert", ("ipv6_rib_edm_advert", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ])
                                                self.address = None
                                                self.prefix_length = None

                                                self.ipv6_rib_edm_advert = YList(self)
                                                self._segment_path = lambda: "advert"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, ['address', 'prefix_length'], name, value)


                                            class Ipv6RibEdmAdvert(Entity):
                                                """
                                                ipv6 rib edm advert
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	  Client advertising the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: number_of_extended_communities
                                                
                                                	Number of extended communities
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_communities
                                                
                                                	Extended communities
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: protocol_opaque_flags
                                                
                                                	OSPF area\-id flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_opaque
                                                
                                                	OSPF area\-id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: code
                                                
                                                	Protocol code
                                                	**type**\: int
                                                
                                                	**range:** \-128..127
                                                
                                                .. attribute:: instance_name
                                                
                                                	Instance name
                                                	**type**\: str
                                                
                                                	**length:** 0..41
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert, self).__init__()

                                                    self.yang_name = "ipv6-rib-edm-advert"
                                                    self.yang_parent_name = "advert"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                        ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                        ('extended_communities', (YLeaf(YType.str, 'extended-communities'), ['str'])),
                                                        ('protocol_opaque_flags', (YLeaf(YType.uint8, 'protocol-opaque-flags'), ['int'])),
                                                        ('protocol_opaque', (YLeaf(YType.uint32, 'protocol-opaque'), ['int'])),
                                                        ('code', (YLeaf(YType.int8, 'code'), ['int'])),
                                                        ('instance_name', (YLeaf(YType.str, 'instance-name'), ['str'])),
                                                    ])
                                                    self.protocol_id = None
                                                    self.client_id = None
                                                    self.number_of_extended_communities = None
                                                    self.extended_communities = None
                                                    self.protocol_opaque_flags = None
                                                    self.protocol_opaque = None
                                                    self.code = None
                                                    self.instance_name = None
                                                    self._segment_path = lambda: "ipv6-rib-edm-advert"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert, ['protocol_id', 'client_id', 'number_of_extended_communities', 'extended_communities', 'protocol_opaque_flags', 'protocol_opaque', 'code', 'instance_name'], name, value)


                                    class DeletedRoutes(Entity):
                                        """
                                        Deleted
                                        
                                        .. attribute:: deleted_route
                                        
                                        	Route information for a specific deleted address 
                                        	**type**\: list of  		 :py:class:`DeletedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, self).__init__()

                                            self.yang_name = "deleted-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("deleted-route", ("deleted_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute))])
                                            self._leafs = OrderedDict()

                                            self.deleted_route = YList(self)
                                            self._segment_path = lambda: "deleted-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, [], name, value)


                                        class DeletedRoute(Entity):
                                            """
                                            Route information for a specific
                                            deleted address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\: int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath>`
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\: str
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\: str
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\: str
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, self).__init__()

                                                self.yang_name = "deleted-route"
                                                self.yang_parent_name = "deleted-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                    ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                    ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                    ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                    ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                    ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                    ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                    ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                    ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                    ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                    ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                    ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                    ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                    ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                    ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                    ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                    ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                    ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                    ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                    ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                    ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                    ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                    ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                ])
                                                self.address = None
                                                self.prefix_length = None
                                                self.prefix = None
                                                self.prefix_length_xr = None
                                                self.route_version = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.instance = None
                                                self.client_id = None
                                                self.route_type = None
                                                self.priority = None
                                                self.svd_type = None
                                                self.flags = None
                                                self.extended_flags = None
                                                self.tag = None
                                                self.distance = None
                                                self.diversion_distance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.attribute_identity = None
                                                self.traffic_index = None
                                                self.route_precedence = None
                                                self.qos_group = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.pic_count = None
                                                self.active = None
                                                self.diversion = None
                                                self.diversion_proto_name = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.version = None
                                                self.tbl_version = None
                                                self.route_modify_time = None

                                                self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._segment_path = lambda: "deleted-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "deleted-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv6_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, [], name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: number_of_nnh
                                                    
                                                    	Number of Next Next Hops
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\: str
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_xcid
                                                    
                                                    	L2 Cross Connect ID exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: xcid
                                                    
                                                    	L2 Cross Connect ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: has_subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: interface_index_present
                                                    
                                                    	Interface Index present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: interface_index_attribute
                                                    
                                                    	Interface Index attribute
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: next_next_hop
                                                    
                                                    	List of Next Next Hops
                                                    	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                            ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                            ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                            ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                            ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                            ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                            ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                            ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                            ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                            ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                            ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                            ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                            ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                            ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                            ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                            ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                            ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                            ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                            ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                            ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                            ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                            ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                            ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                            ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                            ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                            ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                            ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                            ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                            ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                            ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                            ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                            ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                            ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                            ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                            ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                            ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                            ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                            ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                            ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                        ])
                                                        self.address = None
                                                        self.information_source = None
                                                        self.v6_nexthop = None
                                                        self.v6_information_source = None
                                                        self.interface_name = None
                                                        self.metric = None
                                                        self.load_metric = None
                                                        self.flags64 = None
                                                        self.flags = None
                                                        self.private_flags = None
                                                        self.looped = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_vrf_name = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_safi = None
                                                        self.route_label = None
                                                        self.tunnel_id = None
                                                        self.pathid = None
                                                        self.backup_pathid = None
                                                        self.ref_cnt_of_backup = None
                                                        self.number_of_extended_communities = None
                                                        self.mvpn_present = None
                                                        self.path_rt_present = None
                                                        self.vrf_import_rt_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.segmented_nexthop_present = None
                                                        self.number_of_nnh = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.ospf_area_id = None
                                                        self.has_labelstk = None
                                                        self.num_labels = None
                                                        self.binding_label = None
                                                        self.nhid_feid = None
                                                        self.mpls_feid = None
                                                        self.has_vxlan_network_id = None
                                                        self.vxlan_network_id = None
                                                        self.has_xcid = None
                                                        self.xcid = None
                                                        self.has_span_diag_interface = None
                                                        self.span_diag_interface = None
                                                        self.has_subscriber_parent_interface = None
                                                        self.subscriber_parent_interface = None
                                                        self.interface_index_present = None
                                                        self.interface_index_attribute = None

                                                        self.remote_backup_addr = YList(self)
                                                        self.labelstk = YList(self)
                                                        self.next_next_hop = YList(self)
                                                        self._segment_path = lambda: "ipv6-rib-edm-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "remote-backup-addr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "labelstk"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class NextNextHop(Entity):
                                                        """
                                                        List of Next Next Hops
                                                        
                                                        .. attribute:: type
                                                        
                                                        	type
                                                        	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                        
                                                        .. attribute:: unknownval
                                                        
                                                        	Unknown Value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: address
                                                        
                                                        	IPv4 Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_index
                                                        
                                                        	Interface Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                            self.yang_name = "next-next-hop"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                            ])
                                                            self.type = None
                                                            self.unknownval = None
                                                            self.address = None
                                                            self.interface_index = None
                                                            self._segment_path = lambda: "next-next-hop"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                    class Protocol(Entity):
                                        """
                                        Contains the classification of routes by
                                        protocol
                                        
                                        .. attribute:: local
                                        
                                        	Local Protocol
                                        	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local>`
                                        
                                        .. attribute:: bgp
                                        
                                        	BGP Protocol
                                        	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp>`
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile Protocol
                                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	EIGRP Protocol
                                        	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp>`
                                        
                                        .. attribute:: rpl
                                        
                                        	RPL Protocol
                                        	**type**\:  :py:class:`Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl>`
                                        
                                        .. attribute:: static
                                        
                                        	Static Protocol
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static>`
                                        
                                        .. attribute:: te_client
                                        
                                        	TEClient protocol
                                        	**type**\:  :py:class:`TeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient>`
                                        
                                        .. attribute:: subscriber
                                        
                                        	Subscriber Protocol
                                        	**type**\:  :py:class:`Subscriber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber>`
                                        
                                        .. attribute:: ospf
                                        
                                        	OSPF Protocol
                                        	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected Protocol
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISIS Protocol
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol, self).__init__()

                                            self.yang_name = "protocol"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local", ("local", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local)), ("bgp", ("bgp", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp)), ("mobile", ("mobile", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile)), ("eigrp", ("eigrp", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp)), ("rpl", ("rpl", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl)), ("static", ("static", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static)), ("te-client", ("te_client", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient)), ("subscriber", ("subscriber", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber)), ("ospf", ("ospf", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf)), ("connected", ("connected", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected)), ("isis", ("isis", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis))])
                                            self._leafs = OrderedDict()

                                            self.local = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local()
                                            self.local.parent = self
                                            self._children_name_map["local"] = "local"

                                            self.bgp = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"

                                            self.mobile = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile()
                                            self.mobile.parent = self
                                            self._children_name_map["mobile"] = "mobile"

                                            self.eigrp = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp()
                                            self.eigrp.parent = self
                                            self._children_name_map["eigrp"] = "eigrp"

                                            self.rpl = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl()
                                            self.rpl.parent = self
                                            self._children_name_map["rpl"] = "rpl"

                                            self.static = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.te_client = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient()
                                            self.te_client.parent = self
                                            self._children_name_map["te_client"] = "te-client"

                                            self.subscriber = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber()
                                            self.subscriber.parent = self
                                            self._children_name_map["subscriber"] = "subscriber"

                                            self.ospf = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf()
                                            self.ospf.parent = self
                                            self._children_name_map["ospf"] = "ospf"

                                            self.connected = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"
                                            self._segment_path = lambda: "protocol"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol, [], name, value)


                                        class Local(Entity):
                                            """
                                            Local Protocol
                                            
                                            .. attribute:: lspv
                                            
                                            	LSPV(Label Switched Path Verification) protocol
                                            	**type**\:  :py:class:`Lspv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:  :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local, self).__init__()

                                                self.yang_name = "local"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lspv", ("lspv", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv)), ("non-as", ("non_as", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs))])
                                                self._leafs = OrderedDict()

                                                self.lspv = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv()
                                                self.lspv.parent = self
                                                self._children_name_map["lspv"] = "lspv"

                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._segment_path = lambda: "local"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local, [], name, value)


                                            class Lspv(Entity):
                                                """
                                                LSPV(Label Switched Path Verification)
                                                protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv, self).__init__()

                                                    self.yang_name = "lspv"
                                                    self.yang_parent_name = "local"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information)), ("protocol-routes", ("protocol_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "lspv"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "lspv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "lspv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "local"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information)), ("protocol-routes", ("protocol_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "non-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Bgp(Entity):
                                            """
                                            BGP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of  		 :py:class:`As <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("as", ("as_", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As))])
                                                self._leafs = OrderedDict()

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "bgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, [], name, value)


                                            class As(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  (key)
                                                
                                                	Autonomous system
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['as_']
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.Information)), ("protocol-routes", ("protocol_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes))])
                                                    self._leafs = OrderedDict([
                                                        ('as_', (YLeaf(YType.str, 'as'), ['str'])),
                                                    ])
                                                    self.as_ = None

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "as" + "[as='" + str(self.as_) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Mobile(Entity):
                                            """
                                            Mobile Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:  :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile, self).__init__()

                                                self.yang_name = "mobile"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("non-as", ("non_as", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs))])
                                                self._leafs = OrderedDict()

                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._segment_path = lambda: "mobile"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile, [], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "mobile"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information)), ("protocol-routes", ("protocol_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "non-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            EIGRP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of  		 :py:class:`As <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("as", ("as_", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As))])
                                                self._leafs = OrderedDict()

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "eigrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, [], name, value)


                                            class As(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  (key)
                                                
                                                	Autonomous system
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['as_']
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.Information)), ("protocol-routes", ("protocol_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes))])
                                                    self._leafs = OrderedDict([
                                                        ('as_', (YLeaf(YType.str, 'as'), ['str'])),
                                                    ])
                                                    self.as_ = None

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "as" + "[as='" + str(self.as_) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Rpl(Entity):
                                            """
                                            RPL Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of  		 :py:class:`As <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, self).__init__()

                                                self.yang_name = "rpl"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("as", ("as_", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As))])
                                                self._leafs = OrderedDict()

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "rpl"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, [], name, value)


                                            class As(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  (key)
                                                
                                                	Autonomous system
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "rpl"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['as_']
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.Information)), ("protocol-routes", ("protocol_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes))])
                                                    self._leafs = OrderedDict([
                                                        ('as_', (YLeaf(YType.str, 'as'), ['str'])),
                                                    ])
                                                    self.as_ = None

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "as" + "[as='" + str(self.as_) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Static(Entity):
                                            """
                                            Static Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:  :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("non-as", ("non_as", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs))])
                                                self._leafs = OrderedDict()

                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static, [], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information)), ("protocol-routes", ("protocol_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "non-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class TeClient(Entity):
                                            """
                                            TEClient protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:  :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient, self).__init__()

                                                self.yang_name = "te-client"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("non-as", ("non_as", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs))])
                                                self._leafs = OrderedDict()

                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._segment_path = lambda: "te-client"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient, [], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "te-client"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information)), ("protocol-routes", ("protocol_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "non-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Subscriber(Entity):
                                            """
                                            Subscriber Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:  :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber, self).__init__()

                                                self.yang_name = "subscriber"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("non-as", ("non_as", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs))])
                                                self._leafs = OrderedDict()

                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._segment_path = lambda: "subscriber"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber, [], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "subscriber"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information)), ("protocol-routes", ("protocol_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "non-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Ospf(Entity):
                                            """
                                            OSPF Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of  		 :py:class:`As <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("as", ("as_", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As))])
                                                self._leafs = OrderedDict()

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "ospf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, [], name, value)


                                            class As(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  (key)
                                                
                                                	Autonomous system
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['as_']
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.Information)), ("protocol-routes", ("protocol_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes))])
                                                    self._leafs = OrderedDict([
                                                        ('as_', (YLeaf(YType.str, 'as'), ['str'])),
                                                    ])
                                                    self.as_ = None

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "as" + "[as='" + str(self.as_) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected Protocol
                                            
                                            .. attribute:: l2vpn
                                            
                                            	L2VPN
                                            	**type**\:  :py:class:`L2vpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:  :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn", ("l2vpn", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn)), ("non-as", ("non_as", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs))])
                                                self._leafs = OrderedDict()

                                                self.l2vpn = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn()
                                                self.l2vpn.parent = self
                                                self._children_name_map["l2vpn"] = "l2vpn"

                                                self.non_as = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected, [], name, value)


                                            class L2vpn(Entity):
                                                """
                                                L2VPN
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn, self).__init__()

                                                    self.yang_name = "l2vpn"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.Information)), ("protocol-routes", ("protocol_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "l2vpn"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "l2vpn"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "l2vpn"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information)), ("protocol-routes", ("protocol_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "non-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISIS Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of  		 :py:class:`As <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("as", ("as_", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As))])
                                                self._leafs = OrderedDict()

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, [], name, value)


                                            class As(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  (key)
                                                
                                                	Autonomous system
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['as_']
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.Information)), ("protocol-routes", ("protocol_routes", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes))])
                                                    self._leafs = OrderedDict([
                                                        ('as_', (YLeaf(YType.str, 'as'), ['str'])),
                                                    ])
                                                    self.as_ = None

                                                    self.information = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "as" + "[as='" + str(self.as_) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                    class Routes(Entity):
                                        """
                                        Route information 
                                        
                                        .. attribute:: route
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of  		 :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, self).__init__()

                                            self.yang_name = "routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("route", ("route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route))])
                                            self._leafs = OrderedDict()

                                            self.route = YList(self)
                                            self._segment_path = lambda: "routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, [], name, value)


                                        class Route(Entity):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\: int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	NextHop Address 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: interface_name
                                            
                                            	Outgoing Interface 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath>`
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\: str
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\: str
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\: str
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, self).__init__()

                                                self.yang_name = "route"
                                                self.yang_parent_name = "routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str'])),
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                    ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                    ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                    ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                    ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                    ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                    ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                    ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                    ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                    ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                    ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                    ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                    ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                    ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                    ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                    ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                    ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                    ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                    ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                    ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                    ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                    ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                    ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                ])
                                                self.address = None
                                                self.prefix_length = None
                                                self.next_hop_address = None
                                                self.interface_name = None
                                                self.prefix = None
                                                self.prefix_length_xr = None
                                                self.route_version = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.instance = None
                                                self.client_id = None
                                                self.route_type = None
                                                self.priority = None
                                                self.svd_type = None
                                                self.flags = None
                                                self.extended_flags = None
                                                self.tag = None
                                                self.distance = None
                                                self.diversion_distance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.attribute_identity = None
                                                self.traffic_index = None
                                                self.route_precedence = None
                                                self.qos_group = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.pic_count = None
                                                self.active = None
                                                self.diversion = None
                                                self.diversion_proto_name = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.version = None
                                                self.tbl_version = None
                                                self.route_modify_time = None

                                                self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._segment_path = lambda: "route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, ['address', 'prefix_length', 'next_hop_address', 'interface_name', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv6_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, [], name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: number_of_nnh
                                                    
                                                    	Number of Next Next Hops
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\: str
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_xcid
                                                    
                                                    	L2 Cross Connect ID exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: xcid
                                                    
                                                    	L2 Cross Connect ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: has_subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: interface_index_present
                                                    
                                                    	Interface Index present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: interface_index_attribute
                                                    
                                                    	Interface Index attribute
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: next_next_hop
                                                    
                                                    	List of Next Next Hops
                                                    	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                            ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                            ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                            ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                            ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                            ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                            ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                            ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                            ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                            ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                            ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                            ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                            ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                            ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                            ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                            ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                            ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                            ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                            ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                            ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                            ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                            ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                            ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                            ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                            ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                            ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                            ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                            ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                            ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                            ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                            ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                            ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                            ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                            ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                            ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                            ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                            ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                            ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                            ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                        ])
                                                        self.address = None
                                                        self.information_source = None
                                                        self.v6_nexthop = None
                                                        self.v6_information_source = None
                                                        self.interface_name = None
                                                        self.metric = None
                                                        self.load_metric = None
                                                        self.flags64 = None
                                                        self.flags = None
                                                        self.private_flags = None
                                                        self.looped = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_vrf_name = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_safi = None
                                                        self.route_label = None
                                                        self.tunnel_id = None
                                                        self.pathid = None
                                                        self.backup_pathid = None
                                                        self.ref_cnt_of_backup = None
                                                        self.number_of_extended_communities = None
                                                        self.mvpn_present = None
                                                        self.path_rt_present = None
                                                        self.vrf_import_rt_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.segmented_nexthop_present = None
                                                        self.number_of_nnh = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.ospf_area_id = None
                                                        self.has_labelstk = None
                                                        self.num_labels = None
                                                        self.binding_label = None
                                                        self.nhid_feid = None
                                                        self.mpls_feid = None
                                                        self.has_vxlan_network_id = None
                                                        self.vxlan_network_id = None
                                                        self.has_xcid = None
                                                        self.xcid = None
                                                        self.has_span_diag_interface = None
                                                        self.span_diag_interface = None
                                                        self.has_subscriber_parent_interface = None
                                                        self.subscriber_parent_interface = None
                                                        self.interface_index_present = None
                                                        self.interface_index_attribute = None

                                                        self.remote_backup_addr = YList(self)
                                                        self.labelstk = YList(self)
                                                        self.next_next_hop = YList(self)
                                                        self._segment_path = lambda: "ipv6-rib-edm-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "remote-backup-addr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "labelstk"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class NextNextHop(Entity):
                                                        """
                                                        List of Next Next Hops
                                                        
                                                        .. attribute:: type
                                                        
                                                        	type
                                                        	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                        
                                                        .. attribute:: unknownval
                                                        
                                                        	Unknown Value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: address
                                                        
                                                        	IPv4 Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_index
                                                        
                                                        	Interface Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                            self.yang_name = "next-next-hop"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                            ])
                                                            self.type = None
                                                            self.unknownval = None
                                                            self.address = None
                                                            self.interface_index = None
                                                            self._segment_path = lambda: "next-next-hop"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                    class QRoutes(Entity):
                                        """
                                        Quarantine
                                        
                                        .. attribute:: q_route
                                        
                                        	Route information for a specific quarantined address 
                                        	**type**\: list of  		 :py:class:`QRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, self).__init__()

                                            self.yang_name = "q-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("q-route", ("q_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute))])
                                            self._leafs = OrderedDict()

                                            self.q_route = YList(self)
                                            self._segment_path = lambda: "q-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, [], name, value)


                                        class QRoute(Entity):
                                            """
                                            Route information for a specific
                                            quarantined address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\: int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath>`
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\: str
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\: str
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\: str
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, self).__init__()

                                                self.yang_name = "q-route"
                                                self.yang_parent_name = "q-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                    ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                    ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                    ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                    ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                    ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                    ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                    ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                    ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                    ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                    ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                    ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                    ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                    ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                    ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                    ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                    ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                    ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                    ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                    ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                    ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                    ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                    ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                ])
                                                self.address = None
                                                self.prefix_length = None
                                                self.prefix = None
                                                self.prefix_length_xr = None
                                                self.route_version = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.instance = None
                                                self.client_id = None
                                                self.route_type = None
                                                self.priority = None
                                                self.svd_type = None
                                                self.flags = None
                                                self.extended_flags = None
                                                self.tag = None
                                                self.distance = None
                                                self.diversion_distance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.attribute_identity = None
                                                self.traffic_index = None
                                                self.route_precedence = None
                                                self.qos_group = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.pic_count = None
                                                self.active = None
                                                self.diversion = None
                                                self.diversion_proto_name = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.version = None
                                                self.tbl_version = None
                                                self.route_modify_time = None

                                                self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._segment_path = lambda: "q-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "q-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv6_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, [], name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: number_of_nnh
                                                    
                                                    	Number of Next Next Hops
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\: str
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_xcid
                                                    
                                                    	L2 Cross Connect ID exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: xcid
                                                    
                                                    	L2 Cross Connect ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: has_subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: interface_index_present
                                                    
                                                    	Interface Index present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: interface_index_attribute
                                                    
                                                    	Interface Index attribute
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: next_next_hop
                                                    
                                                    	List of Next Next Hops
                                                    	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                            ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                            ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                            ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                            ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                            ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                            ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                            ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                            ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                            ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                            ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                            ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                            ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                            ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                            ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                            ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                            ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                            ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                            ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                            ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                            ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                            ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                            ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                            ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                            ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                            ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                            ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                            ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                            ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                            ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                            ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                            ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                            ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                            ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                            ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                            ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                            ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                            ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                            ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                        ])
                                                        self.address = None
                                                        self.information_source = None
                                                        self.v6_nexthop = None
                                                        self.v6_information_source = None
                                                        self.interface_name = None
                                                        self.metric = None
                                                        self.load_metric = None
                                                        self.flags64 = None
                                                        self.flags = None
                                                        self.private_flags = None
                                                        self.looped = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_vrf_name = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_safi = None
                                                        self.route_label = None
                                                        self.tunnel_id = None
                                                        self.pathid = None
                                                        self.backup_pathid = None
                                                        self.ref_cnt_of_backup = None
                                                        self.number_of_extended_communities = None
                                                        self.mvpn_present = None
                                                        self.path_rt_present = None
                                                        self.vrf_import_rt_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.segmented_nexthop_present = None
                                                        self.number_of_nnh = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.ospf_area_id = None
                                                        self.has_labelstk = None
                                                        self.num_labels = None
                                                        self.binding_label = None
                                                        self.nhid_feid = None
                                                        self.mpls_feid = None
                                                        self.has_vxlan_network_id = None
                                                        self.vxlan_network_id = None
                                                        self.has_xcid = None
                                                        self.xcid = None
                                                        self.has_span_diag_interface = None
                                                        self.span_diag_interface = None
                                                        self.has_subscriber_parent_interface = None
                                                        self.subscriber_parent_interface = None
                                                        self.interface_index_present = None
                                                        self.interface_index_attribute = None

                                                        self.remote_backup_addr = YList(self)
                                                        self.labelstk = YList(self)
                                                        self.next_next_hop = YList(self)
                                                        self._segment_path = lambda: "ipv6-rib-edm-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "remote-backup-addr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "labelstk"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class NextNextHop(Entity):
                                                        """
                                                        List of Next Next Hops
                                                        
                                                        .. attribute:: type
                                                        
                                                        	type
                                                        	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                        
                                                        .. attribute:: unknownval
                                                        
                                                        	Unknown Value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: address
                                                        
                                                        	IPv4 Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_index
                                                        
                                                        	Interface Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                            self.yang_name = "next-next-hop"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                            ])
                                                            self.type = None
                                                            self.unknownval = None
                                                            self.address = None
                                                            self.interface_index = None
                                                            self._segment_path = lambda: "next-next-hop"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                    class BackupRoutes(Entity):
                                        """
                                        Backup route information for the given
                                        table
                                        
                                        .. attribute:: backup_route
                                        
                                        	Route information for a specific backup address 
                                        	**type**\: list of  		 :py:class:`BackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, self).__init__()

                                            self.yang_name = "backup-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("backup-route", ("backup_route", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute))])
                                            self._leafs = OrderedDict()

                                            self.backup_route = YList(self)
                                            self._segment_path = lambda: "backup-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, [], name, value)


                                        class BackupRoute(Entity):
                                            """
                                            Route information for a specific backup
                                            address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\: int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: protoid
                                            
                                            	Proto ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath>`
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\: str
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\: str
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\: str
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, self).__init__()

                                                self.yang_name = "backup-route"
                                                self.yang_parent_name = "backup-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('protoid', (YLeaf(YType.uint32, 'protoid'), ['int'])),
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                    ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                    ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                    ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                    ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                    ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                    ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                    ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                    ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                    ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                    ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                    ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                    ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                    ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                    ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                    ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                    ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                    ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                    ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                    ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                    ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                    ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                    ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                ])
                                                self.address = None
                                                self.prefix_length = None
                                                self.protoid = None
                                                self.prefix = None
                                                self.prefix_length_xr = None
                                                self.route_version = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.instance = None
                                                self.client_id = None
                                                self.route_type = None
                                                self.priority = None
                                                self.svd_type = None
                                                self.flags = None
                                                self.extended_flags = None
                                                self.tag = None
                                                self.distance = None
                                                self.diversion_distance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.attribute_identity = None
                                                self.traffic_index = None
                                                self.route_precedence = None
                                                self.qos_group = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.pic_count = None
                                                self.active = None
                                                self.diversion = None
                                                self.diversion_proto_name = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.version = None
                                                self.tbl_version = None
                                                self.route_modify_time = None

                                                self.route_path = Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._segment_path = lambda: "backup-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, ['address', 'prefix_length', 'protoid', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "backup-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv6_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, [], name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: number_of_nnh
                                                    
                                                    	Number of Next Next Hops
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\: str
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_xcid
                                                    
                                                    	L2 Cross Connect ID exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: xcid
                                                    
                                                    	L2 Cross Connect ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: has_subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: interface_index_present
                                                    
                                                    	Interface Index present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: interface_index_attribute
                                                    
                                                    	Interface Index attribute
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: next_next_hop
                                                    
                                                    	List of Next Next Hops
                                                    	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                            ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                            ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                            ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                            ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                            ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                            ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                            ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                            ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                            ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                            ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                            ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                            ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                            ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                            ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                            ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                            ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                            ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                            ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                            ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                            ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                            ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                            ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                            ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                            ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                            ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                            ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                            ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                            ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                            ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                            ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                            ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                            ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                            ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                            ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                            ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                            ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                            ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                            ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                        ])
                                                        self.address = None
                                                        self.information_source = None
                                                        self.v6_nexthop = None
                                                        self.v6_information_source = None
                                                        self.interface_name = None
                                                        self.metric = None
                                                        self.load_metric = None
                                                        self.flags64 = None
                                                        self.flags = None
                                                        self.private_flags = None
                                                        self.looped = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_vrf_name = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_safi = None
                                                        self.route_label = None
                                                        self.tunnel_id = None
                                                        self.pathid = None
                                                        self.backup_pathid = None
                                                        self.ref_cnt_of_backup = None
                                                        self.number_of_extended_communities = None
                                                        self.mvpn_present = None
                                                        self.path_rt_present = None
                                                        self.vrf_import_rt_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.segmented_nexthop_present = None
                                                        self.number_of_nnh = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.ospf_area_id = None
                                                        self.has_labelstk = None
                                                        self.num_labels = None
                                                        self.binding_label = None
                                                        self.nhid_feid = None
                                                        self.mpls_feid = None
                                                        self.has_vxlan_network_id = None
                                                        self.vxlan_network_id = None
                                                        self.has_xcid = None
                                                        self.xcid = None
                                                        self.has_span_diag_interface = None
                                                        self.span_diag_interface = None
                                                        self.has_subscriber_parent_interface = None
                                                        self.subscriber_parent_interface = None
                                                        self.interface_index_present = None
                                                        self.interface_index_attribute = None

                                                        self.remote_backup_addr = YList(self)
                                                        self.labelstk = YList(self)
                                                        self.next_next_hop = YList(self)
                                                        self._segment_path = lambda: "ipv6-rib-edm-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "remote-backup-addr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "labelstk"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class NextNextHop(Entity):
                                                        """
                                                        List of Next Next Hops
                                                        
                                                        .. attribute:: type
                                                        
                                                        	type
                                                        	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                        
                                                        .. attribute:: unknownval
                                                        
                                                        	Unknown Value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: address
                                                        
                                                        	IPv4 Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_index
                                                        
                                                        	Interface Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                            self.yang_name = "next-next-hop"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                            ])
                                                            self.type = None
                                                            self.unknownval = None
                                                            self.address = None
                                                            self.interface_index = None
                                                            self._segment_path = lambda: "next-next-hop"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)

    def clone_ptr(self):
        self._top_entity = Ipv6Rib()
        return self._top_entity

class Ipv6RibStdby(Entity):
    """
    ipv6 rib stdby
    
    .. attribute:: rib_table_ids
    
    	RIB table
    	**type**\:  :py:class:`RibTableIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds>`
    
    .. attribute:: vrfs
    
    	VRF table
    	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs>`
    
    

    """

    _prefix = 'ip-rib-ipv6-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(Ipv6RibStdby, self).__init__()
        self._top_entity = None

        self.yang_name = "ipv6-rib-stdby"
        self.yang_parent_name = "Cisco-IOS-XR-ip-rib-ipv6-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("rib-table-ids", ("rib_table_ids", Ipv6RibStdby.RibTableIds)), ("vrfs", ("vrfs", Ipv6RibStdby.Vrfs))])
        self._leafs = OrderedDict()

        self.rib_table_ids = Ipv6RibStdby.RibTableIds()
        self.rib_table_ids.parent = self
        self._children_name_map["rib_table_ids"] = "rib-table-ids"

        self.vrfs = Ipv6RibStdby.Vrfs()
        self.vrfs.parent = self
        self._children_name_map["vrfs"] = "vrfs"
        self._segment_path = lambda: "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(Ipv6RibStdby, [], name, value)


    class RibTableIds(Entity):
        """
        RIB table
        
        .. attribute:: rib_table_id
        
        	Specific Table
        	**type**\: list of  		 :py:class:`RibTableId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId>`
        
        

        """

        _prefix = 'ip-rib-ipv6-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Ipv6RibStdby.RibTableIds, self).__init__()

            self.yang_name = "rib-table-ids"
            self.yang_parent_name = "ipv6-rib-stdby"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("rib-table-id", ("rib_table_id", Ipv6RibStdby.RibTableIds.RibTableId))])
            self._leafs = OrderedDict()

            self.rib_table_id = YList(self)
            self._segment_path = lambda: "rib-table-ids"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Ipv6RibStdby.RibTableIds, [], name, value)


        class RibTableId(Entity):
            """
            Specific Table
            
            .. attribute:: tableid  (key)
            
            	Table ID
            	**type**\: str
            
            	**pattern:** [0\-9a\-fA\-F]{1,8}
            
            .. attribute:: information
            
            	Table related Information
            	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.Information>`
            
            .. attribute:: summary_protos
            
            	RIB table summary
            	**type**\:  :py:class:`SummaryProtos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos>`
            
            .. attribute:: rib_table_itf_hndls
            
            	RIB table interface
            	**type**\:  :py:class:`RibTableItfHndls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls>`
            
            

            """

            _prefix = 'ip-rib-ipv6-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Ipv6RibStdby.RibTableIds.RibTableId, self).__init__()

                self.yang_name = "rib-table-id"
                self.yang_parent_name = "rib-table-ids"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['tableid']
                self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.RibTableIds.RibTableId.Information)), ("summary-protos", ("summary_protos", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos)), ("rib-table-itf-hndls", ("rib_table_itf_hndls", Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls))])
                self._leafs = OrderedDict([
                    ('tableid', (YLeaf(YType.str, 'tableid'), ['str'])),
                ])
                self.tableid = None

                self.information = Ipv6RibStdby.RibTableIds.RibTableId.Information()
                self.information.parent = self
                self._children_name_map["information"] = "information"

                self.summary_protos = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos()
                self.summary_protos.parent = self
                self._children_name_map["summary_protos"] = "summary-protos"

                self.rib_table_itf_hndls = Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls()
                self.rib_table_itf_hndls.parent = self
                self._children_name_map["rib_table_itf_hndls"] = "rib-table-itf-hndls"
                self._segment_path = lambda: "rib-table-id" + "[tableid='" + str(self.tableid) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby/rib-table-ids/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId, ['tableid'], name, value)


            class Information(Entity):
                """
                Table related Information
                
                .. attribute:: tableid
                
                	Table id
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: afi
                
                	Address Family
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: safi
                
                	sub Address Family
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vrf_name
                
                	VRF Name of the table
                	**type**\: str
                
                .. attribute:: table_name
                
                	Name of the table
                	**type**\: str
                
                .. attribute:: version
                
                	Table version
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: conf_prefix_limit
                
                	Configured prefix limit
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: current_prefix_count
                
                	Num prefixes in table
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_svdlcl_prefix
                
                	Num SVD local prefixes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_svdrem_prefix
                
                	Num SVD remote prefixes
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_version
                
                	Version no. of the table
                	**type**\: int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: prefix_limit_notified
                
                	Prefix limit state indicator
                	**type**\: bool
                
                .. attribute:: fwd_referenced
                
                	Table in fwd reference state?
                	**type**\: bool
                
                .. attribute:: deleted
                
                	Table deleted?
                	**type**\: bool
                
                .. attribute:: initial_converge
                
                	Table has reached convergence
                	**type**\: bool
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6RibStdby.RibTableIds.RibTableId.Information, self).__init__()

                    self.yang_name = "information"
                    self.yang_parent_name = "rib-table-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('tableid', (YLeaf(YType.uint32, 'tableid'), ['int'])),
                        ('afi', (YLeaf(YType.uint32, 'afi'), ['int'])),
                        ('safi', (YLeaf(YType.uint32, 'safi'), ['int'])),
                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ('table_name', (YLeaf(YType.str, 'table-name'), ['str'])),
                        ('version', (YLeaf(YType.uint64, 'version'), ['int'])),
                        ('conf_prefix_limit', (YLeaf(YType.uint32, 'conf-prefix-limit'), ['int'])),
                        ('current_prefix_count', (YLeaf(YType.uint32, 'current-prefix-count'), ['int'])),
                        ('num_svdlcl_prefix', (YLeaf(YType.uint32, 'num-svdlcl-prefix'), ['int'])),
                        ('num_svdrem_prefix', (YLeaf(YType.uint32, 'num-svdrem-prefix'), ['int'])),
                        ('table_version', (YLeaf(YType.uint64, 'table-version'), ['int'])),
                        ('prefix_limit_notified', (YLeaf(YType.boolean, 'prefix-limit-notified'), ['bool'])),
                        ('fwd_referenced', (YLeaf(YType.boolean, 'fwd-referenced'), ['bool'])),
                        ('deleted', (YLeaf(YType.boolean, 'deleted'), ['bool'])),
                        ('initial_converge', (YLeaf(YType.boolean, 'initial-converge'), ['bool'])),
                    ])
                    self.tableid = None
                    self.afi = None
                    self.safi = None
                    self.vrf_name = None
                    self.table_name = None
                    self.version = None
                    self.conf_prefix_limit = None
                    self.current_prefix_count = None
                    self.num_svdlcl_prefix = None
                    self.num_svdrem_prefix = None
                    self.table_version = None
                    self.prefix_limit_notified = None
                    self.fwd_referenced = None
                    self.deleted = None
                    self.initial_converge = None
                    self._segment_path = lambda: "information"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.Information, ['tableid', 'afi', 'safi', 'vrf_name', 'table_name', 'version', 'conf_prefix_limit', 'current_prefix_count', 'num_svdlcl_prefix', 'num_svdrem_prefix', 'table_version', 'prefix_limit_notified', 'fwd_referenced', 'deleted', 'initial_converge'], name, value)


            class SummaryProtos(Entity):
                """
                RIB table summary
                
                .. attribute:: summary_proto
                
                	Route summary information for a specific table/protocol 
                	**type**\: list of  		 :py:class:`SummaryProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos, self).__init__()

                    self.yang_name = "summary-protos"
                    self.yang_parent_name = "rib-table-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("summary-proto", ("summary_proto", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto))])
                    self._leafs = OrderedDict()

                    self.summary_proto = YList(self)
                    self._segment_path = lambda: "summary-protos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos, [], name, value)


                class SummaryProto(Entity):
                    """
                    Route summary information for a specific
                    table/protocol 
                    
                    .. attribute:: protoid  (key)
                    
                    	Proto ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proto_route_count
                    
                    	Count for proto. instance
                    	**type**\:  :py:class:`ProtoRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount>`
                    
                    .. attribute:: rtype_none
                    
                    	No route type
                    	**type**\:  :py:class:`RtypeNone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone>`
                    
                    .. attribute:: rtype_other
                    
                    	Unknown route type
                    	**type**\:  :py:class:`RtypeOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther>`
                    
                    .. attribute:: rtype_ospf_intra
                    
                    	OSPF route within an area
                    	**type**\:  :py:class:`RtypeOspfIntra <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra>`
                    
                    .. attribute:: rtype_ospf_inter
                    
                    	OSPF route across diff. areas
                    	**type**\:  :py:class:`RtypeOspfInter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter>`
                    
                    .. attribute:: rtype_ospf_extern1
                    
                    	OSPF external route of type 1
                    	**type**\:  :py:class:`RtypeOspfExtern1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1>`
                    
                    .. attribute:: rtype_ospf_extern2
                    
                    	OSPF external route of type 2
                    	**type**\:  :py:class:`RtypeOspfExtern2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2>`
                    
                    .. attribute:: rtype_isis_sum
                    
                    	IS\-IS summary route
                    	**type**\:  :py:class:`RtypeIsisSum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum>`
                    
                    .. attribute:: rtype_isis_l1
                    
                    	IS\-IS level 1 route
                    	**type**\:  :py:class:`RtypeIsisL1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1>`
                    
                    .. attribute:: rtype_isis_l2
                    
                    	IS\-IS level 2 route
                    	**type**\:  :py:class:`RtypeIsisL2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2>`
                    
                    .. attribute:: rtype_isis_l1_ia
                    
                    	IS\-IS level1 inter\-area route
                    	**type**\:  :py:class:`RtypeIsisL1Ia <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia>`
                    
                    .. attribute:: rtype_bgp_int
                    
                    	iBGP route
                    	**type**\:  :py:class:`RtypeBgpInt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt>`
                    
                    .. attribute:: rtype_bgp_ext
                    
                    	eBGP route
                    	**type**\:  :py:class:`RtypeBgpExt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt>`
                    
                    .. attribute:: rtype_bgp_loc
                    
                    	BGP local route
                    	**type**\:  :py:class:`RtypeBgpLoc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc>`
                    
                    .. attribute:: rtype_ospf_nssa1
                    
                    	OSPF NSSA ext. route type 1
                    	**type**\:  :py:class:`RtypeOspfNssa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1>`
                    
                    .. attribute:: rtype_ospf_nssa2
                    
                    	OSPF NSSA ext. route type 2
                    	**type**\:  :py:class:`RtypeOspfNssa2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2>`
                    
                    .. attribute:: rtype_igrp2_int
                    
                    	EIGRP internal route
                    	**type**\:  :py:class:`RtypeIgrp2Int <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int>`
                    
                    .. attribute:: rtype_igrp2_ext
                    
                    	EIGRP external route
                    	**type**\:  :py:class:`RtypeIgrp2Ext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext>`
                    
                    .. attribute:: name
                    
                    	Proto name
                    	**type**\: str
                    
                    .. attribute:: instance
                    
                    	Instance
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto, self).__init__()

                        self.yang_name = "summary-proto"
                        self.yang_parent_name = "summary-protos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['protoid']
                        self._child_classes = OrderedDict([("proto-route-count", ("proto_route_count", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount)), ("rtype-none", ("rtype_none", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone)), ("rtype-other", ("rtype_other", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther)), ("rtype-ospf-intra", ("rtype_ospf_intra", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra)), ("rtype-ospf-inter", ("rtype_ospf_inter", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter)), ("rtype-ospf-extern1", ("rtype_ospf_extern1", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1)), ("rtype-ospf-extern2", ("rtype_ospf_extern2", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2)), ("rtype-isis-sum", ("rtype_isis_sum", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum)), ("rtype-isis-l1", ("rtype_isis_l1", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1)), ("rtype-isis-l2", ("rtype_isis_l2", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2)), ("rtype-isis-l1-ia", ("rtype_isis_l1_ia", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia)), ("rtype-bgp-int", ("rtype_bgp_int", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt)), ("rtype-bgp-ext", ("rtype_bgp_ext", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt)), ("rtype-bgp-loc", ("rtype_bgp_loc", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc)), ("rtype-ospf-nssa1", ("rtype_ospf_nssa1", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1)), ("rtype-ospf-nssa2", ("rtype_ospf_nssa2", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2)), ("rtype-igrp2-int", ("rtype_igrp2_int", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int)), ("rtype-igrp2-ext", ("rtype_igrp2_ext", Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext))])
                        self._leafs = OrderedDict([
                            ('protoid', (YLeaf(YType.uint32, 'protoid'), ['int'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                        ])
                        self.protoid = None
                        self.name = None
                        self.instance = None

                        self.proto_route_count = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount()
                        self.proto_route_count.parent = self
                        self._children_name_map["proto_route_count"] = "proto-route-count"

                        self.rtype_none = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone()
                        self.rtype_none.parent = self
                        self._children_name_map["rtype_none"] = "rtype-none"

                        self.rtype_other = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther()
                        self.rtype_other.parent = self
                        self._children_name_map["rtype_other"] = "rtype-other"

                        self.rtype_ospf_intra = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra()
                        self.rtype_ospf_intra.parent = self
                        self._children_name_map["rtype_ospf_intra"] = "rtype-ospf-intra"

                        self.rtype_ospf_inter = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter()
                        self.rtype_ospf_inter.parent = self
                        self._children_name_map["rtype_ospf_inter"] = "rtype-ospf-inter"

                        self.rtype_ospf_extern1 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1()
                        self.rtype_ospf_extern1.parent = self
                        self._children_name_map["rtype_ospf_extern1"] = "rtype-ospf-extern1"

                        self.rtype_ospf_extern2 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2()
                        self.rtype_ospf_extern2.parent = self
                        self._children_name_map["rtype_ospf_extern2"] = "rtype-ospf-extern2"

                        self.rtype_isis_sum = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum()
                        self.rtype_isis_sum.parent = self
                        self._children_name_map["rtype_isis_sum"] = "rtype-isis-sum"

                        self.rtype_isis_l1 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1()
                        self.rtype_isis_l1.parent = self
                        self._children_name_map["rtype_isis_l1"] = "rtype-isis-l1"

                        self.rtype_isis_l2 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2()
                        self.rtype_isis_l2.parent = self
                        self._children_name_map["rtype_isis_l2"] = "rtype-isis-l2"

                        self.rtype_isis_l1_ia = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia()
                        self.rtype_isis_l1_ia.parent = self
                        self._children_name_map["rtype_isis_l1_ia"] = "rtype-isis-l1-ia"

                        self.rtype_bgp_int = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt()
                        self.rtype_bgp_int.parent = self
                        self._children_name_map["rtype_bgp_int"] = "rtype-bgp-int"

                        self.rtype_bgp_ext = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt()
                        self.rtype_bgp_ext.parent = self
                        self._children_name_map["rtype_bgp_ext"] = "rtype-bgp-ext"

                        self.rtype_bgp_loc = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc()
                        self.rtype_bgp_loc.parent = self
                        self._children_name_map["rtype_bgp_loc"] = "rtype-bgp-loc"

                        self.rtype_ospf_nssa1 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1()
                        self.rtype_ospf_nssa1.parent = self
                        self._children_name_map["rtype_ospf_nssa1"] = "rtype-ospf-nssa1"

                        self.rtype_ospf_nssa2 = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2()
                        self.rtype_ospf_nssa2.parent = self
                        self._children_name_map["rtype_ospf_nssa2"] = "rtype-ospf-nssa2"

                        self.rtype_igrp2_int = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int()
                        self.rtype_igrp2_int.parent = self
                        self._children_name_map["rtype_igrp2_int"] = "rtype-igrp2-int"

                        self.rtype_igrp2_ext = Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext()
                        self.rtype_igrp2_ext.parent = self
                        self._children_name_map["rtype_igrp2_ext"] = "rtype-igrp2-ext"
                        self._segment_path = lambda: "summary-proto" + "[protoid='" + str(self.protoid) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto, ['protoid', 'name', 'instance'], name, value)


                    class ProtoRouteCount(Entity):
                        """
                        Count for proto. instance
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, self).__init__()

                            self.yang_name = "proto-route-count"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "proto-route-count"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeNone(Entity):
                        """
                        No route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, self).__init__()

                            self.yang_name = "rtype-none"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-none"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOther(Entity):
                        """
                        Unknown route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, self).__init__()

                            self.yang_name = "rtype-other"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-other"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOspfIntra(Entity):
                        """
                        OSPF route within an area
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, self).__init__()

                            self.yang_name = "rtype-ospf-intra"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-ospf-intra"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOspfInter(Entity):
                        """
                        OSPF route across diff. areas
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, self).__init__()

                            self.yang_name = "rtype-ospf-inter"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-ospf-inter"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOspfExtern1(Entity):
                        """
                        OSPF external route of type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, self).__init__()

                            self.yang_name = "rtype-ospf-extern1"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-ospf-extern1"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOspfExtern2(Entity):
                        """
                        OSPF external route of type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, self).__init__()

                            self.yang_name = "rtype-ospf-extern2"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-ospf-extern2"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeIsisSum(Entity):
                        """
                        IS\-IS summary route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, self).__init__()

                            self.yang_name = "rtype-isis-sum"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-isis-sum"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeIsisL1(Entity):
                        """
                        IS\-IS level 1 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, self).__init__()

                            self.yang_name = "rtype-isis-l1"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-isis-l1"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeIsisL2(Entity):
                        """
                        IS\-IS level 2 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, self).__init__()

                            self.yang_name = "rtype-isis-l2"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-isis-l2"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeIsisL1Ia(Entity):
                        """
                        IS\-IS level1 inter\-area route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, self).__init__()

                            self.yang_name = "rtype-isis-l1-ia"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-isis-l1-ia"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeBgpInt(Entity):
                        """
                        iBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, self).__init__()

                            self.yang_name = "rtype-bgp-int"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-bgp-int"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeBgpExt(Entity):
                        """
                        eBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, self).__init__()

                            self.yang_name = "rtype-bgp-ext"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-bgp-ext"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeBgpLoc(Entity):
                        """
                        BGP local route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, self).__init__()

                            self.yang_name = "rtype-bgp-loc"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-bgp-loc"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOspfNssa1(Entity):
                        """
                        OSPF NSSA ext. route type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, self).__init__()

                            self.yang_name = "rtype-ospf-nssa1"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-ospf-nssa1"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeOspfNssa2(Entity):
                        """
                        OSPF NSSA ext. route type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, self).__init__()

                            self.yang_name = "rtype-ospf-nssa2"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-ospf-nssa2"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeIgrp2Int(Entity):
                        """
                        EIGRP internal route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, self).__init__()

                            self.yang_name = "rtype-igrp2-int"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-igrp2-int"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


                    class RtypeIgrp2Ext(Entity):
                        """
                        EIGRP external route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, self).__init__()

                            self.yang_name = "rtype-igrp2-ext"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                ('num_backup_routes', (YLeaf(YType.uint32, 'num-backup-routes'), ['int'])),
                                ('num_active_paths', (YLeaf(YType.uint32, 'num-active-paths'), ['int'])),
                                ('num_backup_paths', (YLeaf(YType.uint32, 'num-backup-paths'), ['int'])),
                            ])
                            self.active_routes_count = None
                            self.num_backup_routes = None
                            self.num_active_paths = None
                            self.num_backup_paths = None
                            self._segment_path = lambda: "rtype-igrp2-ext"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, ['active_routes_count', 'num_backup_routes', 'num_active_paths', 'num_backup_paths'], name, value)


            class RibTableItfHndls(Entity):
                """
                RIB table interface
                
                .. attribute:: rib_table_itf_hndl
                
                	Interface handle
                	**type**\: list of  		 :py:class:`RibTableItfHndl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls, self).__init__()

                    self.yang_name = "rib-table-itf-hndls"
                    self.yang_parent_name = "rib-table-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rib-table-itf-hndl", ("rib_table_itf_hndl", Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl))])
                    self._leafs = OrderedDict()

                    self.rib_table_itf_hndl = YList(self)
                    self._segment_path = lambda: "rib-table-itf-hndls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls, [], name, value)


                class RibTableItfHndl(Entity):
                    """
                    Interface handle
                    
                    .. attribute:: handle  (key)
                    
                    	Itf Handle
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: itf_route
                    
                    	Route information for a specific table/interface 
                    	**type**\: list of  		 :py:class:`ItfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, self).__init__()

                        self.yang_name = "rib-table-itf-hndl"
                        self.yang_parent_name = "rib-table-itf-hndls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['handle']
                        self._child_classes = OrderedDict([("itf-route", ("itf_route", Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute))])
                        self._leafs = OrderedDict([
                            ('handle', (YLeaf(YType.uint32, 'handle'), ['int'])),
                        ])
                        self.handle = None

                        self.itf_route = YList(self)
                        self._segment_path = lambda: "rib-table-itf-hndl" + "[handle='" + str(self.handle) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, ['handle'], name, value)


                    class ItfRoute(Entity):
                        """
                        Route information for a specific
                        table/interface 
                        
                        .. attribute:: address  (key)
                        
                        	Network Address 
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: route_path
                        
                        	Path(s) of the route
                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath>`
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length_xr
                        
                        	Length of prefix
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_version
                        
                        	Route version
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol_id
                        
                        	Protocol advertising the route
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol_name
                        
                        	 Name of Protocol
                        	**type**\: str
                        
                        .. attribute:: instance
                        
                        	Instance name
                        	**type**\: str
                        
                        .. attribute:: client_id
                        
                        	Client adding the route to RIB
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_type
                        
                        	Route type
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: priority
                        
                        	Route priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: svd_type
                        
                        	SVD Type of route
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: flags
                        
                        	Route flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: extended_flags
                        
                        	Extended Route flags
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: tag
                        
                        	Opaque proto specific info
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: distance
                        
                        	Distance of the route
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion_distance
                        
                        	Diversion distance of the route
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: metric
                        
                        	Route metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_count
                        
                        	Number of paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_identity
                        
                        	BGP Attribute ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: traffic_index
                        
                        	BGP Traffic Index
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_precedence
                        
                        	Route ip precedence
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: qos_group
                        
                        	Route qos group
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: flow_tag
                        
                        	Flow tag
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: fwd_class
                        
                        	Forward Class
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: pic_count
                        
                        	Number of pic paths in this route
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: active
                        
                        	Is the route active or backup
                        	**type**\: bool
                        
                        .. attribute:: diversion
                        
                        	Route has a diversion path
                        	**type**\: bool
                        
                        .. attribute:: diversion_proto_name
                        
                        	Diversion route protocol name
                        	**type**\: str
                        
                        .. attribute:: route_age
                        
                        	Age of route (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: route_label
                        
                        	Local label of the route
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: version
                        
                        	Route Version
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tbl_version
                        
                        	Table Version
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: route_modify_time
                        
                        	Route modification time(nanoseconds)
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, self).__init__()

                            self.yang_name = "itf-route"
                            self.yang_parent_name = "rib-table-itf-hndl"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['address']
                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath))])
                            self._leafs = OrderedDict([
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                            ])
                            self.address = None
                            self.prefix = None
                            self.prefix_length_xr = None
                            self.route_version = None
                            self.protocol_id = None
                            self.protocol_name = None
                            self.instance = None
                            self.client_id = None
                            self.route_type = None
                            self.priority = None
                            self.svd_type = None
                            self.flags = None
                            self.extended_flags = None
                            self.tag = None
                            self.distance = None
                            self.diversion_distance = None
                            self.metric = None
                            self.paths_count = None
                            self.attribute_identity = None
                            self.traffic_index = None
                            self.route_precedence = None
                            self.qos_group = None
                            self.flow_tag = None
                            self.fwd_class = None
                            self.pic_count = None
                            self.active = None
                            self.diversion = None
                            self.diversion_proto_name = None
                            self.route_age = None
                            self.route_label = None
                            self.version = None
                            self.tbl_version = None
                            self.route_modify_time = None

                            self.route_path = Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath()
                            self.route_path.parent = self
                            self._children_name_map["route_path"] = "route-path"
                            self._segment_path = lambda: "itf-route" + "[address='" + str(self.address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, ['address', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                        class RoutePath(Entity):
                            """
                            Path(s) of the route
                            
                            .. attribute:: ipv6_rib_edm_path
                            
                            	ipv6 rib edm path
                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv6-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, self).__init__()

                                self.yang_name = "route-path"
                                self.yang_parent_name = "itf-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath))])
                                self._leafs = OrderedDict()

                                self.ipv6_rib_edm_path = YList(self)
                                self._segment_path = lambda: "route-path"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, [], name, value)


                            class Ipv6RibEdmPath(Entity):
                                """
                                ipv6 rib edm path
                                
                                .. attribute:: address
                                
                                	Nexthop
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: information_source
                                
                                	Infosource
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: v6_nexthop
                                
                                	V6 nexthop
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: v6_information_source
                                
                                	V6 Infosource
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_name
                                
                                	Interface Name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: metric
                                
                                	Metrics
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: load_metric
                                
                                	Load Metrics
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flags64
                                
                                	Flags extended to 64 bits
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: flags
                                
                                	Flags
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: private_flags
                                
                                	Private Flags
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: looped
                                
                                	Looping path
                                	**type**\: bool
                                
                                .. attribute:: next_hop_table_id
                                
                                	Nexthop tableid
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_vrf_name
                                
                                	VRF Name of the nh table
                                	**type**\: str
                                
                                .. attribute:: next_hop_table_name
                                
                                	NH table name
                                	**type**\: str
                                
                                .. attribute:: next_hop_afi
                                
                                	NH afi
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_safi
                                
                                	NH safi
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_label
                                
                                	Label associated with this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_id
                                
                                	Tunnel ID associated with this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pathid
                                
                                	Path id of this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pathid
                                
                                	Path id of this path's backup
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ref_cnt_of_backup
                                
                                	Refcnt of backup
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_extended_communities
                                
                                	Number of extended communities
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mvpn_present
                                
                                	MVPN attribute present
                                	**type**\: bool
                                
                                .. attribute:: path_rt_present
                                
                                	Path RT present
                                	**type**\: bool
                                
                                .. attribute:: vrf_import_rt_present
                                
                                	VRFIMPORTRTPresent
                                	**type**\: bool
                                
                                .. attribute:: source_asrt_present
                                
                                	SOURCEASRTPresent
                                	**type**\: bool
                                
                                .. attribute:: source_rd_present
                                
                                	SOURCERDPresent
                                	**type**\: bool
                                
                                .. attribute:: segmented_nexthop_present
                                
                                	SegmentedNexthopPresent
                                	**type**\: bool
                                
                                .. attribute:: number_of_nnh
                                
                                	Number of Next Next Hops
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id
                                
                                	NHID associated with this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id_refcount
                                
                                	NHID references
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_area_id
                                
                                	OSPF area associated with the path
                                	**type**\: str
                                
                                .. attribute:: has_labelstk
                                
                                	Path has a label stack
                                	**type**\: bool
                                
                                .. attribute:: num_labels
                                
                                	Number of labels in stack
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: binding_label
                                
                                	binding Label for this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nhid_feid
                                
                                	Fib nhid encap id
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: mpls_feid
                                
                                	Fib mpls encap id
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: has_vxlan_network_id
                                
                                	VXLAN Network Identifier exists for this path
                                	**type**\: bool
                                
                                .. attribute:: vxlan_network_id
                                
                                	VXLAN Network Identifier for this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: has_xcid
                                
                                	L2 Cross Connect ID exists for this path
                                	**type**\: bool
                                
                                .. attribute:: xcid
                                
                                	L2 Cross Connect ID for this path
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: has_span_diag_interface
                                
                                	SPAN Diagnostics Interface exists for this path
                                	**type**\: bool
                                
                                .. attribute:: span_diag_interface
                                
                                	SPAN Diagnostics Interface for this path
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: has_subscriber_parent_interface
                                
                                	Subscriber Parent Interface exists for this path
                                	**type**\: bool
                                
                                .. attribute:: subscriber_parent_interface
                                
                                	Subscriber Parent Interface for this path
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: interface_index_present
                                
                                	Interface Index present
                                	**type**\: bool
                                
                                .. attribute:: interface_index_attribute
                                
                                	Interface Index attribute
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_backup_addr
                                
                                	Remote backup node address
                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                
                                .. attribute:: labelstk
                                
                                	Outgoing label stack for this path
                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                
                                .. attribute:: next_next_hop
                                
                                	List of Next Next Hops
                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                
                                

                                """

                                _prefix = 'ip-rib-ipv6-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                    self.yang_name = "ipv6-rib-edm-path"
                                    self.yang_parent_name = "route-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                    ])
                                    self.address = None
                                    self.information_source = None
                                    self.v6_nexthop = None
                                    self.v6_information_source = None
                                    self.interface_name = None
                                    self.metric = None
                                    self.load_metric = None
                                    self.flags64 = None
                                    self.flags = None
                                    self.private_flags = None
                                    self.looped = None
                                    self.next_hop_table_id = None
                                    self.next_hop_vrf_name = None
                                    self.next_hop_table_name = None
                                    self.next_hop_afi = None
                                    self.next_hop_safi = None
                                    self.route_label = None
                                    self.tunnel_id = None
                                    self.pathid = None
                                    self.backup_pathid = None
                                    self.ref_cnt_of_backup = None
                                    self.number_of_extended_communities = None
                                    self.mvpn_present = None
                                    self.path_rt_present = None
                                    self.vrf_import_rt_present = None
                                    self.source_asrt_present = None
                                    self.source_rd_present = None
                                    self.segmented_nexthop_present = None
                                    self.number_of_nnh = None
                                    self.next_hop_id = None
                                    self.next_hop_id_refcount = None
                                    self.ospf_area_id = None
                                    self.has_labelstk = None
                                    self.num_labels = None
                                    self.binding_label = None
                                    self.nhid_feid = None
                                    self.mpls_feid = None
                                    self.has_vxlan_network_id = None
                                    self.vxlan_network_id = None
                                    self.has_xcid = None
                                    self.xcid = None
                                    self.has_span_diag_interface = None
                                    self.span_diag_interface = None
                                    self.has_subscriber_parent_interface = None
                                    self.subscriber_parent_interface = None
                                    self.interface_index_present = None
                                    self.interface_index_attribute = None

                                    self.remote_backup_addr = YList(self)
                                    self.labelstk = YList(self)
                                    self.next_next_hop = YList(self)
                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                class RemoteBackupAddr(Entity):
                                    """
                                    Remote backup node address
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv6-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                        self.yang_name = "remote-backup-addr"
                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "remote-backup-addr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                class Labelstk(Entity):
                                    """
                                    Outgoing label stack for this path
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv6-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                        self.yang_name = "labelstk"
                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "labelstk"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                class NextNextHop(Entity):
                                    """
                                    List of Next Next Hops
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                    
                                    .. attribute:: unknownval
                                    
                                    	Unknown Value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_index
                                    
                                    	Interface Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv6-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                        self.yang_name = "next-next-hop"
                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                        ])
                                        self.type = None
                                        self.unknownval = None
                                        self.address = None
                                        self.interface_index = None
                                        self._segment_path = lambda: "next-next-hop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


    class Vrfs(Entity):
        """
        VRF table
        
        .. attribute:: vrf
        
        	Specific VRF
        	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf>`
        
        

        """

        _prefix = 'ip-rib-ipv6-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Ipv6RibStdby.Vrfs, self).__init__()

            self.yang_name = "vrfs"
            self.yang_parent_name = "ipv6-rib-stdby"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("vrf", ("vrf", Ipv6RibStdby.Vrfs.Vrf))])
            self._leafs = OrderedDict()

            self.vrf = YList(self)
            self._segment_path = lambda: "vrfs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Ipv6RibStdby.Vrfs, [], name, value)


        class Vrf(Entity):
            """
            Specific VRF
            
            .. attribute:: vrf_name  (key)
            
            	Name of the VRF
            	**type**\: str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: afs
            
            	Address Family (AF) table
            	**type**\:  :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs>`
            
            

            """

            _prefix = 'ip-rib-ipv6-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Ipv6RibStdby.Vrfs.Vrf, self).__init__()

                self.yang_name = "vrf"
                self.yang_parent_name = "vrfs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['vrf_name']
                self._child_classes = OrderedDict([("afs", ("afs", Ipv6RibStdby.Vrfs.Vrf.Afs))])
                self._leafs = OrderedDict([
                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                ])
                self.vrf_name = None

                self.afs = Ipv6RibStdby.Vrfs.Vrf.Afs()
                self.afs.parent = self
                self._children_name_map["afs"] = "afs"
                self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv6-oper:ipv6-rib-stdby/vrfs/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf, ['vrf_name'], name, value)


            class Afs(Entity):
                """
                Address Family (AF) table
                
                .. attribute:: af
                
                	Specific AF information
                	**type**\: list of  		 :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af>`
                
                

                """

                _prefix = 'ip-rib-ipv6-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Ipv6RibStdby.Vrfs.Vrf.Afs, self).__init__()

                    self.yang_name = "afs"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("af", ("af", Ipv6RibStdby.Vrfs.Vrf.Afs.Af))])
                    self._leafs = OrderedDict()

                    self.af = YList(self)
                    self._segment_path = lambda: "afs"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs, [], name, value)


                class Af(Entity):
                    """
                    Specific AF information
                    
                    .. attribute:: af_name  (key)
                    
                    	Name of the AF \- 'IPv6'
                    	**type**\: str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: safs
                    
                    	Subsequent Address Family (SAF) table
                    	**type**\:  :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv6-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af, self).__init__()

                        self.yang_name = "af"
                        self.yang_parent_name = "afs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['af_name']
                        self._child_classes = OrderedDict([("safs", ("safs", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs))])
                        self._leafs = OrderedDict([
                            ('af_name', (YLeaf(YType.str, 'af-name'), ['str'])),
                        ])
                        self.af_name = None

                        self.safs = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs()
                        self.safs.parent = self
                        self._children_name_map["safs"] = "safs"
                        self._segment_path = lambda: "af" + "[af-name='" + str(self.af_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                    class Safs(Entity):
                        """
                        Subsequent Address Family (SAF) table
                        
                        .. attribute:: saf
                        
                        	Specific SAF information
                        	**type**\: list of  		 :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf>`
                        
                        

                        """

                        _prefix = 'ip-rib-ipv6-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs, self).__init__()

                            self.yang_name = "safs"
                            self.yang_parent_name = "af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("saf", ("saf", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf))])
                            self._leafs = OrderedDict()

                            self.saf = YList(self)
                            self._segment_path = lambda: "safs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs, [], name, value)


                        class Saf(Entity):
                            """
                            Specific SAF information
                            
                            .. attribute:: saf_name  (key)
                            
                            	Name of the SAF
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: ip_rib_route_table_names
                            
                            	Global container of routes
                            	**type**\:  :py:class:`IpRibRouteTableNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv6-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf, self).__init__()

                                self.yang_name = "saf"
                                self.yang_parent_name = "safs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['saf_name']
                                self._child_classes = OrderedDict([("ip-rib-route-table-names", ("ip_rib_route_table_names", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames))])
                                self._leafs = OrderedDict([
                                    ('saf_name', (YLeaf(YType.str, 'saf-name'), ['str'])),
                                ])
                                self.saf_name = None

                                self.ip_rib_route_table_names = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames()
                                self.ip_rib_route_table_names.parent = self
                                self._children_name_map["ip_rib_route_table_names"] = "ip-rib-route-table-names"
                                self._segment_path = lambda: "saf" + "[saf-name='" + str(self.saf_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf, ['saf_name'], name, value)


                            class IpRibRouteTableNames(Entity):
                                """
                                Global container of routes
                                
                                .. attribute:: ip_rib_route_table_name
                                
                                	IP RIB Route table name for a topology
                                	**type**\: list of  		 :py:class:`IpRibRouteTableName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName>`
                                
                                

                                """

                                _prefix = 'ip-rib-ipv6-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, self).__init__()

                                    self.yang_name = "ip-rib-route-table-names"
                                    self.yang_parent_name = "saf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ip-rib-route-table-name", ("ip_rib_route_table_name", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName))])
                                    self._leafs = OrderedDict()

                                    self.ip_rib_route_table_name = YList(self)
                                    self._segment_path = lambda: "ip-rib-route-table-names"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, [], name, value)


                                class IpRibRouteTableName(Entity):
                                    """
                                    IP RIB Route table name for a topology
                                    
                                    .. attribute:: route_table_name  (key)
                                    
                                    	Name of the route table 
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: destination_kw
                                    
                                    	Destination KW
                                    	**type**\:  :py:class:`DestinationKw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw>`
                                    
                                    .. attribute:: adverts
                                    
                                    	Route advertiser information 
                                    	**type**\:  :py:class:`Adverts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts>`
                                    
                                    .. attribute:: deleted_routes
                                    
                                    	Deleted
                                    	**type**\:  :py:class:`DeletedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes>`
                                    
                                    .. attribute:: protocol
                                    
                                    	Contains the classification of routes by protocol
                                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol>`
                                    
                                    .. attribute:: routes
                                    
                                    	Route information 
                                    	**type**\:  :py:class:`Routes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes>`
                                    
                                    .. attribute:: q_routes
                                    
                                    	Quarantine
                                    	**type**\:  :py:class:`QRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes>`
                                    
                                    .. attribute:: backup_routes
                                    
                                    	Backup route information for the given table
                                    	**type**\:  :py:class:`BackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes>`
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv6-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, self).__init__()

                                        self.yang_name = "ip-rib-route-table-name"
                                        self.yang_parent_name = "ip-rib-route-table-names"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['route_table_name']
                                        self._child_classes = OrderedDict([("destination-kw", ("destination_kw", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw)), ("adverts", ("adverts", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts)), ("deleted-routes", ("deleted_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes)), ("protocol", ("protocol", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol)), ("routes", ("routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes)), ("q-routes", ("q_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes)), ("backup-routes", ("backup_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes))])
                                        self._leafs = OrderedDict([
                                            ('route_table_name', (YLeaf(YType.str, 'route-table-name'), ['str'])),
                                        ])
                                        self.route_table_name = None

                                        self.destination_kw = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw()
                                        self.destination_kw.parent = self
                                        self._children_name_map["destination_kw"] = "destination-kw"

                                        self.adverts = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts()
                                        self.adverts.parent = self
                                        self._children_name_map["adverts"] = "adverts"

                                        self.deleted_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes()
                                        self.deleted_routes.parent = self
                                        self._children_name_map["deleted_routes"] = "deleted-routes"

                                        self.protocol = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol()
                                        self.protocol.parent = self
                                        self._children_name_map["protocol"] = "protocol"

                                        self.routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes()
                                        self.routes.parent = self
                                        self._children_name_map["routes"] = "routes"

                                        self.q_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes()
                                        self.q_routes.parent = self
                                        self._children_name_map["q_routes"] = "q-routes"

                                        self.backup_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes()
                                        self.backup_routes.parent = self
                                        self._children_name_map["backup_routes"] = "backup-routes"
                                        self._segment_path = lambda: "ip-rib-route-table-name" + "[route-table-name='" + str(self.route_table_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, ['route_table_name'], name, value)


                                    class DestinationKw(Entity):
                                        """
                                        Destination KW
                                        
                                        .. attribute:: dest_q_routes
                                        
                                        	Quarantine
                                        	**type**\:  :py:class:`DestQRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes>`
                                        
                                        .. attribute:: dest_backup_routes
                                        
                                        	Backup
                                        	**type**\:  :py:class:`DestBackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes>`
                                        
                                        .. attribute:: dest_best_routes
                                        
                                        	Best Local
                                        	**type**\:  :py:class:`DestBestRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes>`
                                        
                                        .. attribute:: dest_next_hop_routes
                                        
                                        	Resolving next hop
                                        	**type**\:  :py:class:`DestNextHopRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw, self).__init__()

                                            self.yang_name = "destination-kw"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dest-q-routes", ("dest_q_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes)), ("dest-backup-routes", ("dest_backup_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes)), ("dest-best-routes", ("dest_best_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes)), ("dest-next-hop-routes", ("dest_next_hop_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes))])
                                            self._leafs = OrderedDict()

                                            self.dest_q_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes()
                                            self.dest_q_routes.parent = self
                                            self._children_name_map["dest_q_routes"] = "dest-q-routes"

                                            self.dest_backup_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes()
                                            self.dest_backup_routes.parent = self
                                            self._children_name_map["dest_backup_routes"] = "dest-backup-routes"

                                            self.dest_best_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes()
                                            self.dest_best_routes.parent = self
                                            self._children_name_map["dest_best_routes"] = "dest-best-routes"

                                            self.dest_next_hop_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes()
                                            self.dest_next_hop_routes.parent = self
                                            self._children_name_map["dest_next_hop_routes"] = "dest-next-hop-routes"
                                            self._segment_path = lambda: "destination-kw"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw, [], name, value)


                                        class DestQRoutes(Entity):
                                            """
                                            Quarantine
                                            
                                            .. attribute:: dest_q_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of  		 :py:class:`DestQRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, self).__init__()

                                                self.yang_name = "dest-q-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dest-q-route", ("dest_q_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute))])
                                                self._leafs = OrderedDict()

                                                self.dest_q_route = YList(self)
                                                self._segment_path = lambda: "dest-q-routes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, [], name, value)


                                            class DestQRoute(Entity):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: address
                                                
                                                	Network Address 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length 
                                                	**type**\: int
                                                
                                                	**range:** 0..128
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath>`
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\: str
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\: str
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\: str
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, self).__init__()

                                                    self.yang_name = "dest-q-route"
                                                    self.yang_parent_name = "dest-q-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                        ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                        ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                        ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                        ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                        ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                        ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                        ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                        ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                        ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                        ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                        ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                        ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                        ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                        ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                        ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                        ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                        ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                        ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                        ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                        ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                        ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                        ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                        ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                    ])
                                                    self.address = None
                                                    self.prefix_length = None
                                                    self.prefix = None
                                                    self.prefix_length_xr = None
                                                    self.route_version = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.instance = None
                                                    self.client_id = None
                                                    self.route_type = None
                                                    self.priority = None
                                                    self.svd_type = None
                                                    self.flags = None
                                                    self.extended_flags = None
                                                    self.tag = None
                                                    self.distance = None
                                                    self.diversion_distance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.attribute_identity = None
                                                    self.traffic_index = None
                                                    self.route_precedence = None
                                                    self.qos_group = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.pic_count = None
                                                    self.active = None
                                                    self.diversion = None
                                                    self.diversion_proto_name = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.version = None
                                                    self.tbl_version = None
                                                    self.route_modify_time = None

                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._segment_path = lambda: "dest-q-route"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-q-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath))])
                                                        self._leafs = OrderedDict()

                                                        self.ipv6_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, [], name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: number_of_nnh
                                                        
                                                        	Number of Next Next Hops
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\: str
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_xcid
                                                        
                                                        	L2 Cross Connect ID exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: xcid
                                                        
                                                        	L2 Cross Connect ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: has_subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: interface_index_present
                                                        
                                                        	Interface Index present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: interface_index_attribute
                                                        
                                                        	Interface Index attribute
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: next_next_hop
                                                        
                                                        	List of Next Next Hops
                                                        	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.information_source = None
                                                            self.v6_nexthop = None
                                                            self.v6_information_source = None
                                                            self.interface_name = None
                                                            self.metric = None
                                                            self.load_metric = None
                                                            self.flags64 = None
                                                            self.flags = None
                                                            self.private_flags = None
                                                            self.looped = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_vrf_name = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_safi = None
                                                            self.route_label = None
                                                            self.tunnel_id = None
                                                            self.pathid = None
                                                            self.backup_pathid = None
                                                            self.ref_cnt_of_backup = None
                                                            self.number_of_extended_communities = None
                                                            self.mvpn_present = None
                                                            self.path_rt_present = None
                                                            self.vrf_import_rt_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.segmented_nexthop_present = None
                                                            self.number_of_nnh = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.ospf_area_id = None
                                                            self.has_labelstk = None
                                                            self.num_labels = None
                                                            self.binding_label = None
                                                            self.nhid_feid = None
                                                            self.mpls_feid = None
                                                            self.has_vxlan_network_id = None
                                                            self.vxlan_network_id = None
                                                            self.has_xcid = None
                                                            self.xcid = None
                                                            self.has_span_diag_interface = None
                                                            self.span_diag_interface = None
                                                            self.has_subscriber_parent_interface = None
                                                            self.subscriber_parent_interface = None
                                                            self.interface_index_present = None
                                                            self.interface_index_attribute = None

                                                            self.remote_backup_addr = YList(self)
                                                            self.labelstk = YList(self)
                                                            self.next_next_hop = YList(self)
                                                            self._segment_path = lambda: "ipv6-rib-edm-path"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "remote-backup-addr"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "labelstk"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class NextNextHop(Entity):
                                                            """
                                                            List of Next Next Hops
                                                            
                                                            .. attribute:: type
                                                            
                                                            	type
                                                            	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                            
                                                            .. attribute:: unknownval
                                                            
                                                            	Unknown Value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: address
                                                            
                                                            	IPv4 Address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: interface_index
                                                            
                                                            	Interface Index
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                self.yang_name = "next-next-hop"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                    ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                    ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                ])
                                                                self.type = None
                                                                self.unknownval = None
                                                                self.address = None
                                                                self.interface_index = None
                                                                self._segment_path = lambda: "next-next-hop"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class DestBackupRoutes(Entity):
                                            """
                                            Backup
                                            
                                            .. attribute:: dest_backup_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of  		 :py:class:`DestBackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, self).__init__()

                                                self.yang_name = "dest-backup-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dest-backup-route", ("dest_backup_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute))])
                                                self._leafs = OrderedDict()

                                                self.dest_backup_route = YList(self)
                                                self._segment_path = lambda: "dest-backup-routes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, [], name, value)


                                            class DestBackupRoute(Entity):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: address
                                                
                                                	Network Address 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length 
                                                	**type**\: int
                                                
                                                	**range:** 0..128
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath>`
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\: str
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\: str
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\: str
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, self).__init__()

                                                    self.yang_name = "dest-backup-route"
                                                    self.yang_parent_name = "dest-backup-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                        ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                        ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                        ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                        ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                        ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                        ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                        ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                        ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                        ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                        ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                        ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                        ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                        ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                        ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                        ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                        ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                        ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                        ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                        ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                        ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                        ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                        ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                        ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                    ])
                                                    self.address = None
                                                    self.prefix_length = None
                                                    self.prefix = None
                                                    self.prefix_length_xr = None
                                                    self.route_version = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.instance = None
                                                    self.client_id = None
                                                    self.route_type = None
                                                    self.priority = None
                                                    self.svd_type = None
                                                    self.flags = None
                                                    self.extended_flags = None
                                                    self.tag = None
                                                    self.distance = None
                                                    self.diversion_distance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.attribute_identity = None
                                                    self.traffic_index = None
                                                    self.route_precedence = None
                                                    self.qos_group = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.pic_count = None
                                                    self.active = None
                                                    self.diversion = None
                                                    self.diversion_proto_name = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.version = None
                                                    self.tbl_version = None
                                                    self.route_modify_time = None

                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._segment_path = lambda: "dest-backup-route"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-backup-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath))])
                                                        self._leafs = OrderedDict()

                                                        self.ipv6_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, [], name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: number_of_nnh
                                                        
                                                        	Number of Next Next Hops
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\: str
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_xcid
                                                        
                                                        	L2 Cross Connect ID exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: xcid
                                                        
                                                        	L2 Cross Connect ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: has_subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: interface_index_present
                                                        
                                                        	Interface Index present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: interface_index_attribute
                                                        
                                                        	Interface Index attribute
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: next_next_hop
                                                        
                                                        	List of Next Next Hops
                                                        	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.information_source = None
                                                            self.v6_nexthop = None
                                                            self.v6_information_source = None
                                                            self.interface_name = None
                                                            self.metric = None
                                                            self.load_metric = None
                                                            self.flags64 = None
                                                            self.flags = None
                                                            self.private_flags = None
                                                            self.looped = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_vrf_name = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_safi = None
                                                            self.route_label = None
                                                            self.tunnel_id = None
                                                            self.pathid = None
                                                            self.backup_pathid = None
                                                            self.ref_cnt_of_backup = None
                                                            self.number_of_extended_communities = None
                                                            self.mvpn_present = None
                                                            self.path_rt_present = None
                                                            self.vrf_import_rt_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.segmented_nexthop_present = None
                                                            self.number_of_nnh = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.ospf_area_id = None
                                                            self.has_labelstk = None
                                                            self.num_labels = None
                                                            self.binding_label = None
                                                            self.nhid_feid = None
                                                            self.mpls_feid = None
                                                            self.has_vxlan_network_id = None
                                                            self.vxlan_network_id = None
                                                            self.has_xcid = None
                                                            self.xcid = None
                                                            self.has_span_diag_interface = None
                                                            self.span_diag_interface = None
                                                            self.has_subscriber_parent_interface = None
                                                            self.subscriber_parent_interface = None
                                                            self.interface_index_present = None
                                                            self.interface_index_attribute = None

                                                            self.remote_backup_addr = YList(self)
                                                            self.labelstk = YList(self)
                                                            self.next_next_hop = YList(self)
                                                            self._segment_path = lambda: "ipv6-rib-edm-path"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "remote-backup-addr"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "labelstk"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class NextNextHop(Entity):
                                                            """
                                                            List of Next Next Hops
                                                            
                                                            .. attribute:: type
                                                            
                                                            	type
                                                            	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                            
                                                            .. attribute:: unknownval
                                                            
                                                            	Unknown Value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: address
                                                            
                                                            	IPv4 Address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: interface_index
                                                            
                                                            	Interface Index
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                self.yang_name = "next-next-hop"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                    ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                    ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                ])
                                                                self.type = None
                                                                self.unknownval = None
                                                                self.address = None
                                                                self.interface_index = None
                                                                self._segment_path = lambda: "next-next-hop"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class DestBestRoutes(Entity):
                                            """
                                            Best Local
                                            
                                            .. attribute:: dest_best_route
                                            
                                            	Best local route information for a specific Address 
                                            	**type**\: list of  		 :py:class:`DestBestRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, self).__init__()

                                                self.yang_name = "dest-best-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dest-best-route", ("dest_best_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute))])
                                                self._leafs = OrderedDict()

                                                self.dest_best_route = YList(self)
                                                self._segment_path = lambda: "dest-best-routes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, [], name, value)


                                            class DestBestRoute(Entity):
                                                """
                                                Best local route information for a
                                                specific Address 
                                                
                                                .. attribute:: address  (key)
                                                
                                                	Network Address 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath>`
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\: str
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\: str
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\: str
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, self).__init__()

                                                    self.yang_name = "dest-best-route"
                                                    self.yang_parent_name = "dest-best-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                        ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                        ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                        ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                        ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                        ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                        ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                        ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                        ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                        ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                        ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                        ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                        ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                        ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                        ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                        ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                        ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                        ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                        ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                        ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                        ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                        ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                        ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                        ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                    ])
                                                    self.address = None
                                                    self.prefix = None
                                                    self.prefix_length_xr = None
                                                    self.route_version = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.instance = None
                                                    self.client_id = None
                                                    self.route_type = None
                                                    self.priority = None
                                                    self.svd_type = None
                                                    self.flags = None
                                                    self.extended_flags = None
                                                    self.tag = None
                                                    self.distance = None
                                                    self.diversion_distance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.attribute_identity = None
                                                    self.traffic_index = None
                                                    self.route_precedence = None
                                                    self.qos_group = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.pic_count = None
                                                    self.active = None
                                                    self.diversion = None
                                                    self.diversion_proto_name = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.version = None
                                                    self.tbl_version = None
                                                    self.route_modify_time = None

                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._segment_path = lambda: "dest-best-route" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, ['address', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-best-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath))])
                                                        self._leafs = OrderedDict()

                                                        self.ipv6_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, [], name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: number_of_nnh
                                                        
                                                        	Number of Next Next Hops
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\: str
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_xcid
                                                        
                                                        	L2 Cross Connect ID exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: xcid
                                                        
                                                        	L2 Cross Connect ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: has_subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: interface_index_present
                                                        
                                                        	Interface Index present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: interface_index_attribute
                                                        
                                                        	Interface Index attribute
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: next_next_hop
                                                        
                                                        	List of Next Next Hops
                                                        	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.information_source = None
                                                            self.v6_nexthop = None
                                                            self.v6_information_source = None
                                                            self.interface_name = None
                                                            self.metric = None
                                                            self.load_metric = None
                                                            self.flags64 = None
                                                            self.flags = None
                                                            self.private_flags = None
                                                            self.looped = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_vrf_name = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_safi = None
                                                            self.route_label = None
                                                            self.tunnel_id = None
                                                            self.pathid = None
                                                            self.backup_pathid = None
                                                            self.ref_cnt_of_backup = None
                                                            self.number_of_extended_communities = None
                                                            self.mvpn_present = None
                                                            self.path_rt_present = None
                                                            self.vrf_import_rt_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.segmented_nexthop_present = None
                                                            self.number_of_nnh = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.ospf_area_id = None
                                                            self.has_labelstk = None
                                                            self.num_labels = None
                                                            self.binding_label = None
                                                            self.nhid_feid = None
                                                            self.mpls_feid = None
                                                            self.has_vxlan_network_id = None
                                                            self.vxlan_network_id = None
                                                            self.has_xcid = None
                                                            self.xcid = None
                                                            self.has_span_diag_interface = None
                                                            self.span_diag_interface = None
                                                            self.has_subscriber_parent_interface = None
                                                            self.subscriber_parent_interface = None
                                                            self.interface_index_present = None
                                                            self.interface_index_attribute = None

                                                            self.remote_backup_addr = YList(self)
                                                            self.labelstk = YList(self)
                                                            self.next_next_hop = YList(self)
                                                            self._segment_path = lambda: "ipv6-rib-edm-path"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "remote-backup-addr"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "labelstk"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class NextNextHop(Entity):
                                                            """
                                                            List of Next Next Hops
                                                            
                                                            .. attribute:: type
                                                            
                                                            	type
                                                            	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                            
                                                            .. attribute:: unknownval
                                                            
                                                            	Unknown Value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: address
                                                            
                                                            	IPv4 Address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: interface_index
                                                            
                                                            	Interface Index
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                self.yang_name = "next-next-hop"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                    ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                    ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                ])
                                                                self.type = None
                                                                self.unknownval = None
                                                                self.address = None
                                                                self.interface_index = None
                                                                self._segment_path = lambda: "next-next-hop"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class DestNextHopRoutes(Entity):
                                            """
                                            Resolving next hop
                                            
                                            .. attribute:: dest_next_hop_route
                                            
                                            	Nexthop information for a specific address
                                            	**type**\: list of  		 :py:class:`DestNextHopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, self).__init__()

                                                self.yang_name = "dest-next-hop-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("dest-next-hop-route", ("dest_next_hop_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute))])
                                                self._leafs = OrderedDict()

                                                self.dest_next_hop_route = YList(self)
                                                self._segment_path = lambda: "dest-next-hop-routes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, [], name, value)


                                            class DestNextHopRoute(Entity):
                                                """
                                                Nexthop information for a specific
                                                address
                                                
                                                .. attribute:: address  (key)
                                                
                                                	Network Address 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath>`
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\: str
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\: str
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\: bool
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\: str
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, self).__init__()

                                                    self.yang_name = "dest-next-hop-route"
                                                    self.yang_parent_name = "dest-next-hop-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['address']
                                                    self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath))])
                                                    self._leafs = OrderedDict([
                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                        ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                        ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                        ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                        ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                        ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                        ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                        ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                        ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                        ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                        ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                        ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                        ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                        ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                        ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                        ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                        ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                        ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                        ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                        ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                        ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                        ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                        ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                        ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                    ])
                                                    self.address = None
                                                    self.prefix = None
                                                    self.prefix_length_xr = None
                                                    self.route_version = None
                                                    self.protocol_id = None
                                                    self.protocol_name = None
                                                    self.instance = None
                                                    self.client_id = None
                                                    self.route_type = None
                                                    self.priority = None
                                                    self.svd_type = None
                                                    self.flags = None
                                                    self.extended_flags = None
                                                    self.tag = None
                                                    self.distance = None
                                                    self.diversion_distance = None
                                                    self.metric = None
                                                    self.paths_count = None
                                                    self.attribute_identity = None
                                                    self.traffic_index = None
                                                    self.route_precedence = None
                                                    self.qos_group = None
                                                    self.flow_tag = None
                                                    self.fwd_class = None
                                                    self.pic_count = None
                                                    self.active = None
                                                    self.diversion = None
                                                    self.diversion_proto_name = None
                                                    self.route_age = None
                                                    self.route_label = None
                                                    self.version = None
                                                    self.tbl_version = None
                                                    self.route_modify_time = None

                                                    self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._segment_path = lambda: "dest-next-hop-route" + "[address='" + str(self.address) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, ['address', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv6_rib_edm_path
                                                    
                                                    	ipv6 rib edm path
                                                    	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-next-hop-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath))])
                                                        self._leafs = OrderedDict()

                                                        self.ipv6_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, [], name, value)


                                                    class Ipv6RibEdmPath(Entity):
                                                        """
                                                        ipv6 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: number_of_nnh
                                                        
                                                        	Number of Next Next Hops
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\: str
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: vxlan_network_id
                                                        
                                                        	VXLAN Network Identifier for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_xcid
                                                        
                                                        	L2 Cross Connect ID exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: xcid
                                                        
                                                        	L2 Cross Connect ID for this path
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: has_span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: span_diag_interface
                                                        
                                                        	SPAN Diagnostics Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: has_subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface exists for this path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: subscriber_parent_interface
                                                        
                                                        	Subscriber Parent Interface for this path
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                        
                                                        .. attribute:: interface_index_present
                                                        
                                                        	Interface Index present
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: interface_index_attribute
                                                        
                                                        	Interface Index attribute
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: next_next_hop
                                                        
                                                        	List of Next Next Hops
                                                        	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv6-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.information_source = None
                                                            self.v6_nexthop = None
                                                            self.v6_information_source = None
                                                            self.interface_name = None
                                                            self.metric = None
                                                            self.load_metric = None
                                                            self.flags64 = None
                                                            self.flags = None
                                                            self.private_flags = None
                                                            self.looped = None
                                                            self.next_hop_table_id = None
                                                            self.next_hop_vrf_name = None
                                                            self.next_hop_table_name = None
                                                            self.next_hop_afi = None
                                                            self.next_hop_safi = None
                                                            self.route_label = None
                                                            self.tunnel_id = None
                                                            self.pathid = None
                                                            self.backup_pathid = None
                                                            self.ref_cnt_of_backup = None
                                                            self.number_of_extended_communities = None
                                                            self.mvpn_present = None
                                                            self.path_rt_present = None
                                                            self.vrf_import_rt_present = None
                                                            self.source_asrt_present = None
                                                            self.source_rd_present = None
                                                            self.segmented_nexthop_present = None
                                                            self.number_of_nnh = None
                                                            self.next_hop_id = None
                                                            self.next_hop_id_refcount = None
                                                            self.ospf_area_id = None
                                                            self.has_labelstk = None
                                                            self.num_labels = None
                                                            self.binding_label = None
                                                            self.nhid_feid = None
                                                            self.mpls_feid = None
                                                            self.has_vxlan_network_id = None
                                                            self.vxlan_network_id = None
                                                            self.has_xcid = None
                                                            self.xcid = None
                                                            self.has_span_diag_interface = None
                                                            self.span_diag_interface = None
                                                            self.has_subscriber_parent_interface = None
                                                            self.subscriber_parent_interface = None
                                                            self.interface_index_present = None
                                                            self.interface_index_attribute = None

                                                            self.remote_backup_addr = YList(self)
                                                            self.labelstk = YList(self)
                                                            self.next_next_hop = YList(self)
                                                            self._segment_path = lambda: "ipv6-rib-edm-path"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "remote-backup-addr"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                ])
                                                                self.entry = None
                                                                self._segment_path = lambda: "labelstk"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class NextNextHop(Entity):
                                                            """
                                                            List of Next Next Hops
                                                            
                                                            .. attribute:: type
                                                            
                                                            	type
                                                            	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                            
                                                            .. attribute:: unknownval
                                                            
                                                            	Unknown Value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: address
                                                            
                                                            	IPv4 Address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: interface_index
                                                            
                                                            	Interface Index
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                self.yang_name = "next-next-hop"
                                                                self.yang_parent_name = "ipv6-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                    ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                    ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                ])
                                                                self.type = None
                                                                self.unknownval = None
                                                                self.address = None
                                                                self.interface_index = None
                                                                self._segment_path = lambda: "next-next-hop"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                    class Adverts(Entity):
                                        """
                                        Route advertiser information 
                                        
                                        .. attribute:: advert
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of  		 :py:class:`Advert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, self).__init__()

                                            self.yang_name = "adverts"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advert", ("advert", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert))])
                                            self._leafs = OrderedDict()

                                            self.advert = YList(self)
                                            self._segment_path = lambda: "adverts"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, [], name, value)


                                        class Advert(Entity):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\: int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: ipv6_rib_edm_advert
                                            
                                            	ipv6 rib edm advert
                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmAdvert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, self).__init__()

                                                self.yang_name = "advert"
                                                self.yang_parent_name = "adverts"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv6-rib-edm-advert", ("ipv6_rib_edm_advert", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ])
                                                self.address = None
                                                self.prefix_length = None

                                                self.ipv6_rib_edm_advert = YList(self)
                                                self._segment_path = lambda: "advert"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, ['address', 'prefix_length'], name, value)


                                            class Ipv6RibEdmAdvert(Entity):
                                                """
                                                ipv6 rib edm advert
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	  Client advertising the route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: number_of_extended_communities
                                                
                                                	Number of extended communities
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: extended_communities
                                                
                                                	Extended communities
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: protocol_opaque_flags
                                                
                                                	OSPF area\-id flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_opaque
                                                
                                                	OSPF area\-id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: code
                                                
                                                	Protocol code
                                                	**type**\: int
                                                
                                                	**range:** \-128..127
                                                
                                                .. attribute:: instance_name
                                                
                                                	Instance name
                                                	**type**\: str
                                                
                                                	**length:** 0..41
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert, self).__init__()

                                                    self.yang_name = "ipv6-rib-edm-advert"
                                                    self.yang_parent_name = "advert"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                        ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                        ('extended_communities', (YLeaf(YType.str, 'extended-communities'), ['str'])),
                                                        ('protocol_opaque_flags', (YLeaf(YType.uint8, 'protocol-opaque-flags'), ['int'])),
                                                        ('protocol_opaque', (YLeaf(YType.uint32, 'protocol-opaque'), ['int'])),
                                                        ('code', (YLeaf(YType.int8, 'code'), ['int'])),
                                                        ('instance_name', (YLeaf(YType.str, 'instance-name'), ['str'])),
                                                    ])
                                                    self.protocol_id = None
                                                    self.client_id = None
                                                    self.number_of_extended_communities = None
                                                    self.extended_communities = None
                                                    self.protocol_opaque_flags = None
                                                    self.protocol_opaque = None
                                                    self.code = None
                                                    self.instance_name = None
                                                    self._segment_path = lambda: "ipv6-rib-edm-advert"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv6RibEdmAdvert, ['protocol_id', 'client_id', 'number_of_extended_communities', 'extended_communities', 'protocol_opaque_flags', 'protocol_opaque', 'code', 'instance_name'], name, value)


                                    class DeletedRoutes(Entity):
                                        """
                                        Deleted
                                        
                                        .. attribute:: deleted_route
                                        
                                        	Route information for a specific deleted address 
                                        	**type**\: list of  		 :py:class:`DeletedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, self).__init__()

                                            self.yang_name = "deleted-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("deleted-route", ("deleted_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute))])
                                            self._leafs = OrderedDict()

                                            self.deleted_route = YList(self)
                                            self._segment_path = lambda: "deleted-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, [], name, value)


                                        class DeletedRoute(Entity):
                                            """
                                            Route information for a specific
                                            deleted address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\: int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath>`
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\: str
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\: str
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\: str
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, self).__init__()

                                                self.yang_name = "deleted-route"
                                                self.yang_parent_name = "deleted-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                    ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                    ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                    ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                    ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                    ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                    ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                    ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                    ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                    ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                    ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                    ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                    ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                    ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                    ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                    ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                    ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                    ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                    ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                    ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                    ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                    ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                    ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                ])
                                                self.address = None
                                                self.prefix_length = None
                                                self.prefix = None
                                                self.prefix_length_xr = None
                                                self.route_version = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.instance = None
                                                self.client_id = None
                                                self.route_type = None
                                                self.priority = None
                                                self.svd_type = None
                                                self.flags = None
                                                self.extended_flags = None
                                                self.tag = None
                                                self.distance = None
                                                self.diversion_distance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.attribute_identity = None
                                                self.traffic_index = None
                                                self.route_precedence = None
                                                self.qos_group = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.pic_count = None
                                                self.active = None
                                                self.diversion = None
                                                self.diversion_proto_name = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.version = None
                                                self.tbl_version = None
                                                self.route_modify_time = None

                                                self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._segment_path = lambda: "deleted-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "deleted-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv6_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, [], name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: number_of_nnh
                                                    
                                                    	Number of Next Next Hops
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\: str
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_xcid
                                                    
                                                    	L2 Cross Connect ID exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: xcid
                                                    
                                                    	L2 Cross Connect ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: has_subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: interface_index_present
                                                    
                                                    	Interface Index present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: interface_index_attribute
                                                    
                                                    	Interface Index attribute
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: next_next_hop
                                                    
                                                    	List of Next Next Hops
                                                    	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                            ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                            ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                            ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                            ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                            ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                            ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                            ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                            ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                            ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                            ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                            ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                            ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                            ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                            ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                            ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                            ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                            ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                            ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                            ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                            ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                            ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                            ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                            ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                            ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                            ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                            ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                            ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                            ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                            ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                            ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                            ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                            ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                            ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                            ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                            ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                            ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                            ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                            ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                        ])
                                                        self.address = None
                                                        self.information_source = None
                                                        self.v6_nexthop = None
                                                        self.v6_information_source = None
                                                        self.interface_name = None
                                                        self.metric = None
                                                        self.load_metric = None
                                                        self.flags64 = None
                                                        self.flags = None
                                                        self.private_flags = None
                                                        self.looped = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_vrf_name = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_safi = None
                                                        self.route_label = None
                                                        self.tunnel_id = None
                                                        self.pathid = None
                                                        self.backup_pathid = None
                                                        self.ref_cnt_of_backup = None
                                                        self.number_of_extended_communities = None
                                                        self.mvpn_present = None
                                                        self.path_rt_present = None
                                                        self.vrf_import_rt_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.segmented_nexthop_present = None
                                                        self.number_of_nnh = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.ospf_area_id = None
                                                        self.has_labelstk = None
                                                        self.num_labels = None
                                                        self.binding_label = None
                                                        self.nhid_feid = None
                                                        self.mpls_feid = None
                                                        self.has_vxlan_network_id = None
                                                        self.vxlan_network_id = None
                                                        self.has_xcid = None
                                                        self.xcid = None
                                                        self.has_span_diag_interface = None
                                                        self.span_diag_interface = None
                                                        self.has_subscriber_parent_interface = None
                                                        self.subscriber_parent_interface = None
                                                        self.interface_index_present = None
                                                        self.interface_index_attribute = None

                                                        self.remote_backup_addr = YList(self)
                                                        self.labelstk = YList(self)
                                                        self.next_next_hop = YList(self)
                                                        self._segment_path = lambda: "ipv6-rib-edm-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "remote-backup-addr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "labelstk"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class NextNextHop(Entity):
                                                        """
                                                        List of Next Next Hops
                                                        
                                                        .. attribute:: type
                                                        
                                                        	type
                                                        	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                        
                                                        .. attribute:: unknownval
                                                        
                                                        	Unknown Value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: address
                                                        
                                                        	IPv4 Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_index
                                                        
                                                        	Interface Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                            self.yang_name = "next-next-hop"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                            ])
                                                            self.type = None
                                                            self.unknownval = None
                                                            self.address = None
                                                            self.interface_index = None
                                                            self._segment_path = lambda: "next-next-hop"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                    class Protocol(Entity):
                                        """
                                        Contains the classification of routes by
                                        protocol
                                        
                                        .. attribute:: local
                                        
                                        	Local Protocol
                                        	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local>`
                                        
                                        .. attribute:: bgp
                                        
                                        	BGP Protocol
                                        	**type**\:  :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp>`
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile Protocol
                                        	**type**\:  :py:class:`Mobile <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	EIGRP Protocol
                                        	**type**\:  :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp>`
                                        
                                        .. attribute:: rpl
                                        
                                        	RPL Protocol
                                        	**type**\:  :py:class:`Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl>`
                                        
                                        .. attribute:: static
                                        
                                        	Static Protocol
                                        	**type**\:  :py:class:`Static <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static>`
                                        
                                        .. attribute:: te_client
                                        
                                        	TEClient protocol
                                        	**type**\:  :py:class:`TeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient>`
                                        
                                        .. attribute:: subscriber
                                        
                                        	Subscriber Protocol
                                        	**type**\:  :py:class:`Subscriber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber>`
                                        
                                        .. attribute:: ospf
                                        
                                        	OSPF Protocol
                                        	**type**\:  :py:class:`Ospf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected Protocol
                                        	**type**\:  :py:class:`Connected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISIS Protocol
                                        	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol, self).__init__()

                                            self.yang_name = "protocol"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local", ("local", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local)), ("bgp", ("bgp", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp)), ("mobile", ("mobile", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile)), ("eigrp", ("eigrp", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp)), ("rpl", ("rpl", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl)), ("static", ("static", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static)), ("te-client", ("te_client", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient)), ("subscriber", ("subscriber", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber)), ("ospf", ("ospf", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf)), ("connected", ("connected", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected)), ("isis", ("isis", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis))])
                                            self._leafs = OrderedDict()

                                            self.local = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local()
                                            self.local.parent = self
                                            self._children_name_map["local"] = "local"

                                            self.bgp = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"

                                            self.mobile = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile()
                                            self.mobile.parent = self
                                            self._children_name_map["mobile"] = "mobile"

                                            self.eigrp = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp()
                                            self.eigrp.parent = self
                                            self._children_name_map["eigrp"] = "eigrp"

                                            self.rpl = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl()
                                            self.rpl.parent = self
                                            self._children_name_map["rpl"] = "rpl"

                                            self.static = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"

                                            self.te_client = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient()
                                            self.te_client.parent = self
                                            self._children_name_map["te_client"] = "te-client"

                                            self.subscriber = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber()
                                            self.subscriber.parent = self
                                            self._children_name_map["subscriber"] = "subscriber"

                                            self.ospf = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf()
                                            self.ospf.parent = self
                                            self._children_name_map["ospf"] = "ospf"

                                            self.connected = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"

                                            self.isis = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"
                                            self._segment_path = lambda: "protocol"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol, [], name, value)


                                        class Local(Entity):
                                            """
                                            Local Protocol
                                            
                                            .. attribute:: lspv
                                            
                                            	LSPV(Label Switched Path Verification) protocol
                                            	**type**\:  :py:class:`Lspv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:  :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local, self).__init__()

                                                self.yang_name = "local"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lspv", ("lspv", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv)), ("non-as", ("non_as", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs))])
                                                self._leafs = OrderedDict()

                                                self.lspv = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv()
                                                self.lspv.parent = self
                                                self._children_name_map["lspv"] = "lspv"

                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._segment_path = lambda: "local"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local, [], name, value)


                                            class Lspv(Entity):
                                                """
                                                LSPV(Label Switched Path Verification)
                                                protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv, self).__init__()

                                                    self.yang_name = "lspv"
                                                    self.yang_parent_name = "local"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information)), ("protocol-routes", ("protocol_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "lspv"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "lspv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "lspv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "local"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information)), ("protocol-routes", ("protocol_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "non-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Bgp(Entity):
                                            """
                                            BGP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of  		 :py:class:`As <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("as", ("as_", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As))])
                                                self._leafs = OrderedDict()

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "bgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, [], name, value)


                                            class As(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  (key)
                                                
                                                	Autonomous system
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['as_']
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.Information)), ("protocol-routes", ("protocol_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes))])
                                                    self._leafs = OrderedDict([
                                                        ('as_', (YLeaf(YType.str, 'as'), ['str'])),
                                                    ])
                                                    self.as_ = None

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "as" + "[as='" + str(self.as_) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Mobile(Entity):
                                            """
                                            Mobile Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:  :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile, self).__init__()

                                                self.yang_name = "mobile"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("non-as", ("non_as", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs))])
                                                self._leafs = OrderedDict()

                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._segment_path = lambda: "mobile"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile, [], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "mobile"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information)), ("protocol-routes", ("protocol_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "non-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            EIGRP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of  		 :py:class:`As <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("as", ("as_", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As))])
                                                self._leafs = OrderedDict()

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "eigrp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, [], name, value)


                                            class As(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  (key)
                                                
                                                	Autonomous system
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['as_']
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.Information)), ("protocol-routes", ("protocol_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes))])
                                                    self._leafs = OrderedDict([
                                                        ('as_', (YLeaf(YType.str, 'as'), ['str'])),
                                                    ])
                                                    self.as_ = None

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "as" + "[as='" + str(self.as_) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Rpl(Entity):
                                            """
                                            RPL Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of  		 :py:class:`As <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, self).__init__()

                                                self.yang_name = "rpl"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("as", ("as_", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As))])
                                                self._leafs = OrderedDict()

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "rpl"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, [], name, value)


                                            class As(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  (key)
                                                
                                                	Autonomous system
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "rpl"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['as_']
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.Information)), ("protocol-routes", ("protocol_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes))])
                                                    self._leafs = OrderedDict([
                                                        ('as_', (YLeaf(YType.str, 'as'), ['str'])),
                                                    ])
                                                    self.as_ = None

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "as" + "[as='" + str(self.as_) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Static(Entity):
                                            """
                                            Static Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:  :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("non-as", ("non_as", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs))])
                                                self._leafs = OrderedDict()

                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._segment_path = lambda: "static"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static, [], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information)), ("protocol-routes", ("protocol_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "non-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class TeClient(Entity):
                                            """
                                            TEClient protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:  :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient, self).__init__()

                                                self.yang_name = "te-client"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("non-as", ("non_as", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs))])
                                                self._leafs = OrderedDict()

                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._segment_path = lambda: "te-client"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient, [], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "te-client"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information)), ("protocol-routes", ("protocol_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "non-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Subscriber(Entity):
                                            """
                                            Subscriber Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:  :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber, self).__init__()

                                                self.yang_name = "subscriber"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("non-as", ("non_as", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs))])
                                                self._leafs = OrderedDict()

                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._segment_path = lambda: "subscriber"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber, [], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "subscriber"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information)), ("protocol-routes", ("protocol_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "non-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Ospf(Entity):
                                            """
                                            OSPF Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of  		 :py:class:`As <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("as", ("as_", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As))])
                                                self._leafs = OrderedDict()

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "ospf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, [], name, value)


                                            class As(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  (key)
                                                
                                                	Autonomous system
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['as_']
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.Information)), ("protocol-routes", ("protocol_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes))])
                                                    self._leafs = OrderedDict([
                                                        ('as_', (YLeaf(YType.str, 'as'), ['str'])),
                                                    ])
                                                    self.as_ = None

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "as" + "[as='" + str(self.as_) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected Protocol
                                            
                                            .. attribute:: l2vpn
                                            
                                            	L2VPN
                                            	**type**\:  :py:class:`L2vpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:  :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn", ("l2vpn", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn)), ("non-as", ("non_as", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs))])
                                                self._leafs = OrderedDict()

                                                self.l2vpn = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn()
                                                self.l2vpn.parent = self
                                                self._children_name_map["l2vpn"] = "l2vpn"

                                                self.non_as = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._segment_path = lambda: "connected"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected, [], name, value)


                                            class L2vpn(Entity):
                                                """
                                                L2VPN
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn, self).__init__()

                                                    self.yang_name = "l2vpn"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.Information)), ("protocol-routes", ("protocol_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "l2vpn"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "l2vpn"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "l2vpn"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.L2vpn.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information)), ("protocol-routes", ("protocol_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes))])
                                                    self._leafs = OrderedDict()

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "non-as"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs, [], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISIS Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of  		 :py:class:`As <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("as", ("as_", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As))])
                                                self._leafs = OrderedDict()

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "isis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, [], name, value)


                                            class As(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  (key)
                                                
                                                	Autonomous system
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:  :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['as_']
                                                    self._child_classes = OrderedDict([("information", ("information", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.Information)), ("protocol-routes", ("protocol_routes", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes))])
                                                    self._leafs = OrderedDict([
                                                        ('as_', (YLeaf(YType.str, 'as'), ['str'])),
                                                    ])
                                                    self.as_ = None

                                                    self.information = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"

                                                    self.protocol_routes = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._segment_path = lambda: "as" + "[as='" + str(self.as_) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\: str
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('protocol_names', (YLeaf(YType.str, 'protocol-names'), ['str'])),
                                                            ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                            ('redistribution_client_count', (YLeaf(YType.uint32, 'redistribution-client-count'), ['int'])),
                                                            ('protocol_clients_count', (YLeaf(YType.uint32, 'protocol-clients-count'), ['int'])),
                                                            ('routes_counts', (YLeaf(YType.uint32, 'routes-counts'), ['int'])),
                                                            ('active_routes_count', (YLeaf(YType.uint32, 'active-routes-count'), ['int'])),
                                                            ('deleted_routes_count', (YLeaf(YType.uint32, 'deleted-routes-count'), ['int'])),
                                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                            ('protocol_route_memory', (YLeaf(YType.uint32, 'protocol-route-memory'), ['int'])),
                                                            ('backup_routes_count', (YLeaf(YType.uint32, 'backup-routes-count'), ['int'])),
                                                        ])
                                                        self.protocol_names = None
                                                        self.instance = None
                                                        self.version = None
                                                        self.redistribution_client_count = None
                                                        self.protocol_clients_count = None
                                                        self.routes_counts = None
                                                        self.active_routes_count = None
                                                        self.deleted_routes_count = None
                                                        self.paths_count = None
                                                        self.protocol_route_memory = None
                                                        self.backup_routes_count = None
                                                        self._segment_path = lambda: "information"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.Information, ['protocol_names', 'instance', 'version', 'redistribution_client_count', 'protocol_clients_count', 'routes_counts', 'active_routes_count', 'deleted_routes_count', 'paths_count', 'protocol_route_memory', 'backup_routes_count'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	Route information of a specific Network Address
                                                    	**type**\: list of  		 :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("protocol-route", ("protocol_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute))])
                                                        self._leafs = OrderedDict()

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                        Route information of a specific Network Address
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length 
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..128
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\: str
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath))])
                                                            self._leafs = OrderedDict([
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                                ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                                ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                                ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                                ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                                ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                                ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                                ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                                ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                                ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                                ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                                ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                                ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                                ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                                ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                                ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                                ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                                ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                                ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                                ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                                ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                                ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                                ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                            ])
                                                            self.address = None
                                                            self.prefix_length = None
                                                            self.prefix = None
                                                            self.prefix_length_xr = None
                                                            self.route_version = None
                                                            self.protocol_id = None
                                                            self.protocol_name = None
                                                            self.instance = None
                                                            self.client_id = None
                                                            self.route_type = None
                                                            self.priority = None
                                                            self.svd_type = None
                                                            self.flags = None
                                                            self.extended_flags = None
                                                            self.tag = None
                                                            self.distance = None
                                                            self.diversion_distance = None
                                                            self.metric = None
                                                            self.paths_count = None
                                                            self.attribute_identity = None
                                                            self.traffic_index = None
                                                            self.route_precedence = None
                                                            self.qos_group = None
                                                            self.flow_tag = None
                                                            self.fwd_class = None
                                                            self.pic_count = None
                                                            self.active = None
                                                            self.diversion = None
                                                            self.diversion_proto_name = None
                                                            self.route_age = None
                                                            self.route_label = None
                                                            self.version = None
                                                            self.tbl_version = None
                                                            self.route_modify_time = None

                                                            self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._segment_path = lambda: "protocol-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv6_rib_edm_path
                                                            
                                                            	ipv6 rib edm path
                                                            	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv6-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath))])
                                                                self._leafs = OrderedDict()

                                                                self.ipv6_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv6RibEdmPath(Entity):
                                                                """
                                                                ipv6 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\: str
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: number_of_nnh
                                                                
                                                                	Number of Next Next Hops
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\: str
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: vxlan_network_id
                                                                
                                                                	VXLAN Network Identifier for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_xcid
                                                                
                                                                	L2 Cross Connect ID exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xcid
                                                                
                                                                	L2 Cross Connect ID for this path
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: has_span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: span_diag_interface
                                                                
                                                                	SPAN Diagnostics Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: has_subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface exists for this path
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: subscriber_parent_interface
                                                                
                                                                	Subscriber Parent Interface for this path
                                                                	**type**\: str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                                
                                                                .. attribute:: interface_index_present
                                                                
                                                                	Interface Index present
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: interface_index_attribute
                                                                
                                                                	Interface Index attribute
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: next_next_hop
                                                                
                                                                	List of Next Next Hops
                                                                	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv6-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv6-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                                    self._leafs = OrderedDict([
                                                                        ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                        ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                                        ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                                        ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                                        ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                                        ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                                        ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                                        ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                                        ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                                        ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                                        ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                                        ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                                        ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                                        ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                                        ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                                        ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                                        ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                                        ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                                        ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                                        ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                                        ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                                        ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                                        ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                                        ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                                        ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                                        ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                                        ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                                        ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                                        ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                                        ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                                        ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                                        ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                                        ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                                        ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                                        ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                                        ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                                        ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                                        ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                                        ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                                        ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                                        ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                                        ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                                        ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                                    ])
                                                                    self.address = None
                                                                    self.information_source = None
                                                                    self.v6_nexthop = None
                                                                    self.v6_information_source = None
                                                                    self.interface_name = None
                                                                    self.metric = None
                                                                    self.load_metric = None
                                                                    self.flags64 = None
                                                                    self.flags = None
                                                                    self.private_flags = None
                                                                    self.looped = None
                                                                    self.next_hop_table_id = None
                                                                    self.next_hop_vrf_name = None
                                                                    self.next_hop_table_name = None
                                                                    self.next_hop_afi = None
                                                                    self.next_hop_safi = None
                                                                    self.route_label = None
                                                                    self.tunnel_id = None
                                                                    self.pathid = None
                                                                    self.backup_pathid = None
                                                                    self.ref_cnt_of_backup = None
                                                                    self.number_of_extended_communities = None
                                                                    self.mvpn_present = None
                                                                    self.path_rt_present = None
                                                                    self.vrf_import_rt_present = None
                                                                    self.source_asrt_present = None
                                                                    self.source_rd_present = None
                                                                    self.segmented_nexthop_present = None
                                                                    self.number_of_nnh = None
                                                                    self.next_hop_id = None
                                                                    self.next_hop_id_refcount = None
                                                                    self.ospf_area_id = None
                                                                    self.has_labelstk = None
                                                                    self.num_labels = None
                                                                    self.binding_label = None
                                                                    self.nhid_feid = None
                                                                    self.mpls_feid = None
                                                                    self.has_vxlan_network_id = None
                                                                    self.vxlan_network_id = None
                                                                    self.has_xcid = None
                                                                    self.xcid = None
                                                                    self.has_span_diag_interface = None
                                                                    self.span_diag_interface = None
                                                                    self.has_subscriber_parent_interface = None
                                                                    self.subscriber_parent_interface = None
                                                                    self.interface_index_present = None
                                                                    self.interface_index_attribute = None

                                                                    self.remote_backup_addr = YList(self)
                                                                    self.labelstk = YList(self)
                                                                    self.next_next_hop = YList(self)
                                                                    self._segment_path = lambda: "ipv6-rib-edm-path"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "remote-backup-addr"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                                        ])
                                                                        self.entry = None
                                                                        self._segment_path = lambda: "labelstk"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class NextNextHop(Entity):
                                                                    """
                                                                    List of Next Next Hops
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	type
                                                                    	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                                    
                                                                    .. attribute:: unknownval
                                                                    
                                                                    	Unknown Value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: address
                                                                    
                                                                    	IPv4 Address
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: interface_index
                                                                    
                                                                    	Interface Index
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv6-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                                        self.yang_name = "next-next-hop"
                                                                        self.yang_parent_name = "ipv6-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                            ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                            ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.unknownval = None
                                                                        self.address = None
                                                                        self.interface_index = None
                                                                        self._segment_path = lambda: "next-next-hop"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                    class Routes(Entity):
                                        """
                                        Route information 
                                        
                                        .. attribute:: route
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of  		 :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, self).__init__()

                                            self.yang_name = "routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("route", ("route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route))])
                                            self._leafs = OrderedDict()

                                            self.route = YList(self)
                                            self._segment_path = lambda: "routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, [], name, value)


                                        class Route(Entity):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\: int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	NextHop Address 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: interface_name
                                            
                                            	Outgoing Interface 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath>`
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\: str
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\: str
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\: str
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, self).__init__()

                                                self.yang_name = "route"
                                                self.yang_parent_name = "routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str'])),
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                    ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                    ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                    ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                    ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                    ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                    ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                    ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                    ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                    ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                    ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                    ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                    ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                    ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                    ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                    ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                    ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                    ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                    ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                    ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                    ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                    ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                    ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                ])
                                                self.address = None
                                                self.prefix_length = None
                                                self.next_hop_address = None
                                                self.interface_name = None
                                                self.prefix = None
                                                self.prefix_length_xr = None
                                                self.route_version = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.instance = None
                                                self.client_id = None
                                                self.route_type = None
                                                self.priority = None
                                                self.svd_type = None
                                                self.flags = None
                                                self.extended_flags = None
                                                self.tag = None
                                                self.distance = None
                                                self.diversion_distance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.attribute_identity = None
                                                self.traffic_index = None
                                                self.route_precedence = None
                                                self.qos_group = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.pic_count = None
                                                self.active = None
                                                self.diversion = None
                                                self.diversion_proto_name = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.version = None
                                                self.tbl_version = None
                                                self.route_modify_time = None

                                                self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._segment_path = lambda: "route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, ['address', 'prefix_length', 'next_hop_address', 'interface_name', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv6_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, [], name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: number_of_nnh
                                                    
                                                    	Number of Next Next Hops
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\: str
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_xcid
                                                    
                                                    	L2 Cross Connect ID exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: xcid
                                                    
                                                    	L2 Cross Connect ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: has_subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: interface_index_present
                                                    
                                                    	Interface Index present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: interface_index_attribute
                                                    
                                                    	Interface Index attribute
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: next_next_hop
                                                    
                                                    	List of Next Next Hops
                                                    	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                            ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                            ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                            ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                            ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                            ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                            ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                            ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                            ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                            ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                            ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                            ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                            ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                            ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                            ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                            ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                            ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                            ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                            ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                            ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                            ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                            ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                            ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                            ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                            ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                            ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                            ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                            ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                            ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                            ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                            ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                            ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                            ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                            ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                            ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                            ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                            ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                            ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                            ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                        ])
                                                        self.address = None
                                                        self.information_source = None
                                                        self.v6_nexthop = None
                                                        self.v6_information_source = None
                                                        self.interface_name = None
                                                        self.metric = None
                                                        self.load_metric = None
                                                        self.flags64 = None
                                                        self.flags = None
                                                        self.private_flags = None
                                                        self.looped = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_vrf_name = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_safi = None
                                                        self.route_label = None
                                                        self.tunnel_id = None
                                                        self.pathid = None
                                                        self.backup_pathid = None
                                                        self.ref_cnt_of_backup = None
                                                        self.number_of_extended_communities = None
                                                        self.mvpn_present = None
                                                        self.path_rt_present = None
                                                        self.vrf_import_rt_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.segmented_nexthop_present = None
                                                        self.number_of_nnh = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.ospf_area_id = None
                                                        self.has_labelstk = None
                                                        self.num_labels = None
                                                        self.binding_label = None
                                                        self.nhid_feid = None
                                                        self.mpls_feid = None
                                                        self.has_vxlan_network_id = None
                                                        self.vxlan_network_id = None
                                                        self.has_xcid = None
                                                        self.xcid = None
                                                        self.has_span_diag_interface = None
                                                        self.span_diag_interface = None
                                                        self.has_subscriber_parent_interface = None
                                                        self.subscriber_parent_interface = None
                                                        self.interface_index_present = None
                                                        self.interface_index_attribute = None

                                                        self.remote_backup_addr = YList(self)
                                                        self.labelstk = YList(self)
                                                        self.next_next_hop = YList(self)
                                                        self._segment_path = lambda: "ipv6-rib-edm-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "remote-backup-addr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "labelstk"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class NextNextHop(Entity):
                                                        """
                                                        List of Next Next Hops
                                                        
                                                        .. attribute:: type
                                                        
                                                        	type
                                                        	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                        
                                                        .. attribute:: unknownval
                                                        
                                                        	Unknown Value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: address
                                                        
                                                        	IPv4 Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_index
                                                        
                                                        	Interface Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                            self.yang_name = "next-next-hop"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                            ])
                                                            self.type = None
                                                            self.unknownval = None
                                                            self.address = None
                                                            self.interface_index = None
                                                            self._segment_path = lambda: "next-next-hop"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                    class QRoutes(Entity):
                                        """
                                        Quarantine
                                        
                                        .. attribute:: q_route
                                        
                                        	Route information for a specific quarantined address 
                                        	**type**\: list of  		 :py:class:`QRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, self).__init__()

                                            self.yang_name = "q-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("q-route", ("q_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute))])
                                            self._leafs = OrderedDict()

                                            self.q_route = YList(self)
                                            self._segment_path = lambda: "q-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, [], name, value)


                                        class QRoute(Entity):
                                            """
                                            Route information for a specific
                                            quarantined address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\: int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath>`
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\: str
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\: str
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\: str
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, self).__init__()

                                                self.yang_name = "q-route"
                                                self.yang_parent_name = "q-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                    ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                    ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                    ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                    ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                    ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                    ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                    ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                    ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                    ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                    ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                    ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                    ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                    ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                    ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                    ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                    ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                    ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                    ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                    ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                    ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                    ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                    ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                ])
                                                self.address = None
                                                self.prefix_length = None
                                                self.prefix = None
                                                self.prefix_length_xr = None
                                                self.route_version = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.instance = None
                                                self.client_id = None
                                                self.route_type = None
                                                self.priority = None
                                                self.svd_type = None
                                                self.flags = None
                                                self.extended_flags = None
                                                self.tag = None
                                                self.distance = None
                                                self.diversion_distance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.attribute_identity = None
                                                self.traffic_index = None
                                                self.route_precedence = None
                                                self.qos_group = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.pic_count = None
                                                self.active = None
                                                self.diversion = None
                                                self.diversion_proto_name = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.version = None
                                                self.tbl_version = None
                                                self.route_modify_time = None

                                                self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._segment_path = lambda: "q-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, ['address', 'prefix_length', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "q-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv6_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, [], name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: number_of_nnh
                                                    
                                                    	Number of Next Next Hops
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\: str
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_xcid
                                                    
                                                    	L2 Cross Connect ID exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: xcid
                                                    
                                                    	L2 Cross Connect ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: has_subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: interface_index_present
                                                    
                                                    	Interface Index present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: interface_index_attribute
                                                    
                                                    	Interface Index attribute
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: next_next_hop
                                                    
                                                    	List of Next Next Hops
                                                    	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                            ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                            ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                            ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                            ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                            ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                            ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                            ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                            ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                            ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                            ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                            ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                            ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                            ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                            ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                            ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                            ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                            ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                            ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                            ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                            ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                            ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                            ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                            ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                            ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                            ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                            ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                            ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                            ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                            ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                            ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                            ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                            ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                            ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                            ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                            ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                            ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                            ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                            ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                        ])
                                                        self.address = None
                                                        self.information_source = None
                                                        self.v6_nexthop = None
                                                        self.v6_information_source = None
                                                        self.interface_name = None
                                                        self.metric = None
                                                        self.load_metric = None
                                                        self.flags64 = None
                                                        self.flags = None
                                                        self.private_flags = None
                                                        self.looped = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_vrf_name = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_safi = None
                                                        self.route_label = None
                                                        self.tunnel_id = None
                                                        self.pathid = None
                                                        self.backup_pathid = None
                                                        self.ref_cnt_of_backup = None
                                                        self.number_of_extended_communities = None
                                                        self.mvpn_present = None
                                                        self.path_rt_present = None
                                                        self.vrf_import_rt_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.segmented_nexthop_present = None
                                                        self.number_of_nnh = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.ospf_area_id = None
                                                        self.has_labelstk = None
                                                        self.num_labels = None
                                                        self.binding_label = None
                                                        self.nhid_feid = None
                                                        self.mpls_feid = None
                                                        self.has_vxlan_network_id = None
                                                        self.vxlan_network_id = None
                                                        self.has_xcid = None
                                                        self.xcid = None
                                                        self.has_span_diag_interface = None
                                                        self.span_diag_interface = None
                                                        self.has_subscriber_parent_interface = None
                                                        self.subscriber_parent_interface = None
                                                        self.interface_index_present = None
                                                        self.interface_index_attribute = None

                                                        self.remote_backup_addr = YList(self)
                                                        self.labelstk = YList(self)
                                                        self.next_next_hop = YList(self)
                                                        self._segment_path = lambda: "ipv6-rib-edm-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "remote-backup-addr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "labelstk"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class NextNextHop(Entity):
                                                        """
                                                        List of Next Next Hops
                                                        
                                                        .. attribute:: type
                                                        
                                                        	type
                                                        	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                        
                                                        .. attribute:: unknownval
                                                        
                                                        	Unknown Value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: address
                                                        
                                                        	IPv4 Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_index
                                                        
                                                        	Interface Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                            self.yang_name = "next-next-hop"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                            ])
                                                            self.type = None
                                                            self.unknownval = None
                                                            self.address = None
                                                            self.interface_index = None
                                                            self._segment_path = lambda: "next-next-hop"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)


                                    class BackupRoutes(Entity):
                                        """
                                        Backup route information for the given
                                        table
                                        
                                        .. attribute:: backup_route
                                        
                                        	Route information for a specific backup address 
                                        	**type**\: list of  		 :py:class:`BackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv6-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, self).__init__()

                                            self.yang_name = "backup-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("backup-route", ("backup_route", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute))])
                                            self._leafs = OrderedDict()

                                            self.backup_route = YList(self)
                                            self._segment_path = lambda: "backup-routes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, [], name, value)


                                        class BackupRoute(Entity):
                                            """
                                            Route information for a specific backup
                                            address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length 
                                            	**type**\: int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: protoid
                                            
                                            	Proto ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:  :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath>`
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\: str
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\: str
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\: bool
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\: str
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv6-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, self).__init__()

                                                self.yang_name = "backup-route"
                                                self.yang_parent_name = "backup-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("route-path", ("route_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath))])
                                                self._leafs = OrderedDict([
                                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('protoid', (YLeaf(YType.uint32, 'protoid'), ['int'])),
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length_xr', (YLeaf(YType.uint8, 'prefix-length-xr'), ['int'])),
                                                    ('route_version', (YLeaf(YType.uint32, 'route-version'), ['int'])),
                                                    ('protocol_id', (YLeaf(YType.uint32, 'protocol-id'), ['int'])),
                                                    ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                                    ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                                    ('client_id', (YLeaf(YType.uint32, 'client-id'), ['int'])),
                                                    ('route_type', (YLeaf(YType.uint16, 'route-type'), ['int'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                    ('svd_type', (YLeaf(YType.uint8, 'svd-type'), ['int'])),
                                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                                    ('extended_flags', (YLeaf(YType.uint64, 'extended-flags'), ['int'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                                    ('diversion_distance', (YLeaf(YType.uint32, 'diversion-distance'), ['int'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                    ('attribute_identity', (YLeaf(YType.uint32, 'attribute-identity'), ['int'])),
                                                    ('traffic_index', (YLeaf(YType.uint8, 'traffic-index'), ['int'])),
                                                    ('route_precedence', (YLeaf(YType.uint8, 'route-precedence'), ['int'])),
                                                    ('qos_group', (YLeaf(YType.uint8, 'qos-group'), ['int'])),
                                                    ('flow_tag', (YLeaf(YType.uint8, 'flow-tag'), ['int'])),
                                                    ('fwd_class', (YLeaf(YType.uint8, 'fwd-class'), ['int'])),
                                                    ('pic_count', (YLeaf(YType.uint8, 'pic-count'), ['int'])),
                                                    ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                    ('diversion', (YLeaf(YType.boolean, 'diversion'), ['bool'])),
                                                    ('diversion_proto_name', (YLeaf(YType.str, 'diversion-proto-name'), ['str'])),
                                                    ('route_age', (YLeaf(YType.uint32, 'route-age'), ['int'])),
                                                    ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                    ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                    ('tbl_version', (YLeaf(YType.uint64, 'tbl-version'), ['int'])),
                                                    ('route_modify_time', (YLeaf(YType.uint64, 'route-modify-time'), ['int'])),
                                                ])
                                                self.address = None
                                                self.prefix_length = None
                                                self.protoid = None
                                                self.prefix = None
                                                self.prefix_length_xr = None
                                                self.route_version = None
                                                self.protocol_id = None
                                                self.protocol_name = None
                                                self.instance = None
                                                self.client_id = None
                                                self.route_type = None
                                                self.priority = None
                                                self.svd_type = None
                                                self.flags = None
                                                self.extended_flags = None
                                                self.tag = None
                                                self.distance = None
                                                self.diversion_distance = None
                                                self.metric = None
                                                self.paths_count = None
                                                self.attribute_identity = None
                                                self.traffic_index = None
                                                self.route_precedence = None
                                                self.qos_group = None
                                                self.flow_tag = None
                                                self.fwd_class = None
                                                self.pic_count = None
                                                self.active = None
                                                self.diversion = None
                                                self.diversion_proto_name = None
                                                self.route_age = None
                                                self.route_label = None
                                                self.version = None
                                                self.tbl_version = None
                                                self.route_modify_time = None

                                                self.route_path = Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._segment_path = lambda: "backup-route"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, ['address', 'prefix_length', 'protoid', 'prefix', 'prefix_length_xr', 'route_version', 'protocol_id', 'protocol_name', 'instance', 'client_id', 'route_type', 'priority', 'svd_type', 'flags', 'extended_flags', 'tag', 'distance', 'diversion_distance', 'metric', 'paths_count', 'attribute_identity', 'traffic_index', 'route_precedence', 'qos_group', 'flow_tag', 'fwd_class', 'pic_count', 'active', 'diversion', 'diversion_proto_name', 'route_age', 'route_label', 'version', 'tbl_version', 'route_modify_time'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv6_rib_edm_path
                                                
                                                	ipv6 rib edm path
                                                	**type**\: list of  		 :py:class:`Ipv6RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv6-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "backup-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv6-rib-edm-path", ("ipv6_rib_edm_path", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv6_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, [], name, value)


                                                class Ipv6RibEdmPath(Entity):
                                                    """
                                                    ipv6 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: number_of_nnh
                                                    
                                                    	Number of Next Next Hops
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\: str
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: vxlan_network_id
                                                    
                                                    	VXLAN Network Identifier for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_xcid
                                                    
                                                    	L2 Cross Connect ID exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: xcid
                                                    
                                                    	L2 Cross Connect ID for this path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: has_span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: span_diag_interface
                                                    
                                                    	SPAN Diagnostics Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: has_subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface exists for this path
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: subscriber_parent_interface
                                                    
                                                    	Subscriber Parent Interface for this path
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    .. attribute:: interface_index_present
                                                    
                                                    	Interface Index present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: interface_index_attribute
                                                    
                                                    	Interface Index attribute
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of  		 :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of  		 :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: next_next_hop
                                                    
                                                    	List of Next Next Hops
                                                    	**type**\: list of  		 :py:class:`NextNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv6-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv6-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("remote-backup-addr", ("remote_backup_addr", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr)), ("labelstk", ("labelstk", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk)), ("next-next-hop", ("next_next_hop", Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop))])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                            ('information_source', (YLeaf(YType.str, 'information-source'), ['str'])),
                                                            ('v6_nexthop', (YLeaf(YType.str, 'v6-nexthop'), ['str'])),
                                                            ('v6_information_source', (YLeaf(YType.str, 'v6-information-source'), ['str'])),
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('load_metric', (YLeaf(YType.uint32, 'load-metric'), ['int'])),
                                                            ('flags64', (YLeaf(YType.uint64, 'flags64'), ['int'])),
                                                            ('flags', (YLeaf(YType.uint16, 'flags'), ['int'])),
                                                            ('private_flags', (YLeaf(YType.uint16, 'private-flags'), ['int'])),
                                                            ('looped', (YLeaf(YType.boolean, 'looped'), ['bool'])),
                                                            ('next_hop_table_id', (YLeaf(YType.uint32, 'next-hop-table-id'), ['int'])),
                                                            ('next_hop_vrf_name', (YLeaf(YType.str, 'next-hop-vrf-name'), ['str'])),
                                                            ('next_hop_table_name', (YLeaf(YType.str, 'next-hop-table-name'), ['str'])),
                                                            ('next_hop_afi', (YLeaf(YType.uint32, 'next-hop-afi'), ['int'])),
                                                            ('next_hop_safi', (YLeaf(YType.uint32, 'next-hop-safi'), ['int'])),
                                                            ('route_label', (YLeaf(YType.uint32, 'route-label'), ['int'])),
                                                            ('tunnel_id', (YLeaf(YType.uint32, 'tunnel-id'), ['int'])),
                                                            ('pathid', (YLeaf(YType.uint32, 'pathid'), ['int'])),
                                                            ('backup_pathid', (YLeaf(YType.uint32, 'backup-pathid'), ['int'])),
                                                            ('ref_cnt_of_backup', (YLeaf(YType.uint32, 'ref-cnt-of-backup'), ['int'])),
                                                            ('number_of_extended_communities', (YLeaf(YType.uint32, 'number-of-extended-communities'), ['int'])),
                                                            ('mvpn_present', (YLeaf(YType.boolean, 'mvpn-present'), ['bool'])),
                                                            ('path_rt_present', (YLeaf(YType.boolean, 'path-rt-present'), ['bool'])),
                                                            ('vrf_import_rt_present', (YLeaf(YType.boolean, 'vrf-import-rt-present'), ['bool'])),
                                                            ('source_asrt_present', (YLeaf(YType.boolean, 'source-asrt-present'), ['bool'])),
                                                            ('source_rd_present', (YLeaf(YType.boolean, 'source-rd-present'), ['bool'])),
                                                            ('segmented_nexthop_present', (YLeaf(YType.boolean, 'segmented-nexthop-present'), ['bool'])),
                                                            ('number_of_nnh', (YLeaf(YType.uint32, 'number-of-nnh'), ['int'])),
                                                            ('next_hop_id', (YLeaf(YType.uint32, 'next-hop-id'), ['int'])),
                                                            ('next_hop_id_refcount', (YLeaf(YType.uint32, 'next-hop-id-refcount'), ['int'])),
                                                            ('ospf_area_id', (YLeaf(YType.str, 'ospf-area-id'), ['str'])),
                                                            ('has_labelstk', (YLeaf(YType.boolean, 'has-labelstk'), ['bool'])),
                                                            ('num_labels', (YLeaf(YType.uint8, 'num-labels'), ['int'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('nhid_feid', (YLeaf(YType.uint64, 'nhid-feid'), ['int'])),
                                                            ('mpls_feid', (YLeaf(YType.uint64, 'mpls-feid'), ['int'])),
                                                            ('has_vxlan_network_id', (YLeaf(YType.boolean, 'has-vxlan-network-id'), ['bool'])),
                                                            ('vxlan_network_id', (YLeaf(YType.uint32, 'vxlan-network-id'), ['int'])),
                                                            ('has_xcid', (YLeaf(YType.boolean, 'has-xcid'), ['bool'])),
                                                            ('xcid', (YLeaf(YType.uint32, 'xcid'), ['int'])),
                                                            ('has_span_diag_interface', (YLeaf(YType.boolean, 'has-span-diag-interface'), ['bool'])),
                                                            ('span_diag_interface', (YLeaf(YType.str, 'span-diag-interface'), ['str'])),
                                                            ('has_subscriber_parent_interface', (YLeaf(YType.boolean, 'has-subscriber-parent-interface'), ['bool'])),
                                                            ('subscriber_parent_interface', (YLeaf(YType.str, 'subscriber-parent-interface'), ['str'])),
                                                            ('interface_index_present', (YLeaf(YType.boolean, 'interface-index-present'), ['bool'])),
                                                            ('interface_index_attribute', (YLeaf(YType.uint32, 'interface-index-attribute'), ['int'])),
                                                        ])
                                                        self.address = None
                                                        self.information_source = None
                                                        self.v6_nexthop = None
                                                        self.v6_information_source = None
                                                        self.interface_name = None
                                                        self.metric = None
                                                        self.load_metric = None
                                                        self.flags64 = None
                                                        self.flags = None
                                                        self.private_flags = None
                                                        self.looped = None
                                                        self.next_hop_table_id = None
                                                        self.next_hop_vrf_name = None
                                                        self.next_hop_table_name = None
                                                        self.next_hop_afi = None
                                                        self.next_hop_safi = None
                                                        self.route_label = None
                                                        self.tunnel_id = None
                                                        self.pathid = None
                                                        self.backup_pathid = None
                                                        self.ref_cnt_of_backup = None
                                                        self.number_of_extended_communities = None
                                                        self.mvpn_present = None
                                                        self.path_rt_present = None
                                                        self.vrf_import_rt_present = None
                                                        self.source_asrt_present = None
                                                        self.source_rd_present = None
                                                        self.segmented_nexthop_present = None
                                                        self.number_of_nnh = None
                                                        self.next_hop_id = None
                                                        self.next_hop_id_refcount = None
                                                        self.ospf_area_id = None
                                                        self.has_labelstk = None
                                                        self.num_labels = None
                                                        self.binding_label = None
                                                        self.nhid_feid = None
                                                        self.mpls_feid = None
                                                        self.has_vxlan_network_id = None
                                                        self.vxlan_network_id = None
                                                        self.has_xcid = None
                                                        self.xcid = None
                                                        self.has_span_diag_interface = None
                                                        self.span_diag_interface = None
                                                        self.has_subscriber_parent_interface = None
                                                        self.subscriber_parent_interface = None
                                                        self.interface_index_present = None
                                                        self.interface_index_attribute = None

                                                        self.remote_backup_addr = YList(self)
                                                        self.labelstk = YList(self)
                                                        self.next_next_hop = YList(self)
                                                        self._segment_path = lambda: "ipv6-rib-edm-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath, ['address', 'information_source', 'v6_nexthop', 'v6_information_source', 'interface_name', 'metric', 'load_metric', 'flags64', 'flags', 'private_flags', 'looped', 'next_hop_table_id', 'next_hop_vrf_name', 'next_hop_table_name', 'next_hop_afi', 'next_hop_safi', 'route_label', 'tunnel_id', 'pathid', 'backup_pathid', 'ref_cnt_of_backup', 'number_of_extended_communities', 'mvpn_present', 'path_rt_present', 'vrf_import_rt_present', 'source_asrt_present', 'source_rd_present', 'segmented_nexthop_present', 'number_of_nnh', 'next_hop_id', 'next_hop_id_refcount', 'ospf_area_id', 'has_labelstk', 'num_labels', 'binding_label', 'nhid_feid', 'mpls_feid', 'has_vxlan_network_id', 'vxlan_network_id', 'has_xcid', 'xcid', 'has_span_diag_interface', 'span_diag_interface', 'has_subscriber_parent_interface', 'subscriber_parent_interface', 'interface_index_present', 'interface_index_attribute'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "remote-backup-addr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "labelstk"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class NextNextHop(Entity):
                                                        """
                                                        List of Next Next Hops
                                                        
                                                        .. attribute:: type
                                                        
                                                        	type
                                                        	**type**\:  :py:class:`RibEdmNnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper.RibEdmNnh>`
                                                        
                                                        .. attribute:: unknownval
                                                        
                                                        	Unknown Value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: address
                                                        
                                                        	IPv4 Address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_index
                                                        
                                                        	Interface Index
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv6-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, self).__init__()

                                                            self.yang_name = "next-next-hop"
                                                            self.yang_parent_name = "ipv6-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv6_oper', 'RibEdmNnh', '')])),
                                                                ('unknownval', (YLeaf(YType.uint32, 'unknownval'), ['int'])),
                                                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                                                ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                            ])
                                                            self.type = None
                                                            self.unknownval = None
                                                            self.address = None
                                                            self.interface_index = None
                                                            self._segment_path = lambda: "next-next-hop"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ipv6RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv6RibEdmPath.NextNextHop, ['type', 'unknownval', 'address', 'interface_index'], name, value)

    def clone_ptr(self):
        self._top_entity = Ipv6RibStdby()
        return self._top_entity

